<?php
putenv('SYNOPHOTO_SKIP_IP_CHECK=1');
ini_set("session.use_only_cookies", 0); // Allow sessionid followed by url.
require_once("include/syno_conf.php");
require_once("include/photo/synophoto_csPhotoAcl.php");

/*
 * class: ImageEditorHandler
 * Desc: 1. Create iframe as cross-domain proxy 2. Handle the notify and save action
 */
class ImageEditorHandler
{
	private $in_param = array();
	private $keys = array('action', 'image', 'session', 'path', 'name', 'id', 'file', 'type', 'title', 'mode', 'PHPSESSID', 'topHost', 'version');
	private static $pixlr_url_prefix = 'http://apps.pixlr.com/';

	function __construct() {
		$this->ProcessRequest();
		$this->Dispatch($this->in_param['action']);
	}

	function BridgeService() {
		header('Content-Type: text/html',true);
		$currentURI = $this->in_param['topHost'] . $_SERVER['PHP_SELF'];
		$currentURI .= '?action=notify';
		$keys = $this->keys;
		foreach ($keys as $v) {
			if ($v == 'action') {
				continue;
			}
			$param = $this->in_param[$v];
			$escaped_key = rawurlencode($v);
			$escaped_value = rawurlencode($param);

			$currentURI .= "&$escaped_key=$escaped_value";
		}
		$currentURI = addslashes($currentURI);
		echo "<iframe width='0' height='0' src='$currentURI'> </iframe>";
	}

	function NotifyPS() {
		header('Content-Type: text/html',true);
		$json = array();
		foreach ($this->keys as $v) {
			$json[$v] = $this->in_param[$v];
		}
		$json['imageurl'] = $json['image'];
		$json_str = json_encode($json);
		$json_str = addslashes($json_str);
		$script = "<script> window.top._redirectMessage('$json_str');</script>";
		echo $script;
	}

	function SaveImage() {
		header('Content-Type: text/javascript');
		$ret = array(
			'result' => true,
			'error' => '',
			'message' => '',
			'imageurl' => '');

		do
		{
			$path = base64_decode($this->in_param['path']);
			$path = realpath($path);

			if (0 !== strncmp($path, SYNOPHOTO_SERVICE_REAL_DIR . "/", strlen(SYNOPHOTO_SERVICE_REAL_DIR) + 1)) {
				$ret['result'] = false;
				$ret['error'] = "Not in service dir";
				break;
			}

			$path_info = pathinfo($path);

			$albumName = substr($path_info['dirname'], strlen(SYNOPHOTO_SERVICE_REAL_DIR) + 1);
			if (!$albumName) {
				$albumName = '/';
			}
			if (!csSYNOPhotoMisc::CheckAlbumManageable($albumName)) {
				$ret['result'] = false;
				$ret['error'] = "Dir is not manageable";
				break;
			}

			if (strtolower($path_info['extension']) == strtolower($this->in_param['type'])){
				$this->in_param['type'] = $path_info['extension'];
			}

			$title = (empty($this->in_param['mode'])? $path_info['filename'] : (empty($this->in_param['title'])? $path_info['filename'] : $this->in_param['title']));
			$filename = $title . "." . $this->in_param['type'];

			if (!csSYNOPhotoMisc::IsPhotoFile($filename)) {
				$ret['result'] = false;
				$ret['error'] = "Type is invalid";
				break;
			}
			if (false !== strpos($filename, '/')) {
				$ret['result'] = false;
				$ret['error'] = "Invalid filename";
				break;
			}

			$ret['filename'] = $filename;
			$target_path = $path_info['dirname'] . "/" . $filename;
			$isSameFile = ($target_path == $path);

			if (file_exists($target_path) && !is_writable($target_path)) {
				$ret['result'] = false;
				$ret['error'] = "Target file is read-only";
				break;
			}

			$imageurl = $this->in_param['image'];
			if (0 !== strncmp($imageurl, self::$pixlr_url_prefix, strlen(self::$pixlr_url_prefix))) {
				$ret['result'] = false;
				$ret['error'] = 'Invalid image';
				break;
			}

			$ret['imageurl'] = $imageurl;
			$image_data = @file_get_contents($imageurl);
			if (FALSE === $image_data) {
				$ret['result'] = false;
				$ret['error'] = "Sorry, the image download failed.";
				break;
			}

			$image_filename = sys_get_temp_dir() . "/exported_file" . time() . rand(10000,99999) . ".jpg";
			if (!file_exists($image_filename)) {
				@touch($image_filename);
				csSYNOPhotoAcl::QuotaChown($image_filename, GetLoginUsername());
			}

			file_put_contents($image_filename, $image_data);

			if (!file_exists($image_filename)) {
				$ret['result'] = false;
				$ret['error'] = "Temp file cannot be created";
				break;
			}

			$cwd = @getcwd();

			if (!@chdir($path_info['dirname'])) {
				@chdir($cwd);
				$ret['result'] = false;
				$ret['error'] = "No privilege in the dir";
				unlink($image_filename);
				break;
			}

			foreach(glob('*') as $file) {
				if (strtolower($file) !== strtolower($filename)) {
					continue;
				}

				csSYNOPhotoMisc::ExecCmd(SYNO_PHOTOIO, array('-D',
					$path_info['dirname'] . '/@eaDir/' . $file));
				csSYNOPhotoMisc::ExecCmd(SYNO_PHOTOIO, array('-d',
					$path_info['dirname'] . '/' . $file));
				csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-d',
					$path_info['dirname'] . '/' . $file));
			}

			@chdir($cwd);

			// move the temp photo to replace original one
			if (!@rename($image_filename, $target_path)) {
				$ret['result'] = false;
				$ret['error'] = "Cannot move temp file to target path";
				unlink($image_filename);
				break;
			}

			csSYNOPhotoAcl::Apply($target_path, GetLoginUsername());
			csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-a', $target_path));
		} while(false);

		echo json_encode($ret);
	}

	function RenderEditor() {
		$smarty = $GLOBALS['smarty'];
		//echo "RenderEditor";
		// Prepare data
		$external_addr = str_replace('\\', '%5C', csSYNOPhotoMisc::GetServerHost(true, true)); // replace backslash to %5C, for domain user personal photo
		$param = array(
			'mode'		=> $_GET['mode'], // !required
			'type'		=> $_GET['type'], // !required
			'image'		=> $external_addr .'/'. $_GET['image'], // !required
			'path'		=> SYNOPHOTO_ImageEditor_PathCheck($_GET['id']), // !required
			'loc'		=> $_SESSION[SYNOPHOTO_ADMIN_USER]['lang'],  // !required
			'id'		=> $_GET['id'], // !required, photo object id
			'title'		=> $_GET['title'], // optional
			'target'	=> $_GET['target'], // optional
			'referrer'	=> $_GET['referrer'], // optional
			'hostname'	=> $_GET['hostname'] // optional
		);

		$path_info = pathinfo($param['path']);
		$param['extension'] = $path_info['extension'];
		$param['path'] = base64_encode($param['path']);
		if ($param['type'] == 'express') {
			$param['title'] = $path_info['filename'];
		}

		// Ready to render page
		$packageMtime = csSYNOPhotoMisc::GetPackageMtime();
		$smarty->assign('DSM_VERSION', '?v='.$packageMtime);
		$smarty->assign('PACKAGE_VERSION', '?v='.$packageMtime);

		$lang = $_SESSION[SYNOPHOTO_ADMIN_USER]['lang'];
		$smarty->assign('LAN_PARAM', "ln=$lang");

		$external_ip = csSYNOPhotoMisc::GetExternalIP();
		$pps = (preg_match('/\/~[^\/]+/', $_SERVER['REQUEST_URI'], $matches))? (rawurlencode(SYNOPHOTO_ADMIN_USER) . "/") : "";
		$script .= "var external_ip = '$external_ip';";
		$script .= "var pps = '$pps';";

		$smarty->assign('JS_STRING', $script);
		$smarty->assign('settings', json_encode($param));
		$smarty->display('photo/PixlrEditor.tpl');
	}

	function Dispatch($action) {
		switch ($action) {
		case 'notify':
			$this->NotifyPS();
			break;
		case 'bridge':
			$this->BridgeService();
			break;
		case 'save':
			$this->SaveImage();
			break;
		case 'editor':
			$this->RenderEditor();
			break;
		default:
			$this->BridgeService();
			break;
		}
	}

	function ProcessRequest() {
		$this->in_param = array();
		$keys = $this->keys;
		foreach ($keys as $v) {
			$this->in_param[$v] = $_REQUEST[$v];
		}
		if (strlen($this->in_param['image']) <= 0) {
			$this->in_param['image'] = $this->in_param['file'];
		}
		if (strlen($this->in_param['type']) <= 0) {
			$this->in_param['type'] = 'jpg';
		}

		foreach($this->in_param as $value) {
			if (strlen($value) <= 0) {
				return false;
			}
		}

		return true;
	}

	static function delTree($dir) {
		$files = glob( $dir . '*', GLOB_MARK );
		foreach( $files as $file ){
			if( substr( $file, -1 ) == '/' )
				delTree( $file );
			else
				unlink( $file );
		}
		rmdir( $dir );
	}
}

/**
 * return path if id is valid
 */
function SYNOPHOTO_ImageEditor_PathCheck($id)
{
	$id_arr = explode('_', $id);
	if (3 !== count($id_arr) || 'photo' !== $id_arr[0]) {
		SYNOPHOTO_ImageEditor_RedirectToLogin();
	}

	$albumName = @pack('H*', $id_arr[1]);
	$fileName = @pack('H*', $id_arr[2]);
	$path = realpath(SYNOPHOTO_SERVICE_REAL_DIR . ('/' === $albumName ? "" : "/" . $albumName) . "/" . $fileName);

	if (0 !== strncmp($path, SYNOPHOTO_SERVICE_REAL_DIR . "/", strlen(SYNOPHOTO_SERVICE_REAL_DIR) + 1) ||
		!csSYNOPhotoMisc::CheckAlbumManageable($albumName) || !@file_exists($path)) {
		SYNOPHOTO_ImageEditor_RedirectToLogin();
	}

	return $path;
}

function SYNOPHOTO_ImageEditor_RedirectToLogin()
{
	echo "<script>";
	echo "parent.location = \"".SYNOPHOTO_URL_PREFIX."/photo/login.php?url=".bin2hex($_SERVER['PHP_SELF']."?".$_SERVER['QUERY_STRING'])."\";";
	echo "</script>";
	exit;
}

new ImageEditorHandler();

?>
