<?php
require_once("../include/syno_conf.php");
require_once("util.php");

require_once("./google-api-php-client/src/Google_Client.php");
require_once("./google-api-php-client/src/contrib/Google_YouTubeService.php");

define("YOUTUBE_UPLOAD_TMP", '/tmp/photostation/');

set_time_limit(0);

$error = array(
	'error' => 'Unknown error.',
	'error_code' => '0000',
	'error_source' => 'local'
);

if (isset($_GET['access_token'])) {
	if (!isset($_GET['access_token']) || !isset($_GET['expires_in'])) {
		FillErrorMessage('No GET access_token, expires_in, or uid', '0002', 'local');
		echo json_encode($error);
	}
	session_write_close();
	SYNOPHOTO_YOUTUBE_GetAccessToken($_GET['access_token'], $_GET['expires_in']);
} else if (isset($_POST['action'])) {
	if (isset($_POST['prog_id']) && !preg_match('/^[a-zA-Z0-9\.]+$/', $_POST['prog_id'])) {
		FillErrorMessage('invalid arguments', '', 'local');
		echo json_encode($error);
		return;
	}
	switch ($_POST['action']) {
	case 'get_upload_status':
		if (!isset($_POST['token']) || !isset($_POST['prog_id'])) {
			FillErrorMessage('invalid arguments', '', 'local');
			echo json_encode($error);
		}
		session_write_close();
		SYNOPHOTO_YOUTUBE_GetUploadStatus($_POST['token'], $_POST['prog_id']);
	break;
	case 'upload':
		if ( !isset($_POST['token']) || !isset($_POST['id']) ||
				!isset($_POST['message']) || !isset($_POST['token_create']) ||
				!isset($_POST['token_expire']) || !isset($_POST['title']) ||
				!isset($_POST['privacy']) || !isset($_POST['prog_id'])) {
			FillErrorMessage('invalid arguments', '', 'local');
			echo json_encode($error);
		}
		$token = $_POST['token'];
		$id = $_POST['id'];
		$msg = $_POST['message'];
		$create = $_POST['token_create'];
		$expire = $_POST['token_expire'];
		$title = $_POST['title'];
		$privacy = $_POST['privacy'];
		$progressId = $_POST['prog_id'];
		csSYNOPhotoDB::GetDBInstance()->SetSessionCache(true);
		session_write_close();
		SYNOPHOTO_YOUTUBE_Upload($token, $create, $expire, $id, $title, $msg, $privacy, $progressId);
		break;
	case 'cancel_upload':
		if (!isset($_POST['token']) || !isset($_POST['prog_id'])) {
			FillErrorMessage('invalid arguments', '', 'local');
			echo json_encode($error);
		}
		session_write_close();
		SYNOPHOTO_YOUTUBE_CancelUpload($_POST['token'], $_POST['prog_id']);
		break;
	case 'get_user':
		if (!isset($_POST['token'])) {
			FillErrorMessage('invalid arguments', '', 'local');
			echo json_encode($error);
		}
		session_write_close();
		SYNOPHOTO_YOUTUBE_GetUser($_POST['token']);
		break;
	default:
		FillErrorMessage('Unknown action', '', 'local');
		echo json_encode($error);
	}
} else {
	FillErrorMessage('not access tokwn or action', '', 'local');
	echo json_encode($error);
}


function SYNOPHOTO_YOUTUBE_GetAccessToken ($accessToken, $expire)
{
	$userInfo = SYNOPHOTO_UTIL_GetGoogleUser($accessToken);
	if(!$userInfo['success']) {
		echo json_encode($userInfo);
	}

	echo GetCallbackHtmlTemplate("_onYouTubeLogin", $accessToken, $userInfo['user']['name'], $userInfo['user']['image'], time(), $expire);
}

function SYNOPHOTO_YOUTUBE_GetUser($accessToken)
{
	$userInfo = SYNOPHOTO_UTIL_GetGoogleUser($accessToken);
	echo json_encode($userInfo);
}

function SYNOPHOTO_YOUTUBE_Upload($token, $tokenCreate, $tokenExpire, $videoId, $videoTitle, $videoDesc, $videoPrivacy, $progressId)
{
	$arr = explode('_', $videoId);
	if (3 !== count($arr)) {
		$result = array("success" => false, "message" => "invalid id format");
		echo json_encode($result);
		exit();
	}
	if ($arr[0] !== "video") {
		$result = array("success" => false, "message" => "not video id");
		echo json_encode($result);
		exit();
	}

	if (!csSYNOPhotoMisc::IsAllowedSocialUploadIdentity()) {
		$result = array("success" => false, "message" => "not allowedidentity");
		echo json_encode($result);
		exit();
	}

	$dirName = @pack('H*', $arr[1]);
	$fileName = @pack('H*', $arr[2]);
	if ('/' === $dirName) {
		$filePath = $fileName;
	} else {
		$filePath = $dirName.'/'.$fileName;
	}
	$realPath = realpath(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$filePath);

	if (!@file_exists($realPath)) {
		$result = array("success" => false, "message" => "file not found");
		echo json_encode($result);
		exit();
	}

	//check access right
	if (!CheckAlbumAccessRight($dirName)) {
		$result = array("success" => false, "message" => "access denied");
		echo json_encode($result);
		exit();
	}
	if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) && !csSYNOPhotoMisc::GetConfigDB("photo", "allow_guest_fb_upload", "photo_config")) {
		$result = array("success" => false, "message" => "no upload permission");
		echo json_encode($result);
		exit();
	}
	// check youtube upload Setting
	$social = SocialNetwork::ReadList();
	if (is_array($social)) {
		foreach ($social as $item) {
			if ('YouTube' === $item['name'] && true !== $item['enable']) {
				$result = array("success" => false, "message" => "no youtube upload permission");
				echo json_encode($result);
				exit();
			}
		}
	}

	$client = new Google_CLient();
	$youtube = new Google_YouTubeService($client);

	$tokenJson = '{"access_token": "'.$token.'", "token_type": "Bearer", "expires_in": "'.$tokenExpire.'", "created": "'.$tokenCreate.'"}';

	$client->setAccessToken($tokenJson);

	if ($client->getAccessToken()) {
		$youtubeId = uploadVideo($youtube, $realPath, $videoTitle, $videoDesc, $token, $videoPrivacy, $progressId);
		$result = array("success" => true, "youtubeId" => $youtubeId);
		echo json_encode($result);
		exit();
	}
	$result = array("success" => false, "message" => "token invalid");
	echo json_encode($result);
}

// modified from https://developers.google.com/youtube/v3/docs/videos/insert
function uploadVideo($youtubeObj, $videoPath, $videoTitle, $videoDesc, $token, $videoPrivacy, $progressId)
{
	try {
		// Create a snipet with title, description, tags and category id
		$snippet = new Google_VideoSnippet();
		// YouTube doesn't allow title length larger than 100
		$videoTitle = mb_substr($videoTitle, 0, 100, 'UTF-8');
		$snippet->setTitle($videoTitle);
		$snippet->setDescription($videoDesc);
		// $snippet->setTags(array("tag1", "tag2"));

		// Numeric video category. See
		// https://developers.google.com/youtube/v3/docs/videoCategories/list
		// $snippet->setCategoryId("22");

		// Create a video status with privacy status. Options are "public", "private" and "unlisted".
		$status = new Google_VideoStatus();
		$status->privacyStatus = $videoPrivacy;

		// Create a YouTube video with snippet and status
		$video = new Google_Video();
		$video->setSnippet($snippet);
		$video->setStatus($status);

		// Size of each chunk of data in bytes. Setting it higher leads faster upload (less chunks,
		// for reliable connections). Setting it lower leads better recovery (fine-grained chunks)
		$chunkSizeBytes = 1 * 512 * 1024;

		// Create a MediaFileUpload with resumable uploads
		$media = new Google_MediaFileUpload('video/*', null, true, $chunkSizeBytes);
		$media->setFileSize(filesize($videoPath));

		// Create a video insert request
		$insertResponse = $youtubeObj->videos->insert("status,snippet", $video,
			array('mediaUpload' => $media));


		$uploadStatus = false;

		// Read file and upload chunk by chunk
		$handle = fopen($videoPath, "rb");
		$chunkUploaded = 0;
		$totalChunk = ceil( filesize($videoPath)/$chunkSizeBytes );
		if (!@file_exists(YOUTUBE_UPLOAD_TMP)) {
			@mkdir(YOUTUBE_UPLOAD_TMP, 0777, true);
		} else if (!is_dir(YOUTUBE_UPLOAD_TMP)) {
			$result = array("success" => false, "message" => "failed to create tmpDir");
			echo json_encode($result);
			exit();
		}
		while (!$uploadStatus && !feof($handle)) {
			OutputSingleSpace();
			if (file_exists(YOUTUBE_UPLOAD_TMP.md5($token).$progressId."_cancel")) {
				@unlink(YOUTUBE_UPLOAD_TMP.md5($token).$progressId);
				@unlink(YOUTUBE_UPLOAD_TMP.md5($token).$progressId."_cancel");
				return FALSE;
			}
			@file_put_contents(YOUTUBE_UPLOAD_TMP.md5($token).$progressId, number_format($chunkUploaded/$totalChunk*100, 0)."%");
			$chunk = fread($handle, $chunkSizeBytes);
			$uploadStatus = $media->nextChunk($insertResponse, $chunk);
			$chunkUploaded += 1;
		}
		@unlink(YOUTUBE_UPLOAD_TMP.md5($token).$progressId);
		fclose($handle);

	} catch (Google_ServiceException $e) {
		$msg = sprintf('<p>A service error occurred: <code>%s</code></p>',
			htmlspecialchars($e->getMessage()));
		$result = array("success" => false, "message" => $msg);
		echo json_encode($result);
		return FALSE;
	} catch (Google_Exception $e) {
		$msg = sprintf('<p>An client error occurred: <code>%s</code></p>',
			htmlspecialchars($e->getMessage()));
		$result = array("success" => false, "message" => $msg);
		echo json_encode($result);
		return FALSE;
	}
	return $uploadStatus['id'];
}

function CheckAlbumAccessRight($sharePath) {
	$ret = true;
	// admin
	if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
		return true;
	}

	// not root share folder
	if ($sharePath !== "") {
		$albumInfo = csSYNOPhotoDB::GetDBInstance()->GetAlbum($sharePath);
		if (empty($albumInfo['password'])) {
			// Check accessible
			if (!csSYNOPhotoMisc::CheckAlbumAccessible($sharePath)) {
				$ret = false;
			}
		} else if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['password_pass_album'][$sharePath])) {
			$ret = false;
		}
	} else if (csSYNOPhotoMisc::GetConfigDB("photo", "allow_root_folder_public", "photo_config") !== "on" &&
			!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['uploadable_album']['/'])) {
		$ret = false;
	}
	return $ret;
}

function SYNOPHOTO_YOUTUBE_GetUploadStatus($token, $progressId) {
	$filePath = realpath(YOUTUBE_UPLOAD_TMP.md5($token).$progressId);
	if ($filePath === false) {
		$result = array( "success" => false );
		echo json_encode($result);
		exit();
	}
	$dir = dirname($filePath);
	if ($dir !== YOUTUBE_UPLOAD_TMP) {
		$result = array( "success" => false );
		echo json_encode($result);
		exit();
	}

	$content = file_get_contents($filePath);
	if (FALSE === $content) {
		$result = array( "success" => false, "text" => "0%");
		echo json_encode($result);
		exit();
	}

	$result = array("success" => true, "text" => $content);
	echo json_encode($result);

}

function SYNOPHOTO_YOUTUBE_CancelUpload($token, $progressId)
{
	$filePath = YOUTUBE_UPLOAD_TMP.md5($token).$progressId."_cancel";
	$dir = realpath(dirname($filePath));
	if ($dir !== YOUTUBE_UPLOAD_TMP) {
		$result = array( "success" => false );
		echo json_encode($result);
		exit();
	}
	@file_put_contents($filePath, "");
	$result = array("success" => true);
	echo json_encode($result);
}
?>
