<?php
require_once("../include/syno_conf.php");

csSYNOPhotoMisc::PhotoCheckSynoToken();
csSYNOPhotoMisc::CheckAdminTimeOut();

if($_REQUEST['action'] == 'get_access_right' && isset($_REQUEST['uid'])) {
	echo SYNOPHOTO_ADMIN_GetUserAlbumData($_REQUEST['uid']);
} else if ($_POST['action'] == 'get_access_right' && isset($_POST['gid'])) {
	echo SYNOPHOTO_ADMIN_GetGroupAlbumData($_REQUEST['gid']);
} else if($_POST['action'] == 'get_all_albums_privilege') {
	echo SYNOPHOTO_ADMIN_GetAllAlbumsPrivilege();
} else if($_POST['action'] == 'set_access_right_for_albums') {
	echo SYNOPHOTO_ADMIN_SetAllAlbumsPrivilege($_POST['public_list'], $_POST['private_list'], $_POST['password_list']);
}

class User
{
	private $uid;
	private $accessList;
	private $uploadList;
	private $manageList;

	public function __construct($uid)
	{
		$this->uid = $uid;

		$this->fill(PHOTO_ACCESS_RIGHT_TABLE, $this->accessList);
		$this->fill(PHOTO_UPLOAD_RIGHT_TABLE, $this->uploadList);
		$this->fill(PHOTO_MANAGE_RIGHT_TABLE, $this->manageList);
	}

	private function fill($table, &$list)
	{
		$uid = $this->uid;
		$list = array();

		$query = "SELECT * FROM $table WHERE userid = ?";
		$result = PHOTO_DB_Query($query, array($uid));

		while ($row = PHOTO_DB_FetchRow($result)) {
			$list[$row['shareid']] = true;
		}
	}

	public function hasAccess($shareid)
	{
		return array_key_exists($shareid, $this->accessList);
	}
	public function hasUpload($shareid)
	{
		return array_key_exists($shareid, $this->uploadList);
	}
	public function hasManage($shareid)
	{
		return array_key_exists($shareid, $this->manageList);
	}
}

class Group
{
	private $gid;
	private $accessList;
	private $uploadList;
	private $manageList;

	public function __construct($gid)
	{
		$this->gid = $gid;

		$this->fill(PHOTO_GROUP_PERMISSION_TABLE);
	}

	private function fill($table)
	{
		$gid = $this->gid;

		$query = "SELECT * FROM $table WHERE groupid= ?";
		$result = PHOTO_DB_Query($query, array($gid));

		$this->accessList = array();
		$this->uploadList = array();
		$this->manageList = array();
		while ($row = PHOTO_DB_FetchRow($result)) {
			$perm = $row['permission'];
			$shareid = $row['shareid'];

			$this->fill_by_type($this->accessList, $shareid, $row['permission'], 1);
			$this->fill_by_type($this->uploadList, $shareid, $row['permission'], 2);
			$this->fill_by_type($this->manageList, $shareid, $row['permission'], 4);
		}
	}

	private function fill_by_type(&$list, $shareid, $permission, $permission_bit)
	{
		if ($permission & $permission_bit) {
			$list[$shareid] = true;
		}
	}

	public function hasAccess($shareid)
	{
		return array_key_exists($shareid, $this->accessList);
	}
	public function hasUpload($shareid)
	{
		return array_key_exists($shareid, $this->uploadList);
	}
	public function hasManage($shareid)
	{
		return array_key_exists($shareid, $this->manageList);
	}
}

class Share
{
	private $id;
	private $parent_id;
	private $child_id;
	private $public;
	private $db_sharename;
	private $db_title;
	private $level;
	private $has_password;

	public function __construct($row, $parent_id, $child_id, $level)
	{
		$this->init($row, $parent_id, $child_id, $level);
	}

	private function init($row, $parent_id, $child_id, $level)
	{
		$this->id = $row['shareid'];
		$this->parent_id = $parent_id;
		$this->child_id = $child_id;
		$this->public = PHOTO_DB_IsTrue($row['public']);
		$this->db_sharename = $row['sharename'];
		$this->db_title = $row['title'];
		$this->level = $level;
		$this->has_password = !empty($row['password']);
	}

	private function getFolderName()
	{
		if (!$this->parent_id) {
			// root album
			return __(photo_str_category_albums);
		} elseif ($this->level === 1) {
			// level 1
			return $this->db_sharename;
		} else {
			// level 2
			return explode('/', $this->db_sharename)[1];
		}
	}

	private function getTitle()
	{
		if (!$this->parent_id) {
			// root album
			return __(photo_str_category_albums);
		} else {
			return empty($this->db_title) ? $this->getFolderName() : $this->db_title;
		}
	}

	public function dump($obj)
	{
		$title = $this->getTitle();
		$browse = $this->public ? 1 : ($obj->hasAccess($this->id) ? 1 : 0);
		$upload = $obj->hasUpload($this->id) ? 1 : 0;
		$manage = $obj->hasManage($this->id) ? 1 : 0;
		$child_id_str = is_null($this->child_id) ? null : "[".implode(',', $this->child_id)."]";
		$public_no = $this->has_password ? 2 : ($this->public ? 1 : 0);

		$item = array(
			'_id' => $this->id,
			'_parent' => $this->parent_id,
			'browse' => $browse,
			'upload' => $upload,
			'manage' => $manage,
			'_level' => $this->level,
			'_lft' => $this->level,
			'_is_leaf' => is_null($this->child_id) || count($this->child_id) === 0,
			'title' => $title,
			'public' => $public_no,
			'child_id' => $child_id_str
		);
		return $item;
	}
}

class Shares
{
	private $shares;

	public function __construct()
	{
		$this->init();
	}

	private function init()
	{
		// select root, 1st level, 2nd level album
		$query = "SELECT * FROM photo_share WHERE sharename NOT LIKE '%/%/%' ORDER BY sharename ASC";
		$result = PHOTO_DB_Query($query);

		$share_rows = array();
		$root_shareid = null;
		$level1_list = array();
		$level1_child_list = array();
		$level2_list = array();

		while ($row = PHOTO_DB_FetchRow($result)) {
			$shareid = $row['shareid'];
			$sharename = $row['sharename'];

			$share_rows[$sharename] = $row;

			if ($sharename === '/') {
				$root_shareid = $shareid;
			} elseif (false === strpos($sharename, '/')) {
				// level 1 album
				$level1_child_list[$sharename] = array();
				$level1_list[$sharename] = $shareid;
			} else {
				$level2_list[$sharename] = $shareid;
			}
		}

		$level2_parent_list = array();
		foreach ($level2_list as $sharename => $shareid) {
			$parent_sharename = explode('/', $sharename)[0];
			if (!isset($level1_list[$parent_sharename])) {
				syslog(LOG_ERR, __FILE__.":".__LINE__.", Failed to find share id of $parent_sharename");
				continue;
			}
			$level2_parent_list[$sharename] = $level1_list[$parent_sharename];
			$level1_child_list[$parent_sharename][] = $shareid;
		}

		$this->shares = array();
		foreach ($share_rows as $sharename => $row) {
			if ($sharename === '/') {
				$parent_id = null;
				$child_id = array_values($level1_list);
				$level = 1;
			} elseif (false === strpos($sharename, '/')) {
				$parent_id = $root_shareid;
				$child_id = $level1_child_list[$sharename];
				$level = 1;
			} else {
				$parent_id = $level2_parent_list[$sharename];
				$child_id = null;
				$level = 2;
			}

			$this->shares[] = new Share($row, $parent_id, $child_id, $level);
		}
	}

	public function dump($obj) {
		$list = array();
		foreach ($this->shares as $share) {
			$list[] = $share->dump($obj);
		}

		return $list;
	}
}

function SYNOPHOTO_ADMIN_GetUserAlbumData($uid)
{
	$user = new User($uid);
	$shares = new Shares();

	$list = $shares->dump($user);

	$result['all'] = $list;
	return json_encode($result);
}

function SYNOPHOTO_ADMIN_GetGroupAlbumData($gid)
{
	$group = new Group($gid);
	$shares = new Shares();

	$list = $shares->dump($group);

	$result['all'] = $list;
	return json_encode($result);
}

function SYNOPHOTO_ADMIN_GetUserAlbumPrivilegeOneItem($row, $parent_id)
{
	$item = array();
	$item['_parent'] = $parent_id;
	$item['_id'] = $row['shareid'];
	if ($parent_id) {
		$item['name'] = iconv('UTF-8', 'UTF-8//TRANSLIT', substr($row['sharename'], strpos($row['sharename'], "/") + 1))."";
		$item['_level'] = 2;
		$item['_is_leaf'] = true;
	} else {
		$item['name'] = iconv('UTF-8', 'UTF-8//TRANSLIT', $row['sharename'])."";
		$item['_level'] = 1;
		$item['_is_leaf'] = false;
	}
	$item['title'] = empty($row['title']) ? $item['name'] : iconv('UTF-8', 'UTF-8//TRANSLIT', $row['title'])."";

	if (PHOTO_DB_ConvertBool($row['public']) == 't' && !$row['password']) {
       	$item['public'] = 1;
		$item['original'] = 'public';
	       $item['public_orig'] = 1;
    } else {
       	$item['public'] = 0;
		$item['public_orig'] = 0;
    }

	if ($row['password'] && '' != $row['password']) {
		$item['password_content'] = '＃＃＃＃＃＃＃＃';
		$item['password_content_orig'] = '＃＃＃＃＃＃＃＃';
		$item['password'] = 1;
		$item['original'] = 'password';
		$item['password_orig'] = 1;
	} else {
		$item['password_content'] = $row['password'];
		$item['password'] = 0;
		$item['password_orig'] = 0;
	}

	if (0 == $item['public'] && 0 == $item['password']) {
		$item['private'] = 1;
		$item['private_orig'] = 1;
		$item['original'] = 'private';
	} else {
		$item['private'] = 0;
		$item['private_orig'] = 0;
	}
	return $item;
}

function SYNOPHOTO_ADMIN_GetAllAlbumsPrivilege()
{
	$query = "Select * from photo_share where is_subdir = 'f' and sharename <> '/' order by sharename asc";
	$db_result = PHOTO_DB_Query($query);

	$list = array();
	while(($row = PHOTO_DB_FetchRow($db_result))) {
		$item = SYNOPHOTO_ADMIN_GetUserAlbumPrivilegeOneItem($row, null);

		$escape = PHOTO_DB_GetEscape();
		$query = "Select * from photo_share where sharename like ? $escape and sharename not like ? $escape order by sharename asc";
		$sqlParam = array(PHOTO_DB_EscapForLike($row['sharename']) . '/%', PHOTO_DB_EscapForLike($row['sharename']) . '/%/%');
		$db_result_2 = PHOTO_DB_Query($query, $sqlParam);

		$children = array();
		$children_id = array();
		while(($row_2 = PHOTO_DB_FetchRow($db_result_2))) {
			$children[] = SYNOPHOTO_ADMIN_GetUserAlbumPrivilegeOneItem($row_2, $row['shareid']);
		}


		if(0 == count($children)) {
			$item['_is_leaf'] = true;
		}

		$list[] = $item;

		foreach ($children as $child) {
			$list[] = $child;
		}
	}

	$result['totalCount'] = count($list);
	$result['all'] = $list;
	$result['success'] = true;
	return json_encode($result);
}

function SYNOPHOTO_ADMIN_SetAllAlbumsPrivilege($public_list, $private_list, $password_json)
{
	if (Album::EditAlbumPermission('public', array_map(function($v) {return $v+0;}, explode(',',$public_list))) &&
		Album::EditAlbumPermission('private', array_map(function($v) {return $v+0;}, explode(',',$private_list))) &&
		Album::EditAlbumPermission('password', json_decode($password_json, 1))) {
		$result['success'] = true;
	} else {
		$result['success'] = false;
	}
	return json_encode($result);
}

