<?php

require_once dirname(__FILE__).'/../include/SYNOPhotoEA.php';
require_once dirname(__FILE__).'/../vendor/autoload.php';

use Facebook\Exceptions\FacebookResponseException;
use Facebook\Exceptions\FacebookSDKException;

function FBLog($level, $msg) {
	$handle = fopen('/tmp/fbphoto.log', "a");
	if($handle) {
		fwrite($handle, date('y-m-d H:i:s'). " $level: ".$msg."\n");
		$st = fstat($handle);
		fclose($handle);
		if($st['size'] > 512000) {
			@unlink('/tmp/fbphoto.log');
		}
	}
}

function FBLogErr($msg)
{
	FBLog('Error', $msg);
}

function FBLogInfo($msg)
{
	FBLog('Info', $msg);
}

class FBPhotoUtils {
	private $fb;

	public function __construct($token) {
		$this->fb = new Facebook\Facebook([
			'app_id'     => '178470495541647',
			'app_secret' => 'd7004c60c95075ed1115e6606e182203',
			'default_graph_version' => 'v2.12',
		]);

		$this->fb->setDefaultAccessToken($token);
	}

	public static function CheckFbTokenValid($token)
	{
		if (empty($token)) {
			return null;
		}
		$fb_utils = new FBPhotoUtils($token);
		$user = $fb_utils->getUser();
		if (empty($user)) {
			return null;
		}
		$fb_utils->user_name = $user['name'];
		$fb_utils->user_id = $user['id'];
		return $fb_utils;
	}

	private function sendFacebookRequest($api, $method = 'GET', $options = array())
	{
		if ($method === 'GET') {
			$resp = $this->fb->get($api);
		} elseif ($method === 'POST') {
			$resp = $this->fb->post($api, $options);
		} else {
			// invalid method!
			return null;
		}

		return $resp;
	}

	public function createAlbum($name, $message) {
		try {
			$resp = $this->sendFacebookRequest('/me/albums/', 'POST', array('name' => $name, 'message' => $message));
			$graphAlbum = $resp->getGraphAlbum();
		} catch (FacebookResponseException $e) {
			FBLogErr($e->getMessage());
			return null;
		} catch (FacebookSDKException $e) {
			FBLogErr($e->getMessage());
			return null;
		}

		return $graphAlbum->getId();
	}
	public function getAlbums() {
		try {
			$resp = $this->sendFacebookRequest('/me/albums/');

			$albums = array();
			foreach ($resp->getGraphEdge() as $graphNode) {
				$albums[] = $graphNode->asArray();
			}
		} catch (FacebookResponseException $e) {
			FBLogErr($e->getMessage());
			return null;
		} catch (FacebookSDKException $e) {
			FBLogErr($e->getMessage());
			return null;
		}
		return $albums;
	}
	public function getAlbumPhotos($albumID) {
		try {
			$resp = $this->sendFacebookRequest("/$albumID/photos?limit=200&offset=0");

			$photos = array();
			foreach ($resp->getGraphEdge() as $graphNode) {
				$photos[] = $graphNode->asArray();
			}
		} catch (FacebookResponseException $e) {
			FBLogErr($e->getMessage());
			return null;
		} catch (FacebookSDKException $e) {
			FBLogErr($e->getMessage());
			return null;
		}
		return $photos;
	}
	public function getAlbum($albumID) {
		try {
			$resp = $this->sendFacebookRequest("/$albumID");
			$graphNode = $resp->getGraphNode();
			$resp = $graphNode->asArray();
		} catch (FacebookResponseException $e) {
			FBLogErr($e->getMessage());
			return null;
		} catch (FacebookSDKException $e) {
			FBLogErr($e->getMessage());
			return null;
		}
		return $resp;
	}

	function uploadPhoto($filePath, $albumID, $message, $useOrig) {
		$photoID = '';
		$uploadFile = $filePath;
		$fileStat = stat($filePath);
		if(!$useOrig || false === $fileStat || 30*1024*1024 <= $fileStat['size']) {
			if (SYNOPhotoEA::checkFilePath($filePath, SYNOPhotoEA::FILE_THUMB_XL, $thumbPath)) {
				$uploadFile = $thumbPath;
			} else if (SYNOPhotoEA::checkFilePath($filePath, SYNOPhotoEA::FILE_THUMB_LARGE_PREVIEW, $thumbPath)) {
				$uploadFile = $thumbPath;
			}
		}
		FBLogInfo("Upload file path: " . $uploadFile);
		$opts = array(
			'message' => $message,
			'source' => $this->fb->fileToUpload($uploadFile)
		);
		$url = empty($albumID) ? "/me/photos" : "/$albumID/photos";
		try {
			$resp = $this->sendFacebookRequest($url, 'POST', $opts);
			$graphNode = $resp->getGraphNode();
			$photoID = $graphNode->getProperty('id', null);
		} catch (FacebookResponseException $e) {
			FBLogErr($e->getMessage());
			return null;
		} catch (FacebookSDKException $e) {
			FBLogErr($e->getMessage());
			return null;
		}

		return $photoID;
	}

	public function getUser() {
		try {
			$resp = $this->sendFacebookRequest('/me');
			$graphNode = $resp->getGraphNode();
			$user = $graphNode->asArray();
		} catch (FacebookResponseException $e) {
			FBLogErr($e->getMessage());
			return null;
		} catch (FacebookSDKException $e) {
			FBLogErr($e->getMessage());
			return null;
		}
		if ($user['id'] === null || $user['name'] === null) {
			return null;
		}
		FBLogInfo("User ID: " . $user['id']);
		return $user;
	}
}
?>
