<?php
require_once ('syno_conf.php');
require_once ('photo/synophoto_csPhotoMisc.php');

class AdvancedSharedAlbum {
	const LOG_ALL = 'all';
	const LOG_COMMENT = 0;
	const LOG_LABEL = 1;
	private static $LOG_MAPTO_STRING = array(self::LOG_COMMENT => 'comment', self::LOG_LABEL => 'label');
	private static $LOG_MAPTO_ENUM = array('comment' => self::LOG_COMMENT, 'label' => self::LOG_LABEL, 'all' => self::LOG_ALL);
	private static $LOG_MAP_COLOR_STRING = array(1 => 'red', 2 => 'orange', 3 => 'lime_green', 4 => 'aqua_green', 5 => 'blue', 6 => 'purple');

	public static function GetAdvancedInfoById($id, $userid = NULL)
	{
		$advancedInfo = array();
		if ($userid === NULL) {
			$userid = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : 0;
		}
		$table = SHARED_ALBUM_ADVANCED_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$table = SHARED_ALBUM_ADVANCED_ADMIN_TABLE_NAME;
		}

		$query = "SELECT * FROM " . $table . " WHERE collectionid = ? ";
		$sqlParams[] = $id;
		$db_result = PHOTO_DB_Query($query, $sqlParams);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}
		$advancedInfo['enable_password'] = PHOTO_DB_IsTrue($row['enable_password']);
		$advancedInfo['enable_marquee_tool'] = PHOTO_DB_IsTrue($row['tag_area']);
		$advancedInfo['enable_comment'] = PHOTO_DB_IsTrue($row['comment']);
		$advancedInfo['enable_color_label'] = PHOTO_DB_IsTrue($row['color_label']);
		$advancedInfo['color_label_1'] = $row['color_label_1'];
		$advancedInfo['color_label_2'] = $row['color_label_2'];
		$advancedInfo['color_label_3'] = $row['color_label_3'];
		$advancedInfo['color_label_4'] = $row['color_label_4'];
		$advancedInfo['color_label_5'] = $row['color_label_5'];
		$advancedInfo['color_label_6'] = $row['color_label_6'];

		return $advancedInfo;
	}

	public static function GetPublicShareAlbumPassword($id, $userid = NULL)
	{
		if ($userid === NULL) {
			$userid = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : 0;
		}
		$table = SHARED_ALBUM_ADVANCED_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$table = SHARED_ALBUM_ADVANCED_ADMIN_TABLE_NAME;
		}
		$query = "SELECT password, enable_password FROM " . $table . " WHERE collectionid = ? ";
		$db_result = PHOTO_DB_Query($query, array($id));
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row || !$row['enable_password']) {
			return NULL;
		}
		return $row['password'];
	}

	public static function getAdvancedItemInfoById($item_id, $type, $userid, $collectionid)
	{
		$advancedItemInfo = array();
		$table = SHARED_ALBUM_ADVANCED_ITEM_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$table = SHARED_ALBUM_ADVANCED_ITEM_ADMIN_TABLE_NAME;
		}

		$query = "SELECT * FROM ". $table ." WHERE collectionid = ? AND type = ? AND item_id = ?";
		$sqlParams = array($collectionid, $type, $item_id);
		$db_result = PHOTO_DB_Query($query, $sqlParams);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}

		$advancedItemInfo['id'] = (int)$row['id'];
		$advancedItemInfo['collectionid'] = (int)$row['collectionid'];
		$advancedItemInfo['item_id'] = (int)$row['item_id'];
		$advancedItemInfo['type'] = $row['type'];
		$advancedItemInfo['color_label'] = (int)$row['color_label'];

		return $advancedItemInfo;
	}

	public static function setItemColorLabel($collectionid, $userid, $item_id, $type, $color)
	{
		$table = SHARED_ALBUM_ADVANCED_ITEM_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$table = SHARED_ALBUM_ADVANCED_ITEM_ADMIN_TABLE_NAME;
		}
		PHOTO_DB_BeginTransaction();

		$advanced_item_id = self::updateAdvancedItemTable($item_id, $type, 'insert', $collectionid, $userid);
		if (!$advanced_item_id) {
			PHOTO_DB_RollBack();
			return false;
		}

		$query = "UPDATE $table SET color_label = ? WHERE collectionid = ? AND item_id = ? AND type = ?";
		$sqlParams = array($color, $collectionid, $item_id, $type);
		$db_result = PHOTO_DB_Query($query, $sqlParams);
		if (!$db_result) {
			PHOTO_DB_RollBack();
			return false;
		}

		if ($color === 0) {
			$log = "Unlabelled";
		} else {
			$advancedInfo = self::GetAdvancedInfoById($collectionid, $userid);
			$color_label_name = $advancedInfo['color_label_'.$color];
			$log = "Labeled as " . self::$LOG_MAP_COLOR_STRING[$color] . " [$color_label_name]";
		}

		if (!self::AddLog($userid, $collectionid, $advanced_item_id, $log, date("Y-m-d H:i"), self::LOG_LABEL)) {
			PHOTO_DB_RollBack();
			return false;
		}
		PHOTO_DB_Commit();
		return true;
	}

	public static function updateAdvancedItemTable($item_id, $type, $action, $collectionid, $userid) //insert ; delete
	{
		$query = '';

		$AdvancedItemTable = SHARED_ALBUM_ADVANCED_ITEM_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$AdvancedItemTable = SHARED_ALBUM_ADVANCED_ITEM_ADMIN_TABLE_NAME;
		}
		$advanced_item_id = self::GetAdvancedItemId($userid, $collectionid, $item_id, $type);

		if ('insert' === $action && !$advanced_item_id) {
			$query = "INSERT INTO " . $AdvancedItemTable . " (collectionid, item_id, type) VALUES (?, ?, ?)";

			$sqlParams = array($collectionid, $item_id, $type);
			PHOTO_DB_Query($query, $sqlParams);
			if ('root' === SYNOPHOTO_ADMIN_USER) {
				$advanced_item_id = PHOTO_DB_lastInsertId($AdvancedItemTable . '_id_seq');
			} else {
				$db_result = PHOTO_DB_Query("SELECT id FROM $AdvancedItemTable WHERE collectionid = ? and item_id = ?", array($collectionid, $item_id));
				$row = PHOTO_DB_FetchRow($db_result);
				$advanced_item_id = $row['id'];
			}
		} else if ('delete' === $action) {
			$query = "DELETE FROM " . $AdvancedItemTable . " WHERE collectionid = ? AND item_id = ? AND type = ?";
			$sqlParams = array($collectionid, $item_id, $type);
			PHOTO_DB_Query($query, $sqlParams);
		}

		return $advanced_item_id;
	}

	public static function AddComment($owner_id, $collection_id, $item_db_id, $item_type, $name, $email, $comment, $date)
	{
		$table = PHOTO_DB_IsAdminUid($owner_id) ? SHARED_ALBUM_ADVANCED_COMMENT_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_COMMENT_TABLE_NAME;

		PHOTO_DB_BeginTransaction();

		$advanced_id = self::updateAdvancedItemTable($item_db_id, $item_type, 'insert', $collection_id, $owner_id);
		if (!$advanced_id) {
			PHOTO_DB_RollBack();
			return false;
		}

		$query = "INSERT INTO $table (advanced_item_id, name, email, comment, date) VALUES (?,?,?,?,?)";
		$res = PHOTO_DB_Query($query, array($advanced_id, $name, $email, $comment, $date));
		if (!$res) {
			PHOTO_DB_RollBack();
			return false;
		}
		if (!self::AddLog($owner_id, $collection_id, $advanced_id, $comment, $date, self::LOG_COMMENT)) {
			PHOTO_DB_RollBack();
			return false;
		}
		PHOTO_DB_Commit();
		return true;
	}

	public static function ListComment($owner_id, $collection_id, $item_db_id, $item_type, $offset = 0, $limit = 100)
	{
		$table = PHOTO_DB_IsAdminUid($owner_id) ? SHARED_ALBUM_ADVANCED_COMMENT_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_COMMENT_TABLE_NAME;


		$advanced_id= self::GetAdvancedItemId($owner_id, $collection_id, $item_db_id, $item_type);
		if (!$advanced_id) {
			return false;
		}

		// paging
		//$query = "SELECT * FROM $table where advanced_item_id = ? ORDER BY id DESC ".PHOTO_DB_GetLimitOffsetString($limit, $offset);
		$query = "SELECT * FROM $table where advanced_item_id = ? ORDER BY id DESC";
		$res = PHOTO_DB_Query($query, array($advanced_id));
		$output = array();
		while(($row = $res->fetch())) {
			$output[] = array(
				'name' => iconv('UTF-8', 'UTF-8//IGNORE', $row['name']),
				'email' => $row['email'],
				'comment' => iconv('UTF-8', 'UTF-8//IGNORE', $row['comment']),
				'date'	=> $row['date']
			);
		}
		return $output;
	}

	/*
	 * AddLog:
	 *	params:
	 *		category: 0: Comment, 1: Other operation, eg: add label
	 * */
	private static function AddLog($owner_id, $collection_id, $advanced_id, $log, $date, $category)
	{
		$table = PHOTO_DB_IsAdminUid($owner_id) ? SHARED_ALBUM_ADVANCED_LOG_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_LOG_TABLE_NAME;

		$query = "INSERT INTO $table (collectionid, advanced_item_id, log, date, category) VALUES (?,?,?,?,?)";
		if (!PHOTO_DB_Query($query, array($collection_id, $advanced_id, $log, $date, $category))) {
			return false;
		}
		return true;
	}

	public static function ListLog($owner_id, $collection_id, $category, $offset, $limit)
	{
		$table = PHOTO_DB_IsAdminUid($owner_id) ? SHARED_ALBUM_ADVANCED_LOG_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_LOG_TABLE_NAME;

		if (self::$LOG_MAPTO_ENUM[$category] === 'all') {
			$query = "SELECT * FROM $table WHERE collectionid = ? ORDER BY id DESC ".PHOTO_DB_GetLimitOffsetString($limit, $offset);
			$res = PHOTO_DB_Query($query, array($collection_id));
		} else {
			$query = "SELECT * FROM $table WHERE collectionid = ? AND category = ? ORDER BY id DESC ".PHOTO_DB_GetLimitOffsetString($limit, $offset);
			$res = PHOTO_DB_Query($query, array($collection_id, self::$LOG_MAPTO_ENUM[$category]));
		}
		$output = array();
		$advanced_ids = array();
		while(($row = $res->fetch())) {
			$advanced_ids[$row['advanced_item_id']] = $row['advanced_item_id'] + 0;
			$output[] = array(
				'id' => $row['id'] + 0,
				'collectionid' => $row['collectionid'] + 0,
				'advanced_item_id' => $row['advanced_item_id'] + 0,
				'log' => iconv('UTF-8', 'UTF-8//IGNORE', $row['log']),
				'date'	=> $row['date'],
				'category' => self::$LOG_MAPTO_STRING[$row['category']]
			);
		}
		$item_objects = self::ConvertAdvancedItemIdToDBIdType($owner_id, array_values($advanced_ids));
		for ($i = 0; $i < count($output); ++$i) {
			$output[$i]['item_object'] = $item_objects[$output[$i]['advanced_item_id']];
		}
		return $output;
	}

	public static function GetLogTotalCount($owner_id, $collection_id, $category)
	{
		$LOG_MAPPING = array('comment' => self::LOG_COMMENT, 'label' => self::LOG_LABEL);

		$table = PHOTO_DB_IsAdminUid($owner_id) ? SHARED_ALBUM_ADVANCED_LOG_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_LOG_TABLE_NAME;

		if (self::$LOG_MAPTO_ENUM[$category] === 'all') {
			$query = "SELECT count(id) as total FROM $table WHERE collectionid = ? ";
			$res = PHOTO_DB_Query($query, array($collection_id));
		} else {
			$query = "SELECT count(id) as total FROM $table WHERE collectionid = ? AND category = ?";
			$res = PHOTO_DB_Query($query, array($collection_id, $LOG_MAPPING[$category]));
		}
		$row = PHOTO_DB_FetchRow($res);
		if (!$row) {
			return NULL;
		}
		return $row['total'] + 0;
	}

	private static function GetAdvancedItemId($owner_id, $collection_id, $item_db_id, $item_type)
	{
		$table = PHOTO_DB_IsAdminUid($owner_id) ? SHARED_ALBUM_ADVANCED_ITEM_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_ITEM_TABLE_NAME;
		$query = "SELECT id FROM $table WHERE collectionid = ? AND item_id = ? AND type = ?";
		$db_result = PHOTO_DB_Query($query, array($collection_id, $item_db_id, $item_type));
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}
		return $row['id'] + 0;
	}

	/*
	 *	ConvertAdvancedItemIdToDBIdType($owner_id, [advanced_item_id, advanced_item_id, advanced_item_id, ..]);
	 *	return NULL if id_array is empty
	 *		{
	 *			advanced_item_id => {
	 *				id: dbId,
	 *				type: photo/video
	 *			},
	 *			advanced_item_id => {
	 *				id: dbId,
	 *				type: photo/video
	 *			}
	 *		}
	 * */
	private static function ConvertAdvancedItemIdToDBIdType($owner_id, $advanced_item_ids)
	{
		if (!($count = count($advanced_item_ids))) {
			return NULL;
		}
		$table = PHOTO_DB_IsAdminUid($owner_id) ? SHARED_ALBUM_ADVANCED_ITEM_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_ITEM_TABLE_NAME;
		$mark = implode(',', array_fill(0, $count, '?'));
		$query = "SELECT * FROM $table WHERE id IN ($mark)";
		$db_result = PHOTO_DB_Query($query, $advanced_item_ids);
		$output = array();
		while(($row = $db_result->fetch())) {
			$output[$row['id']] = array(
				'id' => $row['item_id'] + 0,
				'type' => $row['type']
			);
		}
		return $output;
	}

	public function CheckSharedAlbumPassword($collection_id, $user_id, $advanced_info, $public_share_id, $password) {
		$album_uid = $user_id + 0;
		$current_uid = $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] + 0;
		if (PHOTO_DB_IsAdminUid($current_uid)) { // for admin user (keep 0) or non-login user (set to -1)
			$current_uid = isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) ? $current_uid : -1;
		}

		$album_password = self::GetPublicShareAlbumPassword($collection_id, $user_id);

		if ($album_uid === $current_uid ||
			!$advanced_info['enable_password'] ||
			$_SESSION[SYNOPHOTO_ADMIN_USER]['password_pass_album'][$public_share_id] === $album_password) {
			return true;
		}

		$pw_md5 = md5($password);
		if ($pw_md5 === $album_password) {
			csSYNOPhotoMisc::PhotoSessionStart();
			$_SESSION[SYNOPHOTO_ADMIN_USER]['password_pass_album'][$public_share_id] = $pw_md5;
			session_write_close();
			return true;
		}
		return false;
    }

	private static function GetPhotoAreaTagId($advancedItemId, $position, $info, $table)
	{
		$query = "SELECT id FROM $table WHERE advanced_item_id = ? AND position = ? AND info = ?";
		$db_result = PHOTO_DB_Query($query, array($advancedItemId, $position, $info));
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}
		return $row['id'] + 0;
	}

	private static function GetAreaTagById($area_tag_id, $table) {
		$query = "SELECT * FROM $table WHERE id = ?";
		$db_result = PHOTO_DB_Query($query, array($area_tag_id));
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}
		return $row;
	}

	public static function GetAreaTagList($collectionid, $userid, $photo_id)
	{
		$table = PHOTO_DB_IsAdminUid($userid) ? SHARED_ALBUM_ADVANCED_ITEM_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_ITEM_TABLE_NAME;
		$area_tag_table = PHOTO_DB_IsAdminUid($userid) ? SHARED_ALBUM_ADVANCED_TAG_AREA_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_TAG_AREA_TABLE_NAME;

		$query = "SELECT tag_table.id, position, info FROM $area_tag_table as tag_table LEFT JOIN $table as item_table ON item_table.id = tag_table.advanced_item_id WHERE item_table.collectionid = ? AND item_table.item_id = ?;";

		$db_result = PHOTO_DB_Query($query, array($collectionid, $photo_id));
		$list = array();
		while (false !== ($row = PHOTO_DB_FetchRow($db_result))) {
			$list[] = array(
				'id' => $row['id'],
				'position' => json_decode($row['position']),
				'info' => $row['info']
			);
		}
		return $list;
	}

	public static function AddAreaTag($collectionid, $userid, $params)
	{
		$type = "photo";
		$advancedItemId = self::updateAdvancedItemTable($params['photo_id'], $type, 'insert', $collectionid, $userid);
		if (!$advancedItemId) {
			return false;
		}

		$table = PHOTO_DB_IsAdminUid($userid) ? SHARED_ALBUM_ADVANCED_TAG_AREA_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_TAG_AREA_TABLE_NAME;
		$info = $params['info'];
		$position = json_encode(
			array('x' => $params['x'],
				  'y' => $params['y'],
				  'width' => $params['width'],
				  'height' => $params['height'])
		);
		$query = "INSERT INTO $table (advanced_item_id, position, info) VALUES (?, ?, ?);";
		$sqlParam = array($advancedItemId, $position, $info);
		PHOTO_DB_BeginTransaction();
		if (!PHOTO_DB_Query($query, $sqlParam)) {
			PHOTO_DB_RollBack();
			return false;
		}
		if (!self::AddLog($userid, $collectionid, $advancedItemId, "Add - \"$info\"", date("Y-m-d H:i"), 1)) {
			PHOTO_DB_RollBack();
			return false;
		}
		PHOTO_DB_Commit();
		return array('tag_id' => self::GetPhotoAreaTagId($advancedItemId, $position, $params['info'], $table));
	}

	public static function DeleteAreaTag($collectionid, $userid, $area_tag_id)
	{
		$table = PHOTO_DB_IsAdminUid($userid) ? SHARED_ALBUM_ADVANCED_TAG_AREA_ADMIN_TABLE_NAME : SHARED_ALBUM_ADVANCED_TAG_AREA_TABLE_NAME;
		$query = "DELETE FROM $table WHERE id = ?;";
		if (NULL === ($areaTag = self::GetAreaTagById($area_tag_id, $table))) {
			return false;
		}
		PHOTO_DB_BeginTransaction();
		if (!PHOTO_DB_Query($query, array($area_tag_id))) {
			PHOTO_DB_RollBack();
			return false;
		}
		if (!self::AddLog($userid, $collectionid, $areaTag['advanced_item_id'], "Remove - \"${areaTag['info']}\"", date("Y-m-d H:i"), 1)) {
			PHOTO_DB_RollBack();
			return false;
		}
		PHOTO_DB_Commit();
		return true;
	}
}
?>
