<?php
class Album {
	public static function GetBySharename($sharepathArray) {
		$res = array();
		$queryShare = array();

		foreach ($sharepathArray as $sharename) {
			$queryShare[] = $sharename;
		}
		if (0 === count($queryShare)) {
			return $res;
		}

		$str = implode(',', array_fill(0, count($queryShare), '?'));
		$albums = self::GetByCondition("sharename in ($str)", $queryShare);

		foreach ($albums as $row) {
			$res[$row['sharename']] = $row;
		}
		return $res;
	}

	public static function GetByShareId($shareIdArray) {
		$str = "shareid IN (" . implode(',', $shareIdArray) . ")";
		$albums = self::GetByCondition($str);
		return $albums;
	}

	public static function GetSubDirIdByShareId($shareIdString) {
		$subDirIds = array();
		$query = "SELECT sharename FROM photo_share WHERE shareid IN (". $shareIdString .")";
		$result = PHOTO_DB_Query($query);
		if (!$result) {
			return $subDirIds;
		}
		while ($row = $result->fetch()) {
			$subDirQuery = "SELECT shareid from photo_share WHERE sharename LIKE ? AND sharename NOT LIKE ?";
			$dbResult = PHOTO_DB_QUERY($subDirQuery, array($row[0].'/%', $row[0].'/%/%'));
			while($id = $dbResult->fetch()) {
				if (!in_array($id[0], $subDirIds)) {
					array_push($subDirIds, $id[0]);
				}
			}
		}
		return $subDirIds;
	}

	public static function GetPhotoCount($shareid) {
		$query = "SELECT count(id) FROM photo_image WHERE shareid = ?";
		$result = PHOTO_DB_Query($query, array($shareid));

		if (!$result) {
			return 0;
		}

		$row = $result->fetch();
		return $row[0] + 0;
	}

	public static function GetVideoCount($shareid) {
		$query = "SELECT count(id) FROM video WHERE shareid = ?";
		$result = PHOTO_DB_Query($query, array($shareid));

		if (!$result) {
			return 0;
		}

		$row = $result->fetch();
		return $row[0] + 0;
	}

	/*
	 *	return [shareid => share_obj, shareid => share_obj ...]
	 *
	 * */
	public static function GetAccessibleShare($from = '', $publicShareId = NULL)
	{
		$level1Albums = $level2Albums = $restAlbums = $level1Password = $level2Password = array();

		if ($publicShareId === NULL) {
			$isAdmin = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);
			$userid = isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : '';
			$groupid = isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid'] : '';
		} else {
			// get user info by public share link
			$publicShareInfo = SharedAlbum::GetInfoByPublicShare($publicShareId);
			if ($publicShareInfo === NULL || $publicShareInfo['share_status'] !== 'valid') {
				goto End;
			}
			$userid = $publicShareInfo['userid'];
			if (PHOTO_DB_IsAdminUid($userid)) {
				$isAdmin = true;
			} else {
				if ($_SESSION[SYNOPHOTO_ADMIN_USER]['use_dsm_account']) {
					$userInfo = csSYNOPhotoMisc::GetDsmUserInfoById($userid);
				} else {
					$userInfo = csSYNOPhotoMisc::GetUserInfoById($userid);
				}

				if (NULL === $userInfo || $userInfo['isDisabled']) {
					goto End;
				}
				$isAdmin = $userInfo['isAdmin'];
				$groupid = $userInfo['groupids'];
			}
		}

		$privilegeQuery = '';
		if ($isAdmin) {
			// Admin User
			$privilegeQuery = '1=1';
		} else {
			$UserAccessibleShareSql = $userid ? "SELECT shareid FROM ".PHOTO_ACCESS_RIGHT_TABLE." WHERE userid = $userid" : '';
			$GroupAccessibleShareSql = $groupid ? "SELECT shareid FROM ".PHOTO_GROUP_PERMISSION_TABLE." WHERE groupid in ($groupid) AND permission & 1 <> 0" : '';

			$privilegeCondition = array();
			if ($UserAccessibleShareSql) {
				$privilegeCondition[] = " shareid IN ($UserAccessibleShareSql) ";
			}
			if ($GroupAccessibleShareSql) {
				$privilegeCondition[] = " shareid IN ($GroupAccessibleShareSql) ";
			}
			if (count($privilegeCondition)) {
				// Login User
				$privilegeQuery = implode(' OR ', $privilegeCondition);
			} else {
				// Guest
				$privilegeQuery = '1!=1';
			}
		}
		// level 1 password share
		$albums = self::GetByCondition("is_subdir = 'f' AND password != ''");
		foreach ($albums as $album) {
			$level1Password[$album['shareid']] = $album;
		}
		// level 1 photo_share
		if ('session' == $from) {
			// include Root
			// album password is maybe NULL if this photo station is upgraded from very old version
			$albums = self::GetByCondition("is_subdir = 'f' AND (password = '' OR password IS NULL) AND (public ='t' OR $privilegeQuery)");
		} else {
			// album password is maybe NULL if this photo station is upgraded from very old version
			$albums = self::GetByCondition("is_subdir = 'f' AND sharename != '/' AND (password = '' OR password IS NULL) AND (public ='t' OR $privilegeQuery)");
		}

		$count = count($albums);
		foreach ($albums as $album) {
			$level1Albums[$album['shareid']] = $album;
		}
		$levelShareId = '';
		if ($count && 'session' != $from) {
			$level1ShareId = " AND ref_shareid IN (".implode(',', array_keys($level1Albums)). ")";
		} else if ($count && 'session' == $from) {
			$level1ShareId = " AND ref_shareid IN (".implode(',', array_keys($level1Albums + $level1Password)). ")";
		} else {
			goto End;
		}

		// level 2 photo_share
		$albums = self::GetByCondition("is_subdir = 't' AND (password = '' OR password IS NULL) AND (public='t' OR $privilegeQuery) $level1ShareId;");
		$count = count($albums);
		foreach ($albums as $album) {
			$level2Albums[$album['shareid']] = $album;
		}

		$level2ShareId = '';
		if ('session' != $from && $count) {
			$level2ShareId = ' ref_shareid IN ('. implode(',', array_keys($level2Albums)). ")";

			// Rest photo_share
			$albums = self::GetByCondition($level2ShareId);
			foreach ($albums as $album) {
				$restAlbums[$album['shareid']] = $album;
			}
		}

		// level 2 password photo_share
		if ('session' == $from) {
			// get all password album in second level, remove dependency condition
			$albums = self::GetByCondition("is_subdir = 't' AND password != ''");
		} else {
			$albums = self::GetByCondition("is_subdir = 't' AND password != '' $level1ShareId");
		}

		foreach ($albums as $album) {
			$level2Password[$album['shareid']] = $album;
		}
	End:

		$result = $level1Albums + $level2Albums + $restAlbums + $level1Password + $level2Password;
		foreach ($result as $shareid => $item) {
			// skip photo in remote mount (cifs) or read-only mount (iso9660)
			if (csSYNOPhotoMisc::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$item['sharename'], $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])) {
				unset($result[$shareid]);
				continue;
			}
		}
		return $result;
	}

	public static function EditAlbumPermission($album_type, $share_ids) {
		if (0 === count($share_ids)) {
			return true;
		}
		PHOTO_DB_BeginTransaction();
		$fail = false;

		if ('password' === $album_type) {
			$tmpArray = Array();
			foreach ($share_ids as $item) {
				$tmpArray[] = $item['id'];
			}
			$id_string = join("," , $tmpArray);
		} else {
			$id_string = join(",", $share_ids);
		}

		//bug4146: Must clear the ACL before setting up the album's type
		if ($id_string) {
			$access_query = "DELETE FROM " . PHOTO_ACCESS_RIGHT_TABLE . " WHERE shareid IN (".$id_string.")";
			$upload_query = "DELETE FROM " . PHOTO_UPLOAD_RIGHT_TABLE . " WHERE shareid IN (".$id_string.")";
			$manage_query = "DELETE FROM " . PHOTO_MANAGE_RIGHT_TABLE . " WHERE shareid IN (".$id_string.")";
			$group_query = "DELETE FROM ". PHOTO_GROUP_PERMISSION_TABLE . " WHERE shareid IN (".$id_string.")";
			$fail = !PHOTO_DB_Query($access_query) || !PHOTO_DB_Query($upload_query) || !PHOTO_DB_Query($manage_query) || !PHOTO_DB_Query($group_query) || $fail;
			if ($fail) {
				goto End;
			}
		}

		if('public' === $album_type) {
			$query = "UPDATE photo_share SET public='t', password = '' WHERE shareid IN (".$id_string.")";
			$fail = !PHOTO_DB_Query($query) || $fail;

		} else if ('private' === $album_type) {
			$query = "UPDATE photo_share SET public='f', password = '' WHERE shareid IN (".$id_string.")";
			$fail = !PHOTO_DB_Query($query) || $fail;

		} else if('password' === $album_type) {
			foreach ($share_ids as $item) {
				$query = "UPDATE photo_share SET public='f'";
				$params = array($item['id']);
				if (null !== $item['password']) {
					$query .= ", password = ?";
					array_unshift($params, md5($item['password']));
				}
				$query .= " WHERE shareid = ?";
				$fail = !PHOTO_DB_Query($query, $params) || $fail;
				if ($fail) {
					goto End;
				}
			}
		}

	End:
		if ($fail) {
			PHOTO_DB_RollBack();
			return false;
		}
		PHOTO_DB_Commit();
		return true;
	}

	public static function DeleteOneBySharename($sharename) {
		if (self::IsRootSharename($sharename)) {
			return array(false, "invalid name");
		}

		$shareid = -1;
		$query = "SELECT shareid FROM photo_share WHERE sharename =?";
		$result = PHOTO_DB_Query($query, array($sharename));

		if (!$result) {
			return array(false);
		}
		$row = PHOTO_DB_FetchRow($result);

		if (!$row) {
			return array(false, "no data");
		}

		$shareid = $row['shareid'];

		$path  = SYNOPHOTO_SERVICE_REAL_DIR_PATH.$sharename;
		$real_path  = SYNOPHOTO_SERVICE_REAL_DIR.'/'.$sharename;

		$escape = PHOTO_DB_GetEscape();

		//delete from photo_share, directory
		$query = 'DELETE FROM photo_share WHERE sharename LIKE ? '.$escape." OR sharename=?";
		$sqlParamName = array(PHOTO_DB_EscapForLike($sharename).'/%', $sharename);
		PHOTO_DB_Query($query, $sqlParamName);

		PHOTO_DB_Query('DELETE FROM ' . PHOTO_ACCESS_RIGHT_TABLE . ' WHERE shareid=?', array($shareid));
		PHOTO_DB_Query('DELETE FROM ' . PHOTO_UPLOAD_RIGHT_TABLE . ' WHERE shareid=?', array($shareid));

		//delete photo, video in album
		File::DeleteItemsInAlbum($sharename);

		if (file_exists($real_path)) {
			//@exec(SYNO_PHOTOIO ." -D ".escapeshellarg($real_path));
			csSYNOPhotoMisc::ExecCmd(SYNO_PHOTOIO, array('-D', $real_path));
			//@exec("/usr/syno/bin/synoindex -D -p PhotoStation".escapeshellarg($real_path));
			csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-p', 'PhotoStation', '-D', $real_path));
		}
		return array(true);
	}

	public static function IsRootSharename($sharename) {
		return in_array($sharename, array('', '/', '.'), true);
	}

	private static function GetByCondition ($condition, $param = array()) {
		$query = "SELECT * FROM photo_share WHERE $condition";

		$result = PHOTO_DB_Query($query, $param);
		if (!$result) {
			return array();
		}
		$shares = array();
		while (($row = $result->fetch())) {
			foreach($row as $key => $value) {
				if(in_array($key, array('is_subdir', 'public', 'conversion', 'comment'))) {
					$row[$key] = PHOTO_DB_IsTrue($value);
				} else if (in_array($key, array('sharename', 'title', 'description'))) {
					$row[$key] = iconv('UTF-8', 'UTF-8//TRANSLIT', $value)."";
				}
			}
			$shares[] = $row;
		}
		return $shares;
	}

	public static function HasItem($sharename, $item_sharename) {
		$basename = pathinfo($item_sharename, PATHINFO_BASENAME);

		$query = "SELECT '1' FROM photo_share WHERE sharename = ?";
		$result = PHOTO_DB_Query($query, array("$sharename/$basename"));

		if (!$result) {
			return false;
		}

		$row = $result->fetch();
		if ($row[0]) {
			return true;
		}
		return false;
	}

	public static function FilterPasswordAlbum($ids) {
		$output = array();
		if (!count($ids)) {
			return $output;
		}
		$query = "SELECT shareid FROM photo_share WHERE shareid IN (".csSYNOPhotoDB::GetArrayQueryPlaceholder($ids).") AND (password IS NULL OR password = '')";
		$result = PHOTO_DB_Query($query, $ids);
		if (!$result) {
			return $output;
		}
		while (($row = $result->fetch())) {
			$output[] = $row['shareid'];
		}
		return $output;
	}
}

