<?php

class Category {
	private static $categoryBoolField = array('hidden');

	public static function Add ($name, $hidden = false)
	{
		// get max order number
		$row = csSYNOPhotoDB::GetDBInstance()->GetFieldByKeyValue('max(order_number)', 'category');
		$newOrderNumber = $row[0]+1;

		$mtime = date('Y-m-d G:i:s');
		$query = "INSERT INTO category (name, hidden, order_number, create_date, modify_date) VALUES (?,?,?,?,?)";
		$result = PHOTO_DB_Query($query, array($name, PHOTO_DB_ConvertBool($hidden), $newOrderNumber, $mtime, $mtime));
		if (!$result) {
			return false;
		}
		// get inserted category id
		$id = PHOTO_DB_lastInsertId('category_id_seq');

		return $id;
	}

	public static function GetByIds ($ids)
	{
		if (!$ids) {
			return array();
		}

		$str = implode(',', array_fill(0, count($ids), '?'));
		$query = "SELECT * FROM category WHERE id in ($str)";
		$result = PHOTO_DB_Query($query, $ids);

		if (!$result) {
			return false;
		}

		$res = array();
		while (($row = $result->fetch())) {
			foreach ($row as $key => $value) {
				if (in_array($key, self::$categoryBoolField)) {
					$row[$key] = PHOTO_DB_IsTrue($value);
				}
			}
			$res[$row['id']] = $row;
		}
		return $res;
	}

	public static function DeleteByIds ($ids)
	{
		if (!$ids) {
			return 0;
		}

		$str = implode(',', array_fill(0, count($ids), '?'));
		$query = "DELETE FROM category WHERE id in ($str)";
		$result = PHOTO_DB_Query($query, $ids);
		if (false == $result) {
			return false;
		}
		return PHOTO_DB_AffectedRows($result);
	}

	public static function EditById ($id, $name = NULL, $hidden = NULL, $order_number = NULL)
	{
		if (('' === $name || NULL === $name) && NULL === $hidden && NULL === $order_number) {
			return 0;
		}
		$now = new DateTime();
		$updateFields = array('modify_date=?');
		$updateValues = array($now->format('Y-m-d G:i:s'));

		if ('' !== $name && NULL !== $name) {
			$updateFields[] = "name=?";
			$updateValues[] = $name;
		}

		if (NULL !== $hidden) {
			$updateFields[] = "hidden=?";
			$updateValues[] = PHOTO_DB_ConvertBool($hidden);
		}

		if (NULL !== $order_number) {
			$updateFields[] = "order_number=?";
			$updateValues[] = $order_numebr;
		}

		$query = "UPDATE category SET ". implode(',', $updateFields) ." WHERE id = ?";
		$db_result = PHOTO_DB_Query($query, array_merge($updateValues, array($id)));
		if (false === $db_result) {
			return false;
		}
		return PHOTO_DB_AffectedRows($db_result);
	}

	public static function ListItem($offset = false, $limit = false, $isAdmin = false)
	{
		if (false === $isAdmin) {
			$condition = "WHERE hidden='f'";
		}

		if (false === $offset || false === $limit) {
			$query = "SELECT * FROM category {$condition} ORDER BY order_number";
		} else {
			$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);
			$query = "SELECT * FROM category {$condition} ORDER BY order_number ASC $limitOffsetString";
		}
		$dbResult = PHOTO_DB_Query($query);

		$result = array();
		while($row = $dbResult->fetch()) {
			foreach ($row as $key => $value) {
				if (in_array($key, self::$categoryBoolField)) {
					$row[$key] = PHOTO_DB_IsTrue($value);
				}
			}
			$result[] = $row;
		}
		return $result;
	}

	// For Edit
	public static function isDuplicated ($id, $name)
	{
		$query = "SELECT '1' FROM category WHERE id != ? AND name = ? LIMIT 1";
		$result = PHOTO_DB_Query($query, array($id, $name));
		if (false == $result) {
			return false;
		}
		$row = $result->fetch();
		if ($row[0]) {
			return true;
		}
		return false;
	}

	// For Create new category
	public static function CheckNameExists ($name)
	{
		$query = "SELECT '1' FROM category WHERE name = ? LIMIT 1";
		$result = PHOTO_DB_Query($query, array($name));
		if (false == $result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($result);
		if ($row[0]) {
			return true;
		}
		return false;
	}

	public static function HasItem ($categoryId, $item_type, $item_id)
	{
		switch ($item_type) {
		case 'album':
			$item_cond = "type = 'album' AND album_id = ?";
			break;
		case 'smart':
			$item_cond = "type = 'smart' AND smart_id = ?";
			break;
		case 'tag':
			$item_cond = "type = 'tag' AND tag_id = ?";
			break;
		default:
			return false;
			break;
		}
		$query = "SELECT '1' FROM category_items WHERE category_id = ? AND $item_cond";

		$result = PHOTO_DB_Query($query, array($categoryId, $item_id));

		if (!$result) {
			return false;
		}

		$row = $result->fetch();
		if ($row[0]) {
			return true;
		}
        return false;
	}
}
