<?php

require_once(dirname(__FILE__).'/file.php');
require_once(dirname(__FILE__).'/slideshow_music.php');

class DsmShare {
	const OVERWRITE = 'overwrite';
	const IGNORE = 'ignore';
	const RENAME = 'rename';

	private static $get_share_cmd = '/usr/syno/bin/synophoto_dsm_user --getshare %s';
	private static $list_file_cmd = '/usr/syno/bin/synophoto_dsm_user --listshare %s %s %s';

	public static $allowTypes = array('folder', 'photo', 'video', 'music');

	public static function ListItem ($user, $share, $types, $offset = 0, $limit = NULL)
	{
		if (!$share) {
			$data = self::GetDSMShare($user);
		} else {
			$dir = array();
			$filtered = array();
			if (in_array('folder', $types)) {
				$dir = self::GetFiles($user, $share, 'dir');
			}
			if (in_array('video', $types) || in_array('photo', $types) || in_array('music', $types)) {
				$files = self::GetFiles($user, $share, 'file');

				foreach ($files as $file) {
					if(in_array($file['type'], $types)) {
						$filtered[] = $file;
					}
				}
			}

			$data = array_merge($dir, $filtered);
		}
		return array('data' => array_slice($data, $offset, $limit, true),
					 'total' => count($data));
	}

	public static function CopyItem ($user, $list, $dest, $duplicate)
	{
		if ('' !== $dest) {
			$dest = trim($dest, '/') . "/";
		} else {
			// root album
			$dest = '';
		}

		$files = array();
		$result = array();
		foreach ($list as $file) {
			$info = pathinfo($file);
			$destPath = SYNOPHOTO_SERVICE_REAL_DIR.'/'.$dest.$info['basename'];
			$dbPath = SYNOPHOTO_SERVICE_REAL_DIR_PATH.$dest.$info['basename'];

			if (file_exists($destPath)) {
				if (self::IGNORE === $duplicate) {
					continue;
				} else if (self::RENAME === $duplicate) {
					$path_info = pathinfo($destPath);
					$suffix = 0;
					$rename_path = $destPath;
					while (file_exists($rename_path)) {
						$rename_path = sprintf("%s/%s_%d.%s", $path_info['dirname'], $path_info['filename'], ++$suffix, $path_info['extension']);
					}
					$destPath = $rename_path;
					$dbPath = SYNOPHOTO_SERVICE_REAL_DIR_PATH. $dest.$info['filename']."_$suffix.".$path_info['extension'];
				} else {
					// $duplicate === 'overwrite'
					File::DeleteFileByPath($destPath, $dbPath);
				}
			}

			$dest_info = pathinfo($destPath);

			$res = File::Copy($user, $file, $destPath);

			if (!$res) {
				$result[] = 0;
				continue;
			}

			File::AddFile($dbPath, $destPath);
			$result[] = 1;
		}
		$count = 0;
		foreach ($result as $k) {
			if ($k) {
				$count++;
			}
		}

		return $count ? (count($result) ===  $count ? 1 : 2): 0;
	}

	private static function GetDSMShare ($user)
	{
		$res = array();

		//@exec(sprintf(self::$get_share_cmd, escapeshellarg($user)),  $output);
		$output = '';
		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--getshare', $user), false, $output);

		foreach($output as $line) {
			$data = explode("\t", $line);

			if (2 > count($data)) {
				continue;
			}

			$name = trim($data[0]);
			if ("photo" == strtolower($name) && 'root' == SYNOPHOTO_ADMIN_USER) {
				continue;
			}
			$item = array(
				'id' => trim($data[1]),
				'name' => $name,
				'type' => 'folder'
			);
			$res[] = $item;
		}
		return $res;
	}

	private static function GetFiles($user, $share, $type)
	{
		$share = rtrim($share, "/");

		$res = array();
		//@exec(
		//	sprintf(self::$list_file_cmd, escapeshellarg($user), escapeshellarg($share), $type),
		//	$output
		//);
		$output = '';
		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--listshare', $user, $share, $type), false, $output);

		if ('file' === $type) {
			foreach($output as $line) {
				$line = rtrim($line);
				$id = $share.'/'.$line;

				if (csSYNOPhotoMisc::IsPhotoFile($id)) {
					$fileType = 'photo';
				} else if (csSYNOPhotoMisc::IsVideoFile($id)) {
					$fileType = 'video';
				} else if (csSYNOPhotoMisc::IsMusicFile($id)) {
					$fileType = 'music';
				} else {
					continue;
				}

				$item = array(
					'id' => $id,
					'name' => $line,
					'type' => $fileType
				);
				$res[] = $item;
			}
		} else if ('dir' === $type) {
			foreach($output as $line) {
				$line = rtrim($line);
				if (csSYNOPhotoMisc::IsSkipDir($line)) {
					continue;
				}
				$id = $share.'/'.$line;

				if (rtrim(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX,"/") === $id) {
					continue;
				}

				$item = array(
					'id' => $id,
					'name' => $line,
					'type' => 'folder'
				);
				$res[] = $item;
			}
		}

		usort($res, function($a, $b) {
			return strnatcasecmp($a['id'], $b['id']);
		});
		return $res;
	}
}

?>
