<?php
require_once(dirname(__FILE__).'/syno_defines.php');

class File {
	public static function AddFile($dbPath, $fullPath, $title = "", $description = "", $disabled = NULL, $shareid = NULL, $privilege_shareid = NULL)
	{
		$blDisabled = NULL === $disabled ? csSYNOPhotoMisc::IsExcludeFormats($dbPath) : $disabled;

		if (!$shareid  || !$privilege_shareid) {
			list($shareid, $privilege_shareid) = csSYNOPhotoDB::GetDBInstance()->getShareIdByPath($dbPath);
		}

		if (csSYNOPhotoMisc::IsPhotoFile($dbPath)) {
			self::AddPhoto($dbPath, $fullPath, $title, $description, $disabled, $shareid, $privilege_shareid);
		} elseif (csSYNOPhotoMisc::IsVideoFile($dbPath)) {
			self::AddVideo($dbPath, $fullPath, $title, $description, $disabled, $shareid, $privilege_shareid);
		}

		self::DoIndex($fullPath);
	}

	public static function AddPhoto($dbPath, $fullPath, $title, $description, $disabled, $shareid, $privilege_shareid)
	{
		list($width, $height) = @getimagesize($fullPath);

		$pathinfo = pathinfo($dbPath);

		$updateValues = array(
			'name'			=> $pathinfo['basename'],
			'title'			=> $title ? $title : $pathinfo['filename'],
			'description'	=> $description,
			'size'			=> filesize($fullPath),
			'resolutionx'	=> $width,
			'resolutiony'	=> $height,
			'disabled'		=> $disabled ? 't' : 'f',
			'shareid'		=> $shareid,
			'privilege_shareid'=> $privilege_shareid
		);

		if (self::CheckPhotoExists($dbPath)) {
			$query = "UPDATE photo_image SET name=?, title=?, description=?, size=?, resolutionx=?, resolutiony=?, disabled=?, shareid=?, privilege_shareid=? WHERE path=?";
		} else {
			$query = "INSERT INTO photo_image (name, title, description, size, resolutionx, resolutiony, disabled, shareid, privilege_shareid, path) VALUES (?,?,?,?,?,?,?,?,?,?)";
		}
		$sqlParam = array_merge(array_values($updateValues), array($dbPath));

		$result = PHOTO_DB_Query($query, $sqlParam);

		if (!$result) {
			return false;
		}

		if ($description) {
			self::UpdateDescriptionMetadata($fullPath, $description);
		}
		// get inserted image id
		$id = PHOTO_DB_lastInsertId('photo_image_id_seq');

		self::ExtractPreview($fullPath);
		return $id;
	}

	public static function AddVideo($dbPath, $fullPath, $title, $description, $disabled, $shareid, $privilege_shareid)
	{
		PHOTO_DB_BeginTransaction();
		$pathinfo = pathinfo($dbPath);

		$updateTitle = $title ? $title : $pathinfo['filename'];
		$updateValues = array(
			'title'			=> $updateTitle,
			'disabled'		=> $disabled ? 't' : 'f',
			'shareid'		=> $shareid,
			'privilege_shareid'=> $privilege_shareid
		);

		$videoDescUpdateValues = array(
			'title'			=> $updateTitle,
			'description'	=> $description
		);

		if (self::CheckVideoExists($dbPath)) {
			$query = "UPDATE video SET title=?, disabled=?, shareid=?, privilege_shareid=? WHERE path=?";
		} else {
			$query = "INSERT INTO video (title, container_type, disabled, shareid, privilege_shareid, path) VALUES (?,'',?,?,?,?)";
		}

		$sqlParam = array_merge(array_values($updateValues), array($dbPath));
		$result = PHOTO_DB_Query($query, $sqlParam);

		if (!$result) {
			PHOTO_DB_RollBack();
			return false;
		}

		if (self::CheckVideoDescExists($dbPath)) {
			$query = "UPDATE video_desc SET title=?, description=? WHERE path=?";
		} else {
			$query = "INSERT INTO video_desc (title, description, path) VALUES (?,?,?)";
		}

		$sqlParam = array_merge(array_values($videoDescUpdateValues), array($dbPath));
		$result = PHOTO_DB_Query($query, $sqlParam);

		if (!$result) {
			PHOTO_DB_RollBack();
			return false;
		}

		PHOTO_DB_Commit();

		// get inserted image id
		$id = PHOTO_DB_lastInsertId('video_id_seq');

		return $id;
	}

	public static function UpdateDescriptionMetadata($path, $description)
	{
		if (self::IsExiv2SupportWriteMode($path)) {
			csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
				'-M', 'set Xmp.dc.description ' . $description,
				'-M', 'set Xmp.photoshop.headline ' . $description,
				'-M', 'set Iptc.Application2.Caption ' . $description,
				'-M', 'set Exif.Image.ImageDescription ' . $description,
				$path));
			csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-P', 'SynologyMoments', '-R', $path));
		}

		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--updatethumbnailmtime', $path));
	}

	public static function UpdateRatingMetadata($path, $rating)
	{
		if ($rating >= 5) {
			$ratingPercent = 99;
		} else if ($rating > 1) {
			$ratingPercent = ($rating - 1) * 25;
		} else if ($rating == 1) {
			$ratingPercent = $rating;
		} else {
			$ratingPercent = 0;
		}

		if (self::IsExiv2SupportWriteMode($path)) {
			csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
				'-M', 'set Exif.Image.Rating ' . $rating,
				'-M', 'set Exif.Image.RatingPercent ' . $ratingPercent,
				'-M', 'set Xmp.xmp.Rating ' . $rating,
				'-M', 'set Xmp.xmp.RatingPercent ' . $ratingPercent,
				'-M', 'set Xmp.MicrosoftPhoto.Rating ' . $ratingPercent,
				$path));
			csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--updatethumbnailmtime', $path));
		} else {
			$eaDir = '';

			SYNOPhotoEA::createEADir($path, $eaDir);
			$ratingFilePath = sprintf("%s/%s", $eaDir, SYNOPhotoEA::getFilename(SYNOPhotoEA::FILE_RATING));

			@file_put_contents($ratingFilePath, json_encode(array('rating' => $rating)));
			@chmod($ratingFilePath, 0777);
		}
	}

	function IsExiv2SupportWriteMode($filePath)
	{
		global $SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT;
		$ext = strtolower(pathinfo($filePath, PATHINFO_EXTENSION));
		if (!in_array($ext, $SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT)) {
			return false;
		}

		return true;
	}


	/*
	 *	The conditions of photo, video include
	 *		date_begin: string,
	 *		date_end:	string,
	 *		sharename:	string,
	 *		gps:		boolean,
	 *		labels:		array of label ids
	 *
	 * */
	private static function GetQueryByConditions ($hasPhoto, $hasVideo, $conditions = array(), $extraFields = array())
	{
		// init variables
		$sqlParam = $photoSqlParam = $videoSqlParam = $photoConditions = $videoConditions = array();
		$escape = PHOTO_DB_GetEscape();

		if ($conditions['date_begin']) {
			if ('1970-01-01' === $conditions['date_begin']){
				$photoConditions[] = "(photo_image.timetaken IS NULL OR date(photo_image.timetaken) >= '{$conditions['date_begin']}')";
				$videoConditions[] = "(video.mdate IS NULL OR date(video.mdate) >= '{$conditions['date_begin']}')";
			} else {
				$photoConditions[] = "(date(photo_image.timetaken) >= '{$conditions['date_begin']}')";
				$videoConditions[] = "(date(video.mdate) >= '{$conditions['date_begin']}')";
			}
		}
		if ($conditions['date_end']) {
			if ('1970-01-01' === $conditions['date_end']) {
				$photoConditions[] = "(photo_image.timetaken IS NULL OR date(photo_image.timetaken) <= '{$conditions['date_end']}')";
				$videoConditions[] = "(video.mdate IS NULL OR date(video.mdate) <= '{$conditions['date_end']}')";
			} else {
				$photoConditions[] = "(date(photo_image.timetaken) <= '{$conditions['date_end']}')";
				$videoConditions[] = "(date(video.mdate) <= '{$conditions['date_end']}')";
			}
		}
		if ('/' !== $conditions['sharename']) {
			$dbPathPrefix = SYNOPHOTO_SERVICE_REAL_DIR_PATH.$conditions['sharename'];
			$photoConditions[] = "(photo_image.path LIKE ? $escape)";
			$videoConditions[] = "(video.path LIKE ? $escape)";
			$photoSqlParam[] = PHOTO_DB_EscapForLike("$dbPathPrefix")."/%";
			$videoSqlParam[] = PHOTO_DB_EscapForLike("$dbPathPrefix")."/%";
		}

		if ($conditions['labels'] && count($conditions['labels'])) {
			$photoConditions[] = " photo_image.id IN (SELECT photo_image_label.image_id FROM photo_image_label ".
								 " LEFT JOIN photo_image ON photo_image_label.image_id = photo_image.id ".
								 " WHERE label_id IN (".implode(',', $conditions['labels']).") AND status = 't')";
			$videoConditions[] = " video.path IN (SELECT photo_video_label.video_path FROM photo_video_label ".
								 " LEFT JOIN video ON  photo_video_label.video_path = video.path ".
								 " WHERE label_id IN (".implode(",", $conditions['labels'])."))";
		}

		if ($conditions['gps']) {
			$photoConditions[] = "photo_image.gps <> ''";
			$videoConditions[] = "video.gps <> ''";
		}

		if ($conditions['bounds']) {
			$bounds = $conditions['bounds'];
			$neLat = $bounds['ne']['lat'];
			$neLng = $bounds['ne']['lng'];
			$swLat = $bounds['sw']['lat'];
			$swLng = $bounds['sw']['lng'];
			$latCondition = $swLat > $neLat ? "((photo_image.lat <= $neLat AND photo_image.lat <= $swLat) OR (photo_image.lat >= $neLat AND photo_image.lat >= $swLat))" : "(photo_image.lat >= $swLat AND photo_image.lat <= $neLat)";
			$lngCondition = $swLng > $neLng ? "((photo_image.lng <= $neLng AND photo_image.lng <= $swLng) OR (photo_image.lng >= $neLng AND photo_image.lng >= $swLng))" : "(photo_image.lng >= $swLng AND photo_image.lng <= $neLng)";
			$photoConditions[] = "$latCondition AND $lngCondition";
		}

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat();
		if (!$albumCondition['albumCond']) {
			return false;
		}
		$photoConditions[] = $albumCondition['albumCond'];
		$photoSqlParam = array_merge($photoSqlParam, $albumCondition['sqlParam']);

		$videoConditions[] = $albumCondition['albumCond'];
		$videoSqlParam = array_merge($videoSqlParam, $albumCondition['sqlParam']);

		$extra = "";
		if (count($extraFields)) {
			$extra = ",". implode(',', $extraFields);
		}

		if ($hasPhoto && $hasVideo) {
			$query = "SELECT path, timetaken as takendate, name as filename, create_time as createdate, 'photo' as type $extra ".
					 " FROM photo_image WHERE ".implode(" AND ", $photoConditions).
					 " UNION ALL ".
					 "SELECT path, mdate as takendate, title as filename, date as createdate, 'video' as type $extra ".
					 " FROM video WHERE ".implode(" AND ", $videoConditions). " ";
			$sqlParam = array_merge($photoSqlParam, $videoSqlParam);

		} else if ($hasPhoto) {
			$query = "SELECT path, timetaken as takendate, name as filename, create_time as createdate, 'photo' as type $extra".
					 " FROM photo_image WHERE ".implode(" AND ", $photoConditions). " ";
			$sqlParam = $photoSqlParam;

		} else if ($hasVideo) {
			$query = "SELECT path, mdate as takendate, title as filename, date as createdate, 'video' as type $extra".
				     " FROM video WHERE ".implode(" AND ", $videoConditions). " ";
			$sqlParam = $videoSqlParam;

		} else {
			return false;
		}

		return array(
			'query'		=> $query,
			'params'	=> $sqlParam
		);
	}

	public static function ListItems ($hasPhoto, $hasVideo, $conditions, $sort_by, $sort_direction, $limit = -1, $offset = 0)
	{
		// init variables
		$items = array('total' => 0, 'items' => array());
		$idx = $offset;

		$order = "";
		if ($sort_by && $sort_direction) {
			$order = " ORDER BY $sort_by $sort_direction, path ASC";
		}

		$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);

		$query_params = self::GetQueryByConditions($hasPhoto, $hasVideo, $conditions);

		if (false === $query_params) {
			goto End;
		}

		$query = $query_params['query'];
		$sqlParam = $query_params['params'];

		/* get total count */
		$result = PHOTO_DB_Query("SELECT count(*) FROM ($query) as totalCount ", $sqlParam);
		if (!$result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($result);
		$total = $row[0] + 0;

		/* get total items */
		$result = PHOTO_DB_Query($query." $order $limitOffsetString", $sqlParam);
		if (!$result) {
			return false;
		}

		$list = array();
		$itemKeys = array('photo' => array(), 'video' => array());
		while (($row = $result->fetch())) {
			$row['pos'] = $idx++;
			$itemKeys[$row['type']][] = $row['path'];
			$list[$row['path']] = $row;
		}

		$itemObjs = array(
			'photo' => self::GetPhotoByDBPath(array_values($itemKeys['photo'])),
			'video' => self::GetVideoByDBPath(array_values($itemKeys['video']))
		);

		$objs = array();
		foreach ($list as $key => $value) {
			$obj = $itemObjs[$value['type']][$key];
			$obj['pos'] = $value['pos'];
			$objs[] = $obj;
		}
		$items = array(
			'total'	=> $total,
			'items'	=> $objs
		);
	End:
		return $items;
	}

	public static function GetGroupParams($zoom)
	{
		if (5 >= $zoom) {
			$params = array(1, 1);
		} else if (7 >= $zoom) {
			$params = array(0.5, 2);
		} else if (9 >= $zoom) {
			$params = array(0.1, 2);
		} else if (11 >= $zoom) {
			$params = array(0.05, 3);
		} else if (13 >= $zoom) {
			$params = array(0.01, 3);
		} else if (15 >= $zoom) {
			$params = array(0.005, 4);
		} else if (17 >= $zoom) {
			$params = array(0.001, 4);
		} else if (19 >= $zoom) {
			$params = array(0.0005, 5);
		} else {
			$params = array(0.00005, 6);
		}
		return $params;
	}

	public static function ListGPSGroup ($sharename, $labels, $bounds, $zoom = 5, $hasPhoto = true, $hasVideo = false)
	{
		// init variables
		$items = array('total' => 0, 'items' => array());
		$simpleBounds = false;
		list($degree, $precision) = self::GetGroupParams($zoom);

		// search whole world if zoom is below than 5
		if (5 < $zoom) {
			$simpleBounds = array(
				'ne'	=> array(
					'lat' => round($bounds['ne']['lat'], $precision),
					'lng' => round($bounds['ne']['lng'], $precision)
				),
				'sw'	=> array(
					'lat' => round($bounds['sw']['lat'], $precision),
					'lng' => round($bounds['sw']['lng'], $precision)
				)
			);
		}

		// TODO: array('*') means get all fields of photo_image
		// if hasVideo = true, this query will be crashed

		$query_params = self::GetQueryByConditions($hasPhoto, $hasVideo, array(
			'sharename'	 => $sharename,
			'labels'	 => $labels,
			'gps'		 => true,
			'bounds'	 => $simpleBounds
		), array('*'));

		if (false === $query_params) {
			goto End;
		}

		$query = $query_params['query']. " ORDER BY id";
		$sqlParam = $query_params['params'];

		/* get total items */
		$result = PHOTO_DB_Query($query, $sqlParam);
		if (!$result) {
			return false;
		}

		// grouping and filtering
		$grids = array();
		while (($item = $result->fetch())) {
			$latIdx = round($item['lat'] / $degree);
			$lngIdx = round($item['lng'] / $degree);

			if (!$grids["$latIdx,$lngIdx"]) {
				$grids["$latIdx,$lngIdx"] = array(
					'gps_idx' => array('lat' => $latIdx, 'lng' => $lngIdx, 'zoom' => $zoom),
					'count'	=> 0,
					'item'	=> self::FormatDBData($item)
				);
			}
			$grids["$latIdx,$lngIdx"]['count']++;
		}
		$items = array('total' => count($grids), 'groups' => $grids);
	End:
		return $items;
	}

	public static function ListGPSGroupedItems ($sharename, $labels, $idx, $zoom, $limit, $offset, $hasPhoto = true, $hasVideo = false)
	{
		list($degree, $precision) = self::GetGroupParams($zoom);

		$maxLat = ($idx['lat'] + 0.5) * $degree - 0.000001;
		$minLat = ($idx['lat'] - 0.5) * $degree;

		$maxLng = ($idx['lng'] + 0.5) * $degree - 0.000001;
		$minLng = ($idx['lng'] - 0.5) * $degree;

		$query_params = self::GetQueryByConditions($hasPhoto, $hasVideo, array(
			'sharename'	 => $sharename,
			'labels'	 => $labels,
			'gps'		 => true,
			'bounds'	 => array(
				'ne' => array(
					'lat' => $maxLat,
					'lng' => $maxLng
				),
				'sw' => array(
					'lat' => $minLat,
					'lng' => $minLng
				)
			)
		), array('*'));

		if (false === $query_params) {
			goto End;
		}

		$query = $query_params['query'];
		$sqlParam = $query_params['params'];

		/* get total count */
		$result = PHOTO_DB_Query("SELECT count(*) FROM ($query) as totalCount ", $sqlParam);
		if (!$result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($result);
		$total = $row[0] + 0;

		$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);
		$query = $query_params['query']." ORDER BY id $limitOffsetString";

		/* get total items */
		$result = PHOTO_DB_Query($query, $sqlParam);
		if (!$result) {
			return false;
		}

		$objs = array();
		while (($item = $result->fetch())) {
			$obj = self::FormatDBData($item);
			$objs[] = $obj;
		}
	End:
		return array('items' => $objs, 'total' => $total);
	}

	public static function ListFeatured ($date_begin, $date_end, $sharename, $count, $labelConditions, $hasPhoto = true, $hasVideo = true)
	{
		// init variables
		$items = array('total' => 0, 'items' => array());

		$query_params = self::GetQueryByConditions($hasPhoto, $hasVideo, array(
			'date_begin' => $date_begin,
			'date_end'	 => $date_end,
			'sharename'	 => $sharename,
			'labels'	 => $labelConditions));

		if (false === $query_params) {
			goto End;
		}

		$query = $query_params['query'];
		$sqlParam = $query_params['params'];

		/* get total count */
		$result = PHOTO_DB_Query("SELECT count(*) FROM ($query) as totalCount ", $sqlParam);
		if (!$result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($result);
		$total = $row[0] + 0;

		/* get total items */
		$result = PHOTO_DB_Query($query. " ORDER BY takendate ASC, path ASC ", $sqlParam);

		if (!$result) {
			return false;
		}

		$interval = $count > 0 && $total > $count ? round($total / $count): 1;
		$list = array();
		$itemKeys = array('photo' => array(), 'video' => array());
		$idx = -1;
		while (($row = $result->fetch())) {
			if ($count > 0 && count($list) > $count) {
				break;
			}
			if ((++$idx % $interval)) {
				continue;
			}
			$item = $row;
			$item = array(
				'path'	=> $row['path'],
				'type'	=> $row['type'],
				'pos'	=> $idx
			);
			$itemKeys[$row['type']][] = $row['path'];
			$list[$row['path']] = $item;
		}
		$itemObjs = array(
			'photo' => self::GetPhotoByDBPath(array_values($itemKeys['photo'])),
			'video' => self::GetVideoByDBPath(array_values($itemKeys['video']))
		);

		$objs = array();
		foreach ($list as $key => $value) {
			$obj = $itemObjs[$value['type']][$key];
			$obj['pos'] = $value['pos'];
			$obj['type'] = $value['type'];
			$objs[] = $obj;
		}

		$items = array('total' => $total, 'items' => $objs);
	End:
		return $items;
	}

	// csSYNOPhotoAlbum::GetAlbumCoverLatestUpload will cost lots of time because of db query "sort by create_time"
	// this function is used in csSYNOPhotoAlbum::GetAlbumCoverLatestUpload to avoid execution time out
	public static function GetTotalCount()
	{
		return self::GetItemCount("photo_image", "photo_count") + self::GetItemCount("video", "video_count");
	}

	private static function GetItemCount($table, $key = "")
	{
		// get total count from cache or db
		if ($key && isset($_SESSION[SYNOPHOTO_ADMIN_USER][$key])) {
			return $_SESSION[SYNOPHOTO_ADMIN_USER][$key];
		}
		$query = "SELECT count(*) as total FROM $table";

		$result = PHOTO_DB_Query($query);
		if (!$result) {
			// db query fail, won't update session value
			return SYNOPHOTO_SORT_THRESHOLD;
		}
		$row = $result->fetch();
		$_SESSION[SYNOPHOTO_ADMIN_USER][$key] = $row['total'];
		return $row['total'];
	}

	public static function FormatDBData(&$item)
	{
		if ('photo' === $item['type']) {
			// extra info for sorting
			$item['timetaken'] = $item['timetaken'];
			$item['createdate'] = $item['create_time'];
			$title = iconv('UTF-8', 'UTF-8//TRANSLIT', $item['title']);
			$item['title'] = $title ? $title : pathinfo($item['path'], PATHINFO_FILENAME);
			$item['description'] = iconv('UTF-8', 'UTF-8//TRANSLIT', $item['description'])."";
			$item['lat'] = $item['lat'] + 0;
			$item['lng'] = $item['lng'] + 0;
		} else if ('video' === $item['type']) {
			// extra info for sorting
			$item['timetaken'] = $item['mdate'];
			$item['createdate'] = $item['date'];
			$item['name'] = pathinfo($item['path'], PATHINFO_FILENAME);
			$item['title'] = iconv('UTF-8', 'UTF-8//TRANSLIT', $item['title'])."";
			$item['description'] = iconv('UTF-8', 'UTF-8//TRANSLIT', $item['description'])."";
			$item['lat'] = $item['lat'] + 0;
			$item['lng'] = $item['lng'] + 0;
		}
		return $item;
	}

	// this function doesn't need doindex, should do index in album delete action
	public static function DeleteItemsInAlbum ($sharename)
	{
		$escape = PHOTO_DB_GetEscape();
		$dbPath  = SYNOPHOTO_SERVICE_REAL_DIR_PATH.$sharename;
		$param = array(PHOTO_DB_EscapForLike($dbPath).'/%');

		//delete comment
		PHOTO_DB_Query('DELETE FROM photo_comment WHERE photo_id IN '.
					   " (SELECT id FROM photo_image WHERE path LIKE ? $escape)", $param);

		//delete photo, photo_image_label will be automatically deleted after photo removed
		PHOTO_DB_Query("DELETE FROM photo_image WHERE path LIKE ? $escape", $param);

		//delete video
		PHOTO_DB_Query("DELETE FROM video WHERE path LIKE ? $escape", $param);
		PHOTO_DB_Query("DELETE FROM video_convert WHERE video_path LIKE ? $escape", $param);
		PHOTO_DB_Query("DELETE FROM video_comment WHERE path LIKE ? $escape", $param);
		PHOTO_DB_Query("DELETE FROM video_desc WHERE path LIKE ? $escape", $param);
		PHOTO_DB_Query("DELETE FROM photo_video_label WHERE video_path LIKE ? $escape", $param);
	}

	public static function GetPhotoByDBPath($dbPathArray)
	{
		if (0 === count($dbPathArray)) {
			return array();
		}

		$str = implode(',', array_fill(0, count($dbPathArray), '?'));
		$query = "SELECT * FROM photo_image WHERE path in ($str)";
		$result = PHOTO_DB_Query($query, $dbPathArray);

		if (!$result) {
			return false;
		}

		$items = array();
		while (($row = $result->fetch())) {
			$row['type'] = 'photo';
			$items[$row['path']] = self::FormatDBData($row);
		}
		return $items;
	}

	public static function GetVideoByDBPath($dbPathArray)
	{
		if (0 === count($dbPathArray)) {
			return array();
		}

		$str = implode(',', array_fill(0, count($dbPathArray), '?'));
		$query = "SELECT * FROM video WHERE path in ($str)";
		$result = PHOTO_DB_Query($query, $dbPathArray);

		if (!$result) {
			return false;
		}

		$items = array();
		while(($row = $result->fetch())) {
			$row['type'] = 'video';
			$items[$row['path']] = self::FormatDBData($row);
		}
		return $items;
	}

	public static function Copy ($user, $from, $to)
	{
		$retval = csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--copy', $user, $from, $to));
		return (0 == $retval);
	}

	public static function CopyMusic($user, $from, $to)
	{
		$retval = csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--copy-music', $user, $from, $to));
		return (0 == $retval);
	}

	public static function DeleteFileByPath ($fullPath, $dbPath)
	{
		if (csSYNOPhotoMisc::IsPhotoFile($fullPath)) {
			//get photo id for delete comment
			$query = "SELECT id FROM photo_image WHERE path=?";
			$db_result = PHOTO_DB_Query($query, array($dbPath));
			if ($row = PHOTO_DB_FetchRow($db_result)) {
				$query = "DELETE FROM photo_image WHERE path=?";
				PHOTO_DB_Query($query, array($dbPath));
				$query ="DELETE FROM photo_comment WHERE photo_id=?";
				PHOTO_DB_Query($query, array($row[0]));
			}
		} else if (csSYNOPhotoMisc::IsVideoFile($fullPath)) {
			$queryParam = array($dbPath);
			$query = "DELETE FROM video WHERE path=?";
			PHOTO_DB_Query($query, $queryParam);
			$query = "DELETE FROM video_convert WHERE video_path=?";
			PHOTO_DB_Query($query, $queryParam);
			$query = "DELETE FROM video_comment WHERE path=?";
			PHOTO_DB_Query($query, $queryParam);
			$query = "DELETE FROM video_desc WHERE path=?";
			PHOTO_DB_Query($query, $queryParam);
			$query = "DELETE FROM photo_video_label WHERE video_path=?";
			PHOTO_DB_Query($query, $queryParam);
		}

		//@exec(SYNO_PHOTOIO ." -d ".escapeshellarg($fullPath));
		csSYNOPhotoMisc::ExecCmd(SYNO_PHOTOIO, array('-d', $fullPath));
		//@exec("/usr/syno/bin/synoindex -d ".escapeshellarg($fullPath));
		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-d', $fullPath));
	}

	public static function DoIndex ($fullPath)
	{
		//@exec("/usr/syno/bin/synoindex -a ".escapeshellarg($fullPath)." > /dev/null 2>&1");
		csSYNOPhotoMisc::ExecCmdNoOutput('/usr/syno/bin/synoindex', array('-a', $fullPath));
		//@exec(SYNO_PHOTOIO ." -a ".escapeshellarg($fullPath)." > /dev/null 2>&1");
		csSYNOPhotoMisc::ExecCmdNoOutput(SYNO_PHOTOIO, array('-a', $fullPath));
	}

	private static function ExtractPreview($fullPath)
	{
		csSYNOPhotoMisc::ExecCmdNoOutput('/usr/syno/bin/synophoto_dsm_user', array('--extractpreview', $fullPath));
	}

	private static function CheckPhotoExists($dbPath)
	{
		$query = "SELECT '1' FROM photo_image WHERE path = ? LIMIT 1";
		$result = PHOTO_DB_Query($query, array($dbPath));
		if (false == $result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($result);
		if ($row[0]) {
			return true;
		}
		return false;
	}

	private static function CheckVideoExists($dbPath)
	{
		$query = "SELECT '1' FROM video WHERE path = ? LIMIT 1";
		$result = PHOTO_DB_Query($query, array($dbPath));
		if (false == $result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($result);
		if ($row[0]) {
			return true;
		}
		return false;
	}

	private static function CheckVideoDescExists($dbPath)
	{
		$query = "SELECT '1' FROM video_desc WHERE path = ? LIMIT 1";
		$result = PHOTO_DB_Query($query, array($dbPath));
		if (false == $result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($result);
		if ($row[0]) {
			return true;
		}
		return false;
	}

	public static function GetItemIdObjectByIdString($id_string)
	{
		$dbPath = self::GetDBPathByWebAPIIdString($id_string);
		if (!$dbPath) {
			return false;
		}
		$type = explode('_', $id_string)[0];
		if ('photo' === $type) {
			return self::GetPhotoByDBPath([$dbPath])[$dbPath];
		} else {
			return self::GetVideoByDBPath([$dbPath])[$dbPath];
		}
	}

	private static function GetDBPathByWebAPIIdString($id_string)
	{
		$id_arr = explode('_', $id_string);
		if (3 !== count($id_arr) || ('photo' !== $id_arr[0] && 'video' !== $id_arr[0])) {
			return false;
		}
		$albumName = @pack('H*', $id_arr[1]);
		$fileName = @pack('H*', $id_arr[2]);
		$dbPath = SYNOPHOTO_SERVICE_REAL_DIR_PATH. ("/" === $albumName ? "" : $albumName . "/") . $fileName;
		if (!csSynoPhotoMisc::CheckPathValid($dbPath)) {
			return false;
		}
		return $dbPath;
	}

	/*
	 * ## now use in advanced_share_album list_log method
	 *
	 * GetDBPathByIdType([{'type': type , 'id': id}, {'type': type, 'id': id}])
	 *
	 * return {
	 *		'photo': {
	 *			'id': {
	 *				'path': path,
	 *				'name': name
	 *			}
	 *		},
	 *		'video': {
	 *			'id': {
	 *				'path': path,
	 *				'name': name
	 *			}
	 *		}
	 * }
	 * */
	public static function GetNameDBPathByIdType($objects)
	{
		$output = array('video' => array(), 'photo' => array());
		for ($i = 0; $i < count($objects); ++$i) {
			$item_type = $objects[$i]['type'];
			$dbId = $objects[$i]['id'];
			if (!$dbId || !in_array($item_type, array('photo', 'video'))) {
				continue;
			}
			$output[$item_type][$dbId] = $dbId;
		}
		if (($count = count($output['photo']))) {
			$mark = implode(',', array_fill(0, $count, '?'));
			$query = "SELECT id, path, name FROM photo_image WHERE id in ($mark)";
			$result = PHOTO_DB_Query($query, array_keys($output['photo']));
			while(($row = $result->fetch())) {
				$output['photo'][$row[0]] = array(
					'path' => $row['path'],
					'name' => iconv('UTF-8', 'UTF-8//IGNORE', $row['name'])
				);
			}
		}
		if (($count = count($output['video']))) {
			$mark = implode(',', array_fill(0, $count, '?'));
			$query = "SELECT id, path FROM video WHERE id in ($mark)";
			$result = PHOTO_DB_Query($query, array_keys($output['video']));
			while(($row = $result->fetch())) {
				$output['video'][$row[0]] = array(
					'path' => $row['path'],
					'name' => pathinfo($row['path'], PATHINFO_BASENAME)
				);
			}
		}
		return $output;
	}
}

?>
