<?php
require_once(dirname(__FILE__).'/syno_defines.php');

class ItemLabel {
	public static function AddImageLabel ($image_id, $label_id, $info = '')
	{
		$query = 'INSERT INTO photo_image_label (image_id, label_id, info) VALUES (?, ?, ?);';
		$sqlParam = array($image_id, $label_id, $info);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		if (false === $db_result) {
			return false;
		}

		$label = Label::GetByIds(array($label_id));

		if (Label::PEOPLE == $label[$label_id]['category'] || Label::DESC == $label[$label_id]['category']) {
			self::UpdatePhotoMetadata($image_id, $label[$label_id]['category']);
		}
		return true;
	}

	public static function AddPeopleLabel ($image_id, $label_id, $info_new = '')
	{
		$query = 'INSERT INTO photo_image_label (image_id, label_id, info_new) VALUES (?, ?, ?);';
		$sqlParam = array($image_id, $label_id, $info_new);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		if (false === $db_result) {
			return false;
		}

		self::UpdatePhotoMetadata($image_id, Label::PEOPLE);
		return true;
	}

	public static function AddVideoLabel ($dbPath, $label_id, $info='')
	{
		$query = 'INSERT INTO photo_video_label (video_path, label_id, info) VALUES (?, ?, ?);';
		$sqlParam = array($dbPath, $label_id, $info);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		if (false === $db_result) {
			return false;
		}
		return true;
	}

	public static function CheckPhotoLabelExist ($label_id, $image_id)
	{
		$query = "SELECT '1' FROM photo_image_label WHERE image_id=? AND label_id=?";
		$sqlParam = array($image_id, $label_id);
		if (false === ($db_result = PHOTO_DB_Query($query, $sqlParam))) {
			return false;
		}
		if (false === ($row = PHOTO_DB_FetchRow($db_result))) {
			return false;
		}
		if (1 > (int)$row[0]) {
			return false;
		}
		return true;
	}

	public static function CheckVideoLabelExist ($label_id, $videoPath)
	{
		$query = 'SELECT count(id) FROM photo_video_label WHERE video_path=? AND label_id=?';
		$sqlParam = array($videoPath, $label_id);
		if (false === ($db_result = PHOTO_DB_Query($query, $sqlParam))) {
			return false;
		}
		if (false === ($row = PHOTO_DB_FetchRow($db_result))) {
			return false;
		}
		if (1 !== (int)$row[0]) {
			return false;
		}
		return true;
	}

	public static function UpdateMetaData ($labels, $item_label_objs)
	{
		$needUpdateFaceData = false;
		$updateMetaData = array();

		foreach ($item_label_objs as $row) {
			$label = $labels[$row['label_id']];

			if (Label::PEOPLE == $label['category'] || Label::DESC == $label['category']) {
				self::UpdatePhotoMetadata($row['image_id'], $label['category']);
			}

			if (Label::PEOPLE == $label['category'] && !$needUpdateFaceData && $row['status'] &&
				(strstr($row['info'], "face") || strstr($row['info_new'], "face"))) {
				$needUpdateFaceData = true;
			}
		}

		if ($needUpdateFaceData) {
			self::RemoveFaceTrainingData();
		}
	}

	public static function DeleteAllById ($id, $isPhoto)
	{
		if (!$id) {
			return 0;
		}

		$item_label_objs = self::GetByIds(array($id), $isPhoto);
		$item_label = $item_label_objs[0];

		$res = self::DeleteByIds(array($id), $isPhoto);

		if (false === $res || 0 === $res) {
			return $res;
		}

		$count = self::GetCountByLabelId($item_label['label_id']);

		if ($isPhoto) {
			$label_objs = Label::GetByIds(array($item_label['label_id']));
			self::UpdateMetaData($label_objs, $item_label_objs);
		}

		if (0 === $count) {
			Label::DeleteByIds(array($item_label['label_id']));
		}
		return $res;
	}

	public static function DeleteByLabelIdItemId ($label_ids, $item_key, $isPhoto)
	{
		$rows = self::GetAllByItemKeyLabelId($item_key, $label_ids, $isPhoto);
		foreach ($rows as $row) {
			$res = self::DeleteByIds(array($row['id']), $isPhoto);
			if (false === $res || 0 === $res) {
				return false;
			}
			if ($isPhoto) {
				$label_objs = Label::GetByIds(array($row['label_id']));
				self::UpdateMetaData($label_objs, $rows);
			}
		}
		return true;
	}

	static function DeleteByIds ($ids, $isPhoto)
	{
		$count = count($ids);
		if (0 == $count) {
			return 0;
		}
		$id_string = implode(',', array_fill(0, $count, '?'));

		if ($isPhoto) {
			$query = "DELETE FROM photo_image_label WHERE id IN ($id_string)";
		} else {
			$query = "DELETE FROM photo_video_label WHERE id IN ($id_string)";
		}

		$db_result = PHOTO_DB_Query($query, $ids);
		if (false == $db_result) {
			return false;
		}
		return PHOTO_DB_AffectedRows($db_result);
	}

	static function DeleteByLabelIds ($label_ids)
	{
		$label_tables = array('photo_image_label', 'photo_video_label');
		$res = 0;
		$count = count($label_ids);

		if(0 == $count) {
			return $res;
		}

		$id_string = implode(',', array_fill(0, $count, '?'));

		foreach($label_tables as $table) {
			$query = "DELETE FROM $table WHERE label_id IN ($id_string)";
			$db_result = PHOTO_DB_Query($query, $label_ids);
			$res += PHOTO_DB_AffectedRows($db_result);
		}
		return $res;
	}

	public static function GetByItemKeyLabelId ($key, $label_id, $isPhoto)
	{
		if ($isPhoto) {
			$query = 'SELECT * FROM photo_image_label WHERE image_id = ? AND label_id= ?';
		} else {
			$query = 'SELECT * FROM photo_video_label WHERE video_path = ? AND label_id= ?';
		}
		$db_result = PHOTO_DB_Query($query, array($key, $label_id));
		return PHOTO_DB_FetchRow($db_result);
	}

	public static function GetAllByItemKeyLabelId($key, $label_ids, $isPhoto)
	{
		$res = array();

		$count = count($label_ids);
		if (0 == $count) {
			return $res;
		}
		$id_string = implode(',', array_fill(0, $count, '?'));
		if ($isPhoto) {
			$query = "SELECT * FROM photo_image_label WHERE image_id = ? AND label_id IN ($id_string)";
		} else {
			$query = "SELECT * FROM photo_video_label WHERE video_path = ? AND label_id IN ($id_string)";
		}

		$db_result = PHOTO_DB_Query($query, array_merge(array($key), $label_ids));
		while ($row = PHOTO_DB_FetchRow($db_result)) {
			foreach ($row as $k => $v) {
				if ('status' === $k) {
					$row[$k] = PHOTO_DB_IsTrue($v);
				}
			}
			$res[] = $row;
		}
		return $res;
	}

	public static function GetPhotoLabelByLabelIds ($label_ids)
	{
		$res = array();
		$count = count($label_ids);
		if(0 == $count) {
			return $res;
		}
		$id_string = implode(',', array_fill(0, $count, '?'));
		$query = "SELECT * from photo_image_label WHERE label_id IN ($id_string)";
		$db_result = PHOTO_DB_Query($query, $label_ids);
		while ($row = PHOTO_DB_FetchRow($db_result)) {
			$res[] = $row;
		}
		return $res;
	}

	public static function GetLabelByImageId ($image_id)
	{
		$labels = array('person' => array(), 'place' => array(), 'general' => array());

		$query = 'SELECT B.id, B.label_id, B.image_id, B.info, B.status, B.info_new, A.name, A.category, A.info as label_info FROM photo_label A, photo_image_label B '.
			'WHERE A.id=B.label_id AND B.image_id=?';
		$db_result = PHOTO_DB_Query($query, array($image_id));

		$isAdmin = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);

		while (false !== ($row = PHOTO_DB_FetchRow($db_result))) {
			if (Label::PEOPLE == $row['category']) {
				$item = self::GetImageLabelItem($row, $image_id);
				if (!$isAdmin && false == $item['status']) {
					continue;
				}
				$labels['person'][] = $item;
			} else if (Label::GEO == $row['category']) {
				$labels['place'][] = self::GetImageLabelItem($row);
			} else {
				$labels['general'][] = self::GetImageLabelItem($row);
			}
		}
		return $labels;
	}

	public static function GetLabelByVideoPath ($path)
	{
		$labels = array('person' => array(), 'place' => array(), 'general' => array());
		$query = 'SELECT B.id, B.label_id, B.video_path, B.info, B.status, A.name, A.category, A.info as label_info FROM photo_label A, photo_video_label B '.
			'WHERE A.id=B.label_id AND B.video_path=?';
		$dPath = substr($path, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
		$sqlParam = array($dPath);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		while (false !== ($row = PHOTO_DB_FetchRow($db_result))) {
			if (0 == $row['category']) {
				$labels['person'][] = self::GetImageLabelItem($row);
			} else if (1 == $row['category']) {
				$labels['place'][] = self::GetImageLabelItem($row);
			} else {
				$labels['general'][] = self::GetImageLabelItem($row);
			}
		}
		return $labels;
	}

	public static function GetCountByLabelId ($label_id)
	{
		//photo
		$query = "SELECT count(id) FROM photo_image_label WHERE label_id= ? ";
		$db_result = PHOTO_DB_Query($query, array($label_id));
		if (false === ($row = PHOTO_DB_FetchRow($db_result))) {
			return false;
		}
		$photoCount = $row[0];

		// video
		$query = "SELECT count(id) FROM photo_video_label WHERE label_id= ?";
		$db_result = PHOTO_DB_Query($query, array($label_id));
		if (false === ($row = PHOTO_DB_FetchRow($db_result))) {
			return false;
		}
		$videoCount = $row[0];

		return $photoCount + $videoCount;
	}

	public static function UpdateLabelStatus ($image_id, $label_id, $confirm)
	{
		$query = "UPDATE photo_image_label SET status=? WHERE image_id=? and label_id=?";
		$sqlConfirm = ('true' === $confirm) ? 't' : 'f';
		$sqlParam = array($sqlConfirm, $image_id, $label_id);
		if (false === ($dbResult = PHOTO_DB_Query($query, $sqlParam))) {
			return false;
		}
		return true;
	}

	public static function UpdateItemLabelByLabelId ($label_id, $category)
	{
		$image_label_objs = self::GetPhotoLabelByLabelIds(array($label_id));
		foreach ($image_label_objs as $objs) {
			self::UpdatePhotoMetadata($objs['image_id'], $category);
		}
	}

	static function GetImageLabelItem ($image_label_object, $image_id = false)
	{
		$keys = array('id', 'label_id', 'info', 'name', 'category', 'label_info', 'status');
		$item = array();
		foreach ($keys as $key) {
			$item[$key] = $image_label_object[$key];
		}
		if (isSet($image_label_object['image_id'])) {
			$item['image_id'] = $image_label_object['image_id'];
		} else {
			$item['video_path'] = $image_label_object['video_path'];
		}
		// adjust info
		if (!empty($image_label_object['info_new'])) {
			$item['info'] = $image_label_object['info_new'];
		} elseif (!empty($image_label_object['info']) && false !== $image_id) {
			$item['info'] = '';
			$resolution = self::GetPhotoResolution($image_id);
			if (!empty($resolution['x']) && !empty($resolution['y'])) {
				$info = json_decode($image_label_object['info'], true);
				if (!empty($info['face'])) {
					$adjustInfo['face']['x'] = $info['face']['x'] / $resolution['x'];
					$adjustInfo['face']['y'] = $info['face']['y'] / $resolution['y'];
					$adjustInfo['face']['width'] = $info['face']['width'] / $resolution['x'];
					$adjustInfo['face']['height'] = $info['face']['height'] / $resolution['y'];
				}
				$adjustInfo['x'] = $info['x'] / $resolution['x'];
				$adjustInfo['y'] = $info['y'] / $resolution['y'];
				$adjustInfo['width'] = $info['width'] / $resolution['x'];
				$adjustInfo['height'] = $info['height'] / $resolution['y'];
				$item['info'] = json_encode($adjustInfo);
			}
		}
		return $item;
	}

	static function GetByIds ($ids, $isPhoto)
	{
		$count = count($ids);
		if (0 == $count) {
			return false;
		}
		$id_string = implode(',', array_fill(0, $count, '?'));

		if ($isPhoto) {
			$query = "SELECT * FROM photo_image_label WHERE id IN ($id_string)";
		} else {
			$query = "SELECT * FROM photo_video_label WHERE id IN ($id_string)";
		}

		$res = array();
		$db_result = PHOTO_DB_Query($query, $ids);
		while ($row = PHOTO_DB_FetchRow($db_result)) {
			foreach ($row as $k => $v) {
				if ('status' === $k) {
					$row[$k] = PHOTO_DB_IsTrue($v);
				}
			}
			$res[] = $row;
		}
		return $res;
	}

	static function GetPhotoResolution ($image_id, $thumb_size = 800)
	{
		// get path and version
		$imageObj = self::GetImageByImageId($image_id);
		$version = $imageObj['version'];
		$orig_x = $imageObj['resolutionx'];
		$orig_y = $imageObj['resolutiony'];

		// calculate thumb(800px) resolution
		$thumb_L_x = $thumb_L_y = $thumb_size;
		$photoRadio = $orig_x / $orig_y;
		if ($orig_x > $orig_y) { //wider photo
			$thumb_L_y = intval($thumb_size / $photoRadio);
		} else { // higher photo
			$thumb_L_x = intval($thumb_size * $photoRadio);
		}

		// check rotate
		if (1 == ($version % 2)) {
			$tmp = $thumb_L_x;
			$thumb_L_x = $thumb_L_y;
			$thumb_L_y = $tmp;
		}

		$data['x'] = $thumb_L_x;
		$data['y'] = $thumb_L_y;
		return $data;
	}

	static function GetImageByImageId ($image_id)
	{
		$convert2INT = array('version', 'resolutionx', 'resolutiony');

		$query = 'SELECT path, version, resolutionx, resolutiony FROM photo_image WHERE id=?';
		$db_result = PHOTO_DB_Query($query, array($image_id));
		if (false === ($row = PHOTO_DB_FetchRow($db_result))) {
			return false;
		}
		$res = array();
		foreach (array_keys($row) as $key) {
			if (in_array($key, $convert2INT)) {
				$res[$key] = (int) $row[$key];
			} else {
				$res[$key] = $row[$key];
			}
		}
		return $res;
	}

	static function UpdatePhotoMetadata ($image_id, $category)
	{
		//1. query file path from DB
		$query = 'SELECT path, resolutionx, resolutiony FROM photo_image WHERE id = ?';
		$sqlParam = array($image_id);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		if (false === $db_result) {
			return false;
		}
		$row = PHOTO_DB_FetchRow($db_result);
		$path = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
		$resolutionx = floatval($row['resolutionx']);
		$resolutiony = floatval($row['resolutiony']);

		if (false === self::IsExiv2SupportWriteMode($path)) {
			return false;
		}

		//2. remove existed metadata
		if (0 == $category) {
			//people tag
			$peopleTagPrefix = 'Xmp.MP.RegionInfo';
			$metadataList = array();
			$removedMetadataList = array();

			csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array('-PXkt', $path), false, $metadataList);

			foreach($metadataList as $metadata) {
				if (0 === strncmp($peopleTagPrefix, $metadata, strlen($peopleTagPrefix))) {
					$tmp = explode(' ', $metadata);
					$removedMetadataList[] = $tmp[0];
				}
			}
			$removedMetadataList = array_reverse($removedMetadataList);

			//$cmd = '';
			$cmd = array();
			foreach($removedMetadataList as $removedMetadata) {
				//$cmd .= '-M"del '.$removedMetadata.'" ';
				$cmd[] = '-M';
				$cmd[] = 'del ' . $removedMetadata;
			}

			if (!empty($cmd)) {
				//$cmd = sprintf('%s %s %s %s %s %s', SYNO_EXIFTOOL_FILE,
				//	'-M"reg MP http://ns.microsoft.com/photo/1.2/"',
				//	'-M"reg MPRI http://ns.microsoft.com/photo/1.2/t/RegionInfo#"',
				//	'-M"reg MPReg http://ns.microsoft.com/photo/1.2/t/Region#"',
				//	$cmd, escapeshellarg($path));
				$cmd = array_merge(array(
					'-M', 'reg MP http://ns.microsoft.com/photo/1.2/',
					'-M', 'reg MPRI http://ns.microsoft.com/photo/1.2/t/RegionInfo#',
					'-M', 'reg MPReg http://ns.microsoft.com/photo/1.2/t/Region#'), $cmd);
				$cmd[] = $path;
				//@exec($cmd);
				csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, $cmd);
			}
		} else {
			//descriptive tag
			//$cmd = sprintf('%s -M "del %s" -M "del %s" %s', SYNO_EXIFTOOL_FILE,
			//	"Iptc.Application2.Keywords", "Xmp.dc.subject", escapeshellarg($path));
			//@exec($cmd);
			csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
				'-M', 'del Iptc.Application2.Keywords',
				'-M', 'del Xmp.dc.subject',
				$path));
		}

		//3. query new metadata value from DB
		$query = 'SELECT A.id, A.info, A.info_new, B.name FROM photo_image_label A, photo_label B '.
			'WHERE A.image_id = ? AND B.id = A.label_id AND B.category = ? AND A.status = ?';
		$sqlParam = array($image_id, $category, 't');
		$db_result = PHOTO_DB_Query( $query, $sqlParam);
		if (false === $db_result) {
			return false;
		}

		//4. write metadata to file
		if (0 == $category) {
			//people tag
			$precision = 6;
			$thumbSize = 800;
			$peopleTaggingCount = 1;
			//$cmd = '';
			$cmd = array();

			while ($row = PHOTO_DB_FetchRow($db_result)) {
				$info = json_decode($row['info'], true);
				$info_new = json_decode($row['info_new'], true);
				if (!$info && !$info_new) {
					continue;
				}

				if ($info_new) {
					$x = round(floatval($info_new['x']), $precision);
					$y = round(floatval($info_new['y']), $precision);
					$width = round(floatval($info_new['width']), $precision);
					$height = round(floatval($info_new['height']), $precision);
				} elseif ($info) {
					$ratio = $resolutiony / $resolutionx;
					if ($ratio > 1) {//higher image
						$x = round(floatval($info['x']) / ((float)$thumbSize / $ratio), $precision);
						$y = round(floatval($info['y']) / (float)$thumbSize, $precision);
						$width = round(floatval($info['width']) / ((float)$thumbSize / $ratio), $precision);
						$height = round(floatval($info['height']) / (float)$thumbSize, $precision);
					} else {//wider image
						$x = round(floatval($info['x']) / (float)$thumbSize, $precision);
						$y = round(floatval($info['y']) / ((float)$thumbSize * $ratio), $precision);
						$width = round(floatval($info['width']) / (float)$thumbSize, $precision);
						$height = round(floatval($info['height']) / ((float)$thumbSize * $ratio), $precision);
					}
				}

				//$cmd .= '-M"set Xmp.MP.RegionInfo/MPRI:Regions['.$peopleTaggingCount.']/MPReg:Rectangle '."$x, $y, $width, $height".'" ';
				$cmd[] = '-M';
				$cmd[] = 'set Xmp.MP.RegionInfo/MPRI:Regions[' . $peopleTaggingCount . ']/MPReg:Rectangle ' . "$x, $y, $width, $height";
				if ('' !== $row['name']) {
					//$cmd .= '-M"set Xmp.MP.RegionInfo/MPRI:Regions['.$peopleTaggingCount.']/MPReg:PersonDisplayName '.str_replace('"', '\"', $row['name']).'" ';
					$cmd[] = '-M';
					$cmd[] = 'set Xmp.MP.RegionInfo/MPRI:Regions[' . $peopleTaggingCount . ']/MPReg:PersonDisplayName ' . $row['name'];
				}
				$peopleTaggingCount++;
			}

			if (!empty($cmd)) {
				//$cmd = sprintf('%s %s %s %s %s %s %s',
				//	SYNO_EXIFTOOL_FILE,
				//	'-M"reg MP http://ns.microsoft.com/photo/1.2/"',
				//	'-M"reg MPRI http://ns.microsoft.com/photo/1.2/t/RegionInfo#"',
				//	'-M"reg MPReg http://ns.microsoft.com/photo/1.2/t/Region#"',
				//	'-M"set Xmp.MP.RegionInfo/MPRI:Regions XmpText type=Bag"',
				//	$cmd, escapeshellarg($path));
				//@exec($cmd);
				$cmd = array_merge(array(
					'-M', 'reg MP http://ns.microsoft.com/photo/1.2/',
					'-M', 'reg MPRI http://ns.microsoft.com/photo/1.2/t/RegionInfo#',
					'-M', 'reg MPReg http://ns.microsoft.com/photo/1.2/t/Region#',
					'-M', 'set Xmp.MP.RegionInfo/MPRI:Regions XmpText type=Bag'), $cmd);
				$cmd[] = $path;
				csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, $cmd);
			}
		} else {
			//descriptive tag
			$keyword = array();
			$count = 1;
			while ($row = PHOTO_DB_FetchRow($db_result)) {
				//$cmd = sprintf('-M "add %s %s" ', "Iptc.Application2.Keywords String", str_replace('"', '\"', $row['name']));
				$cmd = array('-M', 'add Iptc.Application2.Keywords String ' . $row['name']);
				if (1 === $count) {
					$cmd[] = '-M';
					$cmd[] = "set Iptc.Envelope.CharacterSet String \x1B%G";
					//$cmd .= sprintf('-M "set %s %s" ', "Xmp.dc.subject", "''");
					$cmd[] = '-M';
					$cmd[] = "set Xmp.dc.subject ''";
				}
				//$cmd .= sprintf('-M "set %s[%d] %s" ', "Xmp.dc.subject", $count++,str_replace('"', '\"', $row['name']));
				$cmd[] = '-M';
				$cmd[] = 'set Xmp.dc.subject[' . $count . '] ' . $row['name'];
				++$count;
				//$exec = sprintf('%s %s %s', SYNO_EXIFTOOL_FILE, $cmd, escapeshellarg($path));
				$cmd[] = $path;
				//@exec($exec);
				csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, $cmd);
			}

			csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-P', 'SynologyMoments', '-R', $path));
		}

		//update mtime of all thumbnails for prevent from re-making thumbnail
		//$cmd = sprintf('/usr/syno/bin/synophoto_dsm_user --updatethumbnailmtime %s', escapeshellarg($path));
		//@exec($cmd);
		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--updatethumbnailmtime', $path));
	}

	static function RemoveFaceTrainingData ()
	{
		//$cmd = sprintf("%s -R %s", SYNOPHOTO_FACE_RECOG_TOOL, escapeshellarg(SYNOPHOTO_ADMIN_NAME));
		//@exec($cmd);
		csSYNOPhotoMisc::ExecCmd(SYNOPHOTO_FACE_RECOG_TOOL, array('-R', SYNOPHOTO_ADMIN_NAME));
	}

	static function GetUnconfirmedLabelId()
	{
		$query = "SELECT distinct(label_id) FROM photo_image_label WHERE status = 'f'";
		$db_result = PHOTO_DB_Query($query);

		if (!$db_result) {
			return array();
		}
		$hash = array();

		while(($row = PHOTO_DB_FetchRow($db_result))) {
			$hash[$row['label_id']] = 1;
		}

		$query = "SELECT distinct(label_id) FROM photo_video_label WHERE status = 'f'";
		$db_result = PHOTO_DB_Query($query);

		if (!$db_result) {
			return array_map(function($n) {return $n + 0;}, array_keys($hash));
		}

		while(($row = PHOTO_DB_FetchRow($db_result))) {
			$hash[$row['label_id']] = 1;
		}
		return array_map(function($n) {return $n + 0;}, array_keys($hash));
	}

	static function IsExiv2SupportWriteMode($path)
	{
		global $SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT;

		$ext = strtolower(pathinfo($path, PATHINFO_EXTENSION));
		if (!in_array($ext, $SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT)) {
			return false;
		}
		return true;
	}

}
