<?php
class Label {
	const PEOPLE = 0;
	const GEO = 1;
	const DESC = 2;

	public static function GetCategoryName($num)
	{
		if (!isset($num)) {
			return false;
		}
		switch ($num) {
		case self::PEOPLE:
			$name = 'people';
			break;
		case self::GEO:
			$name = 'geo';
			break;
		case self::DESC:
			$name = 'desc';
			break;
		default:
			return false;
			break;
		}
		return $name;
	}

	public static function Add ($name, $category, $info = '')
	{
		$query = "INSERT INTO photo_label (name, category, info) VALUES (?, ?, ?);";
		$db_result = PHOTO_DB_Query($query, array($name, $category, $info));
		if (false === $db_result) {
			return false;
		}
		return PHOTO_DB_lastInsertId('photo_label_id_seq');
	}

	public static function EditById ($id, $name, $info = null, $category = null, $updateMetadata = false)
	{
		if ('' === $name && null === $category && null === $info) {
			return 0;
		}
		$updateFields = array('name = ?');
		$updateValues = array($name);

		if (null !== $info) {
			$updateFields[] = 'info = ?';
			$updateValues[] = $info;
		}

		if (null !== $category) {
			$updateFields[] = 'category = ?';
			$updateValues[] = $category;
		}

		$query = "UPDATE photo_label SET ". implode(',', $updateFields) ." WHERE id = ?";
		$db_result = PHOTO_DB_Query($query, array_merge($updateValues, array($id)));
		if (false === $db_result) {
			return false;
		}
		$result = PHOTO_DB_AffectedRows($db_result);

		if ($updateMetadata) {
			$label_objs = self::GetByIds(array($id));
			ItemLabel::UpdateItemLabelByLabelId($id, $label_objs[$id]['category']);
		}
		return $result;
	}

	public static function DeleteAllByIds ($ids, $update_metadata = true)
	{
		$query_ids = is_array($ids) ? $ids : array($ids);

		$count = count($query_ids);
		if (0 == $count) {
			return 0;
		}

		$labelsArray = self::GetByIds($query_ids);

		$item_labels = ItemLabel::GetPhotoLabelByLabelIds($query_ids);

		ItemLabel::DeleteByLabelIds($query_ids);

		if ($update_metadata) {
			ItemLabel::UpdateMetaData($labelsArray, $item_labels);
		}

		return self::DeleteByIds($query_ids);
	}

	static function DeleteByIds ($ids)
	{
		$count = count($ids);
		if (0 == $count) {
			return 0;
		}
		$id_string = implode(',', array_fill(0, $count, '?'));

		$query = "DELETE FROM photo_label WHERE id IN ($id_string)";
		$db_result = PHOTO_DB_Query($query, $ids);
		if (false == $db_result) {
			return false;
		}
		return PHOTO_DB_AffectedRows($db_result);
	}

	public static function GetByIds ($ids)
	{
		$count = count($ids);
		if (0 == $count) {
			return false;
		}
		$id_string = implode(',', array_fill(0, $count, '?'));

		$objs = self::GetLabelByCondition("id IN ($id_string)", $ids);
		$result = array();
		foreach($objs as $row) {
			$result[$row['id']] = $row;
		}

		return $result;
	}

	public static function GetByNameCategory($name, $category)
	{
		$objs = self::GetLabelByCondition("name = ? AND category = ?", array($name, $category));
		if ($objs[0]) {
			return $objs[0];
		}
		return false;
	}

	public static function GetGeoLabelByNamePlaceId($name, $placeId)
	{
		$objs = self::GetLabelByCondition("name = ? AND category = ?", array($name, self::GEO));
		foreach ($objs as $row) {
			$dbInfo = json_decode($row['info'], true);
			if ($dbInfo['placeId'] == $placeId) {
				return $row;
			}
		}
		return false;
	}

	public static function GetByCategoryPermission($categories, $isAdmin)
	{
		$tag = array(self::PEOPLE => array(), self::GEO => array(), self::DESC => array());

		$sqlParam = array();
		if ($isAdmin) {
			$query = 'SELECT * FROM photo_label;';
		} else {
			$query = 'SELECT distinct photo_label.id as id, photo_label.name as name, photo_label.info as info, category FROM photo_image_label LEFT JOIN photo_image ON photo_image_label.image_id=photo_image.id LEFT JOIN photo_label ON photo_image_label.label_id=photo_label.id WHERE ';
			$videoQuery = 'SELECT distinct photo_label.id as id, photo_label.name as name, photo_label.info as info, category FROM photo_video_label LEFT JOIN video ON photo_video_label.video_path=video.path LEFT JOIN photo_label ON photo_video_label.label_id=photo_label.id WHERE ';
			if (false !== $filterCategory) {
				$cateogryArr = array();
				foreach ($categories as $categoryID) {
					$str = 'category='.$categoryID;
					$cateogryArr[] = $str;
				}
				$categoryString = '('.implode(' or ', $cateogryArr).')';
				$query .=" $categoryString ";
				$videoQuery .=" $categoryString";
			}

			$operator = (false !== $filterCategory) ? ' AND ' : '';
			$operatorVideo = (false !== $filterCategory) ? ' AND ' :  '';
			$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryCondition();
			if (count($albumCondition['privilege_shareid'])) {
				$query .= " AND privilege_shareid IN (".implode(',', $albumCondition['privilege_shareid']).' )';
				$videoQuery .= " AND privilege_shareid IN (".implode(',', $albumCondition['privilege_shareid']).' )';
			} else {
				return $tag;
			}
		}

		$db_result = PHOTO_DB_Query($query, $sqlParam);
		while (false !== ($row = PHOTO_DB_FetchRow($db_result))) {
			if (empty($row['name'])) {
				continue;
			}
			$row['category'] += 0;
			$tag[$row['category']][$row['id']] = $row;
		}

		if (isSet($videoQuery)) {
			$db_result = PHOTO_DB_Query($videoQuery, $sqlParam);
			while (false !== ($row = PHOTO_DB_FetchRow($db_result))) {
				$row['category'] += 0;
				$tag[$row['category']][$row['id']] = $row;
			}
		}

		for($i = 0; $i < count($tag); ++$i) {
			usort($tag[$i], "self::LabelNameCmpASC");
		}
		return $tag;
	}

	public static function LabelNameCmpASC ($a, $b)
	{
		return strnatcasecmp($a['name'], $b['name']);
	}

	public static function LabelNameCmpDESC ($a, $b)
	{
		return strnatcasecmp($b['name'], $a['name']);
	}

	public static function CheckLabelExistById ($id)
	{
		$query = "SELECT '1' FROM photo_label WHERE id=?";
		if (false === ($db_result = PHOTO_DB_Query($query, array($id)))) {
			return false;
		}
		if (false === ($row = PHOTO_DB_FetchRow($db_result))) {
			return false;
		}
		if (1 !== (int)$row[0]) {
			return false;
		}
		return true;
	}

	public static function isDuplicated ($id, $name, $placeId, $type)
	{
		$query = "SELECT * FROM photo_label WHERE id != ? AND name = ? AND category = ?";
		$db_result = PHOTO_DB_Query($query, array($id, $name, $type));
		while($row = PHOTO_DB_FetchRow($db_result)) {
			if ($type == self::GEO) {
				$json = json_decode($row['info'], true);
				if ($placeId == $json['placeId']) {
					return true;
				}
			} else {
				return true;
			}
		}
		return false;
	}

	public static function SearchGeoLabel ($searchName, $isHideGPS = false)
	{
		$escape = PHOTO_DB_GetEscape();
		$sqlParam = array();

		$sql = "SELECT * FROM photo_label WHERE category = 1 AND name LIKE ? $escape";
		$sqlParam[] = '%' . PHOTO_DB_EscapForLike($searchName) . '%';

		$db_result = PHOTO_DB_Query($sql, $sqlParam);
		$places = array();
		while (false !== ($row = PHOTO_DB_FetchRow($db_result))) {
			$info = json_decode($row['info'], true);
			$item = array();
			$item['name'] = $row['name'];
			$item['tagId'] = 'tag_'.$row['id'];
			$item['placeId'] = '';
			$item['address'] = '';
			$item['gps'] = null;
			if ($info && '' !== $info['placeId'] && !$isHideGPS) {
				$item['placeId'] = $info['placeId'];
				$item['address'] = $info['address'];
				$item['gps'] = array('lat' => $info['lat'], 'lng' => $info['lng']);
			}
			$places[] = $item;
		}
		return $places;
	}

	private static function GetLabelByCondition ($condition, $sqlParams = array())
	{
		$result = PHOTO_DB_Query("SELECT * FROM photo_label WHERE $condition", $sqlParams);

		if (!$result) {
			return array();
		}

		$labels = array();
		while(($row = $result->fetch())) {
			foreach ($row as $key => $value) {
				if(in_array($key, array('id', 'category'))) {
					$row[$key] = $value + 0;
				}
			}
			$labels[] = $row;
		}

		return $labels;
	}
}
