<?php

class PhotoLog {
	const LIMIT = 100000;
	const PURGECOUNT = 10000;
	public static $SupportFormat = array("html", "csv");
	private static $USER_AGENT_JSON = SYNO_PKG_DIR.'/etc/user.agent.json';

	public static function Debug($msg)
	{
		$handle = fopen("/tmp/synophoto_log", "a");
		fwrite($handle, date('ymd H:i:s')." => ".$msg."\n");
		fclose($handle);
	}

	public static function Add ($msg, $success, $user, $enableTransaction = true)
	{
		if ($enableTransaction) {
			PHOTO_DB_BeginTransaction();
		}
		$success = PHOTO_DB_ConvertBool($success);
		$logId = self::PurgePhotoLog();
		$query = 'INSERT INTO photo_log VALUES(?, ?, ?, ?, ?)';
		$sqlParam = array($logId, date('Y-m-d H:i:s'), $msg, $success, $user);
		$res = PHOTO_DB_Query($query, $sqlParam);
		if ($enableTransaction) {
			PHOTO_DB_Commit();
		}
		return !!$res;
	}

	public static function ListItem ($offset, $limit)
	{
		$query = "SELECT * FROM photo_log ORDER BY create_time DESC, logid DESC LIMIT ? OFFSET ?";
		$dbResult = PHOTO_DB_Query($query, array($limit, $offset));

		$data = array();
		while(($row = PHOTO_DB_FetchRow($dbResult))) {
			$item = array(
				'success' => PHOTO_DB_IsTrue($row['success']),
				'create_time' => $row['create_time'],
				'logid' => $row['logid'],
				'log' => $row['log'],
				'user' => $row['user']
			);
			$data[] = $item;
		}

		$dbResult = PHOTO_DB_Query("SELECT count(*) FROM photo_log");
		$row = PHOTO_DB_FetchRow($dbResult);

		return array('data' => $data,
					 'total' => $row[0]); 
	}

	public static function Clear ($user)
	{
		PHOTO_DB_BeginTransaction();
		PHOTO_DB_Query("DELETE FROM photo_log");
		self::Add("Clear log.", true, $user, false);
		PHOTO_DB_Commit();
	}

	public static function ExportFile ($format = "html")
	{
		$exportKeys = array(
			"success" => __(photo_str_status),
			"create_time" => __(photo_str_create_time), 
			"user" => __(photo_str_user),
			"log" => __(photo_str_log_event)
		);

		if ("csv" === $format) {
			self::ExportCSV($exportKeys);
		} else {
			self::ExportHTML($exportKeys);
		}
	}

	public static function DownloadHeader ($filename)
	{
		header('Content-Type: application/force-download');
		header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
		header("Pragma: public");
		header('Content-Disposition: attachment; filename="'.addslashes($filename).'"');
		header("X-Download-Options: noopen");
	}

	public static function ExportHTML ($header)
	{
		$dbResult = PHOTO_DB_Query("SELECT * FROM photo_log ORDER BY create_time DESC, logid DESC ");

		if (!$dbResult) {
			return false;
		}

		$name = sprintf("photolog-%s.html",date("Y-m-d H:i:s"));
		self::DownloadHeader($name);

		echo '<!DOCTYPE HTML><html><head><meta charset="utf-8"></head><body><table border=1 style="width:95%;text-align:center"><tr>';
		foreach ($header as $h => $text) {
			echo "<th>$text</th>";
		}
		echo "</tr>";

		while(($row = $dbResult->fetch())) {
			echo "<tr>";
			foreach ($header as $k => $text) {
				if ('success' === $k) {
					$row[$k] = PHOTO_DB_IsTrue($row[$k]) ? 'success' : 'fail';
				}
				echo "<td>${row[$k]}</td>";
			}
			echo "</tr>";
			ob_flush();
		}
		echo '</body></html>';
		ob_flush();
		exit;
	}

	public static function ExportCSV ($header)
	{
		$dbResult = PHOTO_DB_Query("SELECT * FROM photo_log ORDER BY create_time DESC, logid DESC ");

		if (!$dbResult) {
			return false;
		}

		$name = sprintf("photolog-%s.csv",date("Y-m-d H:i:s"));

		self::DownloadHeader($name);
		echo implode(",", array_values($header));
		echo "\r\n";

		while(($row = $dbResult->fetch())) {
			$line = array();
			foreach ($header as $k => $text) {
				if ('success' === $k) {
					$row[$k] = PHOTO_DB_IsTrue($row[$k]) ? 'success' : 'fail';
				} else {
					$row[$k] = '"'.addslashes($row[$k]).'"';
				}
				$line[] = $row[$k];
			}
			echo implode(",", $line);
			echo "\r\n";
			ob_flush();
		}
		exit;
	}

	private static function PurgePhotoLog()
	{
		$query = 'SELECT count(logid), max(logid) FROM photo_log';
		$dbResult = PHOTO_DB_Query($query);
		$row = PHOTO_DB_FetchRow($dbResult);

		$count = $row[0];
		$maxId = $row[1];

		/* purge stale log record */
		if ($row[0] >= self::LIMIT) {
			$query =  'SELECT create_time FROM photo_log ORDER BY create_time DESC, logid DESC LIMIT 1 OFFSET ?';
			$dbResult = PHOTO_DB_Query($query, array(self::PURGECOUNT));
			$lastRow = PHOTO_DB_FetchRow($dbResult);

			PHOTO_DB_Query("DELETE FROM photo_log WHERE create_time < ?", array($lastRow[0]));

			$dbResult = PHOTO_DB_Query("SELECT max(logid) FROM photo_log");
			$row = PHOTO_DB_FetchRow($dbResult);
			$maxId = $row[0];
		}

		/* rotate to 1 if > PHP_INT_MAX (2147483647) */
		return $maxId >= PHP_INT_MAX ? 1 : $maxId + 1;
	}

	public static function RecordUserAgent()
	{
		$conf = csSYNOPhotoMisc::GetConfigFile(SYNO_CNF_FILE, 'enable_data_collect');
		if ($conf['enable_data_collect'] !== 'yes') {
			return;
		}

		$user_agent = $_SERVER['HTTP_USER_AGENT'];
		if (strlen($user_agent) > 512) {
			// avoid malicious user-agent
			$user_agent = substr(0, 512);
		}

		$json = self::ReadUserAgentJson();
		if (!is_array($json)) {
			syslog(LOG_ERR, __FILE__ . ":" . __LINE__ . " " . "Invalid user agent json value: " . json_encode($json));
			$json = array();
		}

		if (array_key_exists($user_agent, $json)) {
			$json[$user_agent] += 1;
		} else {
			$json[$user_agent] = 1;
		}

		self::WriteUserAgentJson($json);
	}

	private static function ReadUserAgentJson()
	{
		if (!file_exists(self::$USER_AGENT_JSON)) {
			return array();
		}

		$content = file_get_contents(self::$USER_AGENT_JSON);
		if ($content === false) {
			syslog(LOG_ERR, "Failed to read " . self::$USER_AGENT_JSON);
			return null;
		}

		return json_decode($content, true);
	}

	private static function WriteUserAgentJson($json)
	{
		$ret = file_put_contents(self::$USER_AGENT_JSON, json_encode($json), LOCK_EX);
		if ($ret === false) {
			syslog(LOG_ERR, "Failed to write " . self::$USER_AGENT_JSON);
			return;
		}
		@chmod(self::$USER_AGENT_JSON, 0640);
	}
}
?>
