<?php
/*!
 * album list operation
 */
class SmartAlbum {
	const SmartJSON = "SYNOPHOTO_SMART_ALBUM_CONFIG";
	private $_dbh;
	private $smartAlbumList;
	//private $escapeStr = '';
	public $escapeStr = ''; // #1507 - avoid erro when sharing smart album
	private static $instance = null;
	private static $video_convert_type_condition;
	public static $exif2IdPrefix = array(
		'camera' => 'camera_make',
		'model' => 'camera_model',
		'exposure' => 'exposure',
		'aperture' => 'aperture',
		'iso' => 'iso',
		'focal' => 'focal_length',
		'lens' => 'lens',
		'flash' => 'flash',
		'rating' => 'rating'
	);

	public static $exif2Column = array(
		'camera' => 'camera_make',
		'model' => 'camera_model',
		'exposure' => 'exposure',
		'aperture' => 'aperture',
		'iso' => 'iso',
		'focal' => 'focal_length_v2',
		'lens' => 'lens_v2',
		'flash' => 'flash_v2',
		'rating' => 'rating'
	);

	function __construct()
	{
		$this->_dbh = csSYNOPhotoDB::GetDBInstance()->_dbh;
		$this->escapeStr = csSYNOPhotoDB::GetDBInstance()->escapeStr;
		$this->smartAlbumList = $this->_ReadSmartAlbumFile();
	}

	function __destruct()
	{
		$this->_dbh = null;
		$this->escapeStr = '';
		$this->smartAlbumList = null;
	}

	static function GetSmartAlbumInstance()
	{
		if (null === self::$instance) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	static function DestroySmartAlbumInstance()
	{
		self::$instance = null;
	}

	/**
	 *	WebAPI interface
	 */
	function AddSmartAlbum($data)
	{
		$returnJson = array(
			"success" => false
		);

		if (!$json = json_decode($data, true)) {
			PhotoLog::Debug('not valid json format');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		if (!isset($json['name']) || 0 >= strlen($json['name']) ||
			!isset($json['show_photo']) || !isset($json['show_video']) ||
			empty($json['rule_sets']) || !is_array($json['rule_sets'])) {
			PhotoLog::Debug('some field is not set');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		$albumName = $json['name'];
		$albumDesc = $json['desc'];
		$albumShowPhoto = !!$json['show_photo'];
		$albumShowVideo = !!$json['show_video'];
		$albumRuleSet = $json['rule_sets'];

		if (!$albumShowPhoto && !$albumShowVideo) {
			$albumShowPhoto = true;
			$albumShowVideo = true;
		}

		if (!$smartAlbumList = $this->ReadSmartAlbumFile()) {
			$smartAlbumList["smart_albums"] = array();
		}

		if (isset($smartAlbumList["smart_albums"][$albumName])) {
			PhotoLog::Debug("the smart album with name [$albumName] already exist");
			$returnJson["error"]["code"] = 103;
			$returnJson["error"]["message"] = 'The smart album already exist';
			return json_encode($returnJson);
		}

		//to do!! input format validation!!
		$smartAlbumList["smart_albums"][$albumName]["desc"] = $albumDesc;
		$smartAlbumList["smart_albums"][$albumName]["show_photo"] = $albumShowPhoto;
		$smartAlbumList["smart_albums"][$albumName]["show_video"] = $albumShowVideo;
		$smartAlbumList["smart_albums"][$albumName]["rule_sets"] = $albumRuleSet;

		if (!$this->WriteSmartAlbumFile($smartAlbumList)) {
			PhotoLog::Debug("Write failed");
			$returnJson["error"]["code"] = 104;
			$returnJson["error"]["message"] = 'Write failed';
			return json_encode($returnJson);
		}

		$returnJson["success"] = true;
		return json_encode($returnJson);
	}

	/**
	 *  WebAPI interface
	 */
	function LoadSmartAlbumConfig($data)
	{
		$returnJson = array(
			"success" => false
		);

		$returnData = array();

		if (!$json = json_decode($data, true)) {
			PhotoLog::Debug('not valid json format');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		if (!isset($json['name']) || 0 >= strlen($json['name'])) {
			PhotoLog::Debug('some field is not set');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		$albumName = $json['name'];

		if (!$smartAlbumList = $this->ReadSmartAlbumFile()) {
			PhotoLog::Debug("Read failed");
			$returnJson["error"]["code"] = 103;
			$returnJson["error"]["message"] = 'Read failed';
			return json_encode($returnJson);
		}

		if (!isset($smartAlbumList["smart_albums"][$albumName])) {
			PhotoLog::Debug("the smart album with name \"$albumName\" does not exist");
			$returnJson["error"]["code"] = 103;
			$returnJson["error"]["message"] = 'The smart album does not exist';
			return json_encode($returnJson);
		}

		$smartAlbum = $smartAlbumList["smart_albums"][$albumName];

		$returnData["name"] = $albumName;
		$returnData["desc"] = $smartAlbum["desc"];
		$returnData["show_photo"] = $smartAlbum["show_photo"];
		$returnData["show_video"] = $smartAlbum["show_video"];
		$returnData["rule_sets"] = $smartAlbum["rule_sets"];

		if (!$smartAlbum["show_photo"] && !$smartAlbum["show_video"]) {
			$returnData["show_photo"] = true;
			$returnData["show_video"] = true;
		}

		$returnJson["success"] = true;
		$returnJson["data"] = $returnData;
		return json_encode($returnJson);
	}

	/**
	 *  WebAPI interface
	 */
	function EditSmartAlbum($data)
	{
		$returnJson = array(
			"success" => false
		);

		if (!$json = json_decode($data, true)) {
			PhotoLog::Debug('not valid json format');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		if (!isset($json['name']) || 0 >= strlen($json['name']) ||
			!isset($json['orig_name']) || 0 >= strlen($json['orig_name']) ||
			!isset($json['show_photo']) || !isset($json['show_video']) ||
			empty($json['rule_sets']) || !is_array($json['rule_sets'])) {
			PhotoLog::Debug('some field is not set');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		$origAlbumName = $json['orig_name'];
		$albumName = $json['name'];
		$albumDesc = $json['desc'];
		$albumShowPhoto = !!$json['show_photo'];
		$albumShowVideo = !!$json['show_video'];
		$albumRuleSet = $json['rule_sets'];
		if ($json['cover']) {
			$albumCover = $json['cover'];
		}

		if (!$albumShowPhoto && !$albumShowVideo) {
			$albumShowPhoto = true;
			$albumShowVideo = true;
		}

		if (!$smartAlbumList = $this->ReadSmartAlbumFile()) {
			$smartAlbumList["smart_albums"] = array();
		}

		if (!isset($smartAlbumList["smart_albums"][$origAlbumName])) {
			PhotoLog::Debug("the smart album with name \"$albumName\" does not exist");
			$returnJson["error"]["code"] = 103;
			$returnJson["error"]["message"] = 'The smart album does not exist';
			return json_encode($returnJson);
		}

		unset($smartAlbumList["smart_albums"][$origAlbumName]);

		//to do!!
		//input format validation!!
		$smartAlbumList["smart_albums"][$albumName]["desc"] = $albumDesc;
		$smartAlbumList["smart_albums"][$albumName]["show_photo"] = $albumShowPhoto;
		$smartAlbumList["smart_albums"][$albumName]["show_video"] = $albumShowVideo;
		$smartAlbumList["smart_albums"][$albumName]["rule_sets"] = $albumRuleSet;
		if ($albumCover) {
			$smartAlbumList["smart_albums"][$albumName]["cover"] = $albumCover;
		}

		if (!$this->WriteSmartAlbumFile($smartAlbumList)) {
			PhotoLog::Debug("Write failed");
			$returnJson["error"]["code"] = 104;
			$returnJson["error"]["message"] = 'Write failed';
			return json_encode($returnJson);
		}

		$returnJson["success"] = true;
		return json_encode($returnJson);
	}

	/**
	 *  WebAPI interface
	 */
	function DeleteSmartAlbum($data)
	{
		$returnJson = array(
			"success" => false
		);

		if (!$json = json_decode($data, true)) {
			PhotoLog::Debug('not valid json format');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		if (!isset($json['name']) || 0 >= strlen($json['name'])) {
			PhotoLog::Debug('some field is not set');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		$albumName = $json['name'];

		if (!$smartAlbumList = $this->ReadSmartAlbumFile()) {
			PhotoLog::Debug("Read failed");
			$returnJson["error"]["code"] = 103;
			$returnJson["error"]["message"] = 'Read failed';
			return json_encode($returnJson);
		}

		if (!isset($smartAlbumList["smart_albums"][$albumName])) {
			PhotoLog::Debug("the smart album with name \"$albumName\" does not exist");
			$returnJson["error"]["code"] = 103;
			$returnJson["error"]["message"] = 'The smart album does not exist';
			return json_encode($returnJson);
		}

		unset($smartAlbumList["smart_albums"][$albumName]);

		if (!$this->WriteSmartAlbumFile($smartAlbumList)) {
			PhotoLog::Debug("Write failed");
			$returnJson["error"]["code"] = 104;
			$returnJson["error"]["message"] = 'Write failed';
			return json_encode($returnJson);
		}

		$returnJson["success"] = true;
		return json_encode($returnJson);
	}

	/**
	 *  WebAPI interface
	 */
	function ListSmartAlbum()
	{
		$returnJson = array(
			"success" => false
		);

		$data = array(
			"total" => 0,
			"albumList" => array()
		);

		$isAdmin = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);

		//convert smart album file into array
		if (!$smartAlbumList = $this->ReadSmartAlbumFile()) {
			$returnJson["data"] = $data;
			$returnJson["success"] = true;
			return json_encode($returnJson);
		}

		if (!is_array($smartAlbumList["smart_albums"])) {
			$returnJson["data"] = $data;
			$returnJson["success"] = true;
			return json_encode($returnJson);
		}

		foreach ($smartAlbumList["smart_albums"] as $key => $album) {
			if (!$album["show_photo"] && !$album["show_video"]) {
				$album["show_photo"] = true;
				$album["show_video"] = true;
			}

			if (!$isAdmin && 0 >= $this->GetItemCountInSmartAlbum($album)) {
				continue;
			}

			$data["albumList"][] = array(
				"name" => (string)$key,
				//"desc" => $album["desc"],
				"desc" => "",
				"cover" => $this->GetCoverOfSmartAlbum($album)
			);
			$data["total"]++;
		}

		$returnJson["data"] = $data;
		$returnJson["success"] = true;

		return json_encode($returnJson);
	}

	/**
	 *  WebAPI interface
	 */
	function ListItem($data, $sort_by = 'filename', $sort_direction = 'asc')
	{
		$returnJson = array(
			"success" => false
		);

		if (!$json = json_decode($data, true)) {
			PhotoLog::Debug('not valid json format');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		if (!isset($json['name']) || 0 >= strlen($json['name'])) {
			PhotoLog::Debug('some field is not set');
			$returnJson["error"]["code"] = 102;
			$returnJson["error"]["message"] = 'Bad Parameter';
			return json_encode($returnJson);
		}

		$smartAlbumName = $json['name'];
		$offset = (int)$json['offset'] > 0 ? (int)$json['offset']: 0;
		$limit = (int)$json['limit'] >= -1 ? (int)$json['limit']: 0;

		$data = array(
			"total" => 0,
			"itemList" => array()
		);

		if (!$smartAlbumList = $this->ReadSmartAlbumFile()) {
			$returnJson["data"] = $data;
			$returnJson["success"] = true;
			return json_encode($returnJson);
		}

		if (!is_array($smartAlbumList["smart_albums"])) {
			$returnJson["data"] = $data;
			$returnJson["success"] = true;
			return json_encode($returnJson);
		}

		$album = $smartAlbumList["smart_albums"][$smartAlbumName];

		if (isset($json['taken_date'])) {
			$rule_sets = array();
			$taken_date = $json['taken_date'];
			$dateStr = ($taken_date === '1970-01-01') ? 'unknown' : $taken_date . "," . $taken_date;
			$date_filter = array(
				"field" => 'date',
				"operator" => 'taken',
				"value" => $dateStr
			);

			foreach ($album["rule_sets"] as $ruleSetKey => $ruleSet) {
				$ruleSet[] = $date_filter; //append taken_date condition to rule set
				$rule_sets[] = $ruleSet;
			}
			$album["rule_sets"] = $rule_sets;
		} else if (isset($json['date_begin']) || isset($json['date_end'])) {
			$rule_sets = array();
			$dateStr = $json['date_begin']. "," . $json['date_end'];
			$date_filter = array(
				"field" => 'date',
				"operator" => 'taken',
				"value" => $dateStr
			);

			foreach ($album["rule_sets"] as $ruleSetKey => $ruleSet) {
				$ruleSet[] = $date_filter; //append taken_date condition to rule set
				$rule_sets[] = $ruleSet;
			}
			$album["rule_sets"] = $rule_sets;
		}

		if (empty($album)) {
			$returnJson["data"] = $data;
			$returnJson["success"] = true;
			return json_encode($returnJson);
		}

		if (!$album['show_photo'] && !$album['show_video']) {
			$album['show_photo'] = true;
			$album['show_video'] = true;
		}

		$data["itemList"] = array();
		$data["total"] = $this->GetItemCountInSmartAlbum($album);
		if ($data["total"] > 0) {
			$data["itemList"] = $this->GetItemsInSmartAlbum($album, $sort_by, $sort_direction, $offset, $limit);
		}

		$returnJson["data"] = $data;
		$returnJson["success"] = true;

		return json_encode($returnJson);
	}

	function SetSmartAlbumCover($data)
	{
		$returnJson = array("success" => false);

		$smartAlbumList = $this->ReadSmartAlbumFile();
		$albumName = $data['smart_name'];
		$albumCover = $data['cover'];

		$smartAlbumList["smart_albums"][$albumName]["cover"] = $albumCover;

		if (!$this->WriteSmartAlbumFile($smartAlbumList)) {
			PhotoLog::Debug("Write failed");
			$returnJson["error"]["code"] = 104;
			$returnJson["error"]["message"] = 'Write failed';
			return json_encode($returnJson);
		}

		$returnJson["success"] = true;
		return json_encode($returnJson);
	}

    function GetSmartCondition($smartAlbumName) {
        $smartAlbumList = $this->ReadSmartAlbumFile();
		$type = array();
        if ($smartAlbumList['smart_albums'][$smartAlbumName]['show_photo']) {
            array_push($type, 'photo');
        }
        if ($smartAlbumList['smart_albums'][$smartAlbumName]['show_video']) {
            array_push($type, 'video');
		}
		if ($smartAlbumList['smart_albums'][$smartAlbumName]['cover']) {
			$data['cover'] = $smartAlbumList['smart_albums'][$smartAlbumName]['cover'];
		}
		$data['type'] = implode(',', $type);
        $ruleSets = $smartAlbumList['smart_albums'][$smartAlbumName]['rule_sets'][0];
        foreach ($ruleSets as $rule) {
            switch ($rule['field']) {
			case 'albums':
				$arr = explode(',',$rule['value']);
				$albums = Album::GetByShareId($arr);
				$albumIds = $this->GetAlbumId($albums);
				$data['albums'] = $albumIds;
				break;
			case 'keyword':
                $data['keyword'] = $rule['value'];
                $data['keyword_op'] = $rule['operator'];
                break;
            case 'date':
                $data['date'] = $rule['value'];
                $data['date_op'] = $rule['operator'];
                break;
            case 'people':
                $arr = explode(',', $rule['value']);
                $peopleArr = array();
                foreach ($arr as $id) {
                    array_push($peopleArr, 'tag_'.$id);
                }
                $data['people_tag'] = implode(',', $peopleArr);
                $data['people_tag_op'] = $rule['operator'];
                break;
            case 'geo':
                $arr = explode(',', $rule['value']);
                $geoArr = array();
                foreach ($arr as $id) {
                    array_push($geoArr, 'tag_'.$id);
                }
                $data['geo_tag'] = implode(',', $geoArr);
                $data['geo_tag_op'] = $rule['operator'];
                break;
            case 'desc':
                $arr = explode(',', $rule['value']);
                $descArr = array();
                foreach ($arr as $id) {
                    array_push($descArr, 'tag_'.$id);
                }
                $data['desc_tag'] = implode(',', $descArr);
                $data['desc_tag_op'] = $rule['operator'];
                break;
            case 'recently_add':
                $data['recently_add'] = $rule['value'];
                break;
            case 'recently_comment':
                $data['recently_comment'] = $rule['value'];
				break;
			case 'camera':
				$arr = explode(',', $rule['value']);
				$cameraArr = array();
				foreach($arr as $camera) {
					array_push($cameraArr, 'camera_make_'.$camera);
				}
				$data['camera'] = implode(',', $cameraArr);
				$data['camera_op'] = $rule['operator'];
				break;
			case 'model':
				$arr = explode(',', $rule['value']);
				$modelArr = array();
				foreach($arr as $model) {
					array_push($modelArr, 'camera_model_'.$model);
				}
				$data['model'] = implode(',', $modelArr);
				$data['model_op'] = $rule['operator'];
				break;
			case 'exposure':
				$arr = explode(',', $rule['value']);
				$exposureArr = array();
				foreach($arr as $exposure) {
					array_push($exposureArr, 'exposure_'.$exposure);
				}
				$data['exposure'] = implode(',', $exposureArr);
				$data['exposure_op'] = $rule['operator'];
				break;
			case 'aperture':
				$arr = explode(',', $rule['value']);
				$apertureArr = array();
				foreach($arr as $aperture) {
					array_push($apertureArr, 'aperture_'.$aperture);
				}
				$data['aperture'] = implode(',', $apertureArr);
				$data['aperture_op'] = $rule['operator'];
				break;
			case 'iso':
				$arr = explode(',', $rule['value']);
				$isoArr = array();
				foreach($arr as $iso) {
					array_push($isoArr, 'iso_'.$iso);
				}
				$data['iso'] = implode(',', $isoArr);
				$data['iso_op'] = $rule['operator'];
				break;
			case 'focal':
				$arr = explode(',', $rule['value']);
				$focalArr = array();
				foreach($arr as $focal) {
					array_push($focalArr, 'focal_length_'.$focal);
				}
				$data['focal'] = implode(',', $focalArr);
				$data['focal_op'] = $rule['operator'];
				break;
			case 'lens':
				$arr = explode(',', $rule['value']);
				$lensArr = array();
				foreach($arr as $lens) {
					array_push($lensArr, 'lens_'.$lens);
				}
				$data['lens'] = implode(',', $lensArr);
				$data['lens_op'] = $rule['operator'];
				break;
			case 'flash':
				$arr = explode(',', $rule['value']);
				$flashArr = array();
				foreach($arr as $flash) {
					array_push($flashArr, 'flash_'.$flash);
				}
				$data['flash'] = implode(',', $flashArr);
				$data['flash_op'] = $rule['operator'];
				break;
			case 'rating':
				$arr = explode(',', $rule['value']);
				$ratingArr = array();
				foreach($arr as $rating) {
					array_push($ratingArr, 'rating_'.$rating);
				}
				$data['rating'] = implode(',', $ratingArr);
				$data['rating_op'] = $rule['operator'];
				break;
            default:
                break;
            }
        }
        return $data;
    }
	function _ReadSmartAlbumFile()
	{
		$smartAlbumFile = SYNOPHOTO_SERVICE_DIR."/".SYNOPHOTO_EADIR.'/'. self::SmartJSON;
		//test whether smart album file config exist or not
		if (!@file_exists($smartAlbumFile)) {
			return null;
		}

		//get contents from smart album config file
		if (!$smartAlbumJsonStr = @file_get_contents($smartAlbumFile)) {
			return null;
		}

		//parse contents
		if (!$smartAlbumList = json_decode($smartAlbumJsonStr, true)) {
			return null;
		}

		return $smartAlbumList;
	}

	function ReadSmartAlbumFile()
	{
		return $this->smartAlbumList;
	}

	public static function GetByNames($names)
	{
		$obj = self::GetSmartAlbumInstance();
        $smartAlbumList = $obj->ReadSmartAlbumFile();

		$res = array();
		foreach ($names as $name) {
			$smartAlbumList['smart_albums'][$name]['name'] = $name;
			$res[$name] = $smartAlbumList["smart_albums"][$name];
		}
		return $res;
	}

	function WriteSmartAlbumFile($smartAlbumList)
	{
		$eaDir = SYNOPHOTO_SERVICE_DIR."/".SYNOPHOTO_EADIR;
		$smartAlbumFile = $eaDir.'/'.self::SmartJSON;

		//encode smart album list to json string
		if (!$smartAlbumListJsonStr = json_encode($smartAlbumList)) {
			return false;
		}

		//beautify json string
		$smartAlbumListJsonStr = csSYNOPhotoMisc::indentJson($smartAlbumListJsonStr);

		//create @eaDir
		if(!@file_exists($eaDir)) {
			@mkdir($eaDir);
		}

		//put contents to smart album config file
		if (!@file_put_contents($smartAlbumFile, $smartAlbumListJsonStr)) {
			return false;
		}

		$this->smartAlbumList = $smartAlbumList;
		return true;
	}

    static function _GetRecentlyAddSqlCondition($album)
    {
        foreach ($album['rule_sets'][0] as $rule) {
            if ('date' == $rule['field'] && 'recently_add' === $rule['operator']) {
                $sqlCondition = array(
                    'order' => "createdate DESC",
                    'value' => $rule['value']
                );
                break;
            }
        }
        return $sqlCondition;
    }

    static function GetRecentlyAddSqlCondition($album, $type)
    {
        $field = ('photo' === $type) ? 'create_time' : 'date';

        foreach ($album['rule_sets'][0] as $rule) {
            if ('date' == $rule['field'] && 'recently_add' === $rule['operator']) {
                $sqlCondition = array(
                    'order' => "$field DESC",
                    'value' => $rule['value']
                );
                break;
            }
        }
        return $sqlCondition;
    }

    static function GetRecentlyCommentSqlCondition($album, $type, $ref='')
    {
        $table = ('photo' === $type) ? 'photo_image' : 'video';
        $table = $ref != '' ? $ref : $table;
        $field = ('photo' === $type) ? 'id' : 'path';
        $commentTable = ('photo' === $type) ? 'photo_comment' : 'video_comment';
        $commentField = ('photo' === $type) ? 'photo_id' : 'path';
        $commentFieldAs = ('photo' === $type) ? 'photo_id' : 'video_path';

        foreach ($album['rule_sets'][0] as $rule) {
            if ('date' == $rule['field'] && 'recently_comment' === $rule['operator']) {
                $sqlCondition = array(
                    'query' => "LEFT JOIN (SELECT $commentField AS $commentFieldAs, max(date) AS comment_time FROM $commentTable GROUP BY $commentField) comment " .
                        "ON $table.$field = comment.$commentFieldAs",
                    'cond' => 'comment_time IS NOT NULL',
                    'order' => 'comment_time DESC',
                    'value' => $rule['value']
                );
                break;
            }
        }
        return $sqlCondition;
    }

	static function FilterFeatured ($itemList, $total, $count)
	{
		$interval = $count > 0 && $total > $count ? round($total / $count): 1;
		$list = array();
		$itemKeys = array('photo' => array(), 'video' => array());
		$idx = -1;
		foreach ($itemList as $item) {
			if ($count > 0 && count($list) > $count) {
				break;
			}
			if ((++$idx % $interval)) {
				continue;
			}
			$item['pos'] = $idx;
			// convert fullpath to db path
			$item['path'] = substr($item['path'], strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
			$itemKeys[$item['type']][] = $item['path'];
			$list[$item['path']] = $item;
		}

		$itemObjs = array(
			'photo' => File::GetPhotoByDBPath(array_values($itemKeys['photo'])),
			'video' => File::GetVideoByDBPath(array_values($itemKeys['video']))
		);

		$objs = array();
		foreach ($list as $key => $value) {
			$obj = $itemObjs[$value['type']][$key];
			$obj['pos'] = $value['pos'];
			$obj['type'] = $value['type'];
			$objs[] = $obj;
		}
		return $objs;
	}

	function ListGPSGroup ($name, $bounds, $zoom)
	{
		$smartAlbum = self::GetByNames(array($name));
		$itemObjs = $this->GetItemsInSmartAlbum($smartAlbum[$name], 'id', 'asc', 0, -1, true);
		list($degree, $precision) = File::GetGroupParams($zoom);

		// grouping and filtering

		$grids = array();
		$itemKeys = array();
		foreach($itemObjs as $item) {
			if ('video' === $item['type'] || !$item['gps']) {
				continue;
			}
			$latIdx = round($item['lat'] / $degree);
			$lngIdx = round($item['lng'] / $degree);

			if (!$grids["$latIdx,$lngIdx"]) {
				$grids["$latIdx,$lngIdx"] = array(
					'gps_idx' => array('lat' => $latIdx, 'lng' => $lngIdx, 'zoom' => $zoom),
					'count'	=> 0
				);
				$itemKeys["$latIdx,$lngIdx"] = $item['path'];
			}
			$grids["$latIdx,$lngIdx"]['count']++;
		}

		$itemObjs = File::GetPhotoByDBPath(array_values($itemKeys));
		foreach ($grids as $key => &$group) {
			$group['item'] = $itemObjs[$itemKeys[$key]];
		}
		return array('total' => count($grids), 'groups' => $grids);
	}

	function ListGPSGroupedItem ($name, $idx, $zoom, $limit, $offset)
	{
		$smartAlbum = self::GetByNames(array($name));
		$itemObjs = $this->GetItemsInSmartAlbum($smartAlbum[$name], 'id', 'asc', 0, -1, true);
		list($degree, $precision) = File::GetGroupParams($zoom);

		$maxLat = ($idx['lat'] + 0.5) * $degree - 0.000001;
		$minLat = ($idx['lat'] - 0.5) * $degree;

		$maxLng = ($idx['lng'] + 0.5) * $degree - 0.000001;
		$minLng = ($idx['lng'] - 0.5) * $degree;
		if ($minLng > $maxLng) {
			list($minLng, $maxLng) = array($maxLng, $minLng);
		}

		// grouping and filtering
		$itemKeys = array();
		$total = 0;
		foreach($itemObjs as $item) {
			if ('video' === $item['type'] || !$item['gps']) {
				continue;
			}
			if ($minLat > $item['lat'] || $item['lat'] > $maxLat || $minLng > $item['lng'] || $item['lng'] > $maxLng) {
				continue;
			}
			$itemKeys[] = $item['path'];
			$total++;
		}

		if ($limit < 0) {
			$limit = NULL;
		}

		$photos = array_slice($itemKeys, $offset, $limit);

		$itemObjs = File::GetPhotoByDBPath(array_values($photos));
		$res = array();
		foreach ($photos as $path) {
			$res[] = $itemObjs[$path];
		}
		return array('total' => $total, 'items' => $res);
	}

	function GetItemsInSmartAlbum($album, $sort_by, $sort_direction, $offset = 0, $limit = 0, $gps = false)
	{
		$param = $videoPath = $photoIds = $result = array();

		$recentlyAddSqlCond = SmartAlbum::_GetRecentlyAddSqlCondition($album);

		if ($album['show_photo']) {
			$photoIds = $this->GetSmartAlbumToIds($album, 'photo');
			$photoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($album, 'photo');
		}
		if ($album['show_video']) {
			$videoPath = $this->GetSmartAlbumToIds($album, 'video');
			$videoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($album, 'video');
		}

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat();
		if (!$albumCondition['albumCond']) {
			goto END;
		}

		//query photos
		if ($album['show_photo']) {
			$photoSelect = "SELECT 'photo' as type, id, path, name as filename, title, timetaken as takendate, create_time as createdate, description, rating";
			if ($gps) {
				$photoSelect .= ", gps, lat, lng";
			}
			$photoFrom = " FROM photo_image ";
			$cond = "WHERE ({$albumCondition['albumCond']})";

			if (false === $photoIds) {
				// empty condition, do nothing
			} else if (0 < count($photoIds)) {
				$cond .= " AND id IN (".implode(',', $photoIds).")";
			} else if (0 === count($photoIds)) {
				$cond .= " AND 1!=1 ";
			}

			$photoQuery = "$photoSelect $photoFrom";
			if ($photoRecentlyCommentSqlCond) {
				$photoQuery = "$photoSelect, comment_time $photoFrom {$photoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$photoRecentlyCommentSqlCond['cond']}";
			}

			if (false !== $photoIds && 0 === count($photoIds)) {
				$photoQuery = '';
			} else {
				$photoQuery = "$photoQuery $cond";
			}
		}

		//query videos
		if (!$gps && $album['show_video']) {
			$videoSelect = "SELECT 'video' as type, video.id, video.path, video.title as filename, video_desc.title, mdate as takendate, date as createdate, description, rating ";
			$videoFrom = " FROM video LEFT JOIN (SELECT title, path as desc_path, description FROM video_desc) video_desc ON video.path = desc_path ";
			$cond = "WHERE ({$albumCondition['albumCond']})";

			$param = $videoPath;
			if (false === $videoPath) {
				$param = array();
			} else if (0 < count($videoPath)) {
				$path = array();
				for ($i=0; $i < count($videoPath); ++$i) {
					$path[] = '?';
				}
				$cond .= " AND video.path IN (".implode(',', $path).")";
			} else if (0 === count($videoPath)) {
				$cond .= " AND 1!=1 ";
			}

			$videoQuery = "$videoSelect $videoFrom";
			if ($videoRecentlyCommentSqlCond) {
				$videoQuery = "$videoSelect, comment_time $videoFrom {$videoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$videoRecentlyCommentSqlCond['cond']}";
			}

			if (false !==  $videoPath && 0 == count($videoPath)) {
				$videoQuery = '';
			} else {
				$videoQuery = "$videoQuery $cond";
			}
		}

		$queryParam = $this->formPhotoVideoUnionQuery($photoQuery, $albumCondition['sqlParam'], $videoQuery, array_merge($albumCondition['sqlParam'], $param));

		if (false == $queryParam) {
			goto END;
		}

		$mainQuery = $queryParam["query"];
		$param = $queryParam["param"];

		$listOrder = "$sort_by $sort_direction, path $sort_direction";
		if ($recentlyAddSqlCond) {
			$recentlyAddCommentOrder = $recentlyAddSqlCond['order'];
			$recentlyAddCommentLimit = $recentlyAddSqlCond['value'];
		} else if ($photoRecentlyCommentSqlCond || $videoRecentlyCommentSqlCond) {
			$recentlyAddCommentOrder = $photoRecentlyCommentSqlCond['order'];
			$recentlyAddCommentLimit = $photoRecentlyCommentSqlCond['value'];
		}

		$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);

		if ($recentlyAddCommentOrder) {
			$unionSQL = "SELECT * FROM ($mainQuery ORDER BY $recentlyAddCommentOrder LIMIT $recentlyAddCommentLimit) as tmp ORDER BY $listOrder $limitOffsetString";
		} else {
			$unionSQL = "$mainQuery ORDER BY $listOrder $limitOffsetString";
		}
		$dbResult = PHOTO_DB_Query($unionSQL, $param);

		while($row = $dbResult->fetch()) {
			$item = array(
				'type'	=> $row['type'],
				'id'	=> $row['id'],
				'path'	=> SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'],
				'name'	=> basename($row['name']),
				'takendate'=> $row['takendate'],
				'createdate'=> $row['createdate'],
				'description'=> $row['description'],
				'commentdate' => $row['comment_time'],
				'gps'	=> $row['gps'],
				'lat'	=> $row['lat'] + 0,
				'lng'	=> $row['lng'] + 0,
				'rating' => $row['rating']
			);
			$result[] = $item;
		}
	END:
		return $result;
	}

	private function GetItemCountInSmartAlbum($album)
	{
		$returnCount = 0;

		if ($album['show_photo']) {
			$photoIds = $this->GetSmartAlbumToIds($album, 'photo');
            $photoRecentlyAddSqlCond = SmartAlbum::GetRecentlyAddSqlCondition($album, 'photo');
            $photoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($album, 'photo', "A");
		}
		if ($album['show_video']) {
			$videoPath = $this->GetSmartAlbumToIds($album, 'video');
            $videoRecentlyAddSqlCond = SmartAlbum::GetRecentlyAddSqlCondition($album, 'video');
            $videoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($album, 'video', "A");
		}

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat('A');
		if (!$albumCondition['albumCond']) {
			goto END;
		}

		$recentlyCount = false;

		if (0 < count($photoIds) || $photoRecentlyAddSqlCond || $photoRecentlyCommentSqlCond) {
			$query = "SELECT count(*) FROM photo_image as A";
			$cond = "WHERE ({$albumCondition['albumCond']})";

			if (false === $photoIds) {
				// empty condition, do nothing
			} else if (0 < count($photoIds)) {
				$cond .= " AND A.id IN (".implode(',', $photoIds).")";
			} else if (0 === count($photoIds)) {
				$cond .= " AND 1!=1 ";
			}

			if ($photoRecentlyAddSqlCond) {
				$recentlyCount = $photoRecentlyAddSqlCond['value'];
			} elseif ($photoRecentlyCommentSqlCond) {
				$query .= " {$photoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$photoRecentlyCommentSqlCond['cond']}";
				$recentlyCount = $photoRecentlyCommentSqlCond['value'];
			}

			$query = "$query $cond";

			$dbResult = SmartAlbum::GetSmartAlbumInstance()->_dbh->prepare($query);
			$dbResult->execute($albumCondition['sqlParam']);

			if (false !== ($row = $dbResult->fetch())) {
				$returnCount += (int)$row[0];
			}
		}

		if (0 < count($videoPath) || $videoRecentlyAddSqlCond || $videoRecentlyCommentSqlCond) {
			$query = "SELECT COUNT(*) FROM".
				" video as A LEFT JOIN video_desc ON A.path = video_desc.path ";
			$cond = "WHERE ({$albumCondition['albumCond']})";

			$param = $videoPath;
			if (false === $videoPath) {
				$param = array();
			} else if (0 < count($videoPath)) {
				$path = array();
				for ($i=0; $i < count($videoPath); ++$i) {
					$path[] = '?';
				}
				$cond .= " AND A.path IN (".implode(',', $path).")";
			} else if (0 === count($videoPath)) {
				$cound .= " AND 1!=1 ";
			}

			if ($videoRecentlyAddSqlCond) {
				$recentlyCount = $videoRecentlyAddSqlCond['value'];
			} elseif ($videoRecentlyCommentSqlCond) {
				$query .= " {$videoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$videoRecentlyCommentSqlCond['cond']}";
				$recentlyCount = $videoRecentlyCommentSqlCond['value'];
			}

			$query = "$query $cond";

			$dbResult = SmartAlbum::GetSmartAlbumInstance()->_dbh->prepare($query);
			$dbResult->execute(array_merge($albumCondition['sqlParam'], $param));

			if (false !== ($row = $dbResult->fetch())) {
				$returnCount += (int)$row[0];
			}
		}

		if (false !== $recentlyCount) { //recently condition is set
			if ($returnCount > $recentlyCount) {
				$returnCount = $recentlyCount;
			}
		}

	END:
		return $returnCount;
	}

	function GetCoverOfSmartAlbumByName($albumName) {
		$data['success'] = false;

		$isAdmin = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);

		//convert smart album file into array
		if (!$smartAlbumList = $this->ReadSmartAlbumFile()) {
			return $data;
		}

		if (!is_array($smartAlbumList["smart_albums"])) {
			return $data;
		}

		foreach ($smartAlbumList["smart_albums"] as $key => $album) {
			if ((string)$key === (string)$albumName) {
				$hasCover = false;
				if (!empty($smartAlbumList["smart_albums"][$albumName]['cover'])) {
					$cover = $smartAlbumList["smart_albums"][$albumName]['cover'];
					if (csSYNOPhotoMisc::CheckPathAccessible($cover['path']) && $this->CheckPathInSmart($album, $cover['path'], $cover['type'], $cover['id'])) {
						$hasCover = true;
						$data = array(
							"success" => true,
							"name" => (string)$key,
							"cover" => $cover
						);
					}
				}

				if (!$hasCover) {
					$count = $this->GetItemCountInSmartAlbum($album);
					if (!$isAdmin && 0 >= $count) {
						break;
					}

					$data = array(
						"success" => true,
						"name" => (string)$key,
						"cover" => $count > 0 ? $this->GetCoverOfSmartAlbum($album) : ''
					);
				}

				break;
			}
		}

		return $data;
	}

	private function CheckPathInSmart($album, $path, $type, $id) {
		$ids = $this->GetSmartAlbumToIds($album, $type);

		if (false === $ids) {
			$result = $this->GetItemsInSmartAlbum($album, 'id', 'asc', 0, -1);
			foreach ($result as $item) {
				if ($item['id'] === $id) {
					return true;
				}
			}
		} else if (0 < count($ids)){
			if ($type === 'photo' && in_array($id, $ids)) {
				return true;
			} else if ($type === 'video' && in_array($path, $ids)) {
				return true;
			}
		}

		return false;

	}

	private function GetCoverOfSmartAlbum($album)
	{
		$returnCover = '';
		$photoQuery = $videoQuery = '';
		$param = $videoPath = $photoIds = array();

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat();
		if (!$albumCondition['albumCond']) {
			goto END;
		}

		$recentlyAddSqlCond = SmartAlbum::_GetRecentlyAddSqlCondition($album);

		if ($album['show_photo']) {
			$photoIds = $this->GetSmartAlbumToIds($album, 'photo');
            $photoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($album, 'photo');

			$select = "SELECT 'photo' as type, path, create_time as createdate ";
			$from = "FROM photo_image ";
			$cond = "WHERE ({$albumCondition['albumCond']})";

			if (false === $photoIds) {
				// empty condition, do nothing
			} else if (0 < count($photoIds)) {
				$cond .= " AND id IN (".implode(',', $photoIds).")";
			} else if (0 === count($photoIds)) {
				$cond .= " AND 1!=1 ";
			}
			$query = "$select $from";
			if ($photoRecentlyCommentSqlCond) {
				$query = "$select, comment_time $from {$photoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$photoRecentlyCommentSqlCond['cond']}";
			}
			if (false !== $photoIds && 0 == count($photoIds)) {
				$photoQuery = '';
			} else {
				$photoQuery = "$query $cond";
			}
		}

		if ($album['show_video']) {
			$videoPath = $this->GetSmartAlbumToIds($album, 'video');
            $videoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($album, 'video');

			$select = "SELECT 'video' as type, video.path, date as createdate ";
			$from = " FROM video LEFT JOIN (SELECT title, path as desc_path, description FROM video_desc) video_desc ON video.path = video_desc.desc_path ";
			$cond = "WHERE ({$albumCondition['albumCond']})";

			$param = $videoPath;
			if (false === $videoPath) {
				$param = array();
			} else if (0 < count($videoPath)) {
				$path = array();
				for ($i=0; $i < count($videoPath); ++$i) {
					$path[] = '?';
				}
				$cond .= " AND video.path IN (".implode(',', $path).")";
			} else if (0 === count($videoPath)) {
				$cond .= " AND 1!=1 ";
			}
			$query = "$select $from";
			if ($videoRecentlyCommentSqlCond) {
				$query = "$select, comment_time $from {$videoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$videoRecentlyCommentSqlCond['cond']}";
			}

			if (false !== $videoPath && 0 == count($videoPath)) {
				$videoQuery = '';
			} else {
				$videoQuery = "$query $cond";
			}
		}

		$queryParam = $this->formPhotoVideoUnionQuery($photoQuery, $albumCondition['sqlParam'], $videoQuery, array_merge($albumCondition['sqlParam'], $param));

		if (false == $queryParam) {
			goto END;
		}

		$mainQuery = $queryParam["query"];
		$param = $queryParam["param"];

		$listOrder = "createdate DESC, path";
		if ($recentlyAddSqlCond) {
			$recentlyAddCommentOrder = $recentlyAddSqlCond['order'];
			$recentlyAddCommentLimit = $recentlyAddSqlCond['value'];
		} else if ($photoRecentlyCommentSqlCond || $videoRecentlyCommentSqlCond) {
			$recentlyAddCommentOrder = $photoRecentlyCommentSqlCond['order'];
			$recentlyAddCommentLimit = $photoRecentlyCommentSqlCond['value'];
		}

		if ($recentlyAddCommentOrder) {
			$sql = "SELECT * FROM ($mainQuery ORDER BY $recentlyAddCommentOrder LIMIT $recentlyAddCommentLimit) as tmp ORDER BY $listOrder LIMIT 1";
		} else {
			$sql = "$mainQuery ORDER BY $listOrder LIMIT 1";
		}
		$dbResult = PHOTO_DB_Query($sql, $param);

		if ($row = $dbResult->fetch()) {
			$returnCover = array(
				'type'	=> $row['type'],
				'dbPath' => $row['path'],
				'path'	=> SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path']
			);
		}

	END:
		return $returnCover;
	}

	function formPhotoVideoUnionQuery($photoQuery, $photoCond, $videoQuery, $videoCond)
	{
		$result = false;
		if ('' === $photoQuery && '' === $videoQuery) {
			goto END;
		}

		$mainQuery = "";
		$param = array();
		if ($photoQuery && $videoQuery) {
			$mainQuery = "$photoQuery UNION ALL $videoQuery";
			$param = array_merge($photoCond, $videoCond);
		} else if ($photoQuery) {
			$mainQuery = $photoQuery;
			$param = $photoCond;
		} else {
			$mainQuery = $videoQuery;
			$param = $videoCond;
		}

		$result = array(
			"query" => $mainQuery,
			"param" => $param
		);

	END:
		return $result;
	}

	protected function SortByCreateDate($a, $b)
	{
		if ($a['createdate'] === $b['createdate']) {
			return 0;
		}
		return ($a['createdate'] < $b['createdate']) ? 1 : -1;
	}

	protected function SortByCommentDate($a, $b)
	{
		if ($a['commentdate'] === $b['commentdate']) {
			return 0;
		}
		return ($a['commentdate'] < $b['commentdate']) ? 1 : -1;
	}

	function GetSmartAlbumToIds($album, $type)
	{
		$operator = 'and';
		$result = array();
		if (!is_array($album["rule_sets"])) {
			goto END;
		}

		$first = true;
		foreach ($album["rule_sets"] as $ruleSetKey => $ruleSet) {
			$ids = $this->GetRuleSetToIds($ruleSet, $type);

			if (true == $first) {
				$result = $ids;
				$first = false;
				continue;
			}

			if (false === $ids) {
				continue;
			} else if ('and' == $operator) {
				$result = array_intersect($ids, $result);
			} else {
				$result = array_unique(array_merge($ids, $result));
			}
		}

	END:
		return $result;
	}

	private function GetRuleSetToIds($ruleSet, $type)
	{
		$imageIds = array();

		if (!is_array($ruleSet) || empty($ruleSet)) {
			goto End;
		}

		$ruleCount = 0;
		foreach ($ruleSet as $key => $rule) {
			if (!isset($rule['field']) || '' == $rule['field'] ||
				!isset($rule['operator']) || '' == $rule['operator'] ||
				!isset($rule['value'])  || '' == $rule['value']) {
				continue;
			}
			$ids = $this->GetImageIdsByCondition($rule, $type, $imageIds);
			if (false === $ids) {
				$ruleCount++;
				continue;
			} else if (0 == count($ids)) {
				$imageIds = array();
				break;
			} else if (0 == count($imageIds)) {
				$imageIds = $ids;
			} else {
				$imageIds = array_intersect($ids, $imageIds);
				if (0 == count($imageIds)) {
					break;
				}
			}
		}
		if (count($ruleSet) == $ruleCount) {
			$result = false;
		} else {
			$result = $imageIds;
		}
	End:
		return $result;
	}

	private function GetImageIdsByCondition($rule, $type, $imageIds = array())
	{
		$result = false;
		if ('keyword' === $rule['field']) {
			$result = $this->GetImageIdsByKeyword($rule['value'], $rule['operator'], $type);

		} else if ('date' === $rule['field'] && 'taken' === $rule['operator']) {
			$result = $this->GetImageIdsByTaken($rule['value'], $type);

		} else if ('date' === $rule['field'] && 'upload' === $rule['operator']) {
			$result = $this->GetImageIdsByUpload($rule['value'], $type);

		} else if (in_array($rule['field'], array('geo', 'people', 'desc'))) {
			$result = $this->GetImageIdsByTag($rule['value'], $rule['operator'], $type);
		} else if ('albums' === $rule['field']) {
			$result = $this->GetImageIdsByAlbum($rule['value'], $rule['operator'], $type);
		} else if (array_key_exists($rule['field'], self::$exif2Column)) {
			$result = $this->GetImageIdsByExif($rule['value'], $rule['operator'], self::$exif2Column[$rule['field']], $type);
		}
		return $result;
	}

	private function GetImageIdsByKeyword($keywordStr, $operator = 'all', $type = 'photo')
	{
		$fields = 'photo' == $type ? array("name", "title", 'description', 'label_name') : array('title', 'description', 'label_name', 'desc_title');
		if (!is_string($keywordStr) || 0 >= strlen(trim($keywordStr))) {
			goto End;
		}

		$keywords = strtolower(trim($keywordStr));

		if ('all' === $operator || 'any' === $operator) {
			$keywords = array_unique(explode(' ', $keywords));
		} else {
			$keywords = array($keywords);
		}

		$result = NULL;
		foreach ($keywords as &$keyword) {
			if ('' === $keyword) {
				continue;
			}

			$ids = $cond = $param = array();

			foreach ($fields as $field) {
				$cond[] = "lower($field) like ? {$this->escapeStr}";
				$value = csSYNOPhotoDB::GetDBInstance()->EscapeLikeParam($keyword);
				$param[] = "%{$value}%";
			}

			$keyword = '('.implode(' OR ', $cond).')';

			if ('photo' === $type) {
				$query = "SELECT distinct(photo_image.id) FROM photo_image LEFT JOIN".
					" (SELECT photo_image_label.*, photo_label.name AS label_name FROM photo_image_label LEFT JOIN".
					" photo_label ON photo_label.id = photo_image_label.label_id) photo_image_label".
					" ON photo_image.id = photo_image_label.image_id ".
					" WHERE $keyword";
			} else if ('video' === $type) {
				$query = "SELECT distinct(video.path) FROM ".
					" (SELECT description, video_desc.title as desc_title, video.title as title, video.path FROM video ".
					"      LEFT JOIN video_desc ON video.path = video_desc.path) video LEFT JOIN ".
					" (SELECT photo_video_label.*, photo_label.name AS label_name FROM photo_video_label LEFT JOIN".
					" photo_label ON photo_label.id = photo_video_label.label_id) photo_video_label ON video.path = photo_video_label.video_path ".
					" WHERE $keyword";
			}

			if (!($dbResult = PHOTO_DB_Query($query, $param))) {
				goto End;
			}

			while($row = $dbResult->fetch()) {
				$ids[] = $row[0];
			}

			if ('all' === $operator) {
				$result = NULL === $result ? $ids : array_intersect($ids, $result);
			} else if ('any' === $operator) {
				$result = NULL === $result ? array_unique($ids) : array_unique(array_merge($ids, $result));
			} else {
				$result = $ids;
			}
		}
	End:
		return $result;
	}

	private function GetImageIdsByTaken($dateStr, $type = 'photo')
	{
		$field = 'photo' === $type ? 'timetaken' : 'mdate';
		return $this->GetImageIdsByDate($dateStr, $field, $type);
	}

	private function GetImageIdsByUpload($dateStr, $type = 'photo')
	{
		$field = 'photo' === $type ? 'create_time' : 'date';
		return $this->GetImageIdsByDate($dateStr, $field, $type);
	}

	private function GetImageIdsByDate($dateStr, $field, $type)
	{
		$result = array();

		if (!is_string($dateStr) || 0 >= strlen(trim($dateStr))) {
			goto End;
		}

		if ('unknown' === $dateStr) {
			if ('photo' === $type) {
				$cond = "(timetaken IS NULL OR date(timetaken)='1970-01-01')";
			} else {
				$cond = "(mdate IS NULL OR date(mdate)='1970-01-01')";
			}
		} else {
			$dates = explode(',' , trim($dateStr));
			$begin = strtotime($dates[0]);
			$end = strtotime($dates[1]);

			if (false === $begin && false === $end) {
				goto End;
			} else if (false !== $begin) {
				$cond = "$field >= '".date('Y-m-d', $begin)." 00:00:00'";
				if (false !== $end) {
					$cond .= " AND $field <= '".date('Y-m-d', $end)." 23:59:59'";
				}
			} else {
				$cond = "$field <= '".date('Y-m-d', $end)." 23:59:59'";
			}
		}

		if ('photo' == $type) {
			$query = "SELECT id FROM photo_image WHERE $cond";
		} else if ('video' == $type) {
			$query = "SELECT path FROM video WHERE $cond";
		}

		if (!($dbResult = PHOTO_DB_Query($query))) {
			goto End;
		}

		while ($row = $dbResult->fetch()) {
			$result[] = $row[0];
		}

	End:
		return $result;
	}

	private function GetImageIdsByTag($tagStr, $operator = 'all', $type = 'photo')
	{
		$result = array();
		$param = array();

		if (!is_string($tagStr) || 0 >= strlen(trim($tagStr))) {
			goto End;
		}

		$tags = explode(',' , trim($tagStr));

		foreach ($tags as &$tag) {
			if (!is_numeric(trim($tag))) {
				continue;
			}
			$param[] = intval($tag);
		}
		$count = count($param);
		if (0 == $count) {
			goto End;
		}

		$query = '';
		$sqlParam = array();

		if ('all' === $operator) {
			if ('photo' === $type) {
				$query = "SELECT image_id FROM photo_image_label ".
					" WHERE label_id IN (" . csSYNOPhotoDB::GetArrayQueryPlaceholder($param) . ")".
					" GROUP BY image_id HAVING COUNT(label_id) = ?";
			} else if ('video' === $type) {
				$query = "SELECT video_path FROM photo_video_label ".
					" WHERE label_id IN (" . csSYNOPhotoDB::GetArrayQueryPlaceholder($param) . ")".
					" GROUP BY video_path HAVING COUNT(label_id) = ?";
			}
			$sqlParam = array_merge($param, array($count));
		} else if ('any' === $operator) {
			if ('photo' === $type) {
				$query = "SELECT DISTINCT(image_id) FROM photo_image_label ".
					" WHERE label_id IN (" . csSYNOPhotoDB::GetArrayQueryPlaceholder($param) . ")";
			} else if ('video' === $type) {
				$query = "SELECT DISTINCT(video_path) FROM photo_video_label ".
					" WHERE label_id IN (" . csSYNOPhotoDB::GetArrayQueryPlaceholder($param) . ")";
			}
			$sqlParam = $param;
		}

		if ($query) {
			if (!($dbResult = PHOTO_DB_Query($query, $sqlParam))) {
				goto End;
			}

			while ($row = $dbResult->fetch()) {
				$result[] = $row[0];
			}
		}

	End:
		return $result;
	}

	private function GetImageIdsByAlbum($albumStr, $operator = 'any', $type = 'photo')
	{
		$result = array();
		$param = array();

		if (!is_string($albumStr) || 0 >= strlen(trim($albumStr))) {
			goto End;
		}

		$shareids = explode(',',$albumStr);
		foreach ($shareids as &$shareid) {
			if (!is_numeric(trim($shareid))) {
				continue;
			}
			$param[] = intval($shareid);
		}
		$count = count($param);
		if (0 == $count) {
			goto End;
		}

		$query = '';

		if ('photo' === $type) {
			$query = "SELECT DISTINCT (id) FROM photo_image ".
				" WHERE shareid IN (" . csSYNOPhotoDB::GetArrayQueryPlaceholder($param) . ")";
		} else if ('video' === $type) {
			$query = "SELECT DISTINCT (path) FROM video ".
				" WHERE shareid IN (" . csSYNOPhotoDB::GetArrayQueryPlaceholder($param) . ")";
		}

		if ($query) {
			if (!($dbResult = PHOTO_DB_Query($query, $param))) {
				goto End;
			}
			while ($row = $dbResult->fetch()) {
				$result[] = $row[0];
			}
		}
		End:
			return $result;
	}

	private function GetAlbumId($albums) {
		$retArr = array();
		foreach ($albums as $album) {
			$sharename = $album['sharename'];
			$name = bin2hex($sharename);
			$arrayId = "album_{$name}";
			if (0 >= strlen(trim($album['title']))) {
				$paths = explode("/", $album['sharename']);
				$albumname = end($paths);
			} else {
				$albumname = $album['title'];
			}
			$item['id'] = $arrayId;
			$item['name'] = $albumname;
			array_push($retArr, $item);
		}
		return $retArr;
	}

	private function GetImageIdsByExif($exifStr, $operator, $column, $type)
	{
		$result = array();
		$condition = array();
		if (!is_string($exifStr) || 0 >= strlen(trim($exifStr))) {
			goto End;
		}
		$exifs = explode(',', trim($exifStr));
		if (0 === count($exifs)) {
			goto End;
		}
		foreach ($exifs as $i => $exif) {
			if ('flash_v2' === $column) {
				$exifs[$i] = str_replace('#', ',', $exif);
			}
			$condition[] = '?';
		}

		$query = '';
		if ('any' === $operator) {
			if ('photo' == $type) {
				$query = "SELECT DISTINCT(id) FROM photo_image WHERE $column IN (" . implode(',', $condition) . ")";
			} else if ('video' == $type && 'rating' == $column) {
				$query = "SELECT DISTINCT(path) FROM video WHERE $column IN (" . implode(',', $condition) . ")";
			}
		}
		if ($query) {
			if (!($dbResult = PHOTO_DB_Query($query, $exifs))) {
				goto End;
			}
			while ($row = $dbResult->fetch()) {
				$result[] = $row[0];
			}
		}
	End:
		return $result;
	}
}

?>
