<?php
/*!
 * album list operation
 */
class csSYNOPhotoAlbum {
	/*! reference to db handler */
	private $_dbh;
	private $escapeStr = '';
	/*! reference to a self instance */
	private static $instance = null;
	/*! convert type condition to query video_convert table */
	private $video_convert_type_condition;
	/*!
	/*!
	 * Constructor
	 */
	function __construct()
	{
		$this->_dbh = csSYNOPhotoDB::GetDBInstance()->_dbh;
		$this->escapeStr = csSYNOPhotoDB::GetDBInstance()->escapeStr;

		if (isSet($_REQUEST['client']) && $_REQUEST['client'] == SYNOPHOTO_UPLOAD_CLIENT_IPHONE) {
			$this->video_convert_type_condition =' AND path in (SELECT video_path FROM video_convert WHERE convert_type=\'MOBILE_COMMON\' OR convert_type=\'IPHONE\') ';
		} else if (isSet($_REQUEST['client']) && $_REQUEST['client'] == SYNOPHOTO_UPLOAD_CLIENT_ANDROID) {
			$this->video_convert_type_condition =' AND path in (SELECT video_path FROM video_convert WHERE convert_type=\'MOBILE_COMMON\' OR convert_type=\'ANDROID_UPLOAD\') ';
		}
	}
	/* !
	 * !
	 *  Destructor
	 */
	function __destruct() {
		$this->_dbh = null;
		$this->escapeStr = '';
	}
	/*!
	 * Get a exist instance
	 */
	static function GetAlbumInstance()
	{
		if (null === self::$instance) {
			self::$instance = new self;
		}
		return self::$instance;
	}
	/*!
	 * Destroy an existed instance
	 */
	static function DestroyAlbumInstance() {
		self::$instance = null;
	}
	/*!
	 * Get the user-defined album cover for the sub-dir $albumName
	 *
	 * \param $albumName the sub-dir album name
	 * \return cover file path
	 */
	private function GetSubAlbumCover($albumName)
	{
		$result = '';

		$fullDirPath = sprintf("%s/%s", SYNOPHOTO_SERVICE_DIR, $albumName);
		if (false === SYNOPhotoEA::checkFilePath($fullDirPath, SYNOPhotoEA::FILE_ALBUM_COVER, $coverFile)) {
			return '';
		}
		if (false === ($result = @file_get_contents($coverFile))) {
			return '';
		}

		$cover_path = trim(SYNOPHOTO_SERVICE_REAL_DIR."/{$albumName}/".$result);

		if (!@is_file($cover_path)) {
			return '';
		}

		if (preg_match('/\/~[^\/]+/', $_SERVER['REQUEST_URI'], $matches)){
			$cover_path = "{$albumName}/".$result;
		}
		$row = array();
		if (csSYNOPhotoMisc::IsPhotoFile($cover_path)) {
			$query = "SELECT path,resolutionx,resolutiony,version FROM photo_image WHERE path= ?";
			$sqlParam = array($cover_path);
			$dbPhotoResult = $this->_dbh->prepare($query);
			$tt = $dbPhotoResult->execute($sqlParam);
			if($row = $dbPhotoResult->fetch()) {
				$row['dbPath'] = $row['path'];
				$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			}
		} else {
			$query = "SELECT path,resolutionx,resolutiony FROM video WHERE path=?";
			$sqlParam = array($cover_path);
			$dbPhotoResult = $this->_dbh->prepare($query);
			$dbPhotoResult->execute($sqlParam);
			if($row = $dbPhotoResult->fetch()) {
				$row['dbPath'] = $row['path'];
				$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			}
		}
		return $row;
	}
	/*!
	 * pick the latest upload image in the album as cover
	 *
	 * \param $albumName the album name
	 * \return cover file path
	 */
	private function GetAlbumCoverLatestUpload($albumName)
	{
		$isAdmin = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);
		$userId = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : '';
		$groupId = isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid'] : '';

		$sqlParam = array();

		$parts = explode('/', $albumName);
		if (1 === count($parts)) {
			//first-level album
			$privilegeCond = '';
			if (!$isAdmin) {
				$privilegeCond = "AND (public = 't'"; // if the 1st-level folder happen to be a private album, it will be added back by following privilegeCond
				if ($userId) {
					$privilegeCond .= " OR shareid IN (SELECT shareid FROM " . PHOTO_ACCESS_RIGHT_TABLE . " WHERE userid = ?)";
				}
				if ($groupId) {
					$privilegeCond .= " OR shareid IN (SELECT shareid FROM " . PHOTO_GROUP_PERMISSION_TABLE . " WHERE groupid IN ($groupId) AND permission & 1 <> 0)";
				}
				$privilegeCond .= ")";
			}
			$cond = "privilege_shareid IN (SELECT shareid FROM photo_share WHERE ref_shareid = (SELECT shareid FROM photo_share WHERE sharename = ?) $privilegeCond)";
			$sqlParam[] = $albumName;
			if (!$isAdmin) {
				if ($userId) {
					$sqlParam[] = $userId;
				}
			}
		} else if (2 === count($parts)) {
			//second-level album
			$cond = "privilege_shareid = (SELECT shareid FROM photo_share WHERE sharename = ?)";
			$sqlParam[] = $albumName;
		} else {
			//third-level album or lower
			$cond = "path LIKE ? {$this->escapeStr}";
			$sqlParam[] = csSYNOPhotoDB::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH."{$albumName}") . "/%";
		}
		$cond .= " AND disabled = 'f'";

		$table = "(" .
				"SELECT path, resolutionx, resolutiony, version, create_time, privilege_shareid, disabled FROM photo_image WHERE $cond " .
				"UNION ALL " .
				"SELECT path, resolutionx, resolutiony, 0 as version, date as create_time, privilege_shareid, disabled FROM video WHERE $cond " .
		") temp";

		// this may cost lots of time, so it won't sort by create_time if the total count exceeds the threshold (200,000)
		$total_count = File::GetTotalCount();
		if ($total_count < SYNOPHOTO_SORT_THRESHOLD) {
			$query = "SELECT path, resolutionx, resolutiony, version FROM $table ORDER BY create_time DESC LIMIT 1";
		} else {
			$query = "SELECT path, resolutionx, resolutiony, version FROM $table LIMIT 1";
		}
		$result = $this->_dbh->prepare($query);
		$result->execute(array_merge($sqlParam,$sqlParam));
		if($row = $result->fetch()) {
			$row['dbPath'] = $row['path'];
			$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
		}

		return $row;
	}

	/*!
	 * Get cover for album $albumName
	 *
	 * \param $albumName the album name
	 * \return array with cover info
	 *	- src: cover file path
	 *	- width: cover width
	 *	- height: cover height
	 */
	public function GetAlbumCover($albumName)
	{
		/* get user-defined cover */
		$coverFile = $this->GetSubAlbumCover($albumName);

		if (!empty($coverFile)) {
			if (!$filePath = csSYNOPhotoMisc::GetThumbPathFromFullPath($coverFile['path'], SYNOPHOTO_THUMBMEDIUM, false)) {
				$filePath = csSYNOPhotoMisc::GetThumbPathFromFullPath($coverFile['path'], SYNOPhotoEA::FILE_THUMB_PREVIEW, false);
			}
			$isPhotoFileWithThumb = csSYNOPhotoMisc::IsPhotoFileWithThumb($coverFile['path']);
			if (!$isPhotoFileWithThumb) {
				$filePath = $coverFile['path'];
			}
			if (!@file_exists($filePath) || !csSYNOPhotoMisc::CheckPathAccessible($coverFile['path'])) {
				$coverFile = '';
			}
		}

		/* use latest upload photo as cover */
		if (empty($coverFile)) {
			$coverFile = $this->GetAlbumCoverLatestUpload($albumName);
		}

		/* use empty image */
		$album = csSYNOPhotoDB::GetDBInstance()->GetAlbum($albumName);
		$isAdmin = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);

		$result['bigCover'] = array();
		$result['cover'] = array();
		if (!$isAdmin && isSet($album) && $album['password'] != $_SESSION[SYNOPHOTO_ADMIN_USER]['password_pass_album'][$albumName]) {
            $result['coverPath'] = '';
			$result['bigCover']['src'] = SYNOPHOTO_IMG_PASSWORD;
			$imageInfoCover = @getImageSize(SYNOPHOTO_IMG_PASSWORD_FILE_PATH);
			$result['bigCover']['width'] = $imageInfoCover[0];
			$result['bigCover']['height'] = $imageInfoCover[1];
			$result['cover']['src'] = SYNOPHOTO_IMG_EMPTY_HIGH_QUALITY;
			$result['cover']['width'] = $imageInfoCover[0];
			$result['cover']['height'] = $imageInfoCover[1];
			$result['xLargeThumb']['src'] = SYNOPHOTO_IMG_EMPTY_HIGH_QUALITY;
			$result['xLargeThumb']['width'] = $imageInfoCover[0];
			$result['xLargeThumb']['height'] = $imageInfoCover[1];
		} else if (empty($coverFile)) {
            $result['coverPath'] = '';
			$result['bigCover']['src'] = SYNOPHOTO_IMG_EMPTY_HIGH_QUALITY;
			$imageInfoCover = @getImageSize(SYNOPHOTO_IMG_EMPTY_FILE_PATH_HIGH_QUALITY);
			$result['bigCover']['width'] = $imageInfoCover[0];
			$result['bigCover']['height'] = $imageInfoCover[1];
			$result['cover']['src'] = SYNOPHOTO_IMG_EMPTY_HIGH_QUALITY;
			$result['cover']['width'] = $imageInfoCover[0];
			$result['cover']['height'] = $imageInfoCover[1];
			$result['xLargeThumb']['src'] = SYNOPHOTO_IMG_EMPTY_HIGH_QUALITY;
			$result['xLargeThumb']['width'] = $imageInfoCover[0];
			$result['xLargeThumb']['height'] = $imageInfoCover[1];
		} else if (is_array($coverFile) && isSet($coverFile['version'])) {
			// thumb is from photo file
            $result['coverPath'] = $coverFile['dbPath'];
			$result['bigCover'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBMEDIUM, $coverFile['resolutionx'], $coverFile['resolutiony'], $coverFile['version']);
			$result['cover'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBSMALL, $coverFile['resolutionx'], $coverFile['resolutiony'], $coverFile['version']);
			$result['xLargeThumb'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBXLARGE, $coverFile['resolutionx'], $coverFile['resolutiony'], $coverFile['version']);
		} else if (is_array($coverFile) && !isSet($coverFile['version'])) {
			// thumb is from video file
            $result['coverPath'] = $coverFile['dbPath'];
			$result['bigCover'] = csSYNOPhotoMisc::GetVideoThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBMEDIUM, $coverFile['resolutionx'], $coverFile['resolutiony']);
			$result['cover'] = csSYNOPhotoMisc::GetVideoThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBSMALL, $coverFile['resolutionx'], $coverFile['resolutiony']);
			$result['xLargeThumb'] = csSYNOPhotoMisc::GetVideoThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBXLARGE, $coverFile['resolutionx'], $coverFile['resolutiony'], $coverFile['version']);
		}else {
            $result['coverPath'] = $coverFile['dbPath'];
			$result['bigCover'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBMEDIUM, 0, 0, -1);
			$result['cover'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBSMALL, 0, 0, -1);
			$result['xLargeThumb'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBXLARGE, 0, 0, -1);
		}

		return $result;
	}

	/*!
	 * Check if album is uploadable by current login user
	 *
	 * \param $albumName album name
	 * \return true if the album is uploadable for the user
	 */
	function IsAlbumUploadable($albumName)
	{
		if(isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			return true;
		}

		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'])) {
			return false;
		}

		$sharename = $albumName;
		if (strstr($sharename, '/')) {
			$arr = explode('/', $sharename);
			$sharename = $arr[0] . '/' . $arr[1];
		}
		return isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['uploadable_album'][$sharename]);
	}

	/*!
	 * Get album information
	 *
	 * \param $albumName album name
	 * \return array with album info
	 *	- name: folder name
	 *	- title: user-defined title
	 *	- description: user-defined description
	 *	- hits: album hits
	 *	- showTitle: title or name when title is empty
	 *	- photos: # of photos in all alubms in the album
	 *	- link: link to browse the album
	 */
	function GetAlbumInfo($albumName)
	{
		$item = csSYNOPhotoDB::GetDBInstance()->GetAlbum($albumName);
		$result['name'] = $item['sharename'];
		$result['title'] = $item['title'];
		$result['desc'] = $item['description'];
		$result['isPublic'] = $item['public'];
		$result['hit'] = $item['hits'];
		$result['photos'] = 0;//for DSM bug#21213
		$tok = explode('/', $albumName);
		$result['dirName'] = $tok[count($tok) - 1];
		$result['showTitle'] = htmlspecialchars(empty($result['title']) ? $result['dirName'] : $result['title'], ENT_QUOTES);
		$result['dir'] = bin2hex($albumName);
		if (isSet($item) && $item['password'] != $_SESSION[SYNOPHOTO_ADMIN_USER]['password_pass_album'][$albumName]) {
			$result['url'] = "javascript:onEnterPassword('".$result['dir']."');";
		} else {
			$result['url'] = 'photo_thumb.php?dir='.$result['dir'];
		}
		if ($item['password'] !='') {
			$result['needPassword'] = true;
		}
		$result['uploadable'] = $this->IsAlbumUploadable($albumName);

		return $result;
	}
	/*!
	 * Get mos recentalbum information
	 *
	 * \param $source most recent source. Photo or video.
	 * \return array with album info
	 *	- name: folder name
	 *	- title: user-defined title
	 *	- description: user-defined description
	 *	- hits: album hits
	 *	- showTitle: title or name when title is empty
	 *	- photos: # of photos in all alubms in the album
	 *	- link: link to browse the album
	 */
	function GetMostRecentAlbumInfo($source, $isRecentComment = false)
	{
		if ('photo' == $source) {
			if (!$isRecentComment) {
				$title = __(photo_str_recent_photo);
				$result['url'] = 'photo_thumb.php?virtual_album=0';
				$result['dir'] = 'v0';
			} else {
				$title = __(photo_str_recent_commented_photo);
				$result['url'] = 'photo_thumb.php?virtual_album=2';
				$result['dir'] = 'v2';
			}
		} else {
			if (!$isRecentComment) {
				$title = __(photo_str_recent_video);
				$result['url'] = 'photo_thumb.php?virtual_album=1';
				$result['dir'] = 'v1';
			} else {
				$title = __(photo_str_recent_commented_video);
				$result['url'] = 'photo_thumb.php?virtual_album=3';
				$result['dir'] = 'v3';
			}
		}
		$result['name'] = '';
		$result['title'] = $title;
		$result['desc'] = '';
		$result['isPublic'] = TRUE;
		$result['hit'] = 0;
		$result['dirName'] = '';

		$result['showTitle'] = $title;
		$result['uploadable'] = FALSE;
		$result['isVirtual'] = true;

		return $result;
	}

	function GetLabelAlbumInfoFirst($category)
	{
		switch ($category) {
			case 0:
				$title = __('photo_str_person_label');
				$result['url'] = 'photo_thumb.php?virtual_album=4';
				$result['dir'] = 'v4';
				break;
			case 1:
				$title = __('photo_str_place_label');
				$result['url'] = 'photo_thumb.php?virtual_album=5';
				$result['dir'] = 'v5';
				break;
			case 2:
				$title = __('photo_str_general_label');
				$result['url'] = 'photo_thumb.php?virtual_album=6';
				$result['dir'] = 'v6';
				break;
		}
		$result['name'] = '';
		$result['title'] = $title;
		$result['desc'] = '';
		$result['isPublic'] = TRUE;
		$result['hit'] = 0;
		$result['dirName'] = '';

		$result['showTitle'] = $title;
		$result['uploadable'] = FALSE;
		$result['isVirtual'] = true;
		$result['isLabelVirtual'] = true;

		return $result;
	}

	function GetLabelAlbumInfo($category, $tagName, $id)
	{
		$title = $tagName;
		$result['url'] = 'photo_thumb.php?virtual_album='.($category + 4).'&id='.$id;
		$result['dir'] = $id;
		$result['name'] = '';
		$result['title'] = $title;
		$result['desc'] = '';
		$result['isPublic'] = TRUE;
		$result['hit'] = 0;
		$result['dirName'] = '';

		$result['showTitle'] = htmlspecialchars($title, ENT_QUOTES);
		$result['uploadable'] = FALSE;
		$result['isVirtual'] = true;
		$result['isLabelVirtual'] = true;

		return $result;
	}

	function GetLabelAlbumCoverFromDB($id)
	{
		$sqlParam = array();
		if (-1 == $id) {
			$photoQuery = "SELECT path, resolutionx, resolutiony, version FROM photo_image_label LEFT JOIN photo_image ON photo_image_label.image_id=photo_image.id WHERE photo_image_label.status='f' ORDER BY photo_image.create_time DESC LIMIT 1";
			$dbPhotoResult = $this->_dbh->prepare($photoQuery);
			$tt = $dbPhotoResult->execute($sqlParam);
			if($row = $dbPhotoResult->fetch()) {
				$row['dbPath'] = $row['path'];
				$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
				return $row;
			}
			return null;
		}

		$photoQuery = "SELECT path, resolutionx, resolutiony, version FROM photo_image_label LEFT JOIN photo_image ON photo_image_label.image_id=photo_image.id WHERE photo_image_label.label_id=? AND photo_image_label.status='t'";
		$videoQuery = "SELECT path, resolutionx, resolutiony FROM photo_video_label LEFT JOIN video ON photo_video_label.video_path=video.path WHERE photo_video_label.label_id=? ";

		$sqlParam[] = $id;
		if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryCondition();
			if (count($albumCondition['privilege_shareid'])) {
				$photoQuery .= " AND privilege_shareid IN (".implode(',', $albumCondition['privilege_shareid']).' )';
				$videoQuery .= " AND privilege_shareid IN (".implode(',', $albumCondition['privilege_shareid']).' )';
			} else {
				return null;
			}
		}

		$photoQuery .= " LIMIT 1";
		$videoQuery .= " LIMIT 1";

		$dbPhotoResult = $this->_dbh->prepare($photoQuery);
		$tt = $dbPhotoResult->execute($sqlParam);
		if($row = $dbPhotoResult->fetch()) {
			$row['dbPath'] = $row['path'];
			$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			return $row;
		}

		$dbPhotoResult = $this->_dbh->prepare($videoQuery);
		$tt = $dbPhotoResult->execute($sqlParam);
		if($row = $dbPhotoResult->fetch()) {
			$row['dbPath'] = $row['path'];
			$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			return $row;
		}
		return null;
	}

	function GetLabelAlbumCover($id)
	{
		$coverFile = $this->GetLabelAlbumCoverFromDB($id);
		$result = null;
		if (-1 == $id && empty($coverFile)) {
            $result['coverPath'] = '';
			return $result;
		} else if (empty($coverFile)) {
            $result['coverPath'] = '';
			$result['bigCover']['src'] = SYNOPHOTO_IMG_EMPTY_HIGH_QUALITY;
			$imageInfoCover = @getImageSize(SYNOPHOTO_IMG_EMPTY_FILE_PATH_HIGH_QUALITY);
			$result['bigCover']['width'] = $imageInfoCover[0];
			$result['bigCover']['height'] = $imageInfoCover[1];
			$result['cover']['src'] = SYNOPHOTO_IMG_EMPTY_HIGH_QUALITY;
			$result['cover']['width'] = $imageInfoCover[0];
			$result['cover']['height'] = $imageInfoCover[1];
		} else if (is_array($coverFile) && isSet($coverFile['version'])) {
			// thumb is from photo file
            $result['coverPath'] = $coverFile['dbPath'];
			$result['bigCover'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBMEDIUM, $coverFile['resolutionx'], $coverFile['resolutiony'], $coverFile['version']);
			$result['cover'] = csSYNOPhotoMisc::GetThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBSMALL, $coverFile['resolutionx'], $coverFile['resolutiony'], $coverFile['version']);
		} else if (is_array($coverFile) && !isSet($coverFile['version'])) {
			// thumb is from video file
            $result['coverPath'] = $coverFile['dbPath'];
			$result['bigCover'] = csSYNOPhotoMisc::GetVideoThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBMEDIUM, $coverFile['resolutionx'], $coverFile['resolutiony']);
			$result['cover'] = csSYNOPhotoMisc::GetVideoThumbInfoFromFullPath($coverFile['path'], SYNOPHOTO_THUMBSMALL, $coverFile['resolutionx'], $coverFile['resolutiony']);
		}

		return $result;
	}
	/*!
	 * add album hit times
	 *
	 * \param $albumName album name
	 */
	function AddHitTimes($albumName)
	{
		/* hit one time for each session */
		if (!in_array($albumName, $_SESSION[SYNOPHOTO_ADMIN_USER]['accessed_albums'], true)) {
			array_push($_SESSION[SYNOPHOTO_ADMIN_USER]['accessed_albums'], $albumName);
			$query = "UPDATE photo_share SET hits=hits+1 WHERE sharename=?";
			$sqlParam = array($albumName);
			$dbResult = $this->_dbh->prepare($query);
			$dbResult->execute($sqlParam);
			$albumInfo = csSYNOPhotoDB::GetDBInstance()->GetAlbum($albumName);
			if (isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']) && ('f' == $albumInfo['public'] || false == $albumInfo['public'])) {
				$msg = "Album [".htmlspecialchars($albumName)."] was accessed by {$_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']}.";
				PhotoLog::Add($msg, true, $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']);
			}
		}
	}
	/*!
	 * edit album's property
	 *
	 * \param $shareName album share name
	 * \param $title album's new title
	 * \param $description album's new description
	 * \param $public album's new is public property. 't' for true, 'f' for false
	 */
	function EditAlbumProperty($shareName, $title, $description)
	{
		$result = csSYNOPhotoDB::GetDBInstance()->UpdateAlbumProperty($shareName, $title, $description);
		// flush the cache since album property has been changed
		csSYNOPhotoDB::GetDBInstance()->SetSessionCache(true);
		return $result;
	}

	/*!
	 * get link to the picture on photo station
	 *
	 * \param $path file path
	 */
	function GetAlbumUrlLink($path)
	{
		$pos = strrpos($path, '/');
		$dir = substr($path, 0, $pos);
		$dir = substr($dir, strlen(SYNOPHOTO_SERVICE_REAL_DIR.'/'));

		$result = SYNOPHOTO_URL_PREFIX.'/photo/photo_one.php?';
		$result = $result.'name='.bin2hex(basename($path)).'&dir='.bin2hex($dir);
		return $result;
	}

	static function GetAlbumThumbSortType($albumName)
	{
		$result = array();

		if ('/' === $albumName) {
			$fullDirPath = SYNOPHOTO_SERVICE_REAL_DIR;
			$sortFile = $fullDirPath . '/' . SYNOPhotoEA::SYNO_EA_DIR . '/' . SYNOPhotoEA::getFilename(SYNOPhotoEA::FILE_ALBUM_SORT);
		} else {
			$fullDirPath = sprintf("%s/%s", SYNOPHOTO_SERVICE_REAL_DIR, $albumName);
			if (false === SYNOPhotoEA::checkFilePath($fullDirPath, SYNOPhotoEA::FILE_ALBUM_SORT, $sortFile)) {
				return array();
			}
		}
		if (false === ($result = @file_get_contents($sortFile))) {
			return array();
		}

		$result = json_decode($result, true);
		if (empty($result)) {
			return array();
		}
		return $result;
	}

	static function SaveAlbumThumbSortType($albumName, $data, $forcedOverrideList = false)
	{
		$result = '';
		if ('/' === $albumName) {
			$fullDirPath = SYNOPHOTO_SERVICE_REAL_DIR;
		} else {
			$fullDirPath = sprintf("%s/%s", SYNOPHOTO_SERVICE_REAL_DIR, $albumName);
		}

		$newData = self::GetAlbumThumbSortType($albumName);
		if (isSet($data['type'])) {
			$newData['type'] = $data['type'];
		}
		if (isSet($data['order'])) {
			$newData['order'] = $data['order'];
		}
		if (isSet($data['list']) && !empty($data['list'])) {
			$newData['list'] = $data['list'];
		} else if ($forcedOverrideList) {
			$newData['list'] = array();
		}

		if (SYNOPHOTO_SERVICE_REAL_DIR === $fullDirPath) {
			@mkdir(SYNOPHOTO_SERVICE_REAL_DIR . '/' . SYNOPhotoEA::SYNO_EA_DIR, 0777);
			$sortFile = SYNOPHOTO_SERVICE_REAL_DIR . '/' . SYNOPhotoEA::SYNO_EA_DIR . '/' . SYNOPhotoEA::getFilename(SYNOPhotoEA::FILE_ALBUM_SORT);
		} else {
			SYNOPhotoEA::createEADir($fullDirPath, $eaDir);
			$sortFile = SYNOPhotoEA::getFilePath($fullDirPath, SYNOPhotoEA::FILE_ALBUM_SORT);
		}
		file_put_contents($sortFile, json_encode($newData));
	}
}
?>
