<?php
require_once('synophoto_csDBCacher.php');
require_once(SYNOPHOTO_INCLUDE_DIR."/syno_defines.php");

/*!
 * database operation
 */
class csSYNOPhotoDB {
	/*! cache life time (seconds)*/
	public $CACHE_LIFETIME = 300;
	/*! db connection handler */
	public $_dbh;
	/*! db cacher handler */
	private $_dbCacher;
	/*! db cacher handler for mediaserver DB*/
	private $_dbCacherMedia;
	/*! db escape string for like */
	public $escapeStr = '';
	public $db_type = '';
	public static $current_admin = '';
	/*! reference to a self instance */
	private static $instance = null;
	/*! rating value by default */
	public $ratingValue = array('0','1','2','3','4','5');
	/*!
	 * Constructor
	 */
	function __construct()
	{
		if (SYNOPHOTO_IS_PPS) {
			$user = SYNOPHOTO_ADMIN_NAME;
			$ret = $this->GetPersonalPhotoDBCache($user, $user_photo_db);

			if ($ret === false) {
				header("Location: /photo/report.php?nosrv=true&msgkey=photo_str_file_access_denied");
				exit;
			}

			try{
				$this->_dbh = new PDO("sqlite:{$user_photo_db}");
				$this->_dbh->exec('PRAGMA case_sensitive_like=1');
				$this->_dbh->exec('PRAGMA foreign_keys=ON');
				$this->escapeStr = " ESCAPE '\'";
				self::$current_admin = $user;
			} catch (PDOException $e) {
				die($e->getMessage());
			}
		} else {
			try{
				$this->_dbh = new PDO('pgsql:dbname=photo', 'PhotoStation', '',
					array(PDO::ATTR_PERSISTENT => false, PDO::ATTR_EMULATE_PREPARES => true));
				self::$current_admin = 'root';

			} catch (PDOException $e) {
				die($e->getMessage());
			}
		}

		$this->_dbCacher = new DBCacher($this->_dbh, false, self::$current_admin);
		$this->_dbCacherMedia = new DBCacher($this->_dbh, true, self::$current_admin);

		$GLOBALS['dbconn_photo'] = $this->_dbh;

		$this->SetSessionSystemConfigsFromFile();
		$_SESSION[SYNOPHOTO_ADMIN_USER]['photo_config'] = array();

		$GLOBALS['db_type'] = $this->db_type = $this->_dbh->getAttribute(constant("PDO::ATTR_DRIVER_NAME"));
	}
	/*!
	 * close db connection
	 */
	function __destruct()
	{
		$this->_dbh = null;
		$this->escapeStr = '';
		$this->_dbCacher = null;
		$this->_dbCacherMedia = null;
		$this->db_type= '';
	}

	function GetPersonalPhotoDBCache($user, &$user_photo_db)
	{
		$session = &$_SESSION[SYNOPHOTO_ADMIN_USER];
		if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]) && isset($_SESSION[SYNOPHOTO_ADMIN_USER]['personal_photo_db_cache'])) {
			$cache = &$_SESSION[SYNOPHOTO_ADMIN_USER]['personal_photo_db_cache'];

			$user_photo_db = $cache['user_photo_db'];

			return true;
		}

		$userHome = csSYNOPhotoMisc::getUserHomePath($user);
		$user_photo_db = $userHome . "/photo/.SYNOPPSDB";

		$ret = csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_config', array('-c', $user_photo_db));
		if (0 !== $ret) {
			$ret = csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_config_root', array('-f', $user));
		}
		if (!file_exists($user_photo_db) || $ret !== 0 || 'yes' != csSYNOPhotoMisc::UserHomeIsEnabled($user)){
			return false;
		}

		$_SESSION[SYNOPHOTO_ADMIN_USER]['personal_photo_db_cache'] = array(
			'user_photo_db' => $user_photo_db
		);

		return true;
	}

	/*!
	 * Get a exist instance
	 */
	static function GetDBInstance()
	{
		$admin_name = SYNOPHOTO_ADMIN_NAME;
		if (null === self::$instance || $admin_name != self::$current_admin) {
			self::$instance = null;
			self::$instance = new self;
			self::$current_admin = $admin_name;
		}
		return self::$instance;
	}
	/*!
	 * Destroy a exist instance
	 */
	static function DestroyDBInstance()
	{
		self::$instance = null;
	}
	/*!
	 * escape string for like/ilike sql op
	 * \param $param string to escape
	 * \return escaped string
	 */
	static function EscapeLikeParam($param)
	{
		$param = str_replace('\\', '\\\\', $param);
		$param = str_replace('_', '\\_', $param);
		$param = str_replace('%', '\\%', $param);
		return $param;
	}
	private function Query($query, $param = array())
	{
		$stmt = $this->_dbh->prepare($query);
		$ret = $stmt->execute($param);

		if ($ret === false) {
			return false;
		}
		return $stmt;
	}
	private function ConvertItemID($itemID)
	{
		$arr = explode('_', $itemID );
		if (2 != count($arr)) {
			return false;
		}
		if (!in_array($arr[0], array('album', 'smart', 'tag'))) {
			return false;
		}
		$ret = array();
		$ret['type'] = $arr[0];
		switch ($arr[0]) {
			case 'album':
				$shareName = @pack('H*', $arr[1]);
				if (false === ($row = $this->GetFieldByKeyValue('shareid', 'photo_share', 'sharename', $shareName))) {
					return false;
				}
				$ret['id'] = $row['shareid'];
				break;
			case 'smart':
				$ret['id'] = $arr[1];
				break;
			case 'tag':
				$ret['id'] = $arr[1];
				break;
			default:
				return false;
				break;
		}
		return $ret;
	}

	public function IsCategoryAccessible($categoryID)
	{
		$ret = false;

		$row = $this->GetFieldByKeyValue('hidden', 'category', 'id', $categoryID);
		if (true === $row['hidden'] || 't' === $row['hidden']) {
			$ret = true;
		} elseif (false === $row['hidden'] || 'f' === $row['hidden']) {
			$ret = false;
		}

		return $ret;
	}

	private function IsItemsBelongToCateogyID($categoryID, $itemIDs)
	{
		if (empty($categoryID) || 0 === count($itemIDs)) {
			return false;
		}

		$albumIDs = $smartIDs = $tagIDs = array();
		foreach ($itemIDs as $item) {
			$data = $this->ConvertItemID($item);
			$type = $data['type'];
			$id = $data['id'];
			if ('album' === $type) {
				array_push($albumIDs, $id);
			} elseif ('tag' === $type) {
				 array_push($tagIDs, $id);
			} elseif ('smart' === $type) {
				 array_push($smartIDs, $id);
			}
		}
		$idCondition = array();
		if (0 != count($albumIDs)) {
			$albumString = '\''.implode('\',\'', $albumIDs).'\'';
			$albumCondition = "(album_id IN ({$albumString}))";
			array_push($idCondition, $albumCondition);
		}
		if (0 != count($tagIDs)) {
			$tagString = '\''.implode('\',\'', $tagIDs).'\'';
			$tagCondition = "(tag_id IN ({$tagString}))";
			array_push($idCondition, $tagCondition);
		}
		if (0 != count($smartIDs)) {
			$smartString = '\''.implode('\',\'', $smartIDs).'\'';
			$smartCondition = "(smart_id IN ({$smartString}))";
			array_push($idCondition, $smartCondition);
		}
		$conditionString = implode(' OR ', $idCondition);

		$query = "SELECT count(id) FROM category_items WHERE category_id={$categoryID} AND ({$conditionString})";
		$dbResult = $this->_dbh->query($query);
		$row = $dbResult->fetch();
		if ($row[0] != count($itemIDs)) {
			return false;
		}
		return true;
	}

	private function IsCategoryItemExist($type, $id)
	{
		switch ($type) {
			case 'album':
				$name = @pack('H*', $arr[1]);
				$row = $this->GetFieldByKeyValue('count(shareid)', 'photo_share', 'shareid', $id);
				if (1 !== (int)$row[0]) {
					return false;
				}
				break;
			case 'smart':
				$name = @pack('H*', $id);
				$result = SmartAlbum::GetSmartAlbumInstance()->ReadSmartAlbumFile();
				if (!isset($result['smart_albums'][$name])) {
					return false;
				}
				break;
			case 'tag':
				$row = $this->GetFieldByKeyValue('count(id)', 'photo_label', 'id', $id);
				if (1 !== (int)$row[0]) {
					return false;
				}
				break;
			default:
				return false;
				break;
		}
		return true;
	}

	public function GetTotalCategory($isAdmin = false)
	{
		if (false === $isAdmin) {
			$condition = "WHERE hidden='f'";
		}
		$query = "SELECT count(id) FROM category {$condition}";
		$dbResult = $this->_dbh->query($query);
		$row = $dbResult->fetch();
		return $row[0];
	}

	public function GetTotalCategoryItem($categoryID)
	{
		$query = "SELECT count(id) FROM category_items WHERE category_id={$categoryID}";
		$dbResult = $this->_dbh->query($query);
		$row = $dbResult->fetch();

		return $row[0];
	}

	public function GetFieldByKeyValue($field, $table, $key = false, $keyValue = false)
	{
		if (empty($field) || empty($table)) {
			return false;
		}

		$param = array();
		if (false !== $key && false !== $keyValue) {
			$query = "SELECT {$field} FROM {$table} WHERE {$key}=?";
			$param[] = $keyValue;
		} else {
			$query = "SELECT {$field} FROM {$table}";
		}
		$dbResult = $this->Query($query, $param);
		$row = $dbResult->fetch();
		return $row;
	}

	/*
	 *  @params - $catgegoryIDs [array]
	 */
	public function ArrangeCategory($catgegoryIDs, $offset, $limit)
	{
		if (0 === count($catgegoryIDs) || !isset($offset) || !isset($limit)) {
			return false;
		}
		if ($limit != count($catgegoryIDs)) {
			return false;
		}
		$row = $this->GetFieldByKeyValue('count(id)', 'category');
		if ($row[0] < ($offset + $limit)) {
			return false;
		}

		// check category ids
		$idString = implode(',', $catgegoryIDs);
		$query = "SELECT count(id) FROM category WHERE id IN ({$idString})";
		if (false === ($dbResult = $this->_dbh->query($query))) {
			return false;
		}
		$row = $dbResult->fetch();
		if ($row[0] != count($catgegoryIDs)) {
			return false;
		}

		// get start order number
		$query = "SELECT order_number FROM category ORDER BY order_number ASC LIMIT 1 OFFSET {$offset}";
		if (false === ($dbResult = $this->_dbh->query($query))) {
			return false;
		}
		$row = $dbResult->fetch();
		$fillOrderStart = $row['order_number'];

		// expect fill order number
		$fillOrderNumber = array();
		$order = $fillOrderStart;
		for ($i = 0; $i < $limit; $i++) {
			array_push($fillOrderNumber, (int)$order);
			$order++;
		}

		// get not changed order number
		$idString = implode(',', $catgegoryIDs);
		$query = "SELECT order_number FROM category WHERE id NOT IN ({$idString})";
		if (false === ($dbResult = $this->_dbh->query($query))) {
			return false;
		}
		$notChangedOrderNumber = array();
		while($row = $dbResult->fetch()) {
			array_push($notChangedOrderNumber, (int)$row['order_number']);
		}

		// check order confict
		foreach ($fillOrderNumber as $fill) {
			foreach ($notChangedOrderNumber as $notChanged) {
				if ($fill === $notChanged) {
					return false;
				}
			}
		}

		// update order number for changed
		$order = $fillOrderStart;
		foreach ($catgegoryIDs as $id) {
			$query = "UPDATE category SET order_number={$order} WHERE id={$id}";
			if (false === ($dbResult = $this->_dbh->query($query))) {
				return false;
			}
			$order++;
		}

		return true;
	}

	/*
	 *  @params - $categoryID [string]
	 *            $itemIDs [array]
	 */
	public function AddCategoryItem($categoryID, $itemIDs)
	{
		if (empty($categoryID) || (0 === count($itemIDs))) {
			return false;
		}

		// check category id
		$objs = Category::GetByIds(array($categoryID));
		if (!$objs[$categoryID]) {
			return false;
		}

		// get order number
		if (false === ($row = $this->GetFieldByKeyValue('max(order_number)', 'category_items', 'category_id', $categoryID))) {
			return false;
		}
		$newOrderNumber = $row[0] + 1;

		// insert items to category
		$failCount = 0;
		foreach ($itemIDs as $item) {
			// check item id
			$data = $this->ConvertItemID($item);
			if (false === $this->IsCategoryItemExist($data['type'], $data['id'])) {
				$failCount++;
				continue;
			}
			if (Category::HasItem($categoryID, $data['type'], $data['id'])) {
				continue;
			}

			$type = $data['type'];
			$id = $data['id'];

			// insert to category_item table
			if ('album' === $type) {
				$query = "INSERT INTO category_items (category_id, type, order_number, album_id) VALUES ({$categoryID}, '{$type}', {$newOrderNumber}, {$id})";
			} elseif ('tag' === $type) {
				$query = "INSERT INTO category_items (category_id, type, order_number, tag_id) VALUES ({$categoryID}, '{$type}', {$newOrderNumber}, {$id})";
			} elseif ('smart' === $type) {
				$query = "INSERT INTO category_items (category_id, type, order_number, smart_id) VALUES ({$categoryID}, '{$type}', {$newOrderNumber}, '{$id}')";
			}

			$dbResult = $this->_dbh->prepare($query);
			if (false === $dbResult->execute()) {
				$failCount++;
				continue;
			}

			$newOrderNumber++;
		}
		if ($failCount === count($itemIDs)) {
			return false;
		}

		// update modify date in category table
		$modify_date = date("Y-m-d G:i:s");
		$query = "UPDATE category SET modify_date='{$modify_date}' WHERE id={$categoryID}";
		$dbResult = $this->_dbh->prepare($query);
		if (false === $dbResult->execute()) {
			return false;
		}

		return true;
	}

	public function RemoveCategoryItem($categoryID, $itemIDs)
	{
		if (empty($categoryID) || (0 === count($itemIDs))) {
			return false;
		}

		// check category id
		$objs = Category::GetByIds(array($categoryID));
		if (!$objs[$categoryID]) {
			return false;
		}

		foreach ($itemIDs as $itemID) {
			$data = $this->ConvertItemID($itemID);
			$type = $data['type'];
			$id = $data['id'];
			$query = "DELETE FROM category_items WHERE category_id={$categoryID} AND {$type}_id='{$id}'";
			if (false === ($dbResult = $this->_dbh->query($query))) {
				return false;
			}
		}

		return true;
	}

	public function ArrangeCategoryItem($categoryID, $itemIDs, $offset, $limit)
	{
		if (!isset($categoryID) || 0 === count($itemIDs) || !isset($offset) || !isset($limit)) {
			return false;
		}
		if ($limit != count($itemIDs)) {
			return false;
		}

		// check category id
		$objs = Category::GetByIds(array($categoryID));
		if (!$objs[$categoryID]) {
			return false;
		}
		// check item id
		if (false === $this->IsItemsBelongToCateogyID($categoryID, $itemIDs)) {
			return false;
		}
		$row = $this->GetFieldByKeyValue('count(id)', 'category_items', 'category_id', $categoryID);
		if ($row[0] < ($offset + $limit)) {
			return false;
		}

		// get start order number
		$query = "SELECT order_number FROM category_items WHERE category_id={$categoryID} ORDER BY order_number ASC LIMIT 1 OFFSET {$offset}";
		if (false === $dbResult = $this->_dbh->query($query)) {
			return false;
		}
		$row = $dbResult->fetch();
		$fillOrderStart = $row['order_number'];

		// expect fill order number
		$fillOrderNumber = array();
		$order = $fillOrderStart;
		for ($i = 0; $i < $limit; $i++) {
			array_push($fillOrderNumber, $order);
			$order++;
		}

		// get not changed order number
		$albumIDs = $smartIDs = $tagIDs = array();
		foreach ($itemIDs as $item) {
			$data = $this->ConvertItemID($item);
			$type = $data['type'];
			$id = $data['id'];
			if ('album' === $type) {
				array_push($albumIDs, $id);
			} elseif ('tag' === $type) {
				 array_push($tagIDs, $id);
			} elseif ('smart' === $type) {
				 array_push($smartIDs, $id);
			}
		}
		$idCondition = array();
		if (0 != count($albumIDs)) {
			$albumString = '\''.implode('\',\'', $albumIDs).'\'';
			$albumCondition = "(album_id NOT IN ({$albumString}) OR album_id is null)";
			array_push($idCondition, $albumCondition);
		}
		if (0 != count($tagIDs)) {
			$tagString = '\''.implode('\',\'', $tagIDs).'\'';
			$tagCondition = "(tag_id NOT IN ({$tagString}) OR tag_id is null)";
			array_push($idCondition, $tagCondition);
		}
		if (0 != count($smartIDs)) {
			$smartString = '\''.implode('\',\'', $smartIDs).'\'';
			$smartCondition = "(smart_id NOT IN ({$smartString}) OR smart_id is null)";
			array_push($idCondition, $smartCondition);
		}
		$conditionString = implode(' AND ', $idCondition);
		$query = "SELECT order_number FROM category_items WHERE category_id={$categoryID} AND {$conditionString}";
		if (false === $dbResult = $this->_dbh->query($query)) {
			return false;
		}
		$notChangedOrderNumber = array();
		while($row = $dbResult->fetch()) {
			array_push($notChangedOrderNumber, $row['order_number']);
		}

		// check order confict
		foreach ($fillOrderNumber as $fill) {
			foreach ($notChangedOrderNumber as $notChanged) {
				if ($fill === $notChanged) {
					return false;
				}
			}
		}

		// update order number for changed
		$order = $fillOrderStart;
		foreach ($itemIDs as $itemID) {
			$data = $this->ConvertItemID($itemID);
			$type = $data['type'];
			$id = $data['id'];
			$query = "UPDATE category_items SET order_number={$order} WHERE category_id={$categoryID} AND {$type}_id='{$id}'";
			if (false === ($dbResult = $this->_dbh->query($query))) {
				return false;
			}
			$order++;
		}

		return true;
	}

	public function ListCategoryItem($categoryID, $offset, $limit)
	{
		if (empty($categoryID) || !isset($offset) || !isset($limit)) {
			return false;
		}

		// check category id
		$objs = Category::GetByIds(array($categoryID));
		if (!$objs[$categoryID]) {
			return false;
		}

		$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);

		$query = "SELECT * FROM category_items WHERE category_id={$categoryID} ORDER BY order_number ASC $limitOffsetString";
		if (false === ($dbResult = $this->_dbh->query($query))) {
			return false;
		}
		$result = array();
		while($row = $dbResult->fetch()) {
			$type = $row['type'];
			if ('album' === $type) {
				$id = $row['album_id'];
			} elseif ('tag' === $type) {
				$id = $row['tag_id'];
			} elseif ('smart' === $type) {
				$id = $row['smart_id'];
			}
			// if item id not exist, delete it
			if (false === $this->IsCategoryItemExist($type, $id)) {
				$query = "DELETE FROM category_items WHERE category_id={$categoryID} AND {$type}_id='{$id}'";
				if (false === ($dbResult = $this->_dbh->query($query))) {
					return false;
				}
				continue;
			}
			array_push($result, $row);
		}

		return $result;
	}



	/*!
	 * dump photo_config scheme from db
	 *
	 * \return array with data from scheme 'photo_config'
	 */
	private function GetConfigsFromDB()
	{
		$query = 'SELECT * FROM photo_config';
		$dbResult = $this->_dbh->query($query);
		$result = $dbResult->fetchAll();
		if (false === $result) {
			return array();
		}
		return $result;
	}
	/*!
	 * Get accessible album list from db
	 *
	 * \param $userID logined username
	 * \param $noRightCheck true for get all albums
	 * \return array with data from scheme 'photo_share'
	 */
	private function GetAlbumsFromDB($userID, $noRightCheck)
	{
		$sqlParam = array();
		$sqlParamCount = 0;

		/* prepare permission condition */
		$permConditionClause = '';
		if (!$noRightCheck) {
			$permConditionClause = "public='t' OR password <> ''";
			if (!empty($userID)) {
				$permConditionClause .= ' OR shareid IN (SELECT shareid FROM '.PHOTO_ACCESS_RIGHT_TABLE.' WHERE userid=?)';
				$sqlParam[$sqlParamCount++] = $userID;
			}
		}

		/* query first level albums */
		$whereClause = "WHERE is_subdir='f'";
		if (strlen($permConditionClause)) {
			/* sql param already append to $sqlParam */
			$whereClause .= " AND ({$permConditionClause})";
		}
		$query = "SELECT * FROM photo_share {$whereClause} ORDER BY upper(sharename) ASC";
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$rootAlbums = $dbResult->fetchAll();
		if (false === $rootAlbums) {
			return array();
		}

		/* query second level albums accroding to accessible first level albums */
		$secondLevelAlbums = array();
		$whereClause = "WHERE is_subdir='t' AND sharename NOT LIKE '%/%/%'";
		if (strlen($permConditionClause)) {
			/* sql param already append to $sqlParam */
			$whereClause .= " AND ({$permConditionClause})";
		}
		$whereClause .=  " AND sharename LIKE ? {$this->escapeStr}";
		$query = "SELECT * FROM photo_share {$whereClause} ORDER BY upper(sharename) ASC";
		$dbResult = $this->_dbh->prepare($query);
		foreach ($rootAlbums as $key => $item) {
			// skip photo in remote mount (cifs) or read-only mount (iso9660)
			if (csSYNOPhotoMisc::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$item['sharename'], $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])) {
				unset($rootAlbums[$key]);
				continue;
			}

			$item['sharename'] = self::EscapeLikeParam($item['sharename']);
			$sqlParam[$sqlParamCount] = "{$item['sharename']}/%";
			$dbResult->execute($sqlParam);
			$result = $dbResult->fetchAll();
			if (false !== $result) {
				// skip photo in remote mount (cifs) or read-only mount (iso9660)
				foreach ($result as $key => $item) {
					if (csSYNOPhotoMisc::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$item['sharename'], $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])) {
						unset($result[$key]);
					}
				}
				$secondLevelAlbums = array_merge($secondLevelAlbums, $result);
			}
		}

		$result = array_merge($rootAlbums, $secondLevelAlbums);

		$query = "SELECT * FROM photo_share where password <> '' and is_subdir = 't' AND sharename NOT LIKE '%/%/%' ORDER BY upper(sharename) ASC";
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute();
		$passwordAlbums = $dbResult->fetchAll();
		foreach ($passwordAlbums as $item) {
			if (!in_array($item, $result)) {
				$result[] = $item;
			}
		}
		return $result;
	}

	/*!
	 * Get accessible album list from db for a group id
	 *
	 * \param $groupID logined user's group
	 * \param $noRightCheck true for get all albums
	 * \return array with data from scheme 'photo_share'
	 */
	private function GetAlbumsFromDBForGroup($groupID, $noRightCheck)
	{
		$sqlParam = array();
		$sqlParamCount = 0;

		/* prepare permission condition */
		$permConditionClause = '';
		if (!$noRightCheck) {
			$permConditionClause = "public='t' OR password <> ''";
			if (!empty($groupID)) {
				$permConditionClause .= ' OR shareid IN (SELECT shareid FROM '.PHOTO_GROUP_PERMISSION_TABLE.' WHERE groupid=? AND permission & 1 <> 0)';
				$sqlParam[$sqlParamCount++] = $groupID;
			}
		}

		/* query first level albums */
		$whereClause = "WHERE is_subdir='f' AND sharename <> '/'";
		if (strlen($permConditionClause)) {
			/* sql param already append to $sqlParam */
			$whereClause .= " AND ({$permConditionClause})";
		}
		$query = "SELECT * FROM photo_share {$whereClause} ORDER BY upper(sharename) ASC";
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$rootAlbums = $dbResult->fetchAll();
		if (false === $rootAlbums) {
			return array();
		}

		/* query second level albums accroding to accessible first level albums */
		$secondLevelAlbums = array();
		$whereClause = "WHERE is_subdir='t' AND sharename NOT LIKE '%/%/%'";
		if (strlen($permConditionClause)) {
			/* sql param already append to $sqlParam */
			$whereClause .= " AND ({$permConditionClause})";
		}
		$whereClause .=  " AND sharename LIKE ? {$this->escapeStr}";
		$query = "SELECT * FROM photo_share {$whereClause} ORDER BY upper(sharename) ASC";
		$dbResult = $this->_dbh->prepare($query);
		foreach ($rootAlbums as $key => $item) {
			// skip photo in remote mount (cifs) or read-only mount (iso9660)
			if (csSYNOPhotoMisc::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$item['sharename'], $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])) {
				unset($rootAlbums[$key]);
				continue;
			}

			$item['sharename'] = self::EscapeLikeParam($item['sharename']);
			$sqlParam[$sqlParamCount] = "{$item['sharename']}/%";
			$dbResult->execute($sqlParam);
			$result = $dbResult->fetchAll();
			if (false !== $result) {
				// skip photo in remote mount (cifs) or read-only mount (iso9660)
				foreach ($result as $key => $item) {
					if (csSYNOPhotoMisc::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$item['sharename'], $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])) {
						unset($result[$key]);
					}
				}
				$secondLevelAlbums = array_merge($secondLevelAlbums, $result);
			}
		}

		$result = array_merge($rootAlbums, $secondLevelAlbums);

		$query = "SELECT * FROM photo_share where password <> '' and is_subdir = 't' AND sharename NOT LIKE '%/%/%' ORDER BY upper(sharename) ASC";
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute();
		$passwordAlbums = $dbResult->fetchAll();
		foreach ($passwordAlbums as $item) {
			if (!in_array($item, $result)) {
				$result[] = $item;
			}
		}
		return $result;
	}
	/*!
	 * Get uploadable level 1,2 albums for non-admin user
	 *
	 * \param $userID non-admin user's userID
	 * \return array with uploadalbe album
	 */
	private function GetUploadableAlbums($userID)
	{
		$result = array();
		if (empty($userID)) {
			return $result;
		}

		$query = "Select sharename from photo_share where shareid in (select shareid from " . PHOTO_UPLOAD_RIGHT_TABLE . " where userid = ".$userID.") AND sharename NOT LIKE '%/%/%' order by sharename asc";
		$db_result = $this->_dbh->query($query);

		while($row = $db_result->fetch()) {
			$result[$row[0]] = 1;
		}

		return $result;
	}
	/*!
	 * Get uploadable level 1,2 albums for groups
	 *
	 * \param $groupID user's groupID
	 * \return array with uploadalbe album
	 */
	private function GetUploadableAlbumsForGroup($groupID)
	{
		$result = array();
		if (empty($groupID)) {
			return $result;
		}

		$query = "SELECT sharename FROM photo_share WHERE shareid IN (SELECT shareid FROM " . PHOTO_GROUP_PERMISSION_TABLE . " WHERE groupid = " . $groupID . " AND permission & 2 <> 0) AND sharename NOT LIKE '%/%/%' ORDER BY upper(sharename) ASC";
		$db_result = $this->_dbh->query($query);

		while ($row = PHOTO_DB_FetchRow($db_result)) {
			$result[$row[0]] = 1;
		}
		return $result;
	}
	/*!
	 * Get manageable level 1,2 albums for non-admin user
	 *
	 * \param $userID non-admin user's userID
	 * \return array with manageable album
	 */
	private function GetManageableAlbums($userID)
	{
		$result = array();
		if (empty($userID)) {
			return $result;
		}

		$query = "SELECT sharename FROM photo_share WHERE shareid IN (SELECT shareid FROM " . PHOTO_MANAGE_RIGHT_TABLE . " WHERE userid = ".$userID.") AND sharename NOT LIKE '%/%/%' ORDER BY upper(sharename) ASC";
		$db_result = $this->_dbh->query($query);

		while ($row = $db_result->fetch()) {
			$result[$row[0]] = 1;
		}

		return $result;
	}
	/*!
	 * Get manageable level 1,2 albums for group
	 *
	 * \param $groupID user's groupID
	 * \return array with manageable album
	 */
	private function GetManageableAlbumsForGroup($groupID)
	{
		$result = array();
		if (empty($groupID)) {
			return $result;
		}

		$query = "SELECT sharename FROM photo_share WHERE shareid IN (SELECT shareid FROM " . PHOTO_GROUP_PERMISSION_TABLE . " WHERE groupid = " . $groupID . " AND permission & 4 <> 0) AND sharename NOT LIKE '%/%/%' ORDER BY upper(sharename) ASC";
		$db_result = $this->_dbh->query($query);

		while ($row = PHOTO_DB_FetchRow($db_result)) {
			$result[$row[0]] = 1;
		}

		return $result;
	}
	/*!
	 * Cache system config files in session data
	 */
	function SetSessionSystemConfigsFromFile()
	{
		$requiredConfKeys = 'language|userHomeEnable|unique|'
							.'supplang|ddns_update|ddns_select|albumdefpublic|enable_demomode';
		$pkgRequireKey = 'runpersonalphotostation|albumdefpublic|external_host_ip|external_port_photo_https|external_port_photo_http|runfacerecognition|no_iframe|white_list';
		$_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['cfg'] = csSYNOPhotoMisc::GetConfigFile(SYNO_CNF_FILE, $requiredConfKeys);
		$_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['defCfg'] = csSYNOPhotoMisc::GetConfigFile(SYNO_DEF_CNF_FILE, $requiredConfKeys);
		$_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg'] = csSYNOPhotoMisc::GetConfigFile(SYNO_PKG_CNF_FILE, $pkgRequireKey);
		$_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['dsmCfg']['buildnumber'] = csSYNOPhotoMisc::GetDsmVersion();
		if (SYNOPHOTO_IS_PPS){
			//$command = '/usr/syno/bin/synophoto_config --personal '. escapeshellarg(SYNOPHOTO_ADMIN_NAME).' --get runpersonalphotostation';
			//$ret = @exec($command);
			if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['percfg']['runpersonalphotostation'])) {
				$ret = csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_config_root', array('--personal', SYNOPHOTO_ADMIN_NAME, '--get', 'runpersonalphotostation'), false, $outputs);
				if ($ret === 0 && count($outputs) > 0) {
					$value = $outputs[count($outputs) - 1];
				} else {
					$value = 'no';
				}
				$_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['percfg']['runpersonalphotostation'] = $value;
			}

			//$command = '/usr/syno/bin/synophoto_config --personal '. escapeshellarg(SYNOPHOTO_ADMIN_NAME).' --get albumdefpublic';
			//$ret = @exec($command);
			if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['percfg']['albumdefpublic'])) {
				$ret = csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_config_root', array('--personal', SYNOPHOTO_ADMIN_NAME, '--get', 'albumdefpublic'), false, $outputs);
				if ($ret === 0 && count($outputs) > 0) {
					$value = $outputs[count($outputs) - 1];
				} else {
					$value = 'no';
				}
				$_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['percfg']['albumdefpublic'] = $value;
			}
		}
	}
	/*!
	 * Cache album/photo sort type/order in session data
	 * \param $sortType sort type
	 *	- 1: by taken time
	 *	- 2: by create time
	 *	- default: by name
	 * \param $sortOrder sort order
	 *	- 1: descending  sort
	 *	- default: ascending sort
	 */
	function SetSessionSortMethod($sortType, $sortOrder)
	{
		$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_by_preference'] = false;
		switch ($sortType) {
			case '1':
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type'] = 'timetaken';
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type_video'] = "date";
				break;
			case '2':
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type'] = 'create_time';
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type_video'] = "date";
				break;
			case '3':
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_by_preference'] = true;
				break;
			default:
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type'] = 'name';
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type_video'] = "path";
		}

		switch ($sortOrder) {
			case '1':
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_order'] = 'desc';
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_operator_front'] = '>';
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_operator_back'] = '<';
				break;
			default:
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_order'] = 'asc';
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_operator_front'] = '<';
				$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_operator_back'] = '>';
		}
	}
	/*!
	 * cache frequent access data
	 *
	 * \param $isForced force to refresh cache or not
	 */
	function SetSessionCache($isForced = false)
	{
		/*
		 * accessible_album, accessible_subdir: accessible level 1,2 albums.
		 * uploadable_album: level 1,2 uploadable albums when login user is not admin
		 * accessed_albums: set by AddHitTimes(), accessed albums
		 * photoNum_cache[albumName]: set by GetNumberOfPhotos(), the number of accessed albums' photos
		 * list_cache[albumName]: the browsed thumb list (including subdir and photos)
		 * list_video_cache[albumName]: the video's path of the $albumName album
		 * **function controlled** photo_config[key]=value: set by GetConfigsFromDB() in GetConfig() on demand, photo_config scheme from DB
		 * **reset each load** system_config[key]=value: set by SetSessionSystemConfigsFromFile(), from /etc[.default]/synoinfo.conf
		 */

		/* ensure every cache container is exist */
		$sessionInitField = array('accessible_album', 'accessible_subdir', 'photo_config', 'list_cache', 'manageable_album',
								  'system_config', 'accessed_albums', 'photoNum_cache',
								  'list_video_cache', 'uploadable_album', 'commentable_album', 'use_dsm_account', 'albumQueryCondition');
		foreach ($sessionInitField as $field) {
			if (!isSet($_SESSION[SYNOPHOTO_ADMIN_USER][$field])) {
				$_SESSION[SYNOPHOTO_ADMIN_USER][$field] = array();
			}
		}

		/* compatible for desktop edition */
		if (!count($_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_album']) || empty($_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_album'][array_rand($_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_album'])])) {
			$isForced = true;
		}

		/* cache still fresh */
		if (!$isForced && isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['timestamp']) && $_SESSION[SYNOPHOTO_ADMIN_USER]['timestamp'] > (time() - $this->CACHE_LIFETIME)) {
			return;
		}

		$_SESSION[SYNOPHOTO_ADMIN_USER]['albumQueryCondition'] = array();
		$_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'] = csSYNOPhotoMisc::getSkipPhotoDev();

		/* flush non-function controlled cache */
		$sessionStaleField = array('accessible_album', 'accessible_subdir', 'photoNum_cache', 'list_cache', 'list_video_cache', 'uploadable_album', 'commentable_album', 'manageable_album');
		foreach ($sessionStaleField as $field) {
			$_SESSION[SYNOPHOTO_ADMIN_USER][$field] = array();
		}

		/* cache accessible albums/sub-albums */
		$userID = isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : '';
		$isAdmin = isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);

		/*
		$albums = $this->GetAlbumsFromDB($userID, $isAdmin);

		$groups = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) ? explode(',', $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) : array();
		foreach ($groups as $groupID) {
			$albums = array_merge($albums, $this->GetAlbumsFromDBForGroup($groupID, $isAdmin));
		}
		 */
		if (!$isAdmin) {
			$albums = Album::GetAccessibleShare('session');
			usort($albums, function($a, $b) {
				return strcasecmp ($a['sharename'], $b['sharename']);
			});

			$this->WriteAccessibleAlbumToSession($_SESSION[SYNOPHOTO_ADMIN_USER], $albums, $isAdmin);

			/* cache commentable level 1 albums */
			foreach ($albums as $item) {
				if (!$item['is_subdir'] && $item['comment']) {
					$_SESSION[SYNOPHOTO_ADMIN_USER]['commentable_album'][$item['sharename']] = true;
				}
			}
			unset($albums);
		}

		/* cache uploadable albums */
		if (!$isAdmin && !empty($userID)) {
			$uploadableAlbums = $this->GetUploadableAlbums($userID);

			$groups = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) ? explode(',', $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) : array();
			foreach ($groups as $groupID) {
				$uploadableAlbums = $uploadableAlbums + $this->GetUploadableAlbumsForGroup($groupID);
			}

			foreach (array_keys($uploadableAlbums) as $albumName) {
				$_SESSION[SYNOPHOTO_ADMIN_USER]['uploadable_album'][$albumName] = 1;
			}
		}

		/* cache manageable albums */
		if (!$isAdmin && !empty($userID)) {
			$manageableAlbums = $this->GetManageableAlbums($userID);

			$groups = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) ? explode(',', $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_groupid']) : array();
			foreach ($groups as $groupID) {
				$manageableAlbums = $manageableAlbums + $this->GetManageableAlbumsForGroup($groupID);
			}

			foreach (array_keys($manageableAlbums) as $albumName) {
				$_SESSION[SYNOPHOTO_ADMIN_USER]['manageable_album'][$albumName] = 1;
			}
		}

		/* set sort property */
		if (!isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type'])){
			$this->SetSessionSortMethod($this->GetConfig('album', 'thumb_sort_type'),
									$this->GetConfig('album', 'thumb_sort_order'));
		}

		$_SESSION[SYNOPHOTO_ADMIN_USER]['folder_sort_only_name'] = ($this->GetConfig('album', 'folder_sort_only_name') === 'on') ? true : false;

		$_SESSION[SYNOPHOTO_ADMIN_USER]['timestamp'] = time();
		$_SESSION[SYNOPHOTO_ADMIN_USER]['use_dsm_account'] = ($this->GetConfig('global', 'account_system') == 1) ? true : false;
	}

	/*!
	 * cache frequent access data for public share
	 *
	 * \param $publicShareId 8 character of sharelink
	 * \param $isForced force to refresh cache or not
	 *
	 * \return boolean update is successful
	 */
	function SetPublicShareSessionCache($publicShareId, $isForced = false)
	{
		if (!isset($publicShareId)) {
			return false;
		}

		$publicShareInfo = SharedAlbum::GetInfoByPublicShare($publicShareId);
		if (NULL === $publicShareInfo || $publicShareInfo['share_status'] !== 'valid') {
			return false;
		}

		/* ensure every cache container is exist */
		$sessionInitField = array('accessible_album', 'accessible_subdir', 'uploadable_album', 'password_pass_album', 'albumQueryCondition');
		foreach ($sessionInitField as $field) {
			if (!isSet($_SESSION[$publicShareId][$field])) {
				$_SESSION[$publicShareId][$field] = array();
			}
		}

		/* compatible for desktop edition */
		if (!count($_SESSION[$publicShareId]['accessible_album']) || empty($_SESSION[$publicShareId]['accessible_album'][array_rand($_SESSION[$publicShareId]['accessible_album'])])) {
			$isForced = true;
		}

		/* cache still fresh */
		if (!$isForced && isSet($_SESSION[$publicShareId]['timestamp']) && $_SESSION[$publicShareId]['timestamp'] > (time() - $this->CACHE_LIFETIME)) {
			return true;
		}

		$_SESSION[$publicShareId]['albumQueryCondition'] = array();

		/* flush non-function controlled cache */
		$sessionStaleField = array('accessible_album', 'accessible_subdir', 'uploadable_album', 'password_pass_album');
		foreach ($sessionStaleField as $field) {
			$_SESSION[$publicShareId][$field] = array();
		}

		$userID = $publicShareInfo['userid'];
		$use_dsm_account = ($this->GetConfig('global', 'account_system') == 1) ? true : false;
		$_SESSION[$publicShareId]['use_dsm_account'] = $use_dsm_account;
		unset($_SESSION[$publicShareId]['admin_syno_user']);
		unset($_SESSION[$publicShareId]['reg_syno_userid']);
		unset($_SESSION[$publicShareId]['reg_syno_groupid']);
		if (PHOTO_DB_IsAdminUid($userID)) {
			$isAdmin = true;
		} else {
			$_SESSION[$publicShareId]['reg_syno_userid'] = $userID;
			if ($use_dsm_account) {
				$userInfo = csSYNOPhotoMisc::GetDsmUserInfoById($userID);
			} else {
				$userInfo = csSYNOPhotoMisc::GetUserInfoById($userID);
			}
			if (NULL === $userInfo) {
				return false;
			}
			$isAdmin = PHOTO_DB_IsTrue($userInfo['isAdmin']);
			$_SESSION[$publicShareId]['reg_syno_groupid'] = $userInfo['groupids'];
		}
		if ($isAdmin) {
			$_SESSION[$publicShareId]['admin_syno_user'] = SYNOPHOTO_ADMIN_PASS;
		}

		$albums = Album::GetAccessibleShare('session', $publicShareId);
		usort($albums, function($a, $b) {
			return strcasecmp ($a['sharename'], $b['sharename']);
		});

		$this->WriteAccessibleAlbumToSession($_SESSION[$publicShareId], $albums, $isAdmin);

		/* cache uploadable albums */
		if (!$isAdmin && !empty($userID)) {
			$uploadableAlbums = $this->GetUploadableAlbums($userID);

			$groups = isset($userInfo['groupids']) ? explode(',', $userInfo['groupids']) : array();
			foreach ($groups as $groupID) {
				$uploadableAlbums = $uploadableAlbums + $this->GetUploadableAlbumsForGroup($groupID);
			}

			foreach (array_keys($uploadableAlbums) as $albumName) {
				$_SESSION[$publicShareId]['uploadable_album'][$albumName] = 1;
			}
		}
		$_SESSION[$publicShareId]['timestamp'] = time();

		return true;
	}

	function WriteAccessibleAlbumToSession(&$sessionArray, &$albums, $isAdmin)
	{
		$no_password_shareids = array();
		$shareids = array();
		$password_album_list = array();

		foreach ($albums as $item) {
			$shareids[] = $item['shareid'];
			if (empty($item['password']) ||  $sessionArray['password_pass_album'][$item['sharename']] === $item['password']) {
				$no_password_shareids[] = $item['shareid'];
			}

			if (!empty($item['password'])) {
				$password_album_list[$item['sharename']] = $item['password'];
			}

			if ($item['is_subdir']) {
				$sessionArray['accessible_subdir'][$item['sharename']] = $item['shareid'];
				if ($isAdmin) {
					$sessionArray['password_pass_album'][$item['sharename']] = $item['password'];
				}
			} else {
				$sessionArray['accessible_album'][$item['sharename']] = $item['shareid'];
				if ($isAdmin) {
					$sessionArray['password_pass_album'][$item['sharename']] = $item['password'];
				}
			}
		}

		csSYNOPhotoMisc::SetPriviegeShareIdListToSession($sessionArray, $shareids);
		csSYNOPhotoMisc::SetPasswordAlbumsToSession($sessionArray, $password_album_list);
		csSYNOPhotoMisc::SetPriviegeShareIdNoPasswordListToSession($sessionArray, $no_password_shareids);
	}

	function ExpireSessionCache()
	{
		$_SESSION[SYNOPHOTO_ADMIN_USER]['timestamp'] = time() - $this->CACHE_LIFETIME - 1;
	}

	function ExpirePublicShareSessionCache($publicShareId)
	{
		if (!isset($publicShareId) || !isset($_SESSION[$publicShareId])) {
			return;
		}

		$_SESSION[$publicShareId]['timestamp'] = time() - $this->CACHE_LIFETIME - 1;
	}

	/*!
	 * Check user exist in db or not
	 *
	 * \param $userId username
	 * \return true for exist
	 */
	function CheckUserExist($userId)
	{
		$query = 'SELECT count(*) FROM photo_user WHERE username=?';
		$sqlParam = array($userId);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$row = $dbResult->fetch();
		return(0 < $row[0]);
	}
	/*!
	 * validate username and password, and then return user info
	 *
	 * \param $username username
	 * \param $password password
	 * \return false when validate failed, otherwise data from scheme 'photo_user'
	 */
	function GetValidateUserInfo($username, $password)
	{
		$query = 'SELECT * FROM photo_user WHERE lower(username)=? AND password=?';
		$sqlParam = array(strtolower($username), md5(addslashes($password)));
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$userInfo = $dbResult->fetch();
		return $userInfo; // false when no matched
	}
	/*!
	 * Get config value from scheme 'photo_config'
	 *
	 * \param $moduleName module/section name
	 * \param $configKey key name
	 * \return config value
	 */
	function GetConfig($moduleName, $configKey)
	{
		/* cache db scheme on demand */
		if (0 == count($_SESSION[SYNOPHOTO_ADMIN_USER]['photo_config'])) {
			$configs = $this->GetConfigsFromDB();
			foreach ($configs as $item) {
				$_SESSION[SYNOPHOTO_ADMIN_USER]['photo_config'][$item['module_name']][$item['config_key']] = $item['config_value'];
			}
		}
		$item = $_SESSION[SYNOPHOTO_ADMIN_USER]['photo_config'];
		if (isSet($item[$moduleName]) && ($item = $item[$moduleName]) && isSet($item[$configKey])) {
			return $item[$configKey];
		}
		return NULL;
	}
	/*!
	 * Get # of comments for specified photo
	 *
	 * \param $photoId photo id in db
	 * \return # of comments
	 */
	function GetNumberOfComments($photoId)
	{
		$query = 'SELECT count(*) FROM photo_comment WHERE photo_id=?';
		$sqlParam = array($photoId);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$row = $dbResult->fetch();
		return $row[0];
	}
	/*!
	 * Get comments for specified photo
	 *
	 * \param $photoId photo id in db
	 * \param $offset # of comments to skip
	 * \param $limit # of comments to get
	 * \return array with data from scheme 'photo_comment'
	 */
	function GetPhotoComments($photoId, $offset = 0, $limit = -1)
	{
		$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);

		$query = "SELECT * FROM photo_comment WHERE photo_id=? ORDER BY date desc $limitOffsetString";
		$sqlParam = array($photoId);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$result = $dbResult->fetchAll();
		if (false === $result) {
			return array();
		}
		return $result;
	}
	/*!
	 * Get comments for specified video
	 *
	 * \param $videoPath video file full path
	 * \param $offset # of comments to skip
	 * \param $limit # of comments to get
	 * \return array with data from scheme 'photo_comment'
	 */
	function GetVideoComments($videoPath, $offset = 0, $limit = -1)
	{
		$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);

		$query = "SELECT * FROM video_comment WHERE path=? ORDER BY date desc $limitOffsetString";
		$dPath = substr($videoPath, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
		$sqlParam = array($dPath);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$result = $dbResult->fetchAll();
		if (false === $result) {
			return array();
		}
		return $result;
	}
	/*!
	 * Add comment for the photo
	 *
	 * \param $id photo image id
	 * \param $name user name who adding the comment
	 * \param $email email address of whom adding the comment
	 * \param $comment the comment
	 * \return true for adding success
	 */
	function AddPhotoComment($id, $name, $mail, $comment)
	{
		$query = "Insert into photo_comment (photo_id, name, email, comment, date) VALUES (?,?,?,?,?)";

		$this->Query($query, array($id, $name, $mail, $comment, date('Y-m-d H:i:s')));
		return true;
	}
	/*!
	 * Add comment for the video
	 *
	 * \param $path video path
	 * \param $name user name who adding the comment
	 * \param $email email address of whom adding the comment
	 * \param $comment the comment
	 * \return true for adding success
	 */
	function AddVideoComment($path, $name, $mail, $comment)
	{
		$dPath = substr($path, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
		$query = "Insert into video_comment (path, name, email, comment, date) Values (?,?,?,?,?)";

		$this->Query($query, array($dPath, $name, $mail, $comment, date('Y-m-d H:i:s')));
		return true;
	}
	function DeleteComment($type, $id)
	{
		$table = '';
		if ($type == 1) {
			$table = 'photo_comment';
		} else if ($type == 2) {
			$table = 'video_comment';
		}
		$query = "Delete from $table where id =?";
		$sqlParam = array($id);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);

		return true;
	}
	/*!
	 * Get photo info for specified path
	 *
	 * \param $photoPath photo full path
	 * \return array with data from scheme 'photo_image'
	 */
	function GetPhotoInfo($photoPath)
	{
		$dPath = substr($photoPath, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
		/* search db cacher */
		if (is_array($_SESSION[SYNOPHOTO_ADMIN_USER][DBCACHER_SESSION_ID])) {
			foreach($_SESSION[SYNOPHOTO_ADMIN_USER][DBCACHER_SESSION_ID] as $cacheTuple) {
				if (!is_array($cacheTuple[DBCACHER_TUPLE_DATA])) {
					continue;
				}
				foreach ($cacheTuple[DBCACHER_TUPLE_DATA] as $dbTuple) {
					if ($dPath == $dbTuple['path']) {
						$dbTuple['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$dbTuple['path'];
						// extra info for sorting
						$dbTuple['timetaken'] = $dbTuple['timetaken'];
						$dbTuple['createdate'] = $dbTuple['create_time'];
						return $dbTuple;
					}
				}
			}
		}

		/* not found in cache */
		$query = "SELECT * FROM photo_image WHERE path=?";
		$sqlParam = array($dPath);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		if ($row = $dbResult->fetch()) {
			$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			// extra info for sorting
			$row['timetaken'] = $row['timetaken'];
			$row['createdate'] = $row['create_time'];
			$title = iconv('UTF-8', 'UTF-8//TRANSLIT', $row['title']);
			$row['title'] = $title ? $title : pathinfo($row['path'], PATHINFO_FILENAME);
			$row['description'] = iconv('UTF-8', 'UTF-8//TRANSLIT', $row['description'])."";
		}
		return $row;
	}
	/*!
	 * Get video info for specified path
	 *
	 * \param $videoPath video full path
	 * \return array with data from scheme 'video' of mediaserver DB
	 */
	function GetVideoInfo($videoPath)
	{
		$dPath = substr($videoPath, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
		/* search db cacher */
		if (is_array($_SESSION[SYNOPHOTO_ADMIN_USER][DBCACHER_VIDEO_SESSION_ID])) {
			foreach($_SESSION[SYNOPHOTO_ADMIN_USER][DBCACHER_VIDEO_SESSION_ID] as $cacheTuple) {
				if (!is_array($cacheTuple[DBCACHER_TUPLE_DATA])) {
					continue;
				}
				foreach ($cacheTuple[DBCACHER_TUPLE_DATA] as $dbTuple) {
					if ($dPath == $dbTuple['path']) {
						$dbTuple['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$dbTuple['path'];
						// extra info for sorting
						$dbTuple['timetaken'] = $dbTuple['mdate'];
						$dbTuple['createdate'] = $dbTuple['date'];
						$dbTuple['name'] = basename($dbTuple['path']);
						return $dbTuple;
					}
				}
			}
		}

		/* not found in cache */
		$query = "SELECT * FROM video WHERE path=?";
		$sqlParam = array($dPath);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		if ($row = $dbResult->fetch()) {
			$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			// extra info for sorting
			$row['timetaken'] = $row['mdate'];
			$row['createdate'] = $row['date'];
			$row['name'] = basename($row['path']);
			$row['title'] = iconv('UTF-8', 'UTF-8//TRANSLIT', $row['title'])."";
		}
		return $row;
	}
	/*!
	 * Get video convert info for specified path
	 *
	 * \param $videoPath video full path
	 * \return array with data from scheme 'video' of mediaserver DB
	 */
	function GetVideoConvertInfo($videoPath)
	{
		$dPath = substr($videoPath, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
		/* search db cacher */
		if (is_array($_SESSION[SYNOPHOTO_ADMIN_USER][DBCACHER_VIDEO_SESSION_ID])) {
			foreach($_SESSION[SYNOPHOTO_ADMIN_USER][DBCACHER_VIDEO_SESSION_ID] as $cacheTuple) {
				if (!is_array($cacheTuple[DBCACHER_TUPLE_DATA])) {
					continue;
				}
				foreach ($cacheTuple[DBCACHER_TUPLE_DATA] as $dbTuple) {
					if ($dPath == $dbTuple['path']) {
						$dbTuple['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$dbTuple['path'];
						return $dbTuple;
					}
				}
			}
		}

		/* not found in cache */
		$query = "SELECT * FROM video_convert WHERE video_path=?";
		$sqlParam = array($dPath);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		$rows = array();
		while ($row = $dbResult->fetch()) {
			$row['path'] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			array_push($rows, $row);
		}
		return $rows;
	}

	/*!
	 * Get video's customerized  title and description for specified path
	 *
	 * \param $videoPath video db path
	 * \return array with customzeized title and description
	 */
	function GetVideoCustomizedTitleDescription($dPath)
	{
		$result['title']='';
		$result['description']='';
		$query = "SELECT title, description FROM video_desc WHERE path=?";
		$sqlParam = array($dPath);
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		if ($row = $dbResult->fetch()) {
			$result['title']=iconv('UTF-8', 'UTF-8//TRANSLIT', $row[0])."";
			$result['description']=iconv('UTF-8', 'UTF-8//TRANSLIT', $row[1])."";
		}

		return $result;
	}
	/*!
	 * Prepare album photos DB Cache for future use
	 *
	 * \param $albumName alubm name
	 * \param $offset # of photos to skip
	 * \param $length # of photos to prepare
	 * \return prepared db data from scheme 'photo_image'
	 */
	function PrepareAlbumPhotos($albumName, $offset, $limit)
	{
		$sort_type = $_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type'];
		if (in_array($sort_type, array('timetaken', 'create_time'))) {
			$sort_condition = $sort_type;
		} else {
			$sort_condition = "upper($sort_type)";
		}
		$albumRealPath = self::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH."{$albumName}");
		$query = "SELECT * FROM photo_image WHERE path LIKE ? {$this->escapeStr} AND path NOT LIKE ? {$this->escapeStr} ORDER BY $sort_condition {$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_order']}";
		$sqlParam = array("{$albumRealPath}/%", "{$albumRealPath}/%/%");
		return $this->_dbCacher->CacheQuery($query, $sqlParam, $offset, $limit);
	}
	/*!
	 * Prepare album videos DB Cache for future use
	 *
	 * \param $albumName alubm name
	 * \param $offset # of videos to skip
	 * \param $length # of videos to prepare
	 * \return prepared db data from scheme 'video' of mediaserver DB
	 */
	function PrepareAlbumVideos($albumName, $offset, $limit)
	{
		$sort_type = $_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type_video'];
		if (in_array($sort_type, array('date', 'mdate'))) {
			$sort_condition = $sort_type;
		} else {
			$sort_condition = "upper($sort_type)";
		}
		$albumRealPath = self::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH."{$albumName}");
		$query = "SELECT * FROM video WHERE path LIKE ? {$this->escapeStr} AND path NOT LIKE ? {$this->escapeStr} ORDER BY $sort_condition {$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_order']}";
		$sqlParam = array("{$albumRealPath}/%", "{$albumRealPath}/%/%");
		return $this->_dbCacherMedia->CacheQuery($query, $sqlParam, $offset, $limit);
	}
	/*!
	 * Prepare searched photos DB Cache for future use
	 *
	 * \param $cacheToken search token
	 * \param $offset # of photos to skip
	 * \param $length # of photos to prepare
	 * \return prepared db data from scheme 'photo_image'
	 */
	function PrepareSearchPhotos($statement, $param, $offset, $limit)
	{
		$query = $statement;
		$sqlParam = $param;
		return $this->_dbCacher->CacheQuery($query, $sqlParam, $offset, $limit);
	}
	/*!
	 * Prepare searched photos DB Cache for future use
	 *
	 * \param $cacheToken search token
	 * \param $offset # of photos to skip
	 * \param $length # of photos to prepare
	 * \return prepared db data from scheme 'photo_image'
	 */
	function PrepareSearchVideos($statement, $param, $offset, $limit)
	{
		$query = $statement;
		$sqlParam = $param;
		return $this->_dbCacherMedia->CacheQuery($query, $sqlParam, $offset, $limit);
	}

	/*!
	 * Get photo, video full path list for specified album
	 *
	 * \param $albumName alubm name
	 * \param $offset
	 * \param $limit
	 * \param $sort_by - filename, takendate, createdate
	 * \param $sort_direction - asc, desc
	 * \return
	 *   - list: array with full path list
	 *   - totalCount: total count of photo and video
	 */
	function GetAlbumPhotoVideoList($albumName, $offset, $limit, $sort_by, $sort_direction, $removeVideo = false, $removePhoto = false)
	{
		if (!in_array($sort_by, array('filename', 'takendate', 'createdate'))) {
			return false;
		}
		if (!in_array($sort_direction, array('asc', 'desc'))) {
			return false;
		}

		$list['list'] = array();
		$list['totalCount'] = 0;

		$sqlParam = array();
		$pathSqlParam = array();
		$photoQuery = $videoQuery = '';
		if ('/' === $albumName) {
			$albumRealPath = self::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH);
			if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) && csSYNOPhotoMisc::GetConfigDB("photo", "allow_root_folder_public", "photo_config") !== "on" && !isset($_SESSION[SYNOPHOTO_ADMIN_USER]['uploadable_album']['/'])) {
				$removePhoto = true;
				$removeVideo = true;
			}
		} else {
			$albumRealPath = self::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH."{$albumName}/");
		}
		$cond = "path LIKE ? {$this->escapeStr} AND path NOT LIKE ? {$this->escapeStr} AND disabled = 'f' ";
		array_push($pathSqlParam, "{$albumRealPath}%");
		array_push($pathSqlParam, "{$albumRealPath}%/%");

		if (!$removePhoto) {
			$photoQuery = "SELECT path as filename, timetaken as takendate, create_time as createdate, 'photo' as type FROM photo_image WHERE $cond";
			$sqlParam = array_merge($sqlParam, $pathSqlParam);
		}
		if (!$removeVideo) {
			$videoQuery = "SELECT path as filename, mdate as takendate, date as createdate, 'video' as type FROM video WHERE $cond";
			$sqlParam = array_merge($sqlParam, $pathSqlParam);
		}
		$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);

		$sortByCond = "tmp.$sort_by";
		if ('filename' === $sort_by) {
			$sortByCond = "upper($sortByCond)";
		}

		if ('' !== $photoQuery && '' !== $videoQuery) {
			$query = "SELECT * FROM ($photoQuery UNION $videoQuery) AS tmp ORDER BY $sortByCond $sort_direction, filename $sort_direction $limitOffsetString";
			$queryCount = "SELECT COUNT(*) FROM ($photoQuery UNION $videoQuery) AS totalCount";
		} elseif ('' !== $videoQuery && '' === $photoQuery) {
			$query = "SELECT * FROM ($videoQuery) AS tmp ORDER BY $sortByCond $sort_direction, filename $sort_direction $limitOffsetString";
			$queryCount = "SELECT COUNT(*) FROM ($videoQuery) AS totalCount";
		} elseif ('' !== $photoQuery && '' === $videoQuery) {
			$query = "SELECT * FROM ($photoQuery) AS tmp ORDER BY $sortByCond $sort_direction, filename $sort_direction $limitOffsetString";
			$queryCount = "SELECT COUNT(*) FROM ($photoQuery) AS totalCount";
		} else {
			return $list;
		}
		// total
		$dbResult = $this->_dbh->prepare($queryCount);
		$dbResult->execute($sqlParam);
		$row = $dbResult->fetch();
		$list['totalCount'] = (int)$row[0];

		if (0 === $limit) {
			return $list;
		}
		// sql
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		if (false === $result = $dbResult->fetchAll()) {
			return false;
		}
		foreach ($result as $row) {
			if ('photo' === $row['type']) {
				$type = SYNOPHOTO_ITEM_TYPE_PHOTO;
			} else {
				$type = SYNOPHOTO_ITEM_TYPE_VIDEO;
			}
			$list['list'][$row['filename']] = $type;
		}
		return $list;
	}
	/*!
	 * Get photo name list for specified album
	 *
	 * \param $albumName alubm name
	 * \return array with name list
	 */
	function GetAlbumPhotoList($albumName, $recursive = false)
	{
		if (isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['list_cache'][$albumName])) {
			return $_SESSION[SYNOPHOTO_ADMIN_USER]['list_cache'][$albumName];
		}
		$albumRealPath = self::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH."{$albumName}");
		$sort_type = $_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type'];
		if (in_array($sort_type, array('timetaken', 'create_time'))) {
			$sort_condition = $sort_type;
		} else {
			$sort_condition = "upper($sort_type)";
		}

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat();
		if ($recursive) {
			$query = "SELECT name, id, title, path FROM photo_image WHERE path LIKE ? {$this->escapeStr}";
			if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
				$query .= " AND {$albumCondition['albumCond']}";
			}
			$query .= " ORDER BY create_time desc LIMIT 20";
			$sqlParam = ('' !== $albumName) ? array("{$albumRealPath}/%") : array("{$albumRealPath}%");
		} else {
			$query = "SELECT name, id, title FROM photo_image WHERE path LIKE ? {$this->escapeStr} AND path NOT LIKE ? {$this->escapeStr}";
			if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
				$query .= " AND {$albumCondition['albumCond']}";
			}
			$query .= " ORDER BY $sort_condition {$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_order']}";
			$sqlParam = array("{$albumRealPath}/%", "{$albumRealPath}/%/%");
		}
		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);
		}

		$list = array();
		$idList = array();
		$dbResult = PHOTO_DB_Query($query, $sqlParam);
		while ($row = PHOTO_DB_FetchRow($dbResult)) {
			if ($recursive) {
				if ('' !== $albumName) {
					$arr = explode($albumName.'/', $row[3]);
					$name = $arr[1];
				} else {
					$name = substr($row[3], strlen(SYNOPHOTO_SERVICE_REAL_DIR_PATH));
				}
				$list[] = $name;
			} else {
				$list[] = $row[0];
			}
			$idList[$row[1]] = $row[0];
			if ('' != $row[2]) {
				$titleList[$row[1]] = $row[2];
			} else {
				$titleList[$row[1]] = $row[0];
			}
		}

		$_SESSION[SYNOPHOTO_ADMIN_USER]['list_cache'][$albumName] = $list;
		return $list;
	}
	/*!
	 * Get video path list for specified album
	 *
	 * \param $albumName alubm name
	 * \return array with path list
	 */
	function GetAlbumVideoList($albumName, $recursive = false)
	{
		if (isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['list_video_cache'][$albumName])) {
			return $_SESSION[SYNOPHOTO_ADMIN_USER]['list_video_cache'][$albumName];
		}
		$albumRealPath = self::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH."{$albumName}");

		$sort_type = $_SESSION[SYNOPHOTO_ADMIN_USER]['sort_type_video'];
		if (in_array($sort_type, array('date', 'mdate'))) {
			$sort_condition = $sort_type;
		} else {
			$sort_condition = "upper($sort_type)";
		}
		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat();
		if ($recursive) {
			$query = "SELECT path, id FROM video WHERE path LIKE ? {$this->escapeStr}";
			if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
				$query .= " AND {$albumCondition['albumCond']}";
			}
			$query .= " ORDER BY date desc LIMIT 20";
			$sqlParam = ('' !== $albumName) ? array("{$albumRealPath}/%") : array("{$albumRealPath}%");
		} else {
			$query = "SELECT path, id FROM video WHERE path LIKE ? {$this->escapeStr} AND path NOT LIKE ? {$this->escapeStr}";
			if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
				$query .= " AND {$albumCondition['albumCond']}";
			}
			$query .= " ORDER BY $sort_condition {$_SESSION[SYNOPHOTO_ADMIN_USER]['sort_order']}";
			$sqlParam = array("{$albumRealPath}/%", "{$albumRealPath}/%/%");
		}

		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);
		}

		$list = array();
		$idList = array();
		$dbResult = PHOTO_DB_Query($query, $sqlParam);
		while ($row = PHOTO_DB_FetchRow($dbResult)) {
			$list[] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row[0];
			$idList[$row[1]] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row[0];
		}

		$_SESSION[SYNOPHOTO_ADMIN_USER]['list_video_cache'][$albumName] = $list;
		return $list;
	}

	function GetUncategorizedPhotoList($fieldName = 'path')
	{
		$list = array();
		$albumRealPath = csSYNOPhotoDB::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH);
		$albumCond = "(path LIKE ? ".csSYNOPhotoDB::GetDBInstance()->escapeStr." AND path NOT LIKE ? ".csSYNOPhotoDB::GetDBInstance()->escapeStr.") ";
		$sqlParam[] = "{$albumRealPath}%";
		$sqlParam[] = "{$albumRealPath}%/%";
		$query = "SELECT path, id FROM photo_image WHERE {$albumCond}";
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		while (false !== ($row = $dbResult->fetch())) {
			$list[] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row[$fieldName];
		}
		return $list;
	}

	function GetUncategorizedVideoList($fieldName = 'path')
	{
		$list = array();
		$albumRealPath = csSYNOPhotoDB::EscapeLikeParam(SYNOPHOTO_SERVICE_REAL_DIR_PATH);
		$albumCond = "(path LIKE ? ".csSYNOPhotoDB::GetDBInstance()->escapeStr." AND path NOT LIKE ? ".csSYNOPhotoDB::GetDBInstance()->escapeStr.") ";
		$sqlParam[] = "{$albumRealPath}%";
		$sqlParam[] = "{$albumRealPath}%/%";
		$query = "SELECT path, id FROM video WHERE {$albumCond}";
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		while (false !== ($row = $dbResult->fetch())) {
			$list[] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row[$fieldName];
		}
		return $list;
	}

	/*!
	 * Get most recent photo path list
	 *
	 * \return array with path list
	 */
	function GetMostRecentPhotoList()
	{
		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryCondition();
		$list = array();

		if (count($albumCondition['albumCond'])) {
			$limit = 20;
			if (($count = csSYNOPhotoDB::GetDBInstance()->GetConfig('photo', 'recent_photo_num') )!= null) {
				$limit = $count;
			}
			$albumCondition['albumCond'] = implode(' OR ', $albumCondition['albumCond']);
			$query = "SELECT path FROM photo_image WHERE ({$albumCondition['albumCond']}) ORDER BY create_time desc LIMIT ".$limit;
			$dbResult = $this->_dbh->prepare($query);
			$dbResult->execute($albumCondition['sqlParam']);
			while (false !== ($row = $dbResult->fetch())) {
				$list[] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row[0];
			}
		}

		return $list;
	}
	/*!
	 * Get most recent video path list
	 *
	 * \return array with path list
	 */
	function GetMostRecentVideoList()
	{
		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryCondition();
		$list = array();

		if (count($albumCondition['albumCond'])) {
			$limit = 20;
			if (($count = csSYNOPhotoDB::GetDBInstance()->GetConfig('photo', 'recent_video_num') )!= null) {
				$limit = $count;
			}
			$albumCondition['albumCond'] = implode(' OR ', $albumCondition['albumCond']);
			if ($limit == 'all') {
				$query = "SELECT path FROM video WHERE ({$albumCondition['albumCond']}) ORDER BY date desc";
			} else {
				$query = "SELECT path FROM video WHERE ({$albumCondition['albumCond']}) ORDER BY date desc LIMIT ".$limit;
			}
			$dbResult = $this->_dbh->prepare($query);
			$dbResult->execute($albumCondition['sqlParam']);

			while (false !== ($row = $dbResult->fetch())) {
				$list[] = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row[0];
			}
		}

		return $list;
	}

	function GetMostRecentCommentPhotoList()
	{
		$limit = $this->GetConfig('photo', 'recent_commented_photo_num');
		if (!$limit) {
			$limit = '20';
		}
		$query = 'SELECT photo_id FROM photo_comment ORDER BY date desc';
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute();
		$count = 0;
		$list = array();
		while (false !== ($row = $dbResult->fetch()) && $count < $limit) {
			$query1 = 'SELECT path FROM photo_image WHERE id='.$row['photo_id'];
			$dbResult1 = $this->_dbh->prepare($query1);
			$dbResult1->execute();
			if (false !== ($row1 = $dbResult1->fetch())) {
				$path = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row1['path'];
				if (csSYNOPhotoMisc::CheckPathAccessible($path) && false === array_search($path, $list)) {
					$list[] = $path;
					$count++;
				}
			}
		}
		$_SESSION[SYNOPHOTO_ADMIN_USER]['most_recent_comment_cache']['photo'] = $list;
		return $list;
	}

	function GetMostRecentCommentVideoList()
	{
		$limit = $this->GetConfig('photo', 'recent_commented_video_num');
		if (!$limit) {
			$limit = '20';
		}

		$query = 'select path from video_comment order by date desc';
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute();
		$count = 0;
		$list = array();
		while (false !== ($row = $dbResult->fetch()) && $count < $limit) {
			$path = SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path'];
			if (csSYNOPhotoMisc::CheckPathAccessible($path) && false === array_search($path, $list)) {
				$list[] = $path;
				$count++;
			}
		}
		$_SESSION[SYNOPHOTO_ADMIN_USER]['most_recent_comment_cache']['video'] = $list;
		return $list;
	}

	function GetItemListByLabel($labelId, $category)
	{
		$result = array();
		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryCondition();

		if (0 == count($albumCondition['albumCond'])) {
			return $result;
		}
		$sqlParam = array();
		$query = "SELECT photo_image.path FROM photo_image_label LEFT JOIN photo_image ON photo_image_label.image_id=photo_image.id WHERE photo_image_label.label_id=? AND status='t'";
		$sqlParam[] = $labelId;

		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			$query .= " AND (".implode(' OR ', $albumCondition['albumCond']).' )';
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);
		}
		$query .= ' ORDER BY photo_image.create_time DESC';
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		while (false !== ($row = $dbResult->fetch())) {
			if ($row['path']) {
				$result[SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path']] = SYNOPHOTO_ITEM_TYPE_PHOTO;
			}
		}

		if (0 == $category) {
			return $result;
		}
		$query = 'SELECT video_path AS path From photo_video_label LEFT JOIN video ON video.path=photo_video_label.video_path WHERE label_id=?';
		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			$query .= " AND (".implode(' OR ', $albumCondition['albumCond']).' )';
		}
		$query .= ' ORDER BY date DESC';
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		while (false !== ($row = $dbResult->fetch())) {
			$result[SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path']] = SYNOPHOTO_ITEM_TYPE_VIDEO;
		}
		return $result;
	}

	function GetNonConfirmItemList()
	{
		$result = array();

		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			return $result;
		}

		$query = "SELECT photo_image.path FROM photo_image_label LEFT JOIN photo_image ON photo_image_label.image_id=photo_image.id WHERE status='f' ORDER BY photo_image.create_time DESC";
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute();
		while (false !== ($row = $dbResult->fetch())) {
			if ($row['path']) {
				$result[SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path']] = SYNOPHOTO_ITEM_TYPE_PHOTO;
			}
		}
		return $result;
	}

	function GetCategoryItemList($category)
	{
		$result = array();
		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryCondition();

		if (0 == count($albumCondition['albumCond'])) {
			return $result;
		}
		$sqlParam = array();
		$query = "SELECT photo_image.path FROM photo_image_label LEFT JOIN photo_label ON photo_label.id=photo_image_label.label_id LEFT JOIN photo_image ON photo_image_label.image_id=photo_image.id WHERE category=? AND status='t' ";
		$sqlParam[] = $category;

		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			$query .= " AND (".implode(' OR ', $albumCondition['albumCond']).' )';
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);
		}
		$query .= ' ORDER BY photo_image.create_time DESC';
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		while (false !== ($row = $dbResult->fetch())) {
			if ($row['path']) {
				$result[SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path']] = SYNOPHOTO_ITEM_TYPE_PHOTO;
			}
		}

		if (0 == $category) {
			return $result;
		}

		$query = 'SELECT video_path AS path From photo_video_label LEFT JOIN photo_label ON photo_video_label.label_id=photo_label.id LEFT JOIN video ON video.path=photo_video_label.video_path WHERE category=? ';
		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			$query .= " AND (".implode(' OR ', $albumCondition['albumCond']).' )';
		}
		$query .= ' ORDER BY date DESC';
		$dbResult = $this->_dbh->prepare($query);
		$dbResult->execute($sqlParam);
		while (false !== ($row = $dbResult->fetch())) {
			$result[SYNOPHOTO_SERVICE_REAL_DIR_PREFIX.$row['path']] = SYNOPHOTO_ITEM_TYPE_VIDEO;
		}
		return $result;
	}

	function FormSmartRuleSet($searchCondition)
	{
		$ruleset = array();
		if (isset($searchCondition['k']) && isset($searchCondition['k_op'])) {
			$ruleset[] = array(
				'field' => 'keyword',
				'operator' => $searchCondition['k_op'],
				'value'	=> $searchCondition['k']
			);
		}
		if (isset($searchCondition['d']) && isset($searchCondition['d_op'])) {
			$ruleset[] = array(
				'field' => 'date',
				'operator' => $searchCondition['d_op'],
				'value'	=> $searchCondition['d']
			);
		}
		/* people tag condition */
		if (isset($searchCondition['pt']) && isset($searchCondition['pt_op'])) {
			$ruleset[] = array(
				'field' => 'people',
				'operator' => $searchCondition['pt_op'],
				'value'	=> $searchCondition['pt']
			);
		}

		/* geo tag condition */
		if (isset($searchCondition['gt']) && isset($searchCondition['gt_op'])) {
			$ruleset[] = array(
				'field' => 'geo',
				'operator' => $searchCondition['gt_op'],
				'value'	=> $searchCondition['gt']
			);
		}

		/* desc tag condition */
		if (isset($searchCondition['dt']) && isset($searchCondition['dt_op'])) {
			$ruleset[] = array(
				'field' => 'desc',
				'operator' => $searchCondition['dt_op'],
				'value'	=> $searchCondition['dt']
			);
		}
		/* album condition */
		if (isset($searchCondition['albums'])) {
			$ruleset[] = array(
				'field' => 'albums',
				'operator' => 'any',
				'value' => $searchCondition['albums']
			);
		}
		/* exif condition */
		foreach(SmartAlbum::$exif2IdPrefix as $label => $value) {
			$op = $label.'_op';
			if (isset($searchCondition[$label]) && isset($searchCondition[$op])) {
				$ruleset[] = array(
					'field' => $label,
					'operator' => $searchCondition[$op],
					'value' => $searchCondition[$label]
				);
			}
		}
		return $ruleset;
	}

	/*!
	 * Search photos by conditions, and store result in cache
	 *
	 * \param $moreCond array with search conditions, key as the field name
	 * \return the token of cache store search result
	 */
	function GetSearchToken($condition = array())
	{
		/* init variable */
		$offset = 0; $limit = -1; $recentlyCount = false;
		$cacheQuery = $videoCacheQuery = '';
		$photoResult = $videoResult = $photoParam = $videoParam = array();

		/* pack search paramter into smart album format */
		$rules = array('rule_sets' => array(self::FormSmartRuleSet($condition)));

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat('A');

		$sqlParam = $albumCondition['sqlParam'];

		$photoIds = SmartAlbum::GetSmartAlbumInstance()->GetSmartAlbumToIds($rules, 'photo');
		$photoRecentlyAddSqlCond = SmartAlbum::GetRecentlyAddSqlCondition($rules, 'photo');
		$photoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($rules, 'photo');
		$videoPath = SmartAlbum::GetSmartAlbumInstance()->GetSmartAlbumToIds($rules, 'video');
		$videoRecentlyAddSqlCond = SmartAlbum::GetRecentlyAddSqlCondition($rules, 'video');
		$videoRecentlyCommentSqlCond = SmartAlbum::GetRecentlyCommentSqlCondition($rules, 'video');

		$albumCondString = $albumCondition['albumCond'];

		if (0 < count($photoIds) || $photoRecentlyAddSqlCond || $photoRecentlyCommentSqlCond) {
			$query = "SELECT A.path FROM photo_image as A ";
			$cond = "WHERE ($albumCondString)";

			if (0 < count($photoIds)) {
				$cond .= " AND A.id IN (".implode(',', $photoIds).")";
			}
			$order = "create_time DESC";

			if ($photoRecentlyAddSqlCond) {
				$order = $photoRecentlyAddSqlCond['order'];
				$recentlyCount = $photoRecentlyAddSqlCond['value'];
			} elseif ($photoRecentlyCommentSqlCond) {
				$query .= " {$photoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$photoRecentlyCommentSqlCond['cond']}";
				$order = $photoRecentlyCommentSqlCond['order'];
				$recentlyCount = $photoRecentlyCommentSqlCond['value'];
			}

			if (false !== $recentlyCount) {
				if ($offset >= $recentlyCount) {
					return array();
				}
				$offset = 0;
				if ($limit > $recentlyCount) {
					$limit = $recentlyCount;
				}
			}
			$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);
			$cacheQuery = $query = "$query $cond ORDER BY $order $limitOffsetString";
			$photoParam = $sqlParam;

			$dbResult = $this->Query($query, $photoParam);

			while (false !== ($row = $dbResult->fetch())) {
				$photoResult[] = $row[0];
			}
		}

		if (0 < count($videoPath) || $videoRecentlyAddSqlCond || $videoRecentlyCommentSqlCond) {
			$query = "SELECT A.path FROM".
				" video as A LEFT JOIN video_desc ON A.path = video_desc.path ";
			$cond = " WHERE ($albumCondString)";

			if (0 < count($videoPath)) {
				$path = array();
				for ($i=0; $i < count($videoPath); ++$i) {
					$path[] = '?';
				}
				$cond .= " AND A.path IN (".implode(',', $path).")";
			}

			$order = "date DESC";
			if ($videoRecentlyAddSqlCond) {
				$order = $videoRecentlyAddSqlCond['order'];
				$recentlyCount = $videoRecentlyAddSqlCond['value'];
			} elseif ($videoRecentlyCommentSqlCond) {
				$query .= " {$videoRecentlyCommentSqlCond['query']}";
				$cond .= " AND {$videoRecentlyCommentSqlCond['cond']}";
				$order = $videoRecentlyCommentSqlCond['order'];
				$recentlyCount = $videoRecentlyCommentSqlCond['value'];
			}

			if (false !== $recentlyCount) {
				if ($offset >= $recentlyCount) {
					return array();
				}
				$offset = 0;
				if ($limit > $recentlyCount) {
					$limit = $recentlyCount;
				}
			}
			$limitOffsetString = PHOTO_DB_GetLimitOffsetString($limit, $offset);
			$videoCacheQuery = $query = "$query $cond ORDER BY $order $limitOffsetString";
			$videoParam = array_merge($sqlParam, $videoPath);
			$dbResult = $this->Query($query, $videoParam);

			while (false !== ($row = $dbResult->fetch())) {
				$videoResult[] = $row[0];
			}
		}
		/* keep only the latest search result */
		$result['search_result_photo'] = array(
								   'statement' => $cacheQuery,
								   'param' => $photoParam,
								   'result' => $photoResult);
		$result['search_result_video'] = array(
									'statement' => $videoCacheQuery,
									'param' => $videoParam,
									'result' => $videoResult);
		return $result;
	}

	/*!
	 * Get album info by name
	 *
	 * \param $albumName album name
	 * \return array with data from scheme 'photo_share'
	 */
	function GetAlbum($albumName)
	{
		// Get Album From DB
		return $this->getPhotoShareByShareName($albumName);
	}


	/*!
	 * Mearge arrays avoid renumbers string numeric keys
	 *
	 * \param $arr1 Array
	 * \param $arr2 Array
	 * \return Array
	 */

	function MergeArrays($arr1,$arr2)
	{
		if (!is_array($arr1)) {
			$arr1 = array();
		}
		if (!is_array($arr2)) {
			$arr2 = array();
		}
		$keys1 = array_keys($arr1);
		$keys2 = array_keys($arr2);
		$keys  = array_merge($keys1,$keys2);
		$vals1 = array_values($arr1);
		$vals2 = array_values($arr2);
		$vals  = array_merge($vals1,$vals2);
		$ret = array();

		foreach($keys as $key)
		{
			list($unused, $val) = each($vals);
			$ret[$key] = $val;
		}

		return $ret;
	}
	function SearchAlbums($moreCond = array())
	{
		$result = array();
		$keyword = array();
		$param = array();
		$param_sharename = array();
		foreach ($moreCond as $key => $value) {
			if (empty($value) || 'albums' === $key) {
				continue;
			}
			if (!is_array($value)) {
				$value = array('op' => 'MIDDLE', 'value' => $value);
			}
			$op = strtoupper($value['op']);
			$value = strtoupper($value['value']);
			switch ($op) {
				case 'MIDDLE':
					if ('sharename' === $key) {
						$keyword_sharename = "upper(". $key .") LIKE ? {$this->escapeStr}";
						$param_sharename[] = "%".self::EscapeLikeParam($value)."%";
						$value_sharename = $value;
					} else {
						$keyword[] = "upper(". $key .") LIKE ? {$this->escapeStr}";
						$param[] = "%".self::EscapeLikeParam($value)."%";
					}
					break;
			}
		}
		if (0 === count($keyword) && !isset($moreCond['albums'])) {
			goto End;
		}
		$accessAlbums = Album::GetAccessibleShare();
		if (0 == count($accessAlbums)) {
			goto End;
		}
		$idCond = array_keys($accessAlbums);
		if (isset($moreCond['albums'])) {
			$subDirIds = Album::GetSubDirIdByShareId($moreCond['albums']['value']);
			$idCond = array_intersect($idCond, $subDirIds);
			if (0 === count($idCond)) {
				goto End;
			}
		}
		/* Query keyword in title and description */
		$sql = "SELECT * FROM photo_share WHERE shareid IN(".implode(',', $idCond).")";
		if (0 < count($keyword)) {
			$sql = $sql." AND (".implode(" OR ", $keyword).")";
		}
		$dbResult = PHOTO_DB_Query($sql, $param);
		while ($row = PHOTO_DB_FetchRow($dbResult)) {
			$result[] = $row;
		}

		/* Query keyword in sharepath */
		if (empty($keyword_sharename)) {
			goto End;
		}
		$sql = "SELECT * FROM photo_share WHERE shareid IN (" . implode(',', $idCond). ")";
		$sql = $sql ." AND (" . $keyword_sharename . ")";
		$dbResult = PHOTO_DB_Query($sql, $param_sharename);
		while ($row = PHOTO_DB_FetchRow($dbResult)) {
			$sharename = $row['sharename'];
			$path_arr = explode("/", $sharename);
			//filter the keyword in the last dir
			if (false !== stripos(end($path_arr), $value_sharename) && !in_array($row, $result)) {
				$result[] = $row;
			}
		}
	End:
		return $result;
	}
	/*!
	 * Get language to use by system config
	 *
	 * \return ### format language region code
	 */
	function GetLanguage()
	{
		/* use user-defined language */
		if ('1' == $this->GetConfig('global', 'lang_setting') &&
			'def' != ($lang = $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['cfg']['language']) ) {
			return $lang;
		}
		/* use browser default */
		$matches = array();
		if (isSet($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
			preg_match_all('/([-a-z]+)(;q=([\.0-9]+))?/', strtolower(trim($_SERVER['HTTP_ACCEPT_LANGUAGE'])), $matches, PREG_SET_ORDER);
		}
		$acceptLang = array();
		foreach ($matches as $item) {
			$qvalue = isSet($item[3]) ? $item[3] : 1;
			$acceptLang[$qvalue] = $item[1];
		}
		unset($matches);
		/* sort by qvalue (ref. RFC 2616) */
		krsort($acceptLang, SORT_NUMERIC);
		foreach ($acceptLang as $lang) {
			if (false !== ($lang = csSYNOPhotoMisc::GetMappedLanguage($lang)) &&
				false !== stripos($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['defCfg']['supplang'], $lang)) {
				return $lang;
			}
		}
		return 'enu';
	}
	/*!
	 * Update photo's property
	 *
	 * \param $path photo's path
	 * \param $title photo's new title
	 * \param $description photo's new description
	 *
	 */
	function UpdatePhotoProperty($path, $title, $description, $realPath)
	{
		$query = "Update photo_image set title=?, description=? where path=?";
		$db_result = $this->Query($query, array($title, $description, $path));

		if (false === self::IsExiv2SupportWriteMode($path)) {
			return true;
		}
		csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
			'-M', 'set Xmp.dc.description ' . $description,
			$realPath));
		csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
			'-M', 'set Iptc.Application2.Caption ' . $description,
			$realPath));

		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--updatethumbnailmtime', $realPath));

		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-P', 'SynologyMoments', '-R', $realPath));

		return true;
	}
	/*!
	 * Update video property
	 *
	 * \param $path video's path
	 * \param $title video's new title
	 * \param $description video's new description
	 *
	 */
	function UpdateVideoProperty($path, $title, $description)
	{
		$query = "Update video_desc set title = ?, description = ? where path = ?";
		$db_result = $this->Query($query, array($title, $description, $path));

		if($db_result->rowCount() < 1) {
			if (empty($title)) {
				$file_name = basename($path);
				$title = substr($file_name, 0, strpos($file_name, "."));
			}
			$query = "Insert into video_desc (path, title, description) Values (?,?,?)";
			$this->Query($query, array($path, $title, $description));
		}

		return true;
	}
	/*!
	 * Update album property
	 *
	 * \param $shareName album share name
	 * \param $title album's new title
	 * \param $description album's new description
	 * \param $public album's new is public property 't' for true, 'f' for false
	 *
	 */
	function UpdateAlbumProperty($shareName, $title, $description)
	{
		$query = "Update photo_share set title = ?, description = ? where sharename = ?";
		return $this->Query($query, array($title, $description, $shareName));
	}

	function InheritUserPermission($table, $parent_shareid, $new_shareid, &$ids = array())
	{
		$values = array();
		$createTime = date('Y-m-d H:i:s');

		$query = "SELECT userid FROM $table WHERE shareid = $parent_shareid";
		$result = $this->Query($query);
		while (($row = $result->fetch())) {
			$ids[] = $row[0];
			$values[] = "(" . $row[0] . ", $new_shareid, '$createTime')";
		}

		if (count($values) > 0) {
			$query = "INSERT INTO $table (userid, shareid, create_time) VALUES " . implode(',', $values);
			$result = $this->Query($query);
		}
	}

	function InsertUserPermissionByIds($table, $new_shareid, $ids)
	{
		$createTime = date('Y-m-d H:i:s');

		foreach ($ids as $id) {
			$values[] = "($id, $new_shareid, '$createTime')";
		}

		if (count($values) > 0) {
			$query = "INSERT INTO $table (userid, shareid, create_time) VALUES " . implode(',', $values);
			$result = $this->Query($query);
		}
	}

	function InheritGroupPermission($parent_shareid, $new_shareid)
	{
		$values = array();
		$createTime = date('Y-m-d H:i:s');

		$query = "SELECT * FROM ".PHOTO_GROUP_PERMISSION_TABLE." WHERE shareid = ".$parent_shareid;
		$result = $this->Query($query);
		while (($row = $result->fetch())) {
			$groupId = $row[0];
			$permission = $row[2];

			// workaround for root album does not have access permission in db
			if ($permission === 2) {
				$permission = 3;
			} else if ($permission === 4 || $permission === 6) {
				$permission = 7;
			}

			$values[] = "($groupId, $new_shareid, $permission, '$createTime')";
		}

		if (count($values) > 0) {
			$query = "INSERT INTO ".PHOTO_GROUP_PERMISSION_TABLE." (groupid, shareid, permission, create_time) VALUES " . implode(',', $values);
			$this->Query($query);
		}
	}

	function inheritAlbumPrivilege($parent_shareid, $new_shareid, $updatePublic = true)
	{
		$public = 'f';
		$isRootAlbum = false;

		$query = "SELECT public, sharename FROM photo_share WHERE shareid=".$parent_shareid;
		$db_result = $this->Query($query);
		if ($row = PHOTO_DB_FetchRow($db_result)) {
			$public = PHOTO_DB_ConvertBool($row['public']);
			if ($row['sharename'] === '/') {
				$isRootAlbum = true;
			}
		}

		if (!$isRootAlbum && true === $updatePublic) {
			$query = "UPDATE  photo_share SET public = '".$public."' WHERE shareid = ".$new_shareid;
			$db_result = $this->Query($query);
		}

		if (false === $updatePublic) {
			$childPublic = 'f';
			$query = "SELECT public, sharename FROM photo_share WHERE shareid=".$new_shareid;
			$db_result = $this->Query($query);
			if ($row = PHOTO_DB_FetchRow($db_result)) {
				$childPublic = PHOTO_DB_ConvertBool($row['public']);
			}
		}

		// Set access Right the same as parent.
		$accessIds = array();
		self::InheritUserPermission(PHOTO_ACCESS_RIGHT_TABLE, $parent_shareid, $new_shareid, $accessIds);

		// Set upload Right the same as parent.
		$uploadIds = array();
		self::InheritUserPermission(PHOTO_UPLOAD_RIGHT_TABLE, $parent_shareid, $new_shareid, $uploadIds);

		// Set manage Right the same as parent.
		$manageIds = array();
		self::InheritUserPermission(PHOTO_MANAGE_RIGHT_TABLE, $parent_shareid, $new_shareid, $manageIds);

		if ($isRootAlbum || (false === $updatePublic && 'f' === $childPublic)) {
			$rootAccessIds = array_unique(array_merge($uploadIds, $manageIds));
			self::InsertUserPermissionByIds(PHOTO_ACCESS_RIGHT_TABLE, $new_shareid, $rootAccessIds);
		}

		// Set group permission as parent.
		self::InheritGroupPermission($parent_shareid, $new_shareid);
	}

	function checkVideoConvertOrigRotate($path, $ratio)
	{
		SYNOPhotoEA::getFilePath($path, SYNOPhotoEA::FILE_FILM_H264_MP4, $convert_path);

		$query = 'Select resolutionx, resolutiony From video_convert where convert_file_path=?';
		$sqlParam = array($convert_path);
		$db_result = $this->Query($query, $sqlParam);
		if ($row = PHOTO_DB_FetchRow($db_result) && $row['resolutionx'] && $row['resolutiony'] ) {
			if ($row['resolutionx'] / $row['resolutiony'] !== $ratio) {
				return true;
			}
		}
		return false;
	}

	function getPhotoShareByShareName($sharename)
	{
		$ret = array();
		$query = "SELECT * FROM photo_share WHERE sharename = ?";
		$result = $this->Query($query, array($sharename));
		if (!$result) {
			return $ret;
		}

		$row = $result->fetch();
		if (!$row) {
			return $ret;
		}
		foreach ($row as $k => $v) {
			$ret[$k] = $v;
		}
		return $ret;
	}
	static function getSharenameByPath($dbPath)
	{
		$dirname = pathinfo($dbPath, PATHINFO_DIRNAME);
		$sharename = substr($dirname, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PATH));
		if ('' == $sharename || '.' == $sharename) {
			$sharename = '/';
		}

		$pathes = explode('/', $sharename);
		$level = count($pathes);

		if (2 < $level) {
			$res = $pathes[0]."/".$pathes[1];
		} else {
			$res = $sharename;
		}

		return array($sharename, $res);
	}

	function getShareIdByPath($dbPath)
	{
		list($sharename, $privilege_sharename) = $this->getSharenameByPath($dbPath);

		$albums = Album::GetBySharename(array($sharename, $privilege_sharename));
		return array($albums[$sharename]['shareid'], $albums[$privilege_sharename]['shareid']);
	}

	function getExifList($type)
	{
		$valid_col = [
			"focal_length", "focal_length_v2", "flash",
			"flash_v2", "lens", "lens_v2", "rating",
			"camera_make", "camera_model", "exposure", 'aperture', 'iso'
		];

		$results = [];

		if (!in_array($type, $valid_col)) {
			return $results;
		}

		if ('rating' == $type) {
			$results = $this->ratingValue;
			return $results;
		}

		$query = "SELECT DISTINCT($type) AS C FROM photo_image ORDER BY C";

		$dbResult = $this->Query($query);

		if (!$dbResult) {
			return false;
		}
		while ($row = $dbResult->fetch()) {
			if ($row[0]) {
				$results[] = $row[0];
			}
		}

		return $results;
	}

	function IsExiv2SupportWriteMode($path)
	{
		global $SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT;

		$ext = strtolower(pathinfo($filePath, PATHINFO_EXTENSION));
		if (!in_array($ext, $SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT)) {
			return false;
		}

		return true;
	}

	static function GetArrayQueryPlaceholder(&$params)
	{
		// get array(1, 2, 3) return "?,?,?"
		return implode(',', array_fill(0, count($params), '?'));
	}
}
?>
