<?php
require_once(SYNOPHOTO_INCLUDE_DB);
require_once SYNOPHOTO_INCLUDE_EA;
require_once SYNOPHOTO_INCLUDE_CACHE;

define("ROOT_SHAREID", 1);
/*!
 * static misc function
 */
class csSYNOPhotoMisc {
	private static $skipDirList = array('.', '..', SYNOPHOTO_EADIR, SYNOPHOTO_RECYCLE_DIR, SYNOPHOTO_SNAPSHOT_DIR);
	private static $initQuickConnectHost = false;
	private static $quickConnectHost = null;
	private static $initDdnsHost = false;
	private static $ddnsHost = null;

	private static $dbConfigCache = null;
	private static $conversionCache = null;

	/*!
	 * check the prefix of files in eaDir is old or not
	 */
	static function IsOldEAFilePrefix() {
		if ($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['dsmCfg']['buildnumber'] >= SYNOPhotoEA::OLD_EADIR_PREFIX_DSM_VERSION) {
			return false;
		}
		return true;
	}

	static function showArray($input, $type = "console", $level = 0, $currentKey = "") {
		$output = "";
		$now_level = $level;
		$pre = "";

		$end = "\n";
		$preUnit = "   ";

		if ("web" === $type ) {
			$end = "<br>";
			$preUnit = "&nbsp;&nbsp;&nbsp;";
		}

		while ($now_level-- > 0)
			$pre = $preUnit.$pre;

		if ($level == 0)
			$output .= $end;

		if (is_array($input) || is_object($input)) {
			if (is_object($input)) {
				$input = get_object_vars($input);
				$output .= $pre."[$level:$currentKey(object)] {".$end;
			} else {
				$output .= $pre."[$level:$currentKey(array)] {".$end;
			}

			$res = array();
			//$output .= $pre."[$level:$currentKey(array)] {".$end;

			foreach($input as $key => $value)
				$res[] = csSYNOPhotoMisc::showArray($value, $type, $level + 1, $key);

			$output .= join($res, "");

			$output .= $pre."}".$end;

			return $output;
		} else {
			$output .= $pre."[$level:$currentKey] ".$input.$end;
			return $output;
		}
	}

	/**
	* Indents a flat JSON string to make it more human-readable
	*
	* @param string $json The original JSON string to process
	* @return string Indented version of the original JSON string
	*/
	static function indentJson($json)
	{
		if (!json_decode($json)) {
			return $json;
		}

		$result = '';
		$pos = 0;
		$strLen = strlen($json);
		$indentStr = "\t";
		$newLine = "\n";
		$prevChar = '';
		$outOfQuotes = true;

		for($i = 0; $i <= $strLen; $i++) {
			// Grab the next character in the string
			$char = substr($json, $i, 1);

			// Are we inside a quoted string?
			if($char == '"' && $prevChar != '\\') {
				$outOfQuotes = !$outOfQuotes;
			}
			// If this character is the end of an element,
			// output a new line and indent the next line
			else if(($char == '}' || $char == ']') && $outOfQuotes) {
				$result .= $newLine;
				$pos --;
				for ($j=0; $j<$pos; $j++) {
					$result .= $indentStr;
				}
			}
			// Add the character to the result string
			$result .= $char;

			// If the last character was the beginning of an element,
			// output a new line and indent the next line
			if (($char == ',' || $char == '{' || $char == '[') && $outOfQuotes) {
				$result .= $newLine;
				if ($char == '{' || $char == '[') {
					$pos ++;
				}
				for ($j = 0; $j < $pos; $j++) {
					$result .= $indentStr;
				}
			}
			$prevChar = $char;
		}

		return $result;
	}

	static function UrlEncode($str)
	{
		if ($str == "") return NULL;
		$str = rawurlencode($str);
		$str = str_replace("%2F","/", $str);
		return $str;
	}

	/*!
	 * check the $path is a allowed photo file or not
	 *
	 * \param $path file path
	 * \return true or false
	 */
	static function IsPhotoFile($path)
	{
		global $SYNOPHOTO_ALLOW_PICT_NAMES_EXT;

		$path = strtolower($path);
		$ext = substr(strrchr($path, '.'), 1);
		if (in_array($ext, $SYNOPHOTO_ALLOW_PICT_NAMES_EXT)) {
			return true;
		}
		return false;
	}

	static function IsVideoFile($path)
	{
		global $SYNOPHOTO_ALLOW_FILM_NAMES_EXT;

		$path = strtolower($path);
		$ext = substr(strrchr($path, '.'), 1);
		if (in_array($ext, $SYNOPHOTO_ALLOW_FILM_NAMES_EXT)) {
			return true;
		}
		return false;
	}

	static function IsMusicFile($path)
	{
		$allow_ext = array('mp3');

		$path = strtolower($path);
		$ext = substr(strrchr($path, '.'), 1);
		return in_array($ext, $allow_ext);
	}

	/*!
	 * check the photo file $path should have thumb file or not
	 *
	 * \param $path photo file path
	 * \return true or false
	 */
	static function IsPhotoFileWithThumb($path)
	{
		global $SYNOPHOTO_ALLOW_ORIG_NAMES_EXT;

		$path = strtolower($path);
		$ext = substr(strrchr($path, '.'), 1);
		if (!in_array($ext, $SYNOPHOTO_ALLOW_ORIG_NAMES_EXT)) {
			return true;
		}
		return false;
	}

	static function IsSkipDir($dir)
	{
		return in_array($dir, self::$skipDirList);
	}

	static function GetSessionIdentifier()
	{
		$token = $_SERVER['REMOTE_ADDR'];
		if (isset($_SERVER["HTTP_X_FORWARDED_FOR"])) {
			$token .= $_SERVER["HTTP_X_FORWARDED_FOR"];
		}
		return $token;
	}

	static function CheckSessionIdValid($session_id)
	{
		if (!preg_match('/^[a-zA-Z0-9,-]+$/', $session_id)) {
			return false;
		}

		return true;
	}

	static function IsSkipCheckIP()
	{
		return csSYNOPhotoMisc::GetConfigFile(SYNO_CNF_FILE, 'skip_checksrcip')['skip_checksrcip'] === 'yes';
	}

	static function CheckSessionIP()
	{
		if (csSYNOPhotoMisc::IsSkipCheckIP()) {
			return true;
		}
		if (true !== $_SESSION[SYNOPHOTO_ADMIN_USER]['skipIPCheckForMobile'] && $_SESSION[SYNOPHOTO_ADMIN_USER]['security_identifier']) {
			return $_SESSION[SYNOPHOTO_ADMIN_USER]['security_identifier'] === self::GetSessionIdentifier();
		}
		return true;
	}

	static function RestoreSession()
	{
		if (!isset($_REQUEST['session'])) {
			return -1;
		}
		$session_id = $_REQUEST['session'];

		if (!self::CheckSessionIdValid($session_id)) {
			return -1;
		}

		$sessionDir = session_save_path();
		if (empty($sessionDir)) {
			$sessionDir = sys_get_temp_dir();
		}

		$sessionPath = $sessionDir."/sess_".$session_id;
		$serializedSession = @file_get_contents($sessionPath);

		if (empty($serializedSession)) {
			return false;
		}

		$currIdentifier = $_SESSION[SYNOPHOTO_ADMIN_USER]['security_identifier'];
		$currSession = session_encode();
		session_unset();
		if (session_decode($serializedSession)
			&& isset($_SESSION[SYNOPHOTO_ADMIN_USER]['security_identifier'])
			&& ($currIdentifier == $_SESSION[SYNOPHOTO_ADMIN_USER]['security_identifier'])) {
			return true;
		}
		session_unset();
		session_decode($currSession);
		return false;
	}

	/*!
	 * check the if dsm user account exit
	 *
	 * \return true or false
	 */
	static function CheckDsmUserValid ($username)
	{
		//$command = "/usr/syno/bin/synophoto_dsm_user --getinfo " . escapeshellarg($username) . " > /dev/null";
		//@system($command, $auth_retval);
		$auth_retval = false;
		self::ExecCmdNoOutput('/usr/syno/bin/synophoto_dsm_user', array('--getinfo', $username), $auth_retval);
		return (0 == $auth_retval) ? true : false;
	}

	static function UserHomeIsEnabled ($username)
	{
		$requiredConfKeys = 'userHomeEnable|enableluserhome|enableduserhome';
		$result = csSYNOPhotoMisc::GetConfigFile(SYNO_CNF_FILE, $requiredConfKeys);

		$output = '';
		$retval = self::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--getinfo', $username), false, $output);

		if (0 !== $retval) {
			return false;
		}
		foreach($output as $line) {
			if (preg_match('/^User\sType:\s+\[(.+)\]$/', $line, $matches)) {
				if ('AUTH_LOCAL' == $matches[1]) {
					return $result['userHomeEnable'];
				} else if ('AUTH_LDAP' == $matches[1]) {
					return $result['enableluserhome'];
				} else if ('AUTH_DOMAIN' == $matches[1]) {
					return $result['enableduserhome'];
				}
				break;
			}
		}
		return NULL;
	}

	/**
	 *	\array [groupids, isAdmin, isDisabled]
	 */
	static function GetDsmUserInfoById ($userid)
	{
		//$command = "/usr/syno/bin/synophoto_dsm_user --getinfobyuid " . escapeshellarg($userid);
		//@exec($command, $output, $retval);
		$output = '';
		$retval = self::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--getinfobyuid', $userid), false, $output);
		if (0 !== $retval) {
			return NULL;
		}

		$user_info = csSYNOPhotoMisc::ParseDsmUserInfo($output);

		if ($user_info) {
			$result['groupids'] = $user_info['groups'];
			$result['isAdmin'] = $user_info[10] === '1';
			$result['isDisabled'] = $user_info[7] == 'true';
		}

		return $result;
	}

	/**
	 * \return string
	 */
	static function getUserHomePath($username)
	{
		if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['user_home_path'])) {
			//$command = "/usr/syno/bin/synophoto_dsm_user --getinfo " . escapeshellarg($username);
			//@exec($command, $output, $retval);
			$output = '';
			$retval = self::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--getinfo', $username), false, $output);

			if (0 !== $retval) {
				return false;
			}
			foreach($output as $line) {
				if (preg_match('/^User\sDir\s+:\s+\[(.+)\]$/', $line, $matches)) {
					$_SESSION[SYNOPHOTO_ADMIN_USER]['user_home_path'] = $matches[1];
					break;
				}
			}
		}
		return $_SESSION[SYNOPHOTO_ADMIN_USER]['user_home_path'];
	}

	function getUserRealHomePath($username)
	{
		if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['user_share_path'])) {
			//$command = '/usr/syno/bin/synophoto_dsm_user --getshare ' . escapeshellarg($username);
			//@exec($command, $output, $retval);
			$output = '';
			$retval = self::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--getshare', $username), false, $output);

			if (0 !== $retval) {
				return false;
			}
			foreach($output as $line) {
				$data = explode("\t", $line);
				if (2 > count($data)) {
					continue;
				}
				$name = trim($data[0]);
				if ("home" == strtolower($name)) {
					$sharepath = trim($data[1]);
					$_SESSION[SYNOPHOTO_ADMIN_USER]['user_share_path'] = $sharepath;
				}
			}
		}
		return $_SESSION[SYNOPHOTO_ADMIN_USER]['user_share_path'];
	}

	/**
	 * \return converted username
	 */
	static function UserLoginNameConvert($username)
	{
		//$command = "/usr/syno/bin/synophoto_dsm_user --getinfo " . escapeshellarg($username);
		//@exec($command, $output, $retval);
		$output = '';
		$retval = self::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--getinfo', $username), false, $output);

		if (0 !== $retval) {
			return false;
		}
		foreach($output as $line) {
			if (preg_match('/^User\sName:\s+\[(.+)\]$/', $line, $matches)) {
				return $matches[1];
			}
		}
		return false;
	}

	/**
	 *	\array [groupids, isAdmin, isDisabled]
	 */
	static function GetUserInfoById ($userid)
	{
		$query = "SELECT admin, disabled FROM " . PHOTO_USER_TABLE . " WHERE userid = $userid";
		$db_result = PHOTO_DB_Query($query);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}
		$result['isAdmin'] = $row[0];
		$return['isDisabled'] = $row[1];

		/* set user's belonging groups */
		$query = "SELECT groupid FROM " . PHOTO_USER_GROUP_TABLE . " WHERE userid = $userid";
		$db_result = PHOTO_DB_Query($query);
		$groups = array();
		while ($row = PHOTO_DB_FetchRow($db_result)) {
			$groups[] = $row['groupid'];
		}
		$result['groupids'] = implode(',', $groups);

		return $result;
	}

	static function ParseDsmUserInfo($pUser)
	{
		global $SYNOPHOTO_DSM_USER_INFO;
		$result = array();
		if (!is_array($pUser)) {
			return null;
		}

		$groups = array();
    foreach ($pUser as $item) {
      if (preg_match('/^Member\sOf:\s+\[(.+)\]$/', $item, $match)) {
        $groups = array();
        $groups_size = $match[1];
      }
			if (!preg_match('/([\w\s]*)\:/', $item, $match_val) && preg_match('/\((\d+)\)/', $item, $match)) {
				$groups[] = $match[1];
			}
			if (!preg_match('/(^\w+\s?\w+)\s*\:/', $item, $match) || !preg_match('/\[(.*)\]/', $item, $match_val)) {
				continue;
			}

      if (false !== $index = array_search($match[1], $SYNOPHOTO_DSM_USER_INFO)) {
        if (isset($result[$index])) {
          // overwrite user info maybe attack
          exit(0);
        }

				$result[$index] = $match_val[1];
			}

    }
    if(sizeof($groups) != $groups_size){
      // extract group size and member of group size is different
      exit(0);
    }
    $result['groups'] = implode(',', $groups);
		return $result;
	}

	/*!
	 * check the disk space is empty enough or not
	 *
	 * \return true or false
	 */
	static function DiskSpaceCheck()
	{
		static $cachedCheckValue = true;
		static $lastCheckTime = 0;
		$checkTime = time();

		// cache disk check result for 10 second
		if ($checkTime > $lastCheckTime + 10) {
			if (SYNOPHOTO_RSRV_DISK_SPACE < diskfreespace(SYNOPHOTO_SERVICE_DIR)) {
				$cachedCheckValue = true;
			} else {
				$cachedCheckValue = false;
			}
			$lastCheckTime = $checkTime;
		}

		return $cachedCheckValue;
	}

	/*!
	 * Get all accessible dir list
	 *
	 * \param $albumName - '/' means root shared folder
	 * \param $isNeedCtime returned list need include create time or not
	 * \return array with dir list
	 */
    static function GetDir($albumName, $isNeedCtime)
    {
        $result = array();
        if ('/' === $albumName) {
			// admin user need to query share at this time
			$dirList = array();
			if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) && count($_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_album']) === 0) {
				$albums = Album::GetAccessibleShare('session');
				usort($albums, function($a, $b) {
					return strcasecmp ($a['sharename'], $b['sharename']);
				});
				$albumsCount = count($albums);

				csSYNOPhotoMisc::PhotoSessionStart();
				foreach ($albums as $item) {
					if ($item['is_subdir'] && $albumsCount < SYNOPHOTO_SESSION_CACHE_MAX_NUM) {
						$_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_subdir'][$item['sharename']] = 1;
					} else if (!$item['is_subdir']) {
						if ($albumsCount < SYNOPHOTO_SESSION_CACHE_MAX_NUM) {
							$_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_album'][$item['sharename']] = 1;
						}
						$dirList[] = $item['sharename'];
					}
				}
				session_write_close();
			} else {
				$dirList = array_keys($_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_album']);
			}
			if (false !== ($keyIndex = array_search('/', $dirList))) {
				unset($dirList[$keyIndex]);
			}
			/* make sure data type is string */
			foreach ($dirList as &$name) {
				settype($name, 'string');
			}
			unset($name);
			foreach ($dirList as $name) {
				$dir_path = SYNOPHOTO_SERVICE_REAL_DIR.'/'.$name;
				if (!file_exists($dir_path)) {
					continue;
				}
				$result[$name] = $isNeedCtime ? filectime($dir_path) : 0;
			}
		} else {
			$result = self::GetSubDir($albumName, $isNeedCtime);
		}
		return $result;
	}

	/*!
	 * Get accessible sub-dir list
	 *
	 * \param $albumName album name
	 * \param $isNeedCtime returned list need include create time or not
	 * \return array with sub-dir list
	 */
	static function GetSubDir($albumName, $isNeedCtime)
	{
		$list = array();
		$currPath = getcwd();

		if (!@chdir(SYNOPHOTO_SERVICE_DIR . "/{$albumName}")) {
			@chdir($currPath);
			return $list;
		}

		foreach (glob('{,.}*', GLOB_BRACE | GLOB_ONLYDIR) as $dir) {
			// skip photo in remote mount (cifs) or read-only mount (iso9660)
			if (self::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$albumName.'/'.$dir, $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])
				|| !csSYNOPhotoMisc::IsUtf8($dir)) {
				continue;
			}

			if ($dir != SYNOPHOTO_EADIR && $dir != '.' && $dir != '..') {
				if (false === strpos($albumName, '/') &&
					!isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['accessible_subdir']["{$albumName}/{$dir}"]) && !isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
					continue;
				}
				$list["{$albumName}/{$dir}"] = $isNeedCtime ? filectime($dir) : 0;
			}
		}

		@chdir($currPath);
		return $list;
	}

	static function GetSubDirFile($albumName)
	{
		$list = array();
		$currPath = getcwd();
		@chdir(SYNOPHOTO_SERVICE_DIR . "/{$albumName}");
		$latestFile = null;
		$data = null;
		$excludeFormats = self::ParseExcludeFormats(csSYNOPhotoMisc::GetConfigDB("photo", "excluding_index_format", "photo_config"));

		$file = glob('{,.}*', GLOB_BRACE);
		$files = array();
		foreach ($file as $f) {
			if ($f == SYNOPHOTO_EADIR || $f == '.' || $f == '..') {
				continue;
			}
			$files[] = array(
				'name' => $f,
				'ctime' => filectime($f)
			);
		}

		usort($files, function($a, $b) {return $b['ctime'] - $a['ctime'];});
		foreach ($files as $temp) {
			$file = $temp['name'];
			if (in_array(strtolower(pathinfo($file, PATHINFO_EXTENSION)), $excludeFormats)) {
				continue;
			}
			if (csSYNOPhotoMisc::IsPhotoFile($file)) {
				$latestFile = $file;
				$type = 0;
				break;
			} else if (csSYNOPhotoMisc::IsVideoFile($file)) {
				$latestFile = $file;
				$type = 1;
				break;
			}
		}
		if ($latestFile !== null) {
			$path = SYNOPHOTO_SERVICE_REAL_DIR.'/'.$albumName.'/'.$latestFile;
			if ($type == 0) {
				$data = csSYNOPhotoDB::GetDBInstance()->GetPhotoInfo($path);
			} else {
				$data = csSYNOPhotoDB::GetDBInstance()->GetVideoInfo($path);
			}
		}
		return $data;
	}

	/*!
	 * check the album is thumbing or not
	 *
	 * \param $dir the album name
	 * \return true or false
	 */
	static function ThumbingCheck($dir='')
	{
		$isThumbing = false;
		$lockPath = "{$dir}/".SYNOPHOTO_EADIR;

		if (($fp = @fopen($lockPath, 'r'))>0) {
			if (flock($fp, LOCK_EX | LOCK_NB)) {
				flock($fp, LOCK_UN);
			} else {
				$isThumbing = true;
			}
			fclose($fp);
		}
		return $isThumbing;
	}
	/*!
	 * Get thumb file path by photo file path
	 *
	 * \param $path photo file path
	 * \param $isBigThumb return big thumb or not
	 * \param $isFail return thumb for failed thumb or not
	 * \return the thumb file path
	 */
	static function GetThumbPathFromFullPath($path, $thumbType, $isFail, $isVideo=false)
	{
		if ($isFail) {
			$thumbName = SYNOPHOTO_THUMBSMALL != $thumbType ? SYNOPhotoEA::FILE_THUMB_B_FAIL : SYNOPhotoEA::FILE_THUMB_S_FAIL;
			if (!csSYNOPhotoMisc::IsPhotoFile($path) && $isVideo) {
				$thumbName = SYNOPhotoEA::FILE_FILM_FAIL;
			}
		} else {
			switch ($thumbType) {
			case SYNOPhotoEA::FILE_THUMB_PREVIEW:
					$thumbName = SYNOPhotoEA::FILE_THUMB_PREVIEW;
					break;
				case SYNOPHOTO_THUMBSMALL:
					$thumbName = SYNOPhotoEA::FILE_THUMB_S;
					break;
				case SYNOPHOTO_THUMBSMALLMEDIUM:
					$thumbName = SYNOPhotoEA::FILE_THUMB_SM;
					break;
				case SYNOPHOTO_THUMBMEDIUM:
					$thumbName = SYNOPhotoEA::FILE_THUMB_M;
					break;
				case SYNOPHOTO_THUMBBIG:
					$thumbName = SYNOPhotoEA::FILE_THUMB_B;
					break;
				case SYNOPHOTO_THUMBLARGE:
					$thumbName = SYNOPhotoEA::FILE_THUMB_L;
					break;
				default:
					$thumbName = SYNOPhotoEA::FILE_THUMB_XL;
					break;
			}
		}
		SYNOPhotoEA::checkFilePath($path, $thumbName, $thumbPath);
		return $thumbPath;
	}
	/*!
	 * Get alternative thumb type during thumb generating
	 */
	static function GetAlternativeThumbType($thumbType)
	{
		$type = $thumbType;

		switch($thumbType) {
			case SYNOPHOTO_THUMBSMALL:
			case SYNOPHOTO_THUMBMEDIUM:
				$type = SYNOPHOTO_THUMBMEDIUM;
				break;
			case SYNOPHOTO_THUMBBIG:
			case SYNOPHOTO_THUMBLARGE:
			case SYNOPHOTO_THUMBXLARGE:
			default:
				$type = SYNOPHOTO_THUMBXLARGE;
		}

		return $type;
	}
	/*!
	 * Get thumb info by photo file path
	 *
	 * \param $path photo file path
	 * \param $thumbType return large thumb, big thumb or small thumb
	 * \param $width photo width
	 * \param $height photo height
	 * \param $version photo orientation
	 * \return array with thumb info
	 *	- src: link to the thumb file
	 *	- width: thumb width
	 *	- height: thumb height
	 */
	static function GetThumbInfoFromFullPath($path, $thumbType, $width, $height, $version, $createThumb=true)
	{
		if (!csSYNOPhotoMisc::IsPhotoFile($path)) {
			return array();
		}

		$isPhotoFileWithThumb = self::IsPhotoFileWithThumb($path);
		$fileName = basename($path);
		$dir = (false !== strpos($path, SYNOPHOTO_SERVICE_DIR)) ? SYNOPHOTO_SERVICE_DIR.'/' : SYNOPHOTO_SERVICE_REAL_DIR.'/';
        $dir = dirname(str_replace($dir, "", $path));

		$thumbFile = '';
		$failFile = csSYNOPhotoMisc::GetThumbPathFromFullPath($path, $thumbType, true);
		if ($isPhotoFileWithThumb) {
			$thumbFile = csSYNOPhotoMisc::GetThumbPathFromFullPath($path, $thumbType, false);
			if (!@file_exists($thumbFile)) {
				$thumbType = csSYNOPhotoMisc::GetAlternativeThumbType($thumbType);
				$thumbFile = csSYNOPhotoMisc::GetThumbPathFromFullPath($path, $thumbType, false);
			}
		}

		if (!empty($thumbFile) && @file_exists($thumbFile)) {
			if ($version == -1) {
				$photoInfo = csSYNOPhotoDB::GetDBInstance()->GetPhotoInfo($path);
				$version = $photoInfo ? $photoInfo['version'] : -1;
			}
			if (($version % 2) == 1) {
				$tmp = $width;
				$width = $height;
				$height = $tmp;
			}
			$type = $thumbType;
			$result['src'] = SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type={$type}&v={$version}";
		} else if (@file_exists($failFile)) {
			$result['src'] = SYNOPHOTO_IMG_BROKEN;
			$thumbFile = SYNOPHOTO_IMG_BROKEN_FILE_PATH;
		} else {
			if (!csSYNOPhotoMisc::DiskSpaceCheck()) {
				if (SYNOPHOTO_THUMBSMALL != $thumbType) {
					$result['src'] = SYNOPHOTO_IMG_FULL_BIG;
					$thumbFile = SYNOPHOTO_IMG_FULL_BIG_FILE_PATH;
				} else {
					$result['src'] = SYNOPHOTO_IMG_FULL;
					$thumbFile = SYNOPHOTO_IMG_FULL_FILE_PATH;
				}
			} else if (!$isPhotoFileWithThumb) {
					$result['src'] = SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName).'&type=2';
					$thumbFile = $path;
			} else {
				$theme = $_SESSION[SYNOPHOTO_ADMIN_USER]['photo_config']['theme']['template'];
				if (empty($theme) || 'White' == $theme) {
					$result['src'] = SYNOPHOTO_IMG_THUMB;
					$thumbFile = SYNOPHOTO_IMG_THUMB_FILE_PATH;
				} else {
					$result['src'] = SYNOPHOTO_IMG_THUMB_BLACK;
					$thumbFile = SYNOPHOTO_IMG_THUMB_BLACK_FILE_PATH;
				}
			}
		}

		if (false !== strpos($result['src'], 'convert.php') && (0 != $width && 0 != $height)) {
			$imageInfo[0] = $width;
			$imageInfo[1] = $height;
		} else {
			$imageInfo = @getImageSize($thumbFile);
		}

		if	(SYNOPHOTO_THUMBSMALL == $thumbType) {
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBSMALL_WIDTH, SYNOPHOTO_THUMBSMALL_HEIGHT);
		} else if (SYNOPHOTO_THUMBMEDIUM == $thumbType){
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBMEDIUM_WIDTH, SYNOPHOTO_THUMBMEDIUM_HEIGHT);
		} else if (SYNOPHOTO_THUMBBIG == $thumbType){
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBBIG_WIDTH, SYNOPHOTO_THUMBBIG_HEIGHT);
		} else if (SYNOPHOTO_THUMBLARGE == $thumbType) {
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBLARGE_WIDTH, SYNOPHOTO_THUMBLARGE_HEIGHT);
		} else {
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBXLARGE_WIDTH, SYNOPHOTO_THUMBXLARGE_HEIGHT);
		}

		$result['width'] = $imageInfo['width'];
		$result['height'] = $imageInfo['height'];
		return $result;
	}
	/*!
	 * Get video thumb info by video file path
	 *
	 * \param $path video file path
	 * \param $isBigThumb return big thumb or not
	 * \param $width video width
	 * \param $height video height
	 *
	 * \return array with thumb info
	 *	- src: link to the thumb file
	 *	- width: thumb width
	 *	- height: thumb height
	 */
	static function GetVideoThumbInfoFromFullPath($path, $thumbType, $width, $height, $createThumb=true)
	{
		$fileName = basename($path);
		$dir = (false !== strpos($path, SYNOPHOTO_SERVICE_DIR)) ? SYNOPHOTO_SERVICE_DIR.'/' : SYNOPHOTO_SERVICE_REAL_DIR.'/';
		$dir = dirname(str_replace($dir, "", $path));

		$failThumbFile = csSYNOPhotoMisc::GetThumbPathFromFullPath($path, $thumbType, true);
		$failVideoFile = csSYNOPhotoMisc::GetThumbPathFromFullPath($path, $thumbType, true, true);

		$thumbFile = csSYNOPhotoMisc::GetThumbPathFromFullPath($path, $thumbType, false);
		$readyVideoCount = count(csSYNOPhotoMisc::GetConvertedVideoFileInfoFromFullPath($path));

		if ($readyVideoCount > 0 && !empty($thumbFile) && @file_exists($thumbFile)) {
			$type = $thumbType;
			$result['src'] = SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type={$type}&v=0";
		} else if ($readyVideoCount > 0 && @file_exists($failThumbFile)) {
				$result['src'] = SYNOPHOTO_IMG_BROKEN;
				$thumbFile =  SYNOPHOTO_IMG_BROKEN_FILE_PATH;
		} else if ($readyVideoCount == 0 && @file_exists($failVideoFile)) {
				$result['src'] = SYNOPHOTO_IMG_MOVIE;
				$thumbFile = SYNOPHOTO_IMG_MOVIE_FILE_PATH;
		} else {
			if (!csSYNOPhotoMisc::DiskSpaceCheck()) {
				if (SYNOPHOTO_THUMBSMALL != $thumbType) {
					$result['src'] = SYNOPHOTO_IMG_FULL_BIG;
					$thumbFile = SYNOPHOTO_IMG_FULL_BIG_FILE_PATH;
				} else {
					$result['src'] = SYNOPHOTO_IMG_FULL;
					$thumbFile = SYNOPHOTO_IMG_FULL_FILE_PATH;
				}
			} else {
				$theme = $_SESSION[SYNOPHOTO_ADMIN_USER]['photo_config']['theme']['template'];
				if (empty($theme) || 'White' == $theme) {
					$result['src'] = SYNOPHOTO_IMG_THUMB;
					$thumbFile = SYNOPHOTO_IMG_THUMB_FILE_PATH;
				} else {
					$result['src'] = SYNOPHOTO_IMG_THUMB_BLACK;
					$thumbFile = SYNOPHOTO_IMG_THUMB_BLACK_FILE_PATH;
				}
				if ($createThumb) {
					self::ExecCmdNoOutput('/usr/syno/bin/synomkflv', array('-a', $path));
				}
			}
		}

		$imageInfo = @getImageSize($thumbFile);

		if	(SYNOPHOTO_THUMBSMALL == $thumbType) {
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBSMALL_WIDTH, SYNOPHOTO_THUMBSMALL_HEIGHT);
		} else if (SYNOPHOTO_THUMBMEDIUM == $thumbType){
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBMEDIUM_WIDTH, SYNOPHOTO_THUMBMEDIUM_HEIGHT);
		} else if (SYNOPHOTO_THUMBBIG == $thumbType){
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBBIG_WIDTH, SYNOPHOTO_THUMBBIG_HEIGHT);
		} else if (SYNOPHOTO_THUMBLARGE == $thumbType) {
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBLARGE_WIDTH, SYNOPHOTO_THUMBLARGE_HEIGHT);
		} else {
			$imageInfo = csSYNOPhotoMisc::GetJustFitWidthHeight($imageInfo[0], $imageInfo[1], SYNOPHOTO_THUMBXLARGE_WIDTH, SYNOPHOTO_THUMBXLARGE_HEIGHT);
		}

		$result['width'] = $imageInfo['width'];
		$result['height'] = $imageInfo['height'];
		return $result;
	}
	/*!
	 * Get converted video file info by video file path
	 *
	 * \param $path video file path
	 * \param $isBigThumb return big thumb or not
	 * \param $width video width
	 * \param $height video height
	 *
	 * \return array with thumb info
	 *	- src: link to the converted mobile video file
	 */
	static function GetConvertedVideoFileInfoFromFullPath($path)
	{
		$fileName = basename($path);
		$dir = (false !== strpos($path, SYNOPHOTO_SERVICE_DIR)) ? SYNOPHOTO_SERVICE_DIR.'/' : SYNOPHOTO_SERVICE_REAL_DIR.'/';
		$dir = dirname(str_replace($dir, "", $path));

		$eaPath = '';

		if (SYNOPhotoEA::checkFilePath($path, SYNOPhotoEA::FILE_FILM_FLV, $eaPath)) {
			$result['flv_src'] = urlencode(SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type=3&v=0");
		}
		if (SYNOPhotoEA::checkFilePath($path, SYNOPhotoEA::FILE_FILM_H264_MP4, $eaPath)) {
			$result['mp4_orig_src'] = urlencode(SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type=13&v=0");
		}
		if (SYNOPhotoEA::checkFilePath($path, SYNOPhotoEA::FILE_FILM_H_MP4, $eaPath)) {
			$result['mp4_H_src'] = urlencode(SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type=6&v=0");
		}
		if (SYNOPhotoEA::checkFilePath($path, SYNOPhotoEA::FILE_FILM_M_MP4, $eaPath)) {
			$result['mp4_M_src'] = urlencode(SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type=7&v=0");
		}
		if (SYNOPhotoEA::checkFilePath($path, SYNOPhotoEA::FILE_FILM_L_MP4, $eaPath)) {
			$result['mp4_L_src'] = urlencode(SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type=8&v=0");
		}
		if (SYNOPhotoEA::checkFilePath($path, SYNOPhotoEA::FILE_FILM_MOBILE_MP4, $eaPath)) {
			$result['mp4_mobile_src'] = urlencode(SYNOPHOTO_URL_PREFIX.'/photo/convert.php?dir='.bin2hex($dir).'&name='.bin2hex($fileName)."&type=9&v=0");
		}

		return $result;
	}
	/*!
	 * get the rounded float number
	 *
	 * \param $value the number to be round
	 * \return rounded number
	 */
	static function RoundFloat($value)
	{
		$round = 3;
		$tmp_value = $value * 10 % 10;
		if ($tmp_value < $round) {
			return floor($value);
		} else {
			return ceil($value);
		}
	}
	/*!
	 * Get the css style to just fit image
	 *
	 * \param $img array with image info
	 *	- width: image width
	 *	- height: image height
	 * \param $maxWidth
	 * \param $maxHeight
	 */
	static function GetJustFitCenterStyle($img, $maxWidth, $maxHeight, &$videoIconOffset = 0)
	{
		if ($img['width'] <= $maxWidth && $img['height'] <= $maxHeight) {
			return self::GetCenterStyle($img, $maxWidth, $maxHeight);
		}
		$scaledImg = self::GetJustFitWidthHeight($img['width'], $img['height'], $maxWidth, $maxHeight);
		if ($scaledImg['width'] > $scaledImg['height']) {
			$top = ($maxHeight - $scaledImg['height'])*4/5;
			$videoIconOffset = $top - ($maxHeight - $scaledImg['height']-1)/2;
			return "width: {$scaledImg['width']}px; margin-top: {$top}px;";
		}
		$left = ($maxWidth - $scaledImg['width'])/2;
		return "height: {$scaledImg['height']}px; margin-left: {$left}px;";
	}
	/*!
	 * Get the scaled size to just fit expected size
	 *
	 * \param $width photo width
	 * \param $height photo height
	 * \param $expectWidth expected width to scale
	 * \param $expectHeight expected height to scale
	 * \return array with scaled size
	 *	- width: scaled width
	 *	- height: scaled height
	 */
	static function GetJustFitWidthHeight($width, $height, $expectWidth, $expectHeight)
	{
		if ($width > $expectWidth && $height > $expectHeight) {
			if (($height / $expectHeight) < ($width / $expectWidth)) {
				$result['width'] = $expectWidth;
				$result['height'] = self::RoundFloat($height * ($expectWidth / $width));
			} else {
				$result['height'] = $expectHeight;
				$result['width'] = self::RoundFloat($width * ($expectHeight / $height));
			}
		} else if ($height > $expectHeight) {
			$result['height'] = $expectHeight;
			$result['width'] = self::RoundFloat($width * ($expectHeight / $height));
		} else if ($width > $expectWidth) {
			$result['width'] = $expectWidth;
			$result['height'] = self::RoundFloat($height*($expectWidth / $width));
		} else {
			$result['width'] = $width;
			$result['height'] = $height;
		}
		return $result;
	}
	/*!
	 * Get the scaled size to over fit expected size
	 * (ie. the shorter side will fit the expected size,
	 * and the longer side will overflow the expected size)
	 *
	 * \param $width photo width
	 * \param $height photo height
	 * \param $expectWidth expected width to scale
	 * \param $expectHeight expected height to scale
	 * \return array with scaled size
	 *	- width: scaled width
	 *	- height: scaled height
	 */
	static function GetOverFitWidthHeight($width, $height, $expectWidth, $expectHeight)
	{
		if ($width > $expectWidth && $height > $expectHeight) {
			if (($height / $expectHeight) > ($width / $expectWidth)) {
				$result['width'] = $expectWidth;
				$result['height'] = self::RoundFloat($height * ($expectWidth / $width));
			} else {
				$result['height'] = $expectHeight;
				$result['width'] = self::RoundFloat($width * ($expectHeight / $height));
			}
		} else if ($height > $expectHeight) {
			$result['width'] = $expectWidth;
			$result['height'] = self::RoundFloat($height*($expectWidth / $width));
		} else if ($width > $expectWidth) {
			$result['height'] = $expectHeight;
			$result['width'] = self::RoundFloat($width * ($expectHeight / $height));
		} else {
			$result['width'] = $width;
			$result['height'] = $height;
		}
		return $result;
	}
	/*!
	 * Get the css style to over fit image
	 * (ie. the shorter side will fit the expected size,
	 * and the longer side will overflow the expected size)
	 *
	 * \param $img array with image info
	 *	- width: image width
	 *	- height: image height
	 * \param $maxWidth
	 * \param $maxHeight
	 */
	static function GetOverFitCenterStyle($img, $maxWidth, $maxHeight)
	{
		if ($img['width'] <= $maxWidth && $img['height'] <= $maxHeight) {
			return self::GetCenterStyle($img, $maxWidth, $maxHeight);
		}
		$scaledImg = self::GetOverFitWidthHeight($img['width'], $img['height'], $maxWidth, $maxHeight);
		if ($scaledImg['width'] > $scaledImg['height']) {
			$left = ($scaledImg['width'] - $maxWidth)/2;
			return "height: {$scaledImg['height']}px; margin-left: -{$left}px;";
		}
		$top = ($scaledImg['height'] - $maxHeight)/2;
		return "width: {$scaledImg['width']}px; margin-top: -{$top}px;";
	}
	/*!
	 * Get the css style to center image in a block
	 * both image width/height should less then the block
	 *
	 * \param $img array with image info
	 *	- width: image width
	 *	- height: image height
	 * \param $maxWidth
	 * \param $maxHeight
	 */
	static function GetCenterStyle($img, $maxWidth, $maxHeight)
	{
		$style = "";
		if ($img['width'] < $maxWidth) {
			$left = ($maxWidth - $img['width'])/2;
			$style .= "margin-left: {$left}px; ";
		}
		if ($img['height'] < $maxHeight) {
			$top = ($maxHeight - $img['height'])/2;
			$style .= "margin-top: {$top}px; ";
		}
		$style .= 'width: '.$img['width'].'px';
		return $style;
	}
	/*!
	 * Get css styles for various purposes
	 *
	 * \param $imgInfo array with various css style
	 *	- listStyle: img style to over fit div in list mode
	 *	- blockStyle: img style to over fit div in block mode
	 *	- bgAlbumStyle: img style to just fit div in backgrounded album mode
	 *	- bgThumbStyle: img style to just fit div in backgrounded photo mode
	 */
	static function GetThumbStyle($imgInfo, $size=SYNOPHOTO_DEFAULT_THUMBSMALL_SIZE, $isJustFit = false, &$videoIconOffset = 0)
	{
		if ($isJustFit) {
			return self::GetJustFitCenterStyle($imgInfo, $size, $size, $videoIconOffset);
		}
		return self::GetOverFitCenterStyle($imgInfo, $size, $size);
	}
	/*!
	 * check album accessible or not
	 *
	 * \param $albumName album name
	 * \return true or false
	 */
	static function CheckAlbumAccessible($albumName, $isNeedRedirect=false, $publicShareId=NULL)
	{
		$sessionArray = &$_SESSION[SYNOPHOTO_ADMIN_USER];
		if (NULL !== $publicShareId) {
			if (!isset($_SESSION[$publicShareId])) {
				return false;
			}
			$sessionArray = &$_SESSION[$publicShareId];
		}
		if (isset($sessionArray['admin_syno_user'])){
			return true;
		}

		/* root album accessibility depends on settings */
		if ('/' === $albumName) {
			if (isset($sessionArray['admin_syno_user'])) {
				return true;
			}
			if (isset($sessionArray['uploadable_album']['/'])) {
				return true;
			}
			if (csSYNOPhotoMisc::GetConfigDB("photo", "allow_root_folder_public", "photo_config") !== "on") {
				return false;
			}
			return true;
		}
		if (!file_exists(SYNOPHOTO_SERVICE_DIR."/".$albumName)) {
			if ($isNeedRedirect) {
				header("Location: ".SYNOPHOTO_URL_PREFIX."/photo/index.php");
				exit;
			}
			return false;
		}
		$albumToken = explode('/', $albumName);
		if (2 < count($albumToken)) {
			$albumName = $albumToken[0] . '/' . $albumToken[1];
		}
		if (1 == count($albumToken)) {
			if (!isSet($sessionArray['accessible_album'][$albumName])) {
				if ($isNeedRedirect) {
					self::RedirectToLoginPage($albumName);
				}
				return false;
			}
			if (self::IsPasswordAlbumsFromSession($sessionArray, $albumName) &&
				!self::ValidatePasswordFromSession($sessionArray, $albumName)) {
				if ($isNeedRedirect) {
					self::RedirectToLoginPage($albumName, 1);
				}
				return false;
			}
			return true;
		}
		/* album is not accessible */
		if (!isSet($sessionArray['accessible_subdir'][$albumName])) {
			if ($isNeedRedirect) {
				self::RedirectToLoginPage($albumName);
			}
			return false;
		}

		$is_password_album = self::IsPasswordAlbumsFromSession($sessionArray, $albumName);
		$parentAlbum = $albumToken[0];
		$is_parent_password_album = self::IsPasswordAlbumsFromSession($sessionArray, $parentAlbum);

		/* public/private album, can access */
		// public/public
		// public/private
		// private/public
		// private/private
		if (!$is_password_album && !$is_parent_password_album) {
			return true;
		}

		if ($is_password_album) {
			// public/password
			// private/password
			// password/password
			$testAlbum = $albumName;
		} elseif ($is_parent_password_album) {
			// check parent is password album
			// password/private
			// password/public
			$testAlbum = $parentAlbum;
		} else {
			$testAlbum = null;
		}

		if (!empty($testAlbum)) {
			if (self::ValidatePasswordFromSession($sessionArray, $testAlbum)) {
				return true;
			} else {
				if ($isNeedRedirect) {
					self::RedirectToLoginPage($testAlbum, 1);
				}
				return false;
			}
		}

		// leave a syslog for unexpected state
		syslog(LOG_ERR, __FILE__.":".__LINE__." "."Unexpected state.");
		return true;
	}

	static function GetPhotoVideoDBId($filePath, $type) {
		$realPath = SYNOPHOTO_SERVICE_REAL_DIR.'/'.$filePath;

		if (!csSynoPhotoMisc::CheckPathValid($realPath)) {
			return false;
		}

		$table = $type === 'photo' ? 'photo_image' : 'video';
		if ('root' === SYNOPHOTO_ADMIN_USER) {
			$row = csSYNOPhotoDB::GetDBInstance()->GetFieldByKeyValue('id', $table, 'path', $realPath);
		} else {
			$row = csSYNOPhotoDB::GetDBInstance()->GetFieldByKeyValue('id', $table, 'path', $filePath);
		}
		if (!$row) {
			return false;
		}
		return $row['id'];
	}

	static function GetAlbumDBId($albumName) {
		$row = csSYNOPhotoDB::GetDBInstance()->GetFieldByKeyValue('shareid', 'photo_share', 'sharename', $albumName);
		if (!$row) {
			return false;
		}
		return $row['shareid'];
	}

	static function RedirectToLoginPage($albumName, $isForPassword=false)
	{
		$query = "Select sharename from photo_share where sharename = ?";
		$db_result = PHOTO_DB_Query($query, array($albumName));

		echo "<script>";
		if (PHOTO_DB_FetchRow($db_result)) {
			if ($isForPassword) {
				echo "parent.location = \"".SYNOPHOTO_URL_PREFIX."/photo/login.php?albumName=".bin2hex($albumName)."&password=true&".
				"&url=".bin2hex($_SERVER['PHP_SELF']."?".$_SERVER['QUERY_STRING'])."\";";
			} else {
				echo "parent.location = \"".SYNOPHOTO_URL_PREFIX."/photo/login.php?url=".bin2hex($_SERVER['PHP_SELF']."?".$_SERVER['QUERY_STRING'])."\";";
			}
		} else {
			echo "parent.location = \"".SYNOPHOTO_URL_PREFIX."/photo/index.php\";";
		}
		echo "</script>";
		exit;
	}

	static function CheckPathAccessible($path)
	{
		$dir = dirname(realpath($path));

		if ($dir === SYNOPHOTO_SERVICE_REAL_DIR) {
			$sharename = '/';
		} else if (0 === strncmp(SYNOPHOTO_SERVICE_REAL_DIR . '/', $dir, strlen(SYNOPHOTO_SERVICE_REAL_DIR . '/'))) {
			$sharename = substr($dir, strlen(SYNOPHOTO_SERVICE_REAL_DIR) + 1);
		}

		if (!$sharename) {
			return false;
		}

		return self::CheckAlbumAccessible($sharename);
	}

	static function CheckAlbumUploadable($albumName)
	{
		// skip photo in remote mount (cifs) or read-only mount (iso9660)
		if (self::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$albumName, $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])) {
			return false;
		}
		if (isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			return true;
		}
		/* if album is under 3rd level, check uploadable in second level */
		$albumToken = explode('/', $albumName);
		if (count($albumToken) > 2) {
			$albumName = $albumToken[0] . '/' . $albumToken[1];
		}
		if (!self::CheckAlbumAccessible($albumName) ||
			!isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['uploadable_album'][$albumName])) {
			return false;
		}
		return true;
	}

	static function CheckAlbumManageable($albumName)
	{
		// skip photo in remote mount (cifs) or read-only mount (iso9660)
		if (self::isSkipPhotoDev(SYNOPHOTO_SERVICE_REAL_DIR.'/'.$albumName, $_SESSION[SYNOPHOTO_ADMIN_USER]['mount_dev_list'])) {
			return false;
		}
		if (isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			return true;
		}
		$albumToken = explode('/', $albumName);
		if (count($albumToken) > 2) {
			$albumName = $albumToken[0] . '/' . $albumToken[1];
		}
		if (!self::CheckAlbumUploadable($albumName) ||
			!isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['manageable_album'][$albumName])) {
			return false;
		}
		return true;
	}
	/*!
	 * Get translated string from desktop edition language file by variable name
	 *
	 * \param $token variable name without '$photo_' prefix
	 * \return translated string
	 */
	static function GetPhotoText($token)
	{
		preg_match_all("/^\\\$photo_{$token}\\s*=\\s*'(.+)'/m",
		file_get_contents(SYNOPHOTO_LANGS_DIR."/{$_SESSION[SYNOPHOTO_ADMIN_USER]['lang']}.php"), $matches, PREG_SET_ORDER);
		return $matches[0][1];
	}
	/*!
	 * Get translated legal information from webman strings
	 *
	 * \return array with translated legal information
	 *	- copyright_mark_desc
	 *	- copyright_note_desc
	 */
	static function GetLegalText()
	{
		preg_match_all('/^(copyright_\w+)\s*=\s*"(.+)"/m',
		file_get_contents("../../../webman/texts/{$_SESSION[SYNOPHOTO_ADMIN_USER]['lang']}/strings"), $matches, PREG_SET_ORDER);
		$result = array();
		foreach ($matches as $item) {
			$result[$item[1]] = $item[2];
		}
		return $result;
	}
	/*!
	 * Get reduced datetime string
	 *
	 * \param $string the full datetime string: YYYY-mm-dd H:i:s
	 * \return only time if the string is in today, or otherwise only date.
	 */
	static function GetReducedDate($string)
	{
		$date = substr($string, 0, 10);
		if (date('Y-m-d') == $date) {
			return substr($string, 11);
		}
		return $date;
	}
	/*!
	 * Map ##-## language region to ###
	 *
	 * \param $lang language region
	 * \return mapped ### for supported language region, otherwise 'enu'
	 */
	static function GetMappedLanguage($lang)
	{
		if (2 == strlen($lang)) {
			$lang .= '-';
		}
		switch (true) {
			case !strcasecmp($lang, "zh-tw"):
			case !strcasecmp($lang, "zh-hk"):
			case !strcasecmp($lang, "zh-mo"):
			case !strncasecmp($lang, "zh-hant", 7): // ISO 639
				$lang = 'cht';
				break;
			case !strncasecmp($lang, "zh-", 3):
				$lang = 'chs';
				break;
			case !strncasecmp($lang, "en-", 3):
				$lang = 'enu';
				break;
			case !strncasecmp($lang, "de-", 3):
				$lang = 'ger';
				break;
			case !strncasecmp($lang, "ja-", 3):
				$lang = 'jpn';
				break;
			case !strncasecmp($lang, "ko-", 3):
				$lang = 'krn';
				break;
			case !strncasecmp($lang, "es-", 3):
				$lang = 'spn';
				break;
			case !strncasecmp($lang, "fr-", 3):
				$lang = 'fre';
				break;
			case !strncasecmp($lang, "it-", 3):
				$lang = 'ita';
				break;
			case !strncasecmp($lang, "ru-", 3):
				$lang = 'rus';
				break;
			case !strncasecmp($lang, "nl-", 3):
				$lang = 'nld';
				break;
			case !strncasecmp($lang, "no-", 3):
			case !strncasecmp($lang, "nb-", 3):
			case !strncasecmp($lang, "nn-", 3):
				$lang = 'nor';
				break;
			case !strncasecmp($lang, "sv-", 3):
				$lang = 'sve';
				break;
			case !strncasecmp($lang, "da-", 3):
				$lang = 'dan';
				break;
			case !strncasecmp($lang, "pl-", 3):
				$lang = 'plk';
				break;
			case !strncasecmp($lang, "pt-br", 5):
				$lang = 'ptb';
				break;
			case !strncasecmp($lang, "pt-", 3):
				$lang = 'ptg';
				break;
			case !strncasecmp($lang, "hu-", 3):
				$lang = 'hun';
				break;
			case !strncasecmp($lang, "tr-", 3):
				$lang = 'trk';
				break;
			case !strncasecmp($lang, "cs-", 3):
				$lang = 'csy';
				break;
			case !strncasecmp($lang, "th-", 3):
				$lang = 'tha';
				break;
			default:
				$lang = false;
		}
		return $lang;
	}
	/*!
	 * Get parsed config from file
	 *
	 * \param $cfgFile config file
	 * \param $confKeys config keys that values need to be returned
	 * \return array with parsed data
	 *	- key = 'value' will parse into $result['key'] = value
	 */
	static function GetConfigFile($cfgFile, $confKeys = '.+')
	{
		$trimmedCharSet = " \t\n\r\0\x0B\"'";
		preg_match_all('/^\s*('.$confKeys.')\s*=\s*(.*)/m', file_get_contents($cfgFile), $matches, PREG_SET_ORDER);
		$result = array();
		foreach ($matches as $item) {
			$result[$item[1]] = trim($item[2], $trimmedCharSet);
		}
		return $result;
	}
	static function SetConfigFile($cfgKey, $value)
	{
		return (self::ExecCmd('/usr/syno/bin/synophoto_config_root', array('-s', $cfgKey, '-v', $value)) === 0);
	}

	static function IsDockerDSM()
	{
		$bin = '/var/packages/PhotoStation/target/bin/synophoto_config';
		$ret = self::ExecCmd($bin, array('--dsm', '--get', 'dockerdsm'), false, $output);

		if ($ret === 0 && count($output) > 0 && $output[0] === 'yes') {
			return true;
		}

		return false;
	}

	static function IsNSM()
	{
		// FIXME The key 'syno_os' cannot be found in /etc/synoinfo.conf
		return false;
		/*
		$cmd = '/usr/syno/bin/synophoto_config -d -g syno_os';
		//@exec($cmd, $output, $retVal);
		$output = '';
		$retVal = self::ExecCmd('/usr/syno/bin/synophoto_config', array('-d', '-g', 'syno_os'), false, $output);

		if ($output[0] != "nsm") {
			return false;
		}
		return true;
		*/
	}
	/*!
	 * Get syno user's email from /etc/synouser.conf
	 *
	 * \param $user username
	 */
	static function GetSynoUserEmail($user)
	{
		$output = '';
		$retval = self::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--getinfo', $user), false, $output);
		if (0 !== $retval) {
			return '';
		}

		$user_info = csSYNOPhotoMisc::ParseDsmUserInfo($output);

		return $user_info[8];
	}
	/*!
	 * Get translated legal information from webman strings
	 *
	 * \return array with translated legal information
	 *	- copyright_mark_desc
	 *	- copyright_note_desc
	 */
	static function checkServiceEnabled()
	{
		$result =true;
		if (!preg_match('/\/~[^\/]+/', $_SERVER['REQUEST_URI'], $matches)){
			/* check whether photo service enabled */
			if (!file_exists(SYNO_PKG_DIR.'/enabled')) {
				$result = false;
			}
		} else{
			if (!file_exists(SYNO_PKG_DIR.'/enabled') ||
				!isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['runpersonalphotostation']) ||
				'yes' != $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['runpersonalphotostation'] ||
				!isSet($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['percfg']['runpersonalphotostation']) ||
				'yes' != $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['percfg']['runpersonalphotostation']) {
				$result = false;
			}
		}
		return $result;
	}

	/*!
	 * Check accont system if use dsm account
	 *
	 * \return true when use DSM account
	 */
	static function checkDsmAccountEnabled()
	{
		$result = true;

		if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['use_dsm_account'])) {
			return $_SESSION[SYNOPHOTO_ADMIN_USER]['use_dsm_account'];
		}

		if (null == ( $use_dsm_account = self::GetConfigDB("global", "account_system", "photo_config" ))) {
			if(self::GetUserType() == 2) {
				self::AddConfigDB("global", "account_system", "1", "photo_config");
			}
			$use_dsm_account = '1';
		}

		if ('0' == $use_dsm_account) {
			$result = false;
		}
		return $result;
	}

	static function IsBlogEnabled()
	{
		$result = self::GetConfigDB('main', 'enable_blog');
		if ($result == null || $result == '') {
			return false;
		}
		return ($result == '1');
	}

	static function CheckSessionTimeOut($userIsEnough = false)
	{
		$timeout = true;
		if(isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) && $_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'] === SYNOPHOTO_ADMIN_PASS) {
			$timeout = false;
		}
		if ($userIsEnough) {
			if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']) && $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'] !== "") {
				$timeout = false;
			}
		}
		if ($timeout) {
			header('x-request-error: error_timeout');
			exit;
		}
	}

	static function CheckAdminTimeOut()
	{
		if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) || $_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'] != SYNOPHOTO_ADMIN_PASS) {
			header('x-request-error: error_timeout');
			exit;
		}
	}

	static function CheckUserTimeOut()
	{
		if (!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']) || $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'] == "") {
			header('x-request-error: error_timeout');
			exit;
		}
	}

	static function GetUserType()
	{
		if(isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) && $_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'] == SYNOPHOTO_ADMIN_PASS) {
			$result = 2;
		} else if(isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'])) {
			$result = 1;
		} else {
			$result = 0;
		}
		return $result;
	}

	private static function GetConfigCacheKey($module_name, $config_key, $table='')
	{
		return "$table::$module_name::$config_key";
	}

	static function CheckConfigTable(&$table)
	{
		if ($table == null || $table == "") {
			$table = 'blog_config';
		}
		if ($table !== 'blog_config' && $table !== 'photo_config') {
			return false;
		}
		return true;
	}

	static function GetConfigDB($module_name, $config_key, $table="")
	{
		if (!self::CheckConfigTable($table)) {
			return null;
		}

		// get from temp cache array, to avoid exactly the same db query doing multiple times in a single PHP
		$cache_key = self::GetConfigCacheKey($module_name, $config_key, $table);
		if (!self::$dbConfigCache) {
			self::$dbConfigCache = new Cache();
		}
		if (self::$dbConfigCache->check($cache_key)) {
			return self::$dbConfigCache->get($cache_key);
		}

		// TODO: Bug#2282 Should Move into DB!!!
		if (!$GLOBALS['dbconn_photo']) {
			$db = csSYNOPhotoDB::GetDBInstance();
		}

		$query = "Select config_value from $table where module_name = ? and config_key = ?";
		$db_result = PHOTO_DB_Query($query, array($module_name, $config_key));

		if ($row = PHOTO_DB_FetchRow($db_result)) {
			$value = $row[0];
		} else {
			$value = null;
		}

		self::$dbConfigCache->set($cache_key, $value);
		return $value;
	}

	static function UpdateConfigDB($module_name, $config_key, $config_value, $table="", $blSkipTimeout=false)
	{
		if (!$blSkipTimeout) {
			self::CheckAdminTimeOut();
		}

		// TODO: Bug#2282 Should Move into DB!!!
		if (!$GLOBALS['dbconn_photo']) {
			$db = csSYNOPhotoDB::GetDBInstance();
		}

		if (!self::CheckConfigTable($table)) {
			return null;
		}

		$query = "Update $table set config_value = ? where module_name = ? and config_key = ?";
		$sqlParam = array($config_value, $module_name, $config_key);
		$db_result = PHOTO_DB_Query($query, $sqlParam);

		if (!$db_result || PHOTO_DB_AffectedRows($db_result) == 0) {
			self::AddConfigDB($module_name, $config_key, $config_value, $table, $blSkipTimeout);
		}

		if (self::$dbConfigCache) {
			self::$dbConfigCache->delete(self::GetConfigCacheKey($module_name, $config_key, $table));
		}

		$result['success'] = TRUE;
		return json_encode($result);
	}

	static function UpdateConfigDBDontCheckAdmin($module_name, $config_key, $config_value, $table="") {
		return csSYNOPhotoMisc::UpdateConfigDB($module_name, $config_key, $config_value, $table, true);
	}

	static function AddConfigDB($module_name, $config_key, $config_value, $table="", $blSkipTimeout=false)
	{
		if (!$blSkipTimeout) {
			self::CheckAdminTimeOut();
		}

		// TODO: Bug#228 Should Move into DB!!!
		if (!$GLOBALS['dbconn_photo']) {
			$db = csSYNOPhotoDB::GetDBInstance();
		}

		if (!self::CheckConfigTable($table)) {
			return null;
		}
		$query = "Insert Into $table (module_name, config_key, config_value) ";
		$query = $query."Values(?, ?, ?)";
		$sqlParam = array($module_name, $config_key, $config_value);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		$result['success'] = TRUE;

		return json_encode($result);
	}

	static function DeleteConfigByID($module_name, $config_id, $table="")
	{
		self::CheckAdminTimeOut();

		// TODO: Bug#228 Should Move into DB!!!
		if (!$GLOBALS['dbconn_photo']) {
			$db = csSYNOPhotoDB::GetDBInstance();
		}

		if (!self::CheckConfigTable($table)) {
			return null;
		}
		$query = "Delete from $table where module_name = ? AND config_id = ?";
		$sqlParam = array($module_name, $config_id);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		$result['success'] = TRUE;

		if (self::$dbConfigCache) {
			self::$dbConfigCache->delete(self::GetConfigCacheKey($module_name, $config_key, $table));
		}

		return json_encode($result);
	}

	static function GetQuickConnectHostName(&$host)
	{
		if (self::$initQuickConnectHost) {
			if (empty(self::$quickConnectHost)) {
				return false;
			} else {
				$host = self::$quickConnectHost;
				return true;
			}
		}
		self::$initQuickConnectHost = true;

		// get from QuickConnect alias
		$command = '/usr/syno/bin/synophoto_external_access --quickconnect';
		//@exec($command, $resultArray, $ret);
		$resultArray = '';
		$ret = self::ExecCmd('/usr/syno/bin/synophoto_external_access', array('--quickconnect'), false, $resultArray);
		if (0 === $ret && count($resultArray) > 0) {
			$host = $resultArray[0];
			self::$quickConnectHost = $host;

			return true;
		}

		return false;
	}

	static function GetDDNSHostName(&$host)
	{
		if (self::$initDdnsHost) {
			if (empty(self::$ddnsHost)) {
				return false;
			} else {
				$host = self::$ddnsHost;
				return true;
			}
		}
		self::$initDdnsHost = true;

		if ($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['cfg']['ddns_update'] == "yes") {
			$command = "/usr/syno/bin/synophoto_external_access --ddns";
			//@exec($command, $hostname, $retval);
			$hostname = '';
			$retval = self::ExecCmd('/usr/syno/bin/synophoto_external_access', array('--ddns'), false, $hostname);
			if (0 == $retval && 0 < strlen($hostname[0])) {
				$host = $hostname[0];
				self::$ddnsHost = $host;

				return true;
			}
		}
		return false;
	}

	static function GetUserDefinedExternalHost(&$host)
	{
		if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_host_ip'])
			&& $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_host_ip'] != '') {
			$host = $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_host_ip'];
			return true;
		}
		return false;
	}

	static function GetExternalIP(&$isQuickConnect=false, $enableQuickConnect = false)
	{
		$host = '';
		if ((strtolower(substr($_SERVER['SERVER_NAME'], -15)) === 'quickconnect.to' ||
			 strtolower(substr($_SERVER['SERVER_NAME'], -15)) === 'quickconnect.cn') &&
			 csSYNOPhotoMisc::GetQuickConnectHostName($host)) {
			$isQuickConnect = true;
			return $host;
		}

		if (csSYNOPhotoMisc::GetUserDefinedExternalHost($host)) {
			return $host;
		}

		if (csSYNOPhotoMisc::GetDDNSHostName($host)) {
			return $host;
		}

		if ($enableQuickConnect && csSYNOPhotoMisc::GetQuickConnectHostName($host)) {
			$isQuickConnect = true;
			return $host;
		}

		//$server_ip = exec("/usr/syno/bin/synophoto_external_access --external_ip");
		$server_ip = '';
		self::ExecCmd('/usr/syno/bin/synophoto_external_access', array('--external_ip'), false, $server_ip);
		$server_ip = $server_ip[count($server_ip) - 1];
		if ($server_ip === "0.0.0.0" || $server_ip === "") {
			$server_ip = $_SERVER['HTTP_HOST'];
		}
		return $server_ip;
	}

	static function GetServerHost($enableQuickConnect = false, $enableExternalIp = false)
	{
		$serverHost = explode(":", $_SERVER['HTTP_HOST']);
		$host = "";
		$port = count($serverHost) > 1 ? $serverHost[1] : "";
		//$host = $enableExternalIp ? exec("/usr/syno/bin/synophoto_external_access --external_ip") : $_SERVER['HTTP_HOST'];

		if ($enableExternalIp) {
			self::ExecCmd('/usr/syno/bin/synophoto_external_access', array('--external_ip'), false, $host);
			$host = $host[count($host) - 1];
		}

		if ($host === "0.0.0.0" || $host === "") {
			$host = $serverHost[0];
		}

		$isQuickConnect = false;

		if ((strtolower(substr($_SERVER['SERVER_NAME'], -15)) === 'quickconnect.to' ||
			 strtolower(substr($_SERVER['SERVER_NAME'], -15)) === 'quickconnect.cn'
			) &&
			csSYNOPhotoMisc::GetQuickConnectHostName($host)) {
			return 'https://'.$host;
		}

		if ($enableQuickConnect && csSYNOPhotoMisc::GetQuickConnectHostName($host)) {
			$isQuickConnect = true;
		}

		if (csSYNOPhotoMisc::GetUserDefinedExternalHost($host) || csSYNOPhotoMisc::GetDDNSHostName($host)) {
			$port = $_SERVER['SERVER_PORT'];
			$isQuickConnect = false;
		}

		if ($_SERVER["HTTPS"] == 'on' || isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] === 'https') {
			$protocol = "https";
			if(isset($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_https'])
				&& $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_https'] != '') {
				$port = $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_https'];
			}
		} else {
			$protocol = "http";
			if(isset($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_http'])
				&& $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_http'] != '') {
				$port = $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_http'];
			}
		}

		if (('http' === $protocol && $port == 80) ||
			('https' === $protocol && $port == 443) ||
			$port === '') {
			$result = "$protocol://$host";
		} else {
			$result = "$protocol://$host:$port";
		}
		if ($isQuickConnect) {
			// always uses https for QuickConnect relay host
			// http will redirect to https, but Pixlr cannot handle HTTP redirect,
			// aviary post url uses https will also fail
			$result = 'https://'.$host;
		}

		return $result;
	}

	static function checkRedirectToHttps()
	{
		if ("on" === csSYNOPhotoMisc::GetConfigDB("global", "redirect_to_https", "photo_config") && !$_SERVER['HTTPS']) {
			return true;
		} else {
			return false;
		}
	}

	static function RedirectToHttps()
	{
		if ($_SERVER['HTTPS']) {
			return;
		}

		$port = '';
		$host = $_SERVER['HTTP_HOST'];

		if(isset($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_https'])
			&& $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_https'] != '') {
			$port = ':'.$_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['external_port_photo_https'];
		}

		$result = 'https://'.$host.$port.$_SERVER['REQUEST_URI'];
		header('Location: ' . $result);
	}

	static function formatTime($secs)
	{
		return str_pad(floor($secs/3600),2,"0",STR_PAD_LEFT).":".
			str_pad(floor(($secs%3600)/60),2,"0",STR_PAD_LEFT).":".
			str_pad($secs%60,2,"0",STR_PAD_LEFT);
	}

	static function getFbSyncConfPath($albumName)
	{
		$dirPath = sprintf("%s/%s", SYNOPHOTO_SERVICE_REAL_DIR, $albumName);
		SYNOPhotoEA::checkFilePath($dirPath, SYNOPhotoEA::FILE_ALBUM_FBSYNC, $confPath);

		return $confPath;
	}

	static function isSetToSyncWithFb($albumName)
	{
		if (null == $conf_path = self::getFbSyncConfPath($albumName)) {
			return FALSE;
		}
		$conf_path = $conf_path.".set";
		if (FALSE == @stat($conf_path)) {
			return FALSE;
		}
		return TRUE;
	}

	static function isSyncingWithFb($albumName)
	{
		$albumPath = SYNOPHOTO_SERVICE_REAL_DIR."/".$albumName;
		$syncing_array = array();
		$handle = @fopen(SYNOPHOTO_FB_SYNCING_FILE, "r");
		if ($handle) {
			while (!feof($handle)) {
				$line = fgets($handle, 4096);
				$syncing_array[] = trim($line);
			}
			fclose($handle);
		}
		if (in_array($albumPath, $syncing_array)) {
			return TRUE;
		}
		return FALSE;
	}

	static function getVirtualAlbumText($type)
	{
		switch($type) {
			case 0:
				$virtual_album_text = __('photo_str_recent_photo');
				break;
			case 1:
				$virtual_album_text = __('photo_str_recent_video');
				break;
			case 2:
				$virtual_album_text = __('photo_str_recent_commented_photo');
				break;
			case 3:
				$virtual_album_text = __('photo_str_recent_commented_video');
				break;
			case 4:
				$virtual_album_text =__('photo_str_person_label');
				break;
			case 5:
				$virtual_album_text = __('photo_str_place_label');
				break;
			case 6:
				$virtual_album_text = __('photo_str_general_label');
				break;
		}
		return $virtual_album_text;
	}

	static function GetWelcomeText()
	{
		if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'])) {
			$welcome_text = __(photo_str_welcome).", ".$_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'];
		} elseif (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			if ('root' == SYNOPHOTO_ADMIN_USER) {
				$welcome_text = __(photo_str_welcome).", admin";
			}else {
				$welcome_text = __(photo_str_welcome).', '.SYNOPHOTO_ADMIN_NAME;
			}
		} else {
			$welcome_text = "";
		}
		return $welcome_text;
	}

	static function GetBlogTopHeaderLinkArray()
	{
		$result = array();
		$item = array();

		// Guest
		// Photos | Sign in
		//
		// admin
		// Photos | Settings | Sign Out
		//
		// normal user
		// Photos | Sign Out

		// photo links
		$item['href'] = SYNOPHOTO_URL_PREFIX."/photo";
		$item['name'] = __(photo_str_photo);
		$result[] = $item;

		$userType = self::GetUserType();
		if (0 < $userType) {
			if ($userType === 2) {
				$item['href'] = SYNOPHOTO_URL_PREFIX."/photo/admin_index.php";
				$item['name'] = __(photo_str_management);
				$result[] = $item;
			}

			$item['href'] = SYNOPHOTO_URL_PREFIX."/photo/photo_login.php?action=logout&redirect=".$redirect;
			$item['name'] = __(photo_logout);
			$result[] = $item;
		} else {
			$item['href'] = "javascript:onLogin('".rawurlencode($_SERVER['REQUEST_URI'])."')";
			$item['name'] = __(photo_login);
			$result[] = $item;
		}

		$result['blog'] = array(
			'href' => SYNOPHOTO_URL_PREFIX . '/blog/'
		);

		return $result;
	}

	/**
	 * @deprecated Only used by Photo Station 5
	 */
	static function GetTopHeaderLinkArray($isPhotoStation6 = false)
	{
		//TODO: for develepment process, use flag that indicates PhotoStation6 temporarily.

		$result = array();
		$item = array();

		if (!strstr($_SERVER['PHP_SELF'], "/photo/") || strstr($_SERVER['PHP_SELF'], "/photo/admin_index.php")
			|| strstr($_SERVER['PHP_SELF'], "/photo/timeline.php")) {
			$item['href'] = SYNOPHOTO_URL_PREFIX."/photo";
			$item['name'] = __(photo_str_photo);
			$result[] = $item;
		}

		if (self::GetConfigDB('main', 'enable_blog', 'blog_config') != "0") {
			if (!strstr($_SERVER['PHP_SELF'], "/blog/index.php")) {
				$item['href'] = SYNOPHOTO_URL_PREFIX."/blog";
				$item['name'] = __(photo_str_blog);
				$result[] = $item;
			}
		}

		$pkg_default_conf = csSYNOPhotoMisc::GetConfigFile(SYNO_PKG_DEFAULT_CONF, 'support_timeline');
		$enableTimeline = (csSYNOPhotoMisc::GetConfigDB("photo", "disable_timeline", "photo_config") !== "on");
		if (!$isPhotoStation6 && 'yes' == $pkg_default_conf['support_timeline'] && $enableTimeline && !strstr($_SERVER['PHP_SELF'], "/photo/timeline.php")) {
			$item['href'] = SYNOPHOTO_URL_PREFIX."/photo/timeline.php";
			$item['name'] = __(photo_str_timeline);
			$result[] = $item;
		}

		if (0 < self::GetUserType()) {
			$redirect = (!strstr($_SERVER['PHP_SELF'], "/blog/index.php")) ? "photo" : "blog";
			if (!strstr($_SERVER['PHP_SELF'], "/photo/admin_index.php") && 2 == self::GetUserType()) {
				$item['href'] = SYNOPHOTO_URL_PREFIX."/photo/admin_index.php";
				$item['name'] = __(photo_str_management);
				$result[] = $item;

				if (!$isPhotoStation6 && !strstr($_SERVER['PHP_SELF'], "/photo/timeline.php")) {
					$item['href'] = SYNOPHOTO_URL_PREFIX."/photo/theme.php?type=".$redirect;
					$item['name'] = __(photo_theme_btnTheme);
					$result[] = $item;
				}
			}

			if (!strstr($_SERVER['PHP_SELF'], "/photo/admin_index.php") && 1 == self::GetUserType() &&
					isset($_SESSION[SYNOPHOTO_ADMIN_USER]['use_dsm_account']) && false == $_SESSION[SYNOPHOTO_ADMIN_USER]['use_dsm_account']) {
				$item['href'] = SYNOPHOTO_URL_PREFIX."/photo/admin_index.php";
				$item['name'] = __(photo_str_management);
				$result[] = $item;
			}

			$item['href'] = SYNOPHOTO_URL_PREFIX."/photo/photo_login.php?action=logout&redirect=".$redirect;
			$item['name'] = __(photo_logout);
			$result[] = $item;
		} else {
			$item['href'] = "javascript:onLogin('".rawurlencode($_SERVER['REQUEST_URI'])."')";
			$item['name'] = __(photo_login);
			$result[] = $item;
		}

		$result['blog'] = array(
			'href' => SYNOPHOTO_URL_PREFIX . '/blog/');

		return $result;
	}

	static function GetAccessibleAlbumQueryConditionWithExcludeFormat($ref = '', $publicShareId = NULL)
	{
		$albumCondition = self::GetAccessibleAlbumQueryCondition($ref, $publicShareId);

		if (count($albumCondition['albumCond'])) {
			$albumCondition['albumCond'] = "(" . implode(' OR ', $albumCondition['albumCond']) . ") AND disabled = 'f'";
		} else {
			$albumCondition['albumCond'] = '';
		}

		return $albumCondition;
	}

	static function GetAccessibleAlbumQueryCondition($ref = '', $publicShareId = NULL)
	{
		$albumCond = array();
		$sqlParam = array();

		$sessionArray = &$_SESSION[SYNOPHOTO_ADMIN_USER];
		if (NULL !== $publicShareId) {
			if (!isset($_SESSION[$publicShareId])) {
				return false;
			}
			$sessionArray = &$_SESSION[$publicShareId];
		}

		$isAdmin = isset($sessionArray['admin_syno_user']);

		if ($isAdmin) {
			$albumCond = array("1=1");
			$result['albumCond'] = $albumCond;
			$result['sqlParam'] = $sqlParam;
			return $result;
		}

		if ('' !== $ref) {
			$path = $ref . '.path';
			if (!empty($sessionArray['albumQueryCondition_' . $ref])) {
				return $sessionArray['albumQueryCondition_' . $ref];
			}
		} else {
			$path = 'path';
			if (!empty($sessionArray['albumQueryCondition'])) {
				return $sessionArray['albumQueryCondition'];
			}
		}
		$ref_shareid = self::GetPriviegeShareIdNoPasswordListFromSession($sessionArray);
		if (count($ref_shareid)) {
			if(!isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) and
					csSYNOPhotoMisc::GetConfigDB("photo", "allow_root_folder_public", "photo_config") !== "on" and
					($key = array_search(ROOT_SHAREID, $ref_shareid)) !== false) {
				// delete root folder if not allow root folder public
				unset($ref_shareid[$key]);
			}
			$albumCond[] = "privilege_shareid IN (". implode(',', $ref_shareid).")";
		}

		$result['albumCond'] = $albumCond;
		$result['sqlParam'] = $sqlParam;
		$result['privilege_shareid'] = self::GetPriviegeShareIdListFromSession($sessionArray);

		// due to Photo bug #1894, unlock session earlier.
		// need to call session_start() again to write to session here.
		csSYNOPhotoMisc::PhotoSessionStart();
		if ('' !== $ref) {
			$sessionArray['albumQueryCondition_' . $ref] = $result;
		} else {
			$sessionArray['albumQueryCondition'] = $result;
		}

		return $result;
	}

	static function GetVideoNameList($videoList)
	{
		$i=0;
		$length = count($videoList);
		$list = array();
		while ($i < $length) {
			$list[] = basename($videoList[$i]);
			$i++;
		}
		return $list;
	}

	static function ResizePhoto($source, $dest, $width = '1920', $height = null)
	{
		$ret = false;
		if (!file_exists($source)) {
			return $ret;
		}
		$imageInfo = @getImageSize($source);
		if (strstr($imageInfo['mime'], 'gif')) {
			return $ret;
		}

		if ($height == null) {
			//$command = "/usr/syno/bin/convert -resize ".$width.'x'.$width." ";
			$command = '' . $width . 'x' . $width;
		} else {
			//$command = "/usr/syno/bin/convert -resize ".$width.'x'.$height." ";
			$command = '' . $width . 'x' . $height;
		}
		//$command .= escapeshellarg($source) . " " . escapeshellarg($dest);
		//@system($command, $retval);
		$retval = false;
		self::ExecCmdNoOutput('/usr/bin/convert', array('-resize', $command, $source, $dest), $retval);
		if (0 == $retval) {
			$ret = true;
		}
		return $ret;
	}

	/*!
	 * Check if album should be skipped on ui
	 *
	 * \param $path album's directory
	 * \return true or false
	 */
	static function IsSkipPhotoPath($path)
	{
		if (!file_exists($path) || !file_exists('/proc/mounts')) {
			return false;
		}
		if (!($stPath = stat($path))) {
			return false;
		}

		$handle = @fopen('/proc/mounts', 'r');
		$ret = false;

		while (($buf = fgets($handle, 4096)) != false) {
			list(, $dir, $type, ) = explode(" ", $buf);
			if (!($stMount = stat($dir))) {
				$ret = false;
				break;
			}
			if ($stMount['dev'] == $stPath['dev']) {
				if ($type == 'cifs' || $type == 'iso9660') {
					$ret = true;
					break;
				}
			}
		}
		fclose($handle);
		return $ret;
	}

	static function getSkipPhotoDev()
	{
		if (!file_exists('/proc/mounts')) {
			return null;
		}
		$handle = @fopen('/proc/mounts', 'r');
		$skipPathArr = array();
		while (($buf = fgets($handle, 4096)) != false) {
			list(, $dir, $type, ) = explode(" ", $buf);
			if ($type == 'cifs' || $type == 'iso9660' || $type == 'udf') {
				$dir = csSYNOPhotoMisc::decodeName($dir);
				$skipPathArr[] = $dir;
			}
		}
		fclose($handle);
		return $skipPathArr;
	}
	static function isSkipPhotoDev($path, $skipDevArr)
	{
		if (!file_exists($path) || empty($skipDevArr)) {
			return false;
		}
		if (false !== array_search($path, $skipDevArr)) {
			return true;
		}
		if (is_link($path)) {
			$real_path = realpath($path);
			foreach($skipDevArr as $skipPath){
				if (0 === strncmp($skipPath, $real_path, strlen($skipPath))) {
					return true;
				}
			}
		}
		return false;
	}

	static function decodeName($path)
	{
		$i = 0;
		$count = strlen($path);
		$newPath = '';
		while($i < $count) {
			$four = substr($path, $i, 4);
			$two = substr($path, $i, 2);

			if ($four == '\040') {// space
				$newPath .= ' ';
				$i+=4;
			} else if ($four == '\011'){// \t
				$newPath .= "\t";
				$i+=4;
			} else if ($four == '\012') {// \n
				$newPath .= "\n";
				$i+=4;
			} else if ($two == '\\\\') {// \
				$newPath .= '\\';
				$i+=2;
			} else if ($four == '\134') {
				$newPath .= '\\';
				$i+=4;
			} else {
				$newPath .= substr($path, $i, 1);
				$i++;
			}
		}
		return $newPath;
	}

	static function GetDsmVersion()
	{
		$values = self::GetConfigFile(SYNO_DEF_VERSION_FILE, 'buildnumber');
		return $values['buildnumber'];
	}

	static function GetPackageVersion()
	{
		$values = self::GetConfigFile(SYNOPHOTO_PACKAGE_INFO, 'version');
		return $values['version'];
	}

	static function GetFileWithMtime($string)
	{
		$pos = strpos($string, '?');
		$path = ($pos === false) ? $string : substr($string, 0, $pos);
		$mtime = @filemtime($path);
		$separator = ($pos === false) ? '?' : '&';
		return "$string${separator}v=$mtime";
	}

	static function GetPackageMtime()
	{
		// we assume file mtime will be package installation time
		// so get mtime of this PHP file to represent package mtime
		// generally used for smarty template based page browser cache prevention mechanism
		return @filemtime(__FILE__);
	}

	static function CheckPathValid($path)
	{
		$pathToken = explode('/', $path);
		foreach ($pathToken as $token) {
			if ('.' == $token || '..' == $token) {
				return false;
			}
		}
		return true;
	}

	static function IsUtf8($string)
	{
		return preg_match('%^(?:
			[\x09\x0A\x0D\x20-\x7E]            # ASCII
			| [\xC2-\xDF][\x80-\xBF]             # non-overlong 2-byte
			| \xE0[\xA0-\xBF][\x80-\xBF]         # excluding overlongs
			| [\xE1-\xEC\xEE\xEF][\x80-\xBF]{2}  # straight 3-byte
			| \xED[\x80-\x9F][\x80-\xBF]         # excluding surrogates
			| \xF0[\x90-\xBF][\x80-\xBF]{2}      # planes 1-3
			| [\xF1-\xF3][\x80-\xBF]{3}          # planes 4-15
			| \xF4[\x80-\x8F][\x80-\xBF]{2}      # plane 16
		)*$%xs', $string);
	}

	static function ParseExcludeFormats($input)
	{
		if (!is_string($input)) {
			$input = "";
		}

		$fileFormats = array();

		foreach(preg_split("/[\s\.,;]+/", $input) as $token) {
			if ("" === $token) {
				continue;
			}

			$fileFormats[strtolower($token)] = true;
		}

		return array_keys($fileFormats);
	}

	static function IsExcludeFormats($path)
	{
		$ext = strtolower(pathinfo($path, PATHINFO_EXTENSION));
		$excludeExts = self::ParseExcludeFormats(csSYNOPhotoMisc::GetConfigDB("photo", "excluding_index_format", "photo_config"));

		if (in_array($ext, $excludeExts)) {
			return true;
		}

		return false;
	}

	static function IsAlbumAllowConversion($albumPath)
	{
		if ('/' === $albumPath) {
			$albumName = '/';
		} else {
			$parts = explode('/', $albumPath);
			$albumName = $parts[0];
		}

		if (!self::$conversionCache) {
			self::$conversionCache = new Cache();
		}
		if (self::$conversionCache->check($albumName)) {
			return self::$conversionCache->get($albumName);
		}

		$albums = Album::GetBySharename(array($albumName));
		$value = $albums[$albumName]['conversion'];

		self::$conversionCache->set($albumName, $value);

		return $value;
	}

	static function GetRefSharename($sharename)
	{
		$parts = explode('/', $sharename);
		if (count($parts) > 2) {
			return $parts[0].'/'.$parts[1];
		} else if (2 == count($parts) && $sharename != '/') {
			return $parts[0];
		} else {
			return $sharename;
		}
	}

	static function IsAllowedSocialUploadIdentity()
	{
		$isAdmin = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);
		$isUser = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']);

		if ($isAdmin ||
			($isUser && ('on' === csSYNOPhotoMisc::GetConfigDB("photo", "allow_guest_fb_upload", "photo_config"))) ||
			(!$isUser && ('on' === csSYNOPhotoMisc::GetConfigDB("photo", "allow_social_network_upload_guest", "photo_config")))) {
			return true;
		}

		return false;
	}

	static function PhotoCheckSynoToken()
	{
		if (empty(session_id())) {
			return true;
		}

		if (true !== $_SESSION[SYNOPHOTO_ADMIN_USER]['enable_syno_token']) {
			return true;
		}

		if ($_GET['SynoToken'] !== session_id() && $_SERVER['HTTP_X_SYNO_TOKEN'] !== session_id()) {
			unset($_SESSION[SYNOPHOTO_ADMIN_USER]);
			return false;
		}

		if (!self::CheckSessionIP()) {
			self::ClearSession();
			unset($_SESSION[SYNOPHOTO_ADMIN_USER]);
			return false;
		}

		return true;
	}

	/*
	 * Instead of session_start function to avoid
	 * set cookie with no expire time while second session_start
	 */
	static function PhotoSessionStart(){
		session_start();
		if(!empty($_COOKIE['PHPSESSID'])){
			//Avoid duplicate 'Set-Cookie'(PHPSESSID)
			header_remove('Set-Cookie');
		}
		if(!empty($_COOKIE['photo_remember_me'])){
			//php session_start send cookie with path(the third param),
			//setcookie need path to overwrite it
			setcookie('photo_remember_me', 1, time() + 60*60*24*30, '/');
			setcookie('PHPSESSID', session_id(), time() + 60*60*24*30, '/');
		}
	}
	// bug#4273, #4274
	static function RegenSessionId() {
		$res = session_regenerate_id(true);
		$newId = session_id();
		setcookie('PHPSESSID', $newId, 0, '/');
	}

	static function ClearSession() {
		header_remove('Set-Cookie');
		setcookie('PHPSESSID', '', 0, '/');
		setcookie('photo_remember_me', 0, 0, '/');
	}

	function EscapeArguments(array $parameters)
	{
		$escapedArguments = array();
		foreach ($parameters as $param) {
			$escapedArguments[] = escapeshellarg($param);
		}
		return $escapedArguments;
	}

	function ExecCmd($binaryPath, array $parameters, $passthru = false, &$buffer = NULL, $oneline = false)
	{
		$ret = -1;
		if (is_string($binaryPath) && is_array($parameters)) {
			$cmd = escapeshellarg($binaryPath) . ' ' . implode(' ', self::EscapeArguments($parameters));
			if ($passthru) {
				passthru($cmd, $ret);
			} else if ($oneline) {
				$buffer = shell_exec($cmd);
				$ret = 0;
			} else {
				exec($cmd, $buffer, $ret);
			}
		}
		return $ret;
	}

	function ExecCmdNoOutput($binaryPath, array $parameters, &$returnValue = null)
	{
		if (!is_string($binaryPath) || !is_array($parameters)) {
			return;
		}

		$cmd = escapeshellarg($binaryPath) . ' ' . implode(' ', self::EscapeArguments($parameters)) . ' > /dev/null 2>&1';
		@exec($cmd, $dummy, $returnValue);
	}

	public static function SetPriviegeShareIdListToSession(&$sessionArray, $shareids)
	{
		$sessionArray['privilege_share_ids'] = $shareids;
	}

	public static function SetPriviegeShareIdNoPasswordListToSession(&$sessionArray, $shareids)
	{
		$sessionArray['privilege_no_password_share_ids'] = $shareids;
	}

	public static function GetPriviegeShareIdNoPasswordListFromSession(&$sessionArray)
	{
		return $sessionArray['privilege_no_password_share_ids'];
	}

	public static function UpdatePriviegeShareIdNoPasswordListFromSession(&$sessionArray, $shareid)
	{
		if (in_array($shareid, $sessionArray['privilege_no_password_share_ids'])) {
			return;
		}

		$sessionArray['privilege_no_password_share_ids'][] = $shareid;
	}

	public static function GetPriviegeShareIdListFromSession(&$sessionArray)
	{
		return $sessionArray['privilege_share_ids'];
	}

	public static function SetPasswordAlbumsToSession(&$sessionArray, $password_album_list)
	{
		$sessionArray['password_album_list'] = $password_album_list;
	}
	public static function IsPasswordAlbumsFromSession(&$sessionArray, $key)
	{
		return array_key_exists($key, $sessionArray['password_album_list']);
	}
	public static function GetPasswordOfPasswordAlbumsFromSession(&$sessionArray, $key)
	{
		if (self::IsPasswordAlbumsFromSession($sessionArray, $key)) {
			return $sessionArray['password_album_list'][$key];
		}
		return '';
	}
	public static function ValidatePasswordFromSession(&$sessionArray, $album)
	{
		if (!self::IsPasswordAlbumsFromSession($sessionArray, $album)) {
			return false;
		}

		$password_value = self::GetPasswordOfPasswordAlbumsFromSession($sessionArray, $album);
		$entered_password_value = $sessionArray['password_pass_album'][$album];

		return ($password_value === $entered_password_value);
	}

	static function CheckAllowDownload() {
		$blAllowUserDownload = ('on' === csSYNOPhotoMisc::GetConfigDB("photo", "allow_user_download", "photo_config"));
		$blAllowGuestDownload = ('on' === csSYNOPhotoMisc::GetConfigDB("photo", "allow_guest_download", "photo_config"));

		if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			return true;
		} elseif ($blAllowGuestDownload) {
			return true;
		} elseif ($blAllowUserDownload && isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'])) {
			return true;
		}
		return false;
	}

	static function CheckLightboxDetail() {
		$blHideUserDetail = ('on' === csSYNOPhotoMisc::GetConfigDB("photo", "hide_user_lightbox_detail", "photo_config"));
		$blHideGuestDetail = ('on' === csSYNOPhotoMisc::GetConfigDB("photo", "hide_guest_lightbox_detail", "photo_config"));

		if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			return true;
		} elseif (!$blHideGuestDetail) {
			return true;
		} elseif (!$blHideUserDetail && isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'])) {
			return true;
		}
		return false;
	}

	static function GetMetaRobots() {
		$allow = ('on' === csSYNOPhotoMisc::GetConfigDB("global", "allow_search_engine_index", "photo_config"));

		if ($allow === true) {
			return '';
		} else {
			return '<meta name="robots" content="noindex,nofollow" />';
		}
	}

}
?>
