<?php
require_once ('photo/synophoto_csPhotoMisc.php');
require_once ('advanced_shared_album.php');

class SharedAlbum {
	public static function GetInfoById($sharedAlbumId, $userid, $additional = array())
	{
		if ($sharedAlbumId === NULL) {
			return NULL;
		}

		$table = SHARED_ALBUM_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$table = SHARED_ALBUM_ADMIN_TABLE_NAME;
		}

		$sqlParams = array($sharedAlbumId);
		$query = "SELECT * FROM " . $table . " WHERE id = ?";
		if (!PHOTO_DB_IsAdminUid($userid)) {
			$query .= " AND userid = ?";
			$sqlParams[] = $userid;
		}
		$db_result = PHOTO_DB_Query($query, $sqlParams);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}

		$sharedAlbum['id'] = 'sharedalbum_'.$row['id'];
		$sharedAlbum['userid'] = $userid;
		$sharedAlbum['type'] = "sharedalbum";
		$sharedAlbum['name'] = $row['name'];
		$shareStatus = self::CheckShareStatus($row);
		$sharedAlbum['share_status'] = $shareStatus;
		$sharedAlbum['additional'] = array();

		if (in_array("public_share", $additional)) {
			$publicShareInfo['share_status'] = $shareStatus;
			$publicShareInfo['start_time'] = $row['start_time'];
			$publicShareInfo['end_time'] = $row['end_time'];
			$publicShareInfo['shareid'] = $row['sharelink'];
			if ($shareStatus === 'valid') {
				$publicShareInfo['public_share_url'] = csSYNOPhotoMisc::GetServerHost(true). SYNOPHOTO_URL_PREFIX ."/photo/share/" . $row['sharelink'];
			}
			if (PHOTO_DB_IsTrue($row['is_advanced'])) {
				$advancedInfo = AdvancedSharedAlbum::GetAdvancedInfoById($row['id']);
				$publicShareInfo['is_advanced'] = PHOTO_DB_IsTrue($row['is_advanced']);
				$publicShareInfo['advanced_info'] = $advancedInfo;
			}

			$sharedAlbum['additional']['public_share'] = $publicShareInfo;
		}

		$sharedAlbum['thumbnail_status'] = 'default';
		$thumbSize['preview']['resolutionx'] = 0;
		$thumbSize['preview']['resolutiony'] = 0;
		$thumbSize['small']['resolutionx'] = 0;
		$thumbSize['small']['resolutiony'] = 0;
		$thumbSize['large']['resolutionx'] = 0;
		$thumbSize['large']['resolutiony'] = 0;
		$thubmSize['sig'] = "";
		if (in_array("thumb_size", $additional)) {
			$sharedAlbum['additional']['thumb_size'] = $thumbSize;
		}
		$sharedAlbum['shareid'] = $row['shareid'] + 0;
		$sharedAlbum['recursive'] = PHOTO_DB_IsTrue($row['recursive']);

		return $sharedAlbum;
	}

	public static function GetInfoByPublicShare($publicShareId, $needHiddenInfo = false)
	{
		$selectField = 'id, name, is_shared, start_time, end_time, hidden, is_advanced, shareid, recursive';
		$sql = "SELECT $selectField, 0 as userid FROM " . SHARED_ALBUM_ADMIN_TABLE_NAME . " WHERE sharelink = ? UNION ALL SELECT $selectField, userid FROM " . SHARED_ALBUM_TABLE_NAME . " WHERE sharelink = ?";
		$sqlParam = array($publicShareId, $publicShareId);
		$db_result = PHOTO_DB_Query($sql, $sqlParam);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}
		$result['id'] = (int)$row['id'];
		$result['userid'] = $row['userid']; // cannot cast to int due to Domain uid may be greater than 2G
		$result['name'] = $row['name'];
		$shareStatus = self::CheckShareStatus($row);
		$hasComment = self::CheckCommentStatus($result['id'], $result['userid']);
		if ($needHiddenInfo) {
			$result['hidden'] = PHOTO_DB_IsTrue($row['hidden']);
		}
		$result['share_status'] = $shareStatus;
		$result['shareid'] = $row['shareid'] + 0;
		$result['recursive'] = PHOTO_DB_IsTrue($row['recursive']);
		$result['is_advanced'] = PHOTO_DB_IsTrue($row['is_advanced']);
		$result['has_comment'] = $hasComment;

		if ($result['is_advanced']) {
			$advancedInfo = AdvancedSharedAlbum::GetAdvancedInfoById($result['id'], $result['userid']);
			$result['advanced_info'] = $advancedInfo;
		}

		return $result;
	}

	public static function GetSharedAlbumCover($sharedAlbumId = NULL, $publicShareId = NULL)
	{
		if ($sharedAlbumId === NULL && $publicShareId === NULL) {
			return NULL;
		}

		if (NULL !== $sharedAlbumId) {
			$userid = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : 0;
			$table = SHARED_ALBUM_TABLE_NAME;
			if (PHOTO_DB_IsAdminUid($userid)) {
				$table = SHARED_ALBUM_ADMIN_TABLE_NAME;
			}
			$query = "SELECT * FROM $table WHERE id = ?";
			$sqlParam = array($sharedAlbumId);
			if (!PHOTO_DB_IsAdminUid($userid)) {
				$query .= " AND userid = ?";
				$sqlParam[] = $userid;
			}
			$db_result = PHOTO_DB_Query($query, $sqlParam);
			$row = PHOTO_DB_FetchRow($db_result);
			if (!$row) {
				return NULL;
			}
			$shareid = $row['shareid'] + 0;
		} else if ('' !== $publicShareId) {
			// filter by public share link, check public share is existent and valid
			$publicShareInfo = self::GetInfoByPublicShare($publicShareId);
			if (NULL === $publicShareInfo || 'valid' !== $publicShareInfo['share_status']) {
				return NULL;
			}
			$sharedAlbumId = (int)$publicShareInfo['id'];
			$userid = $publicShareInfo['userid'];
			$shareid = $publicShareInfo['shareid'];
		}

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat('A', $publicShareId);
		if (!$albumCondition['albumCond']) {
			return NULL;
		}

		if ($shareid) {
			$result = self::GetSingleSharedAlbumCover($sharedAlbumId, $publicShareId, $shareid);
		} else {
			$PublicSharePhotoTable = SHARED_ALBUM_PHOTO_TABLE_NAME;
			$PublicShareVideoTable = SHARED_ALBUM_VIDEO_TABLE_NAME;
			if (PHOTO_DB_IsAdminUid($userid)) {
				$PublicSharePhotoTable = SHARED_ALBUM_PHOTO_ADMIN_TABLE_NAME;
				$PublicShareVideoTable = SHARED_ALBUM_VIDEO_ADMIN_TABLE_NAME;
			}

			$sqlParam = array();
			$photoQuery = "SELECT  A.path as path, A.name as filename, A.timetaken as takendate, A.create_time as createdate, 'photo' as type FROM photo_image A, $PublicSharePhotoTable B WHERE A.id = B.photoid AND B.collectionid = ?";
			$sqlParam[] = $sharedAlbumId;

			$photoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$videoQuery = "SELECT  A.path as path, A.title as filename, A.mdate as takendate, A.date as createdate, 'video' as type FROM video A, $PublicShareVideoTable B WHERE A.id = B.videoid AND B.collectionid = ?";
			$sqlParam[] = $sharedAlbumId;
			$videoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$query = "$photoQuery UNION ALL $videoQuery ORDER BY createdate DESC LIMIT 1";

			$db_result = PHOTO_DB_Query($query, $sqlParam);
			$row = PHOTO_DB_FetchRow($db_result);
			if (!$row) {
				return NULL;
			}
			$result = array(
				"path" => $row['path'],
				"type" => $row['type']
			);
		}
		return $result;
	}

	private static function GetSingleSharedAlbumCover($sharedAlbumId, $publicShareId, $shareid)
	{
		$sqlParam = array();
		$query = "SELECT shareid, sharename as sharename from photo_share where shareid = ?";
		$sqlParam[] = $shareid;

		$db_result = PHOTO_DB_Query($query, $sqlParam);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}

		$albumName = $row['sharename'];
		$albumId = $row['shareid'];

		$result = self::GetUserDefinedCoverWithoutSub($albumName, $albumId);

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat('', $publicShareId);
		$sqlParam = array();
		if (!$result) {
			$photoQuery = "SELECT path, name as filename, timetaken as takendate, create_time as createdate, 'photo' as type FROM photo_image WHERE shareid = ?";
			$sqlParam[] = $albumId;
			$photoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$videoQuery = "SELECT path, title as filename, mdate as takendate, date as createdate, 'video' as type FROM video WHERE shareid = ?";
			$sqlParam[] = $albumId;
			$videoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$query = "$photoQuery UNION ALL $videoQuery ORDER BY createdate DESC LIMIT 1";
			$db_result = PHOTO_DB_Query($query, $sqlParam);
			$row = PHOTO_DB_FetchRow($db_result);
			if (!$row) {
				return NULL;
			}

			$result = array(
				"path" => $row['path'],
				"type" => $row['type']
			);
		}
		return $result;
	}

	private static function GetUserDefinedCoverWithoutSub($albumName, $albumId)
	{
		$result = '';
		$fullDirPath = sprintf("%s/%s", SYNOPHOTO_SERVICE_DIR, $albumName);
		if (false === SYNOPhotoEA::checkFilePath($fullDirPath, SYNOPhotoEA::FILE_ALBUM_COVER, $coverFile)) {
			return false;
		}
		if (false === ($result = @file_get_contents($coverFile))) {
			return false;
		}

		$cover_path = trim(SYNOPHOTO_SERVICE_REAL_DIR."/{$albumName}/".$result);
		$type = '';

		if (!@is_file($cover_path)) {
			return false;
		}

		if (preg_match('/\/~[^\/]+/', $_SERVER['REQUEST_URI'], $matches)){
			$cover_path = "{$albumName}/".$result;
		}

		// Check define cover is in the same album
		if (!empty($cover_path)) {
			if (csSYNOPhotoMisc::IsPhotoFile($cover_path)) {
				$type = 'photo';
				$query = "SELECT * FROM photo_image WHERE path = ? AND shareid = ?";
				$sqlParam = array($cover_path, $albumId);
			} else {
				$type = 'video';
				$query = "SELECT * FROM video WHERE path = ? AND shareid = ?";
				$sqlParam = array($cover_path, $albumId);
			}

			$db_result = PHOTO_DB_QUERY($query, $sqlParam);
			$row = PHOTO_DB_FetchRow($db_result);
			if (!$row) {
				$result = NULL;
			} else {
				$result = array(
					"path" => $cover_path,
					"type" => $type
				);
			}
		}

		return $result;
	}

	public static function CheckSharedAlbumItemValid($filePath, $type, $publicShareId)
	{
		if ($filePath === NULL || $publicShareId === NULL) {
			return false;
		}
		$dbPath = SYNOPHOTO_SERVICE_REAL_DIR_PATH.$filePath;

		$publicShareInfo = self::GetInfoByPublicShare($publicShareId);
		if ($publicShareInfo === NULL) {
			return false;
		}
		$db_object = 'photo' == $type ? File::GetPhotoByDBPath([$dbPath])[$dbPath] : File::GetVideoByDBPath([$dbPath])[$dbPath];
		if (!$db_object) {
			return false;
		}

		$is_admin_user = PHOTO_DB_IsAdminUid($publicShareInfo['userid']);
		if ($publicShareInfo['shareid']) {
			return $publicShareInfo['shareid'];
		} else {
			return self::CheckSharedAlbumItemValidByDBId($db_object['id'], $type, $publicShareInfo['id'], $is_admin_user);
		}
	}

	private static function CheckSharedAlbumItemValidByDBId($item_db_id, $type, $publicShareId, $use_admin_table)
	{
		if ($type === NULL) {
			return false;
		}

		if ('photo' === $type) {
			$tableName = $use_admin_table ? SHARED_ALBUM_PHOTO_ADMIN_TABLE_NAME : SHARED_ALBUM_PHOTO_TABLE_NAME;
		} else if ('video' === $type) {
			$tableName = $use_admin_table ? SHARED_ALBUM_VIDEO_ADMIN_TABLE_NAME : SHARED_ALBUM_VIDEO_TABLE_NAME;
		} else {
			return false;
		}
		$query = "SELECT 1 FROM $tableName WHERE collectionid = ? AND {$type}id = ?";
		$sqlParam = array($publicShareId, $item_db_id);
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return false;
		}
		return true;
	}

	public static function CheckPublicSharePermission($publicShareId = NULL)
	{
		$sessionArray = &$_SESSION[SYNOPHOTO_ADMIN_USER];
		if (NULL !== $publicShareId) {
			if (!isset($_SESSION[$publicShareId])) {
				return false;
			}
			$sessionArray = &$_SESSION[$publicShareId];
		}
		$publicSharingPriviege = (int)csSYNOPhotoMisc::GetConfigDB("photo", "public_sharing_privilege", "photo_config");

		$allow_public_share = false;
		if (isset($sessionArray['admin_syno_user'])) {
			// admin
			$allow_public_share = true;
		} else if ($publicSharingPriviege === 1 && isset($sessionArray['reg_syno_userid'])) {
			// all user
			$allow_public_share = true;
		} else if ($publicSharingPriviege === 2) {
			if (isset($sessionArray['reg_syno_userid'])) {
				$query = "SELECT COUNT(*) FROM " . SHARED_ALBUM_USER_PRIVILEGE_TABLE_NAME . " WHERE userid = ?";
				$db_result = PHOTO_DB_Query($query, array($sessionArray['reg_syno_userid']));
				$row = PHOTO_DB_FetchRow($db_result);
				if ($row[0] > 0) {
					$allow_public_share = true;
				}
			}
			if (!empty($sessionArray['reg_syno_groupid'])) {
				$query = "SELECT COUNT(*) FROM " . SHARED_ALBUM_GROUP_PRIVILEGE_TABLE_NAME . " WHERE groupid IN (" . $sessionArray['reg_syno_groupid'] . ")";

				$db_result = PHOTO_DB_Query($query);
				$row = PHOTO_DB_FetchRow($db_result);
				if ($row[0] > 0) {
					$allow_public_share = true;
				}
			}
		}
		return $allow_public_share;
	}

	public static function GetHiddenAlbumInfo($publicShareId = NULL, $additional = array('public_share'), $createNew = true)
	{
		if ($publicShareId !== NULL) {
			$sharedAlbum = self::GetInfoByPublicShare($publicShareId, true);
			if ($sharedAlbum === NULL || !$SharedAlbum['hidden']) {
				return NULL;
			}
		} else {
			$userid = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : 0;
			$table = SHARED_ALBUM_TABLE_NAME;
			if (PHOTO_DB_IsAdminUid($userid)) {
				$table = SHARED_ALBUM_ADMIN_TABLE_NAME;
			}
			$query = "SELECT id FROM " . $table . " WHERE hidden = 't'";
			$sqlParams = array();
			if (!PHOTO_DB_IsAdminUid($userid)) {
				$query .= " AND userid = ?";
				$sqlParams[] = $userid;
			}
			$db_result = PHOTO_DB_Query($query, $sqlParams);
			$row = PHOTO_DB_FetchRow($db_result);
			if (!$row) {
				return $createNew ? self::CreateHiddenAlbum($additional) : NULL;
			}
			$sharedAlbum = self::GetInfoById($row['id'], $userid, $additional);
		}
		if ($sharedAlbum !== NULL) {
			$sharedAlbum['name'] = __(photo_str_single_item_shared_album);
		}
		return $sharedAlbum;
	}

	private static function CheckShareStatus($row)
	{
		$shareStatus = "none";
		if (PHOTO_DB_IsTrue($row['is_shared'])) {
			$shareStatus = "valid";
		}
		if ($row['start_time'] !== NULL && $row['end_time'] !== NULL) {
			$timeNow = new DateTime();
			$startDate = new DateTime($row['start_time']);
			$endDate = new DateTime($row['end_time']);
			$endDate->modify('+1 day');
			if ($timeNow < $startDate) {
				$shareStatus = "invalid";
			} else if ($timeNow >= $endDate) {
				$shareStatus = "expired";
			}
		}
		return $shareStatus;
	}

	private static function CheckCommentStatus($shareAlbumId, $userid)
	{
		$itemTable = SHARED_ALBUM_ADVANCED_ITEM_TABLE_NAME;
		$commentTable = SHARED_ALBUM_ADVANCED_COMMENT_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$itemTable = SHARED_ALBUM_ADVANCED_ITEM_ADMIN_TABLE_NAME;
			$commentTable = SHARED_ALBUM_ADVANCED_COMMENT_ADMIN_TABLE_NAME;
		}
		$query = "SELECT 1 FROM $commentTable A LEFT JOIN $itemTable B ON A.advanced_item_id = B.id where B.collectionid = ?";
		$res = PHOTO_DB_Query($query, array($shareAlbumId));
		$row = PHOTO_DB_FetchRow($res);
		if (!$row[0]) {
			return false;
		}
		return true;
	}

	public static function CreateHiddenAlbum($additional = array())
	{
		$userid = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : 0;
		$table = SHARED_ALBUM_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$table = SHARED_ALBUM_ADMIN_TABLE_NAME;
		}
		$sqlParams = array();
		do {
			$shareLink = self::GetRandomString();
		} while (self::CheckExistenceBySharelink($shareLink));

		if (!PHOTO_DB_IsAdminUid($userid)) {
			$query = "INSERT INTO " . $table . " (userid, name, sharelink, is_shared, hidden) VALUES (?, ?, ?, 't', 't')";
			$sqlParams = array($userid, 'hidden_album', $shareLink);
		} else {
			$query = "INSERT INTO " . $table . " (name, sharelink, is_shared, hidden) VALUES (?, ?, 't', 't')";
			$sqlParams = array('hidden_album', $shareLink);
		}
		$db_result = PHOTO_DB_Query($query, $sqlParams);

		return self::GetHiddenAlbumInfo(NULL, $additional, false);
	}

	public static function CheckExistenceBySharelink($sharelink)
	{
		$sqlParams = array($sharelink, $sharelink);
		$forDsmTableQuery = "";
		if ('root' === SYNOPHOTO_ADMIN_USER) {
			$forDsmTableQuery = " UNION ALL SELECT COUNT(*) AS rows FROM photo_personal_collection_for_dsm_account WHERE sharelink = ?";
			$sqlParams[] = $sharelink;
		}
		$query = "SELECT SUM(rows) FROM ( SELECT COUNT(*) AS rows FROM photo_personal_collection WHERE sharelink = ? UNION ALL SELECT COUNT(*) AS rows FROM photo_personal_collection_for_admin WHERE sharelink = ? $forDsmTableQuery) AS rowsum";
		$db_result = PHOTO_DB_Query($query, $sqlParams);
		$row = PHOTO_DB_FetchRow($db_result);
		if (1 === (int)$row[0]) {
			return TRUE;
		}

		return FALSE;
	}

	public static function GetRandomString($length = 8)
	{
		$validCharacters = "abcdefghijklmnopqrstuxyvwzABCDEFGHIJKLMNOPQRSTUXYVWZ0123456789";
		$validCharNumber = strlen($validCharacters);

		$result = "";
		for ($i = 0; $i < $length; $i++) {
			$index = mt_rand(0, $validCharNumber - 1);
			$result .= $validCharacters[$index];
		}

		return $result;
	}

	private static function getSharedAlbumInfoById($sharedAlbumId)
	{
		$sharedAlbum = array();
		$userid = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : 0;
		$table = SHARED_ALBUM_TABLE_NAME;
		if (PHOTO_DB_IsAdminUid($userid)) {
			$table = SHARED_ALBUM_ADMIN_TABLE_NAME;
		}
		$query = "SELECT * FROM $table WHERE id = ?";
		$sqlParam = array($sharedAlbumId);
		if (!PHOTO_DB_IsAdminUid($userid)) {
			$query .= " AND userid = ?";
			$sqlParam[] = $userid;
		}
		$db_result = PHOTO_DB_Query($query, $sqlParam);
		$row = PHOTO_DB_FetchRow($db_result);
		if (!$row) {
			return NULL;
		}
		$sharedAlbum['collectionid'] = $row['id'];
		$sharedAlbum['name'] = $row['name'];
		$sharedAlbum['share_status'] = self::CheckShareStatus($row);
		$sharedAlbum['public_share_id'] = $row['sharelink'];
		$sharedAlbum['is_advanced'] = PHOTO_DB_IsTrue($row['is_advanced']);

		return $sharedAlbum;
	}

	public static function getItemsInSharedAlbum($sharedAlbumId)
	{
		$items = array();
		$sharedAlbum = self::getSharedAlbumInfoById($sharedAlbumId);

		$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat('A');
		$PublicSharePhotoTable = SHARED_ALBUM_PHOTO_TABLE_NAME;
		$PublicShareVideoTable = SHARED_ALBUM_VIDEO_TABLE_NAME;

		if (PHOTO_DB_IsAdminUid($userid)) {
			$PublicSharePhotoTable = SHARED_ALBUM_PHOTO_ADMIN_TABLE_NAME;
			$PublicShareVideoTable = SHARED_ALBUM_VIDEO_ADMIN_TABLE_NAME;
		}

		if ($sharedAlbum['shareid']) {
		} else {
			$sqlParam = array();
			$photoQuery = "SELECT A.id as id, 'photo' as type FROM photo_image A, $PublicSharePhotoTable B WHERE A.id = B.photoid AND B.collectionid = ?";
			$sqlParam[] = $sharedAlbumId;
			$photoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$videoQuery = "SELECT A.id as id, 'video' as type FROM video A, $PublicShareVideoTable B WHERE A.id = B.videoid AND B.collectionid = ?";
			$sqlParam[] = $sharedAlbumId;
			$videoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$query = "$photoQuery UNION ALL $videoQuery";
			$db_result = PHOTO_DB_Query($query, $sqlParam);
			while ($row = PHOTO_DB_FetchRow($db_result)) {
				$item['item_id'] = (int)$row['id'];
				$item['type'] = $row['type'];
				$items[] = $item;
			}
		}

		return $items;
	}

	public static function HasPasswordAncestorAlbum($sharedAlbum)
	{
		if(!$sharedAlbum['shareid']) {
			return false;
		}

		$albums = Album::GetByShareId(array($sharedAlbum['shareid']));
		if (count($albums) === 0) {
			return false;
		}

		$tokens = explode("/", $albums[0]['sharename']);
		if (count($tokens) === 0) {
			return false;
		}

		$sharenames = array($tokens[0]);
		if (count($tokens) >= 2) {
			$sharenames[] = join('/', array_slice($tokens, 0, 2));
		}

		$ancestor_albums = Album::GetBySharename($sharenames);
		foreach ($ancestor_albums as &$album) {
			if ($album['password'] !== '') {
				return true;
			}
		}
		return false;
	}
}
?>
