<?php
require_once(dirname(__FILE__).'/file.php');

class SlideshowMusic {
	const LIMIT = 10;
	const MusicJSON = "SYNOPHOTO_MUSIC_CONFIG";
	const MusicNamePrefx = "SYNOPHOTO_MUSIC_";
	const DefaultMusicId = "SYNOPHOTO_MUSIC_DEFAULT";
	const DefaultMusicPath = "target/photo/photo_new/mp3/peaceful-now.mp3";

	private static $data;
	private static $last_insert_data;

	public static function Add($filename, $source, $title = '', $user = '')
	{
		$data = self::GetMusicData();

		$id = self::GetMusicId();

		if (NULL === $id) {
			return false;
		}

		// a.mp3 , a.b.mp3
		$ext = pathinfo($filename, PATHINFO_EXTENSION);

		$eaDir = self::GetEADir();
		$dest = $eaDir.'/'."$id.".strtolower($ext);

		if (!self::CopyMusic($source, $dest, $user)) {
			return false;
		}

		$info = self::MusicFileInfo($filename, $dest);

		$data[$id] = array(
			'title' => $title ? $title : $info['title'],
			'default' => false
		);

		if (!self::WriteMusicFile($data)) {
			return false;
		}
		self::$last_insert_data = array(
			'id' => $id,
			'title'	=> $data[$id]['title']
		);
		return true;
	}

	public static function GetCount()
	{
		$data = self::GetMusicData();
		return count(array_keys($data));
	}

	public static function CopyMusic($tmpPath, $destPath, $user = '')
	{
		$res = true;
		if (is_uploaded_file($tmpPath)) {
			if (!@move_uploaded_file($tmpPath, $destPath)) {
				$res = false;
				goto End;
			}
		} else {
			if (!$user) {
				$res = false;
				goto End;
			}
			if (!File::CopyMusic($user, $tmpPath, $destPath)) {
				$res = false;
				goto End;
			}
		}

		@chmod($destPath, 0777);

	End:
		return $res;
	}

	public static function GetLastInsertMusic()
	{
		return self::$last_insert_data;
	}

	public static function GetMusicId()
	{
		$dataKeys = array_keys(self::GetMusicData());
		$range = range(0, 9, 1);

		foreach ($range as $i) {
			if (!in_array(self::MusicNamePrefx.$i, $dataKeys)) {
				goto End;
			}
		}
		return null;

	End:
		return self::MusicNamePrefx.$i;
	}

	public static function DeleteById ($ids)
	{
		$data = self::GetMusicData();

		if(!$ids) {
			return false;
		}

		$eaDir = self::GetEADir();

		$modified = 0;
		foreach ($ids as $k) {
			if (array_key_exists($k, $data)) {
				unset($data[$k]);
				if ($k !== self::DefaultMusicId) {
					unlink($eaDir.'/'."$k.mp3");
				}
				$modified = 1;
			}
		}

		if (!$modified) {
			return false;
		}
		return self::WriteMusicFile($data);
	}

	public static function EditById ($filename, $title, $default)
	{
		$data = self::GetMusicData();

		if (!array_key_exists($filename, $data)) {
			return false;
		}

		if ($title) {
			$data[$filename]['title'] = $title;
		}

		if (NULL !== $default) {
			if ($default) {
				foreach ($data as $k => $v) {
					$data[$k]['default'] = false;
				}
			}
			$data[$filename]['default'] = $default ? true : false;
		}

		return self::WriteMusicFile($data);
	}

	public static function ListItem ($offset = 0, $limit = NULL)
	{
		$data = self::GetMusicData();
		uasort($data, function($a, $b) {
			return strnatcasecmp($a['title'], $b['title']);
		});

		return array('data' => array_slice($data, $offset, $limit, true),
					 'total' => count($data));
	}

	static function WriteMusicFile($data)
	{
		$eaDir = self::GetEADir();
		$musicFile = $eaDir.'/'.self::MusicJSON;

		if (!$music = json_encode($data)) {
			return false;
		}

		//beautify json string
		$content = csSYNOPhotoMisc::indentJson($music);

		//put contents to smart album config file
		if (!@file_put_contents($musicFile, $content)) {
			return false;
		}

		self::$data = $data;
		return true;
	}

	static function GetMusicData ()
	{
		if(!self::$data) {
			self::$data = self::ReadMusicFile();
		}
		return self::$data;
	}

	static function ReadMusicFile ()
	{
		$eaDir = self::GetEADir();
		$musicFile = $eaDir.'/'.self::MusicJSON;

		if (!@file_exists($musicFile)) {
			return array();
		}

		//get contents from smart album config file
		if (!$musicFileJSON = @file_get_contents($musicFile)) {
			return array();
		}

		//parse contents
		if (!$music = json_decode($musicFileJSON, true)) {
			return array();
		}

		$res = array();

		foreach ($music as $k => $v) {
			$res[$k] = array(
				'title' => $v['title'],
				'default' => $v['default'] ? true : false
			);
		}
		return $res;
	}

	static function GetMusicPath ($id)
	{
		$data = self::GetMusicData();

		if (!array_key_exists($id, $data)) {
			return false;
		}
		if ($id === self::DefaultMusicId) {
			$path = SYNO_PKG_DIR."/". self::DefaultMusicPath;
		} else {
			$eaDir = self::GetEADir();
			$path = $eaDir.'/'.$id.".mp3";
		}

		if (!file_exists($path)) {
			return false;
		}

		return $path;
	}

	static function MusicFileInfo($filename, $path)
	{
		// a.mp3 , a.b.mp3

		$file = explode('.', $filename);
		$ext = array_pop($file);

		//$cmd = sprintf('/usr/syno/bin/synophoto_music -t %s', escapeshellarg($path));
		//$result = exec($cmd, $ret);
		$result = '';
		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_music', array('-t', $path), false, $result);
		$result = $result[count($result) - 1];

		return array(
			"ext" => strtolower($ext),
			"title" => $result ? $result : implode('.', $file)
		);
	}

	static private function GetEADir()
	{
		$eaDir = SYNOPHOTO_SERVICE_DIR."/".SYNOPHOTO_EADIR;

		//create @eaDir
		if(!@file_exists($eaDir)) {
			@mkdir($eaDir);
		}
		return $eaDir;
	}
}
