<?php
require_once("include/syno_conf.php");

$publicShareId = NULL;
if (isset($_GET['shareid'])) {
	$publicShareId = $_GET['shareid'];
}

// itemid should be like album_{hex} or photo_{hex}_{hex}
function validateItemId($id) {
	$info = explode('_', $id);
	$len = count($info);
	if (($len != 2) && ($len != 3)) {
		return false;
	}
	if (!preg_match('/^[a-z]+$/i', $info[0])) {
		return false;
	}
	for ($i = 1; $i < $len; ++$i) {
		if (!preg_match('/^[a-f0-9]+$/i', $info[$i])) {
			return false;
		}
	}
	return true;
}

$itemId = NULL;
if (isset($_GET['itemid']) && validateItemId($_GET['itemid'])) {
	$itemId = $_GET['itemid'];
}

if (csSYNOPhotoMisc::checkRedirectToHttps()) {
	csSYNOPhotoMisc::RedirectToHttps();
	exit();
}

if (!csSYNOPhotoDB::GetDBInstance()->SetPublicShareSessionCache($publicShareId, true) || !SharedAlbum::CheckPublicSharePermission($publicShareId)) {
	show404Page();
}

$sharedAlbum = SharedAlbum::GetInfoByPublicShare($publicShareId, true);
if ($sharedAlbum === NULL || ($itemId === NULL && $sharedAlbum['hidden'] === true )) {
	show404Page();
}

if (SharedAlbum::HasPasswordAncestorAlbum($sharedAlbum)) {
	show404Page();
}

if (NULL !== $itemId) {
	if ($sharedAlbum['hidden'] !== true) {
		show404Page();
	}
	$id_arr = explode('_', $itemId);
	$type = $id_arr[0];
	if (count($id_arr) !== 3 || ($type !== 'photo' && $type !== 'video')) {
		show404Page();
	}
	$albumName = @pack('H*', $id_arr[1]);
	$fileName = @pack('H*', $id_arr[2]);
	$filePath = ('/' === $albumName ? "" : $albumName . "/") . $fileName;
	if (!csSYNOPhotoMisc::CheckAlbumAccessible($albumName, false, $publicShareId)) {
		show404Page();
	}
	if (!SharedAlbum::CheckSharedAlbumItemValid($filePath, $id_arr[0], $publicShareId)) {
		show404Page();
	}
}

$mobileUAPattern = '/Android|webOS|iPhone|iPad|iPod|BlackBerry|Opera Mini|IEMobile|windows phone os 7|windows phone 8/i';
$userAgent = isSet($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
$mobileUI = false;
if (!isSet($_GET['forceDesktop']) && preg_match($mobileUAPattern, $userAgent)) {
	$mobileUI = true;
}
$LANGUEGE = $_SESSION[SYNOPHOTO_ADMIN_USER]['lang'];
$DEBUG = isset($_GET['jsDebug']);
$PAGE_TITLE = "Photo Station 6";

// TODO: get fb/g+ share data
$SHARE_DATA = GetShareData();

require_once('include/content_security_policy.php');
?>
<!DOCTYPE html>
<html>
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
	<meta http-equiv="X-UA-Compatible" content="IE=11" />
<?php
	if ($mobileUI) {
		echo '<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">';
	}
?>
	<?php echo csSYNOPhotoMisc::GetMetaRobots(); ?>

	<!-- Open Graph sharing meta tags -->
	<meta property="og:type" content="<?php echo $SHARE_DATA['type'] ?>" />
	<meta property="og:title" content="<?php echo $SHARE_DATA['title'] ?>" />
	<meta property="og:description" content="<?php echo $SHARE_DATA['description'] ?>" />
	<meta property="og:image" content="<?php echo $SHARE_DATA['img'] ?>" />

	<!-- javascript -->
<?php
	$mobileParameter = "&mobile=" . ($mobileUI ? "true" : "false");
	$shareIdParameter = "&share_id=$publicShareId";
	$itemIdParameter = "&item_id=" . ($itemId === null ? "" : $itemId);
	$jsFiles = array(
		"js_php/prevent_iframe.js.php",
		"scripts/uistrings.php?ln=$LANGUEGE",
		"photo_new/jquery-1.11.0.min.js",
		"photo_new/flux.min.js",
		"scripts/ext-3/adapter/ext/ext-base.js",
		"scripts/ext-3/ext-all.js",
		"scripts/ext-3/ux/ux-all.js",
		"scripts/scrollbar/flexcroll.js",
		"include/client_string.php?ln=$LANGUEGE",
		"jwplayer/jwplayer.js",

		"js_php/share.js.php?demo_mode=false$shareIdParameter$mobileParameter$itemIdParameter",

		"photo_new/syno_photo_share.js"
	);

	$prefix = "/photo/";
	foreach ($jsFiles as $item) {
		printf(
			"\t" . '<script type="text/javascript" src="%s%s"></script>' . "\n",
			$prefix . csSynoPhotoMisc::GetFileWithMtime($item), ($DEBUG === true) ? '&_dc='.time() : ''
		);
	}
?>

	<!-- style sheet -->
<?php
	$cssFiles = array(
		"scripts/ext-3/resources/css/ext-all.css",
		"scripts/ext-3/ux/ux-all-default.css",
		"include/custom_css.php",
		"photo_new/css/style.css",
		"photo_new/css/style_share.css"
	);

	$prefix = "/photo/";
	foreach ($cssFiles as $item) {
		printf(
			"\t" . '<link rel="stylesheet" type="text/css" href="%s%s" />' . "\n",
			$prefix . csSynoPhotoMisc::GetFileWithMtime($item), ($DEBUG === true) ? '&_dc='.time() : ''
		);
	}
?>
	<link rel="shortcut icon" href="favicon.ico">

	<title><?php echo $PAGE_TITLE ?></title>
</head>
<body class="<?php echo $mobileUI ? "share-mobile" : ""; ?>">
	<form id="history-form" class="x-hidden">
		<input type="hidden" id="x-history-field" />
		<iframe id="x-history-frame"></iframe>
	</form>
</body>
</html>

<?php

function GetShareData()
{
	global $publicShareId, $itemId;
	$token = "";
	if (isset($_GET['_escaped_fragment_'])) {
		$token = $_GET['_escaped_fragment_'];
	} else if ($itemId !== NULL) {
		// Get Single Item OG
		$token = "/" . $itemId;
	}
	$parts = explode("/", $token);

	$data = false;
	$publicShareInfo = SharedAlbum::GetInfoByPublicShare($publicShareId);
	if (NULL === $publicShareInfo || 'valid' !== $publicShareInfo['share_status']) {
		goto End;
	}

	if (count($parts) >= 2 && (0 === strpos($parts[1], "photo_") || 0 === strpos($parts[1], "video_"))) {
		$idParts = explode("_", $parts[1]);
		$data = GetPhotoVideoShareData($idParts[1], $idParts[2]);
	} else {
		$data = array(
			'type' => 'album',
			'title' => htmlspecialchars($publicShareInfo['name']),
			'description' => '',
			'img' => GetThumbUrl()
		);
	}
End:
	if (false === $data) {
		$data = GetDefaultShareData();
	}
	return $data;
}

function GetThumbUrl($id = NULL)
{
	global $publicShareId;

	$params = array(
		'api' => 'SYNO.PhotoStation.Thumb',
		'version' => 1,
		'method' => 'get',
		'size' => 'small',
	);

	if (NULL === $id) {
		$params['id'] = 'publicshare_'.$publicShareId;
	} else {
		$params['id'] = $id;
		$params['public_share_id'] = $publicShareId;
	}

	return csSYNOPhotoMisc::GetServerHost().SYNOPHOTO_URL_PREFIX.'/photo/webapi/thumb.php?' . http_build_query(
		$params,
		'',
		'&'
	);
}

function GetDefaultShareData()
{
	global $PAGE_TITLE;

	$desc = csSYNOPhotoDB::GetDBInstance()->GetConfig('main', 'main_page_desc');
	if (empty($desc) || $desc === __(photo_str_add_description)) {
		$desc = '';
	}

	return array(
		'type' => 'album',
		'title' => $PAGE_TITLE,
		'description' => $desc,
		'img' => "/photo/photo_new/images/White/logo_ps6.png"
	);
}

function GetPhotoVideoShareData($album, $file)
{
	global $publicShareId;

	$albumName = @pack('H*', $album);
	$fileName = @pack('H*', $file);

	$path = realpath(SYNOPHOTO_SERVICE_REAL_DIR . "/" . $albumName . "/" . $fileName);

	if (0 !== strncmp($path, SYNOPHOTO_SERVICE_REAL_DIR . "/", strlen(SYNOPHOTO_SERVICE_REAL_DIR) + 1)) {
		return false;
	}
	if (!@file_exists($path)) {
		return false;
	}
	if (!csSYNOPhotoMisc::CheckAlbumAccessible($albumName, false, $publicShareId)) {
		return false;
	}

	$isPhoto = csSYNOPhotoMisc::IsPhotoFile($path);
	if ($albumName === '/') {
		$dbPath = SYNOPHOTO_SERVICE_REAL_DIR_PATH. $fileName;
	} else {
		$dbPath = SYNOPHOTO_SERVICE_REAL_DIR_PATH. $albumName . "/" . $fileName;
	}

	if ($isPhoto) {
		$type = 'album';
		$items = File::GetPhotoByDBPath(array($dbPath));
		$info = $items[$dbPath];
	} else {
		$type = 'movie';
		$items = File::GetVideoByDBPath(array($dbPath));
		$info = $items[$dbPath];
	}

	return array(
		'type' => $type,
		'title' => htmlspecialchars($info['title']),
		'description' => htmlspecialchars($info['description']),
		'img' => GetThumbUrl(($isPhoto ? 'photo_' : 'video_') . $album . '_' . $file)
	);
}

function show404Page() {
	header("HTTP/1.0 404 Not Found");
	echo "<h1> 404 Not Found</h1>";
	exit();
}
?>
