<?php
require_once('advanced_share.inc.php');

class AdvancedShareAPI extends WebAPI
{
	private $public_share_id = NULL;
	private $shareAlbumInfo = NULL;

	function __construct()
	{
		parent::__construct(SZ_WEBAPI_API_DESCRIPTION_PATH);
	}

	protected function Process()
	{
		if ($_REQUEST['public_share_id']) {
			$this->public_share_id = trim($_REQUEST['public_share_id']);
			$this->shareAlbumInfo = SharedAlbum::GetInfoByPublicShare($this->public_share_id);
			if (!$this->shareAlbumInfo) {
				$this->SetError(PHOTOSTATION_SHARED_ALBUM_NOT_EXISTS);
				return;
			}
		}

		if (!AdvancedSharedAlbum::CheckSharedAlbumPassword(
				$this->shareAlbumInfo['id'],
				$this->shareAlbumInfo['userid'],
				$this->shareAlbumInfo['advanced_info'],
				$this->public_share_id,
				$_REQUEST['password'])) {
			$this->SetError(PHOTOSTATION_ALBUM_PASSWORD_ERROR);
			return;
		}

		if (!strcasecmp($this->method, "getinfo")) {
			$this->GetInfo();
		} else if (!strcasecmp($this->method, "list_comment")) {
			$this->ListComment();
		} else if (!strcasecmp($this->method, "add_comment")) {
			$this->AddComment();
		} else if (!strcasecmp($this->method, "list_log")) {
			$this->ListLog();
		} else if (!strcasecmp($this->method, "set_color_label")) {
			$this->SetColorLabel();
		} elseif (!strcasecmp($this->method, "list_area")) {
			$this->ListArea();
		} elseif (!strcasecmp($this->method, "add_area")) {
			$this->AddArea();
		} elseif (!strcasecmp($this->method, "delete_area")) {
			$this->DeleteArea();
		}
	}

	private function GetInfo()
	{
		$resp = array();
		$resp['success'] = true;
		$this->SetResponse($resp);
		return;
	}

	private function ListComment()
	{
		$item_id = trim($_REQUEST['item_id']);
		$offset = $_REQUEST['offset'] + 0;
		$limit = $_REQUEST['limit'] + 0;

		$itemIdObject = File::GetItemIdObjectByIdString($item_id);
		if (!$itemIdObject) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}
		$output = AdvancedSharedAlbum::ListComment(
			$this->shareAlbumInfo['userid'],
			$this->shareAlbumInfo['id'],
			$itemIdObject['id'],
			$itemIdObject['type'],
			$offset, $limit);

		$this->SetResponse($output);
	}

	/**
	 *	AddComment
	 *		params:
	 *			public_share_id
	 *			photo_id/video_id: photo_xxxx/video_xxxx
	 *			name
	 *			email
	 *			comment
	 */
	private function AddComment()
	{
		$item_id = trim($_REQUEST['item_id']);
		$name = trim($_REQUEST['name']);
		$email = trim($_REQUEST['email']);
		$comment = trim($_REQUEST['comment']);

		if (!$name || !$comment) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}
		if ($email && !WebAPIUtil::IsEMail($email)) {
			$email = '';
		}

		// check is advanced share album
		if (!$this->shareAlbumInfo['is_advanced']) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}

		$itemIdObject = File::GetItemIdObjectByIdString($item_id);
		if (!$itemIdObject) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}

		// convert id string to db path
		// TODO: revise, wrap all pack("H*")
		$id_arr = explode('_', $item_id);
		if (3 !== count($id_arr) || ('photo' !== $id_arr[0] && 'video' !== $id_arr[0])) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}
		$albumName = @pack('H*', $id_arr[1]);
		$fileName = @pack('H*', $id_arr[2]);
		if ('/' === $albumName) {
			$filePath = $fileName;
		} else {
			$filePath = $albumName.'/'.$fileName;
		}

		// check file is in the share collection
		if (!SharedAlbum::CheckSharedAlbumItemValid($filePath, $id_arr[0], $this->public_share_id)) {
			$this->SetError(PHOTOSTATION_SHARED_ALBUM_ACCESS_DENY);
			return;
		}


		if (!AdvancedSharedAlbum::AddComment(
			$this->shareAlbumInfo['userid'],
			$this->shareAlbumInfo['id'],
			$itemIdObject['id'],
			$itemIdObject['type'],
			$name, $email, $comment, date("Y-m-d H:i")))
		{
			$this->SetError(WEBAPI_ERR_UNKNOWN);
			return;
		}
	}

	private function ListLog()
	{
		$offset = $_REQUEST['offset'] + 0;
		$limit = $_REQUEST['limit'] + 0;
		$category = $_REQUEST['category'] ? trim($_REQUEST['category']) : 'all';

		$total = AdvancedSharedAlbum::GetLogTotalCount(
			$this->shareAlbumInfo['userid'],
			$this->shareAlbumInfo['id'],
			$category
		);

		$result = AdvancedSharedAlbum::ListLog(
			$this->shareAlbumInfo['userid'],
			$this->shareAlbumInfo['id'],
			$category, $offset, $limit);

		$queryItem = array();
		for ($i = 0; $i < count($result); ++$i) {
			$queryItem[] = $result[$i]['item_object'];
		}

		$itemNameDBPath = File::GetNameDBPathByIdType($queryItem);

		$output = array();
		for ($i = 0; $i < count($result); ++$i) {
			$item_type = $result[$i]['item_object']['type'];
			$item_id = $result[$i]['item_object']['id'];
			$output[] = array(
				'id' => $result[$i]['id'],
				'collectionid' => $result[$i]['collectionid'],
				'item_id' => Decorator::EncodeItemId($itemNameDBPath[$item_type][$item_id]['path'], $item_type."_"),
				'name' => $itemNameDBPath[$item_type][$item_id]['name'],
				'log' => $result[$i]['log'],
				'date'	=> $result[$i]['date'],
				'category' => $result[$i]['category']
			);
		}

		$output = array(
			'total' => $total,
			'data' => $output
		);
		$this->SetResponse($output);
	}

	private function SetColorLabel()
	{
		$ret = false;

		if (!isset($_REQUEST['public_share_id']) || !isset($_REQUEST['item_id'])) {
			$this->SetError(PHOTOSTATION_SHARED_ALBUM_BAD_PARAMS);
			goto End;
		}

		$sharedAlbum = SharedAlbum::GetInfoByPublicShare($_REQUEST['public_share_id']);
		if (NULL === $sharedAlbum) {
			$this->SetError(PHOTOSTATION_SHARED_ALBUM_GET_INFO_ERROR);
			goto End;
		}

		$id_arr = explode("_", $_REQUEST['item_id']);
		if (3 !== count($id_arr) || ('photo' !== $id_arr[0] && 'video' !== $id_arr[0])) {
			$this->SetError(PHOTOSTATION_SHARED_ALBUM_BAD_PARAMS);
			goto End;
		}
		$type = $id_arr[0];
		$albumName = @pack('H*', $id_arr[1]);
		$fileName = @pack('H*', $id_arr[2]);

		if ('/' === $albumName) {
			$filePath = $fileName;
		} else {
			$filePath = $albumName.'/'.$fileName;
		}

		$dbId = csSYNOPhotoMisc::GetPhotoVideoDBId($filePath, $type);
		// (todo) check color label valid - 0~6 and color enable
		$color = $_REQUEST['color_label'] + 0;
		AdvancedSharedAlbum::setItemColorLabel($this->shareAlbumInfo['id'], $this->shareAlbumInfo['userid'], $dbId, $type, $color);

		$ret = true;
	End:
		return $ret;
	}

	private function CheckAreaTagEnabled()
	{
		if (!$this->shareAlbumInfo['is_advanced']) {
			return false;
		}

		$advancedInfo = AdvancedSharedAlbum::GetAdvancedInfoById(
			$this->shareAlbumInfo['id'],
			$this->shareAlbumInfo['userid']);

		if (!$advancedInfo || !$advancedInfo['enable_marquee_tool']) {
			return false;
		}

		return true;
	}

	private function ListArea()
	{
		if (!isset($_REQUEST['photo_id'])) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}

		if (!$this->CheckAreaTagEnabled()) {
			$this->SetResponse([]);
			return;
		}

		$list = AdvancedSharedAlbum::GetAreaTagList(
			$this->shareAlbumInfo['id'],
			$this->shareAlbumInfo['userid'],
			File::GetItemIdObjectByIdString($_REQUEST['photo_id'])['id']);
		$this->SetResponse($list);
	}

	private function GetParams_AddArea()
	{
		// TODO make sure item type is photo
		if (!isset($_REQUEST['photo_id']) || !isset($_REQUEST['info']) ||
			!isset($_REQUEST['x']) || !isset($_REQUEST['y']) ||
			!isset($_REQUEST['width']) || !isset($_REQUEST['height'])) {
			return false;
		}
		if (!is_numeric($_REQUEST['x']) || !is_numeric ($_REQUEST['y']) ||
			!is_numeric ($_REQUEST['width']) || !is_numeric($_REQUEST['height']) ||
			!is_string($_REQUEST['info'])) {
			return false;
		}
		$id_arr = explode("_", $_REQUEST['photo_id']);
		if (3 !== count($id_arr) || 'photo' !== $id_arr[0]) {
			return false;
		}
		$params['photo_id'] = File::GetItemIdObjectByIdString($_REQUEST['photo_id'])['id'];
		$params['x'] = floatval($_REQUEST['x']);
		$params['y'] = floatval($_REQUEST['y']);
		$params['width'] = floatval($_REQUEST['width']);
		$params['height'] = floatval($_REQUEST['height']);
		$params['info'] = strval($_REQUEST['info']);

		if (1 < $params['x'] || 0 > $params['x'] ||
			1 < $params['y'] || 0 > $params['y'] ||
			1 < $params['width'] || 0 >= $params['width'] ||
			1 < $params['height'] || 0 >= $params['height'] ||
			$params['info'] === '') {
			return false;
		}
		return $params;
	}

	private function AddArea()
	{
		if (false === ($params = $this->GetParams_AddArea())) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}

		if (!$this->CheckAreaTagEnabled()) {
			$this->SetError(PHOTOSTATION_PHOTO_AREA_TAG_NOT_ENABLED);
			return;
		}

		$resp = AdvancedSharedAlbum::AddAreaTag(
			$this->shareAlbumInfo['id'],
			$this->shareAlbumInfo['userid'],
			$params);

		if (false !== $resp) {
			$this->SetResponse($resp);
		} else {
			$this->SetError(PHOTOSTATION_PHOTO_AREA_TAG_ADD_FAIL);
		}
	}

	private function DeleteArea()
	{
		if (!isset($_REQUEST['tag_id'])) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			return;
		}

		if (!$this->CheckAreaTagEnabled()) {
			$this->SetError(PHOTOSTATION_PHOTO_AREA_TAG_NOT_ENABLED);
			return;
		}

		if (!AdvancedSharedAlbum::DeleteAreaTag(
			$this->shareAlbumInfo['id'],
			$this->shareAlbumInfo['userid'],
			$_REQUEST['tag_id'])) {
			$this->SetError(PHOTOSTATION_PHOTO_AREA_TAG_DELETE_FAIL);
		}
		return;
	}
}

$api = new AdvancedShareAPI();
$api->Run();

?>
