<?php

require_once('auth.inc.php');
require_once('authutil.php');
require_once('albumutil.php');
require_once('../include/shared_album.php');

class AuthAPI extends WebAPI {
	function __construct() {
		parent::__construct(SZ_WEBAPI_API_DESCRIPTION_PATH);
		$this->SetCheckSynoToken(false);
	}

	protected function Process() {
		if (!strcasecmp($this->method, "login")) {
			$this->MobileLogin();
		} else if (!strcasecmp($this->method, "photo_login")) {
			$this->OtherLogin();
		} elseif (!strcasecmp($this->method, "logout")) {
			$this->Logout();
		} elseif (!strcasecmp($this->method, "checkauth")) {
			$this->CheckAuth();
		}
	}

	private function GetConfig() {
		$resp = array();
		// php session id
		$resp['sid'] = session_id();

		// get username
		// not personal photo
		if ('root' === SYNOPHOTO_ADMIN_USER) {
			$resp['username'] = (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) && !isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'])) ? 'admin' : $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'];
		} else {
		// personal photo
			$resp['username'] = (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']) && !isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'])) ? SYNOPHOTO_ADMIN_NAME : $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user'];
		}
		$resp['reg_syno_user'] = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_user']);

		// get manager
		$resp['is_admin'] = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user']);

		// get commentable
		$resp['allow_comment'] = AlbumAPIUtil::IsAlbumCommentalbGlobal();

		$permission['browse'] = csSYNOPhotoMisc::CheckAlbumAccessible('/');
		$permission['upload'] = csSYNOPhotoMisc::CheckAlbumUploadable('/');
		$permission['manage'] = csSYNOPhotoMisc::CheckAlbumManageable('/');
		$resp['permission'] = $permission;

		$resp['enable_face_recog'] = false;
		if (isset($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['runfacerecognition']) &&
	  'yes' == $_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['pkgCfg']['runfacerecognition'] &&
		  false === strstr($_SESSION[SYNOPHOTO_ADMIN_USER]['system_config']['defCfg']['unique'], '88f628')) {
			$resp['enable_face_recog'] = true;
		}

		$resp['allow_public_share'] = SharedAlbum::CheckPublicSharePermission();
		$resp['allow_download'] = csSYNOPhotoMisc::CheckAllowDownload();
		$resp['show_detail'] = csSYNOPhotoMisc::CheckLightboxDetail();

		return $resp;
	}

	private function PhotoLogin() {
		$error_code = WEBAPI_ERR_NONE;
		$user_name = csSYNOPhotoMisc::UserLoginNameConvert($_REQUEST['username']);
		$auth_result = '';

		AuthAPIUtil::SYNOPHOTO_LOGIN_AddEnv();

		//if username is ADMIN
		if (strtoupper($_REQUEST['username']) == "ADMIN" || strtoupper($user_name) == strtoupper(SYNOPHOTO_ADMIN_NAME)) {
			$ret = AuthAPIUtil::SYNOPHOTO_LOGIN_ValidateAdmin($auth_result);
			if(1 != $ret) {
				$error_code = PHOTOSTATION_AUTH_LOGIN_ERROR;
			}
		} else {
		// not ADMIN
			// PhotoStation user
			if ("0" == $_SESSION[SYNOPHOTO_ADMIN_USER]['photo_config']['global']['account_system'] || 'root' != SYNOPHOTO_ADMIN_USER){
				$ret = AuthAPIUtil::SYNOPHOTO_LOGIN_ValidateUser();
			} else {
			// DSM user
				$ret = AuthAPIUtil::SYNOPHOTO_LOGIN_ValidateDsmUser($auth_result);
			}
			switch ($ret) {
				case 1:
					$error_code = WEBAPI_ERR_NONE;
					break;
				case -1:
					$error_code = PHOTOSTATION_AUTH_LOGIN_DISABLE_ACCOUNT;  // for PhotoStation user
					break;
				case -3:
					$error_code = PHOTOSTATION_AUTH_LOGIN_GUEST_ERROR;  // for DSM user
					break;
				case -4:
					$error_code = PHOTOSTATION_AUTH_LOGIN_NOPRIVILEGE;  // for DSM user
					break;
				case -5:
					$error_code = PHOTOSTATION_AUTH_LOGIN_MAX_TRIES;  // for DSM user
					break;
				default:
					$error_code = PHOTOSTATION_AUTH_LOGIN_ERROR;
					break;
			}
		}

		if (1 != $ret && !empty($auth_result)) {
			if ("-3" == $auth_result) {
				$error_code = PHOTOSTATION_AUTH_LOGIN_NOPRIVILEGE;
			} else if ("-8" == $auth_result) {
				$error_code = PHOTOSTATION_AUTH_LOGIN_MAX_TRIES;
			}
		}
		if (1 === $ret) {
			csSYNOPhotoMisc::RegenSessionId();
		}

		return $error_code;
	}

	private function IsEnableDemoMode()
	{
		$isDemoMode = csSYNOPhotoMisc::GetConfigFile(SYNO_CNF_FILE, 'enable_demomode');
		if ('yes' === $isDemoMode['enable_demomode']) {
			return true;
		}
		return false;
	}

	private function PhotoLogout() {
		unset($_SESSION[SYNOPHOTO_ADMIN_USER]);
	}

    private function Login() {
		if (!isset($_REQUEST['username'])) {
			return [false, WEBAPI_ERR_BAD_REQUEST];
		}
		if (!$this->IsEnableDemoMode())  {
			$error_code = $this->PhotoLogin();
			if (WEBAPI_ERR_NONE != $error_code) {
				return [false, $error_code];
			}
		}
		csSYNOPhotoDB::GetDBInstance()->SetSessionCache(true);
		if ("true" === $_REQUEST['enable_syno_token']) {
			$_SESSION[SYNOPHOTO_ADMIN_USER]['enable_syno_token'] = true;
		}
		$resp = $this->GetConfig();
		if(isset($_REQUEST['remember_me'])){
			setcookie('PHPSESSID', session_id(), time() + 60*60*24*30, '/');
			setcookie('photo_remember_me', 1, time() + 60*60*24*30, '/');
		}
		return [true, $resp];
	}

	private function OtherLogin() {
		list ($success, $resp) = $this->Login();
		if (!$success) {
			$this->SetError($resp);
		} else {
			$this->SetResponse($resp);
		}
	}

	private function MobileLogin() {
		list ($success, $resp) = $this->Login();
		$_SESSION[SYNOPHOTO_ADMIN_USER]['skipIPCheckForMobile'] = true;
		if (!$success) {
			$this->SetError($resp);
		} else {
			$this->SetResponse($resp);
		}
	}

	private function Logout() {
		$this->PhotoLogout();
		setcookie('PHPSESSID', '', time() - 180, '/');
		setcookie('photo_remember_me', '', time() - 180, '/');
	}

	private function CheckAuth() {
		$this->CheckSynoToken();
		$resp = $this->GetConfig();
		AuthAPIUtil::SYNOPHOTO_LOGIN_UpdateUserSession($resp['username']);
		if ($resp['is_admin'] !== isset($_SESSION[SYNOPHOTO_ADMIN_USER]['admin_syno_user'])) {
			csSYNOPhotoDB::GetDBInstance()->SetSessionCache(true);
			$resp = $this->GetConfig();
		}
		$this->SetResponse($resp);
	}
}

$api = new AuthAPI();
$api->Run();

?>

