<?PHP

putenv('SYNOPHOTO_SKIP_IP_CHECK=1');
ini_set("session.use_only_cookies", 0);
set_time_limit(0);
session_cache_limiter("must-revalidate");

require_once('download.inc.php');

if (!session_id()) {
	csSYNOPhotoMisc::PhotoSessionStart();
}

class DownloadAPI extends WebAPI
{
	private $publicShareId, $publicShareInfo, $userID;
	const RECURSIVE = true;
	const NORECURSIVE = false;

	function __construct()
	{
		parent::__construct(SZ_WEBAPI_API_DESCRIPTION_PATH);
	}

	protected function Process()
	{
		$this->publicShareId = NULL;
		$this->UserID = NULL;
		if (isset($_REQUEST['public_share_id'])) {
			$this->publicShareId = $_REQUEST['public_share_id'];
			csSYNOPhotoDB::GetDBInstance()->SetPublicShareSessionCache($this->publicShareId);
			if (!SharedAlbum::CheckPublicSharePermission($this->publicShareId)) {
				$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
				return;
			}
			$this->publicShareInfo = SharedAlbum::GetInfoByPublicShare($this->publicShareId);
			if (NULL === $this->publicShareInfo || 'valid' !== $this->publicShareInfo['share_status']) {
				$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
				return;
			}
			$this->UserID = $this->publicShareInfo['userid'];
		}
		csSYNOPhotoDB::GetDBInstance()->SetSessionCache();
		if ($this->UserID === NULL) {
			$this->UserID = isset($_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid']) ? $_SESSION[SYNOPHOTO_ADMIN_USER]['reg_syno_userid'] : 0;
		}
		if (!strcasecmp($this->method, "getphoto")) {
			$this->GetPhoto();
		}
		if (!strcasecmp($this->method, "getvideo")) {
			$this->GetVideo();
		}
		if (!strcasecmp($this->method, "getitem")) {
			$this->GetItem();
		}
	}

	private function GetPhoto()
	{
		$ret = false;
		//if ('on' !== csSYNOPhotoDB::GetDBInstance()->GetConfig('photo', 'allow_orig')) {
		if (!csSYNOPhotoMisc::CheckAllowDownload()) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			goto End;
		}
		// return when lack of params
		if (!isset($_REQUEST['id'])) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_BAD_PARAMS);
			goto End;
		}

		// check params
		$id = $_REQUEST['id'];
		$id_arr = explode('_', $id);
		if ('photo' !== $id_arr[0] || 3 !== count($id_arr)) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_BAD_PARAMS);
			goto End;
		}

		// start to construct photo path from the given id
		$albumName = @pack('H*', $id_arr[1]);
		$fileName = @pack('H*', $id_arr[2]);
		$path = SYNOPHOTO_SERVICE_REAL_DIR."/". ('/' === $albumName ? "" : $albumName."/") . $fileName;

		// check access right
		if (!$this->CheckPath($albumName, $fileName, $path)) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			goto End;
		}
		$filePath = ('/' === $albumName ? "" : $albumName . "/") . $fileName;
		if (NULL !== $this->publicShareId && !SharedAlbum::CheckSharedAlbumItemValid($filePath, $id_arr[0], $this->publicShareId)) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			goto End;
		}
		session_write_close();

		// set mime type
		$mime = $this->SYNOPHOTO_CONVERT_GetPhotoMimeType($path);

		$download = $_REQUEST['download'] === "true";
		if ($download) {
			header('Content-Disposition: attachment; filename="' . $this->GetDownloadName($fileName) . '"');
		} else {
			header('Content-Disposition: inline; filename="' . $this->GetDownloadName($fileName) . '"');
		}

		// output binary
		@header("Content-Type: $mime");
		if (!($fd = @fopen($path, 'rb'))) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			goto End;
		}
		if ($download) {
			$relativePath = substr($path, strlen(SYNOPHOTO_SERVICE_REAL_DIR.'/'));
			PhotoLog::Add("File [$relativePath] was downloaded.", true, GetLoginUsername());
		}
		PHOTO_DB_Close();
		$fsize = filesize($path);
		$buffer = 1024 * 1024 * 8;
		while (!feof($fd)) {
			$p = ftell($fd);
			if ($p + $buffer > $fsize) {
				$buffer = $fsize - $p + 1;
			}
			echo fread($fd, $buffer);
			flush(); // Free up memory. Otherwise large files will trigger PHP's memory limit.
		}
		fclose($fd);
		exit;

		End:
			return $ret;
	}

	private function GetVideo()
	{
		// return when lack of params
		if (!isset($_REQUEST['id'])) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_BAD_PARAMS);
			return false;
		}

		// check params
		$id = $_REQUEST['id'];
		$id_arr = explode('_', $id);
		if ('video' !== $id_arr[0] || 3 !== count($id_arr)) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_BAD_PARAMS);
			return false;
		}

		$quality = isset($_REQUEST['quality_id']) ? $_REQUEST['quality_id'] : 'original';

		// start to construct video path from the given id
		$albumName = @pack('H*', $id_arr[1]);
		$fileName = @pack('H*', $id_arr[2]);
		$path = SYNOPHOTO_SERVICE_REAL_DIR ."/". ('/' === $albumName ? "" : "$albumName/") . $fileName;

		if ('original' !== $quality) {
			$path = @pack('H*', $quality);

			if ($this->ValidateVideoQualityId($path)) {
				$this->SetError(PHOTOSTATION_DOWNLOAD_BAD_PARAMS);
				return false;
			}

			// mp4 in mp4 only occurs in non-original
			if ($this->NeedToUseMov()) {
				$mov_path = $this->GetMovPath($path);

				if (file_exists($mov_path)) {
					$path = $mov_path;
				}
			}
		} else {
			$ext = strtolower(pathinfo($path, PATHINFO_EXTENSION));
			if ((!in_array($ext, array('flv', 'f4v')) && csSYNOPhotoMisc::IsAlbumAllowConversion(dirname($path))) && !csSYNOPhotoMisc::CheckAllowDownload()) {
				//do not check allow_video_download when asking flv&f4v or the album is conversion-less
				$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
				return false;
			}
		}

		// check access right
		if (!$this->CheckPath($albumName, $fileName, $path)) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			return false;
		}
		$filePath = ('/' === $albumName ? "" : $albumName . "/") . $fileName;

		if (NULL !== $this->publicShareId &&
			!$this->publicShareInfo['shareid'] &&
			!SharedAlbum::CheckSharedAlbumItemValid($filePath, $id_arr[0], $this->publicShareId)) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			return false;
		}
		session_write_close();

		// set mime type
		$mime = $this->SYNOPHOTO_CONVERT_GetVideoMimeType($path, 'application/octet-stream');

		// check last-modified value
		$lastModified = $this->GetLastModified($path);
		if ($lastModified) {
			if ($this->CheckLastModified($lastModified)) {
				@header("HTTP/1.1 304 Not Modified");
				return;
			} else {
				@header("Last-Modified: " . $lastModified);
			}
		}
		$contentDisp = 'inline';
		if ($_REQUEST['download'] === "true") {
			$mime = 'application/octet-stream';
			$contentDisp = 'attachment';
			@header("X-Download-Options: noopen");
			$relativePath = substr($path, strlen(SYNOPHOTO_SERVICE_REAL_DIR.'/'));
			PhotoLog::Add("File [$relativePath] was downloaded.", true, GetLoginUsername());
		}
		@header("Content-Type: $mime");
		@header("Cache-Control: max-age=".(3600*24*7));
		@header("Content-Disposition: $contentDisp; filename=\"" . $this->GetDownloadName($fileName) . '"');

		global $SYNOPHOTO_VIDEO_MIME;
		$moveMoovAtom = false;
		if (isset($_REQUEST['move_moov']) && $_REQUEST['move_moov'] == true && ($mime === $SYNOPHOTO_VIDEO_MIME['mp4'] || $mime === $SYNOPHOTO_VIDEO_MIME['mov'] || $mime === $SYNOPHOTO_VIDEO_MIME['m4v'])) {
			$moveMoovAtom = true;
		}
		PHOTO_DB_Close();

		if ($moveMoovAtom || csSYNOPhotoMisc::IsDockerDSM()) {
			$this->SYNOPHOTO_CONVERT_Rrange_Download($path, $moveMoovAtom);
		} else {
			@header('X-Accel-Redirect:' . rawurlencode($path));
		}
		exit;
	}

	private function MakeLinkRename($targetDir, $filepath)
	{
		if (!file_exists($filepath)) {
			return FALSE;
		}
		$info = pathinfo($filepath);
		$number = 2;
		$filename = $info['basename'];
		while (file_exists($targetDir."/".$filename)) {
			$filename = $info['filename'] . "_" . $number . "." . $info['extension'];
			$number ++;
		}
		$ret = @symlink($filepath, $targetDir . "/" . $filename);
		if (FALSE === $ret) {
			return $ret;
		}
		return $filename;
	}

	// targetDir - where the link will be generate
	// sourceDir - relative path under SYNOPHOTO_SERVICE_DIR
	private function MakeFlatLink($targetDir, $sourceDir, $recursive)
	{
		$src = "";
		if (!is_dir(SYNOPHOTO_SERVICE_DIR . "/" . $sourceDir)) {
			goto ERR;
		}
		$currentDir = getcwd();
		if (FALSE === $currentDir) {
			goto ERR;
		}
		if (false === chdir(SYNOPHOTO_SERVICE_DIR . "/" . $sourceDir)) {
			return '';
		}

		foreach (@glob("{,.}*", GLOB_BRACE) as $file) {
			if ($file == "." || $file == ".." || $file == SYNOPHOTO_EADIR) {
				continue;
			}
			if ($recursive && is_dir($file)) {
				if (!csSYNOPhotoMisc::CheckAlbumAccessible($sourceDir . "/" . $file, false, $this->publicShareId)) {
					continue;
				}
				$src .= self::MakeFlatLink($targetDir, $sourceDir . "/" . $file, $recursive);
			} else if (!is_dir($file)){
				if (FALSE !== ($link = self::MakeLinkRename($targetDir, SYNOPHOTO_SERVICE_DIR . "/" . $sourceDir . "/" . $file))) {
					$src .= $link . "\n";
				}
			}
		}

		chdir($currentDir);
		ERR:
			return $src;
	}

	private function GetItem()
	{
		$ret = false;
		if (!csSYNOPhotoMisc::CheckAllowDownload()) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			goto End;
		}

		// return when lack of param
		if (!isset($_REQUEST['id'])) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_BAD_PARAMS);
			goto End;
		}

		// zip the files from a specific album
		$albumid = isset($_REQUEST['album_id']) ? $_REQUEST['album_id'] : ''; // ex: album_3131312f323232
		$arr = explode('_', $albumid); // ["album", "3131312f323232"]
		$albumPrefix = '' === $albumid ? '' : @pack('H*', $arr[1]); // "111/222"
		$zipPrefix = dirname($albumPrefix); // "111"

		if ('' === $albumid) {
			$ret = @chdir(SYNOPHOTO_SERVICE_DIR);
		} else {
			$ret = @chdir(dirname(SYNOPHOTO_SERVICE_DIR . "/" . $albumPrefix)); // chdir to "111"
		}
		if (!$ret) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_CHDIR_ERROR);
			goto End;
		}

		// src is the target files which we are going to make a zip file
		$src = '';
		$emptyAlbumList = '';
		$noStructure = $_REQUEST['no_structure'];
		if ("true" === $noStructure || strpos($_REQUEST['id'], 'sharedalbum_') !== FALSE) {
			$tmpDirPath = "/tmp/synophoto_download_dir_".session_id()."_".time()."_".rand();
			@mkdir($tmpDirPath);
			$ret = @chdir($tmpDirPath);
		}
		if (!$ret) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_CHDIR_ERROR);
			goto End;
		}
		$ids = explode(',', $_REQUEST['id']);
		if (NULL !== $this->publicShareId && '' === $_REQUEST['id']) {
			$ids = ["sharedalbum_". $this->publicShareInfo['id']];
		}
		session_write_close();
		$sharedAlbumNameArray = array();
		$user = GetLoginUsername();
		foreach ($ids as $idStr) {
			$id = explode('_', $idStr);
			$sharename = @pack('H*', $id[1]);
			$filename = @pack('H*', $id[2]);

			if ('album' === $id[0]) {
				$path = SYNOPHOTO_SERVICE_REAL_DIR . "/" . $sharename;
			} elseif ('photo' === $id[0] || 'video' === $id[0]) {
				$path = SYNOPHOTO_SERVICE_REAL_DIR . "/" . ('/' === $sharename ? $filename : "$sharename/$filename");
			} elseif ('sharedalbum' === $id[0]) {
				$src .= $this->SYNOPHOTO_DOWNLOAD_MakeSharedAlbumLinks($tmpDirPath, $id[1], $emptyAlbumList, $sharedAlbumName);
				$sharedAlbumNameArray[] = $sharedAlbumName;
				continue;
			} else {
				continue;
			}

			if (!$this->CheckPath($sharename, $filename, $path)) {
				continue;
			}
			$relativePath = substr($path, strlen(SYNOPHOTO_SERVICE_REAL_DIR.'/'));
			if ('album' === $id[0]) {
				PhotoLog::Add("Album [$relativePath] was downloaded.", true, $user);
			} else {
				PhotoLog::Add("File [$relativePath] was downloaded.", true, $user);
			}

			if ("true" === $noStructure) {
				if ('album' === $id[0]) {
					$src .= self::MakeFlatLink($tmpDirPath, $sharename, self::RECURSIVE);
				} else {
					$link = self::MakeLinkRename($tmpDirPath, $path);
					if (FALSE !== $link) {
						$src .= $link . "\n";
					}
				}
			} else {
				$zipPath = preg_replace('/^' . preg_quote($zipPrefix . '/', '/') . '/', '', $sharename);
				$emptyAlbumList = $emptyAlbumList . "'$zipPath' ";
				if ('album' === $id[0]) {
					$src .= $this->SYNOPHOTO_DOWNLOAD_GetDownloadList($sharename, $zipPath) . "\n";
				} else {
					if ('/' === $sharename) {
						$src .= $filename . "\n";
					} else {
						$src .= $zipPath . "/" . $filename . "\n";
					}
				}
			}
		}

		if (count($sharedAlbumNameArray) === 1) {
			$basename = $sharedAlbumNameArray[0];
		} else {
			$basename = '' === $albumid ? 'data' : basename($albumPrefix);
		}
		PHOTO_DB_Close();

		$src = trim($src);
		if (empty($src) && empty($emptyAlbumList)) {
			$this->SetError(PHOTOSTATION_DOWNLOAD_ACCESS_DENY);
			return false;
		}

		$this->SYNOPHOTO_DOWNLOAD_PrintHeaders($basename . '.zip', true);
		if (empty($src)) {
			if (!empty($emptyAlbumList)) {
				csSYNOPhotoMisc::ExecCmd('/usr/bin/zip', array('-q', '-G', '-0', '-', $emptyAlbumList,
					'-x@' . SYNOPHOTO_INCLUDE_DIR . '/exclude.txt'), true);
			}
		} else {
			$zipFileList = '/tmp/synophoto_download_list_'.session_id().'_'.time().'_'.rand();
			@touch($zipFileList);
			@file_put_contents($zipFileList, $src);

			csSYNOPhotoMisc::ExecCmd(
				'/usr/bin/zip',
				array(
					'-q',  // --quiet
					'-G',  // --syscp, SYNO option: use default system codepage to store filename
					'-r',  // --recurse-paths, recurse down listed paths
					'-0',  // --store
					'-yf', // --symlinks-follow, SYNO option: follow symbolic links
					'-@',
					'-',
					'-x@' . SYNOPHOTO_INCLUDE_DIR . '/exclude.txt',
					'-fn', // --filename, SYNO option: Take the list of input files from given file, Only one filename per line
					$zipFileList
				),
				true // use passthru
			);
			@unlink($zipFileList);
		}
		if ("true" === $noStructure || strpos($_REQUEST['id'], 'sharedalbum_') !== FALSE) {
			// leave tmp directory
			chdir(SYNOPHOTO_SERVICE_DIR);
			$this->SYNOPHOTO_DOWNLOAD_RecursiveUnlink($tmpDirPath);
		}

		exit;

		End:
			return $ret;
	}

	private function CheckPath($albumName, $fileName, $path)
	{
		// check invalid character in fileName
		// if fileName is empty, skip check (for album)
		if (!empty($fileName) && false !== strpos($fileName, '/')) {
			return false;
		}

		// make sure real path is under photo share or personal photo
		if (0 !== strpos(realpath($path), SYNOPHOTO_SERVICE_REAL_DIR)) {
			return false;
		}

		if (!csSYNOPhotoMisc::CheckAlbumAccessible($albumName, false, $this->publicShareId)) {
			return false;
		}

		if (!file_exists($path)) {
			return false;
		}

		return true;
	}

	private function ValidateVideoQualityId($path)
	{
		if (false === strpos(realpath($path), '/@eaDir/SYNOPHOTO')) {
			return false;
		}

		return true;
	}

	private function SYNOPHOTO_DOWNLOAD_RecursiveUnlink($tmpDirPath)
	{
		$dirs = glob($tmpDirPath.'/*', GLOB_ONLYDIR);
		foreach($dirs as $dir) {
			$this->SYNOPHOTO_DOWNLOAD_RecursiveUnlink($dir);
		}
		@array_map('unlink', glob($tmpDirPath.'/*'));
		@rmdir($tmpDirPath);
	}

	private function SYNOPHOTO_DOWNLOAD_MakeSharedAlbumLinks($tmpDirPath, $sharedAlbumId, &$emptyAlbumList, &$sharedAlbumName)
	{
		$src = "";
		if ($sharedAlbumId === 'single') {
			$sharedAlbum = SharedAlbum::GetHiddenAlbumInfo();
		} else {
			$sharedAlbum = SharedAlbum::GetInfoById($sharedAlbumId, $this->UserID);
		}
		if ($sharedAlbum === NULL) {
			goto End;
		}
		if ($sharedAlbumId === 'single') {
			$sharedAlbumId = explode("_", $sharedAlbum['id'])[1];
		}
		$sharedAlbumName = $sharedAlbum['name'];
		if (!mkdir($sharedAlbum['name'])) {
			goto End;
		}

		$itemIds = $this->SYNOPHOTO_DOWNLOAD_GetSharedAlbumDownloadList($sharedAlbumId, $sharedAlbum['shareid']);

		if (count($itemIds) === 0) {
			$emptyAlbumList .= "'{$sharedAlbum['name']}' ";
			goto End;
		}
		foreach ($itemIds as $itemId) {
			$id_arr = explode('_', $itemId);
			$sharename = @pack('H*', $id_arr[1]);
			if ($id_arr[2]) {
				$filename = @pack('H*', $id_arr[2]);
			}
			if ('photo' === $id_arr[0] || 'video' === $id_arr[0]) {
				$path = SYNOPHOTO_SERVICE_REAL_DIR . "/" . $sharename . "/" . $filename;

				if (!$this->CheckPath($sharename, $filename, $path)) {
					continue;
				}
				$link = self::MakeLinkRename($tmpDirPath.'/'.$sharedAlbum['name'], $path);
				if (FALSE !== $link) {
					$src .= $sharedAlbum['name'] .'/'. $link . "\n";
				}
			} else if ('album' === $id_arr[0]) {
				/* make link to tmpdirpath, but it return wrong relative path */
				self::MakeFlatLink($tmpDirPath.'/'.$sharedAlbum['name'], $sharename, self::NORECURSIVE);
				/* get correct relative path */
				$src .= $this->SYNOPHOTO_DOWNLOAD_GetDownloadList($sharename, $sharedAlbum['name']);
			}
		}
	End:
		return $src;
	}

	private function SYNOPHOTO_DOWNLOAD_GetSharedAlbumDownloadList($sharedAlbumId, $shareid)
	{
		$ret = array();

		if ($this->publicShareId === NULL && $sharedAlbumId === NULL) {
			return $ret;
		}

		if ($shareid) {
			$photo_share = Album::GetByShareId([$shareid]);
			$ret[] = 'album_'. bin2hex($photo_share[0]['sharename']);
		} else {
			$albumCondition = csSYNOPhotoMisc::GetAccessibleAlbumQueryConditionWithExcludeFormat('A', $this->publicShareId);
			if (!$albumCondition['albumCond']) {
				return $ret;
			}

			$PublicSharePhotoTable = SHARED_ALBUM_PHOTO_TABLE_NAME;
			$PublicShareVideoTable = SHARED_ALBUM_VIDEO_TABLE_NAME;
			if (PHOTO_DB_IsAdminUid($this->UserID)) {
				$PublicSharePhotoTable = SHARED_ALBUM_PHOTO_ADMIN_TABLE_NAME;
				$PublicShareVideoTable = SHARED_ALBUM_VIDEO_ADMIN_TABLE_NAME;
			}

			$sqlParam = array();

			$photoQuery = "SELECT  A.path as path, A.name as filename, A.timetaken as takendate, A.create_time as createdate, 'photo' as type FROM photo_image A, $PublicSharePhotoTable B WHERE A.id = B.photoid AND B.collectionid = ?";
			$sqlParam[] = $sharedAlbumId;
			$photoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$videoQuery = "SELECT  A.path as path, A.title as filename, A.mdate as takendate, A.date as createdate, 'video' as type FROM video A, $PublicShareVideoTable B WHERE A.id = B.videoid AND B.collectionid = ?";
			$sqlParam[] = $sharedAlbumId;
			$videoQuery .= " AND {$albumCondition['albumCond']} ";
			$sqlParam = array_merge($sqlParam, $albumCondition['sqlParam']);

			$query = "$photoQuery UNION ALL $videoQuery";

			$db_result = PHOTO_DB_Query($query, $sqlParam);
			$getRealPath = ('root' === SYNOPHOTO_ADMIN_USER) ? false : true;
			while ($row = PHOTO_DB_FetchRow($db_result)) {
				if (false !== ($item = PhotoAPIUtil::getItemByPath($row['path'], array(), $row['type'], $getRealPath))) {
					$ret[] = $item['id'];
				}
			}
		}
		return $ret;
	}

	private function SYNOPHOTO_CONVERT_GetPhotoMimeType($path)
	{
		global $SYNOPHOTO_ALLOW_PICT_NAMES_MIME;

		$path = strtolower($path);
		$path_parts = pathinfo($path);
		$extension = $path_parts['extension'];

		if (array_key_exists($extension, $SYNOPHOTO_ALLOW_PICT_NAMES_MIME)) {
			return $SYNOPHOTO_ALLOW_PICT_NAMES_MIME[$extension];
		} else {
			return "image/x-" . strtolower($extension);
		}
	}

	private function SYNOPHOTO_CONVERT_GetVideoMimeType($path, $default)
	{
		global $SYNOPHOTO_VIDEO_MIME;

		$path = strtolower($path);
		$path_parts = pathinfo($path);
		$extension = $path_parts['extension'];
		if (array_key_exists($extension, $SYNOPHOTO_VIDEO_MIME)) {
			return $SYNOPHOTO_VIDEO_MIME[$extension];
		}
		return $default;
	}

	private function SYNOPHOTO_DOWNLOAD_GetDownloadList($album_name, $zipPath)
	{
		$currPath = getcwd();
		@chdir(SYNOPHOTO_SERVICE_REAL_DIR . "/" . $album_name);
		$result = '';
		foreach (glob('{,.}*', GLOB_BRACE) as $file) {
			if (is_dir($file)) {
				if ($file == SYNOPHOTO_EADIR || $file == '.' || $file == '..') {
					continue;
				}
				if (!csSYNOPhotoMisc::CheckAlbumAccessible($album_name . "/" . $file, false, $this->publicShareId)) {
					continue;
				}
				$result = $result . $zipPath . "/" . $file . "\n";
			} else {
				if ($file == '.' || $file == '..') {
					continue;
				}
				if (!csSYNOPhotoMisc::IsPhotoFile($file) && !csSYNOPhotoMisc::IsVideoFile($file)) {
					continue;
				}
				$excludeFormats = csSYNOPhotoMisc::ParseExcludeFormats(csSYNOPhotoMisc::GetConfigDB("photo", "excluding_index_format", "photo_config"));
				if (in_array(strtolower(pathinfo($file, PATHINFO_EXTENSION)), $excludeFormats)) {
					continue;
				}
				$result = $result . $zipPath . "/" . $file . "\n";
			}
		}
		@chdir($currPath);
		return $result;
	}

	private function SYNOPHOTO_DOWNLOAD_PrintHeaders($filename, $force_filename)
	{
		header('Content-Type: application/force-download');
		header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
		header("Pragma: public");
		if ($force_filename) {
			header('Content-Disposition: attachment; filename="' . $this->GetDownloadName($filename) . '"');
		} else {
			header('Content-Disposition: attachment');
		}
		header("X-Download-Options: noopen");
	}

	private function SYNOPHOTO_CONVERT_Rrange_Download($file, $moveMoovAtom = false)
	{
		if ($moveMoovAtom) {
			$isMoovAtomFront = self::IsMoovAtomFront($file);
		} else {
			$isMoovAtomFront = false;
		}

		$fp = @fopen($file, 'rb');
		if (false == $fp) {
			return false;
		}

		$size   = filesize($file); // File size
		$length = $size;		   // Content length
		$start  = 0;			   // Start byte
		$end	= $size - 1;	   // End byte
		// Now that we've gotten so far without errors we send the accept range header
		// At the moment we only support single ranges.
		// Multiple ranges requires some more work to ensure it works correctly
		// and comply with the spesifications: http://www.w3.org/Protocols/rfc2616/rfc2616-sec19.html#sec19.2
		//
		// Multirange support annouces itself with:
		// header('Accept-Ranges: bytes');
		//
		// Multirange content must be sent with multipart/byteranges mediatype,
		// (mediatype = mimetype)
		// as well as a boundry header to indicate the various chunks of data.
		//
		//header("Accept-Ranges: 0-$length");
		header('Accept-Ranges: bytes');
		// multipart/byteranges
		// http://www.w3.org/Protocols/rfc2616/rfc2616-sec19.html#sec19.2
		if (isset($_SERVER['HTTP_RANGE'])) {
			$c_start = $start;
			$c_end   = $end;
			// Extract the range string
			list(, $range) = explode('=', $_SERVER['HTTP_RANGE'], 2);
			// Make sure the client hasn't sent us a multibyte range
			if (strpos($range, ',') !== false) {

				// (?) Shoud this be issued here, or should the first
				// range be used? Or should the header be ignored and
				// we output the whole content?
				header('HTTP/1.1 416 Requested Range Not Satisfiable');
				header("Content-Range: bytes $start-$end/$size");
				// (?) Echo some info to the client?
				exit;
			}
			// If the range starts with an '-' we start from the beginning
			// If not, we forward the file pointer
			// And make sure to get the end byte if spesified
			if ($range{0} == '-') {

				// The n-number of the last bytes is requested
				$c_start = $size - substr($range, 1);
			} else {

				$range  = explode('-', $range);
				$c_start = $range[0];
				$c_end   = (isset($range[1]) && is_numeric($range[1])) ? $range[1] : $size;
			}
			// Check the range and make sure it's treated according to the specs.
			// http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html
			//
			// End bytes can not be larger than $end.
			$c_end = ($c_end > $end) ? $end : $c_end;
			// Validate the requested range and return an error if it's not correct.
			if ($c_start > $c_end || $c_start > $size - 1 || $c_end >= $size) {

				header('HTTP/1.1 416 Requested Range Not Satisfiable');
				header("Content-Range: bytes $start-$end/$size");
				// (?) Echo some info to the client?
				exit;
			}
			$start  = $c_start;
			$end	= $c_end;
			$length = $end - $start + 1; // Calculate new content length
			header('HTTP/1.1 206 Partial Content');
		}
		// Notify the client the byte range we'll be outputting
		header("Content-Range: bytes $start-$end/$size");
		header("Content-Length: $length");


		// Start buffered download
		if ($moveMoovAtom && $isMoovAtomFront === false) {
			if ('ftyp' !== self::GetAtomInfo($fp, $ftypAtomType, $ftypAtomSize)) {
				syslog(LOG_ERR, "ftyp not found");
				return false;
			}
			if (FALSE === self::FindMoovAtom($fp, $ftypAtomSize, $moovAtomPos, $moovAtomSize)) {
				syslog(LOG_ERR, "moov not found");
				return false;
			}
			if ($start == 0) {
				// output ftyp atom
				self::OutputFileWithRange($fp, 0, $ftypAtomSize - 1);

				// output moov atom with patch
				self::OutputMoovAtom($fp, $moovAtomPos, $moovAtomSize, 0);

				// output atoms between ftyp and moov
				self::OutputFileWithRange($fp, $ftypAtomSize, $moovAtomPos - 1);

				// output ths rest
				self::OutputFileWithRange($fp, $moovAtomPos+$moovAtomSize, -1);
			} else if (($start - $ftypAtomSize) < $moovAtomSize ) {
				// client request moov atom again
				self::OutputMoovAtom($fp, $moovAtomPos, $moovAtomSize, $start-$ftypAtomSize);
			} else {
				$start -= $moovAtomSize;
				$end -= $moovAtomSize;
				if ($end < $moovAtomPos) {
					self::OutputFileWithRange($fp, $start, $end);
				} else {
					self::OutputFileWithRange($fp, $start, $moovAtomPos-1);
					self::OutputFileWithRange($fp, $moovAtomPos + $moovAtomSize, $end + $moovAtomSize);
				}
			}
		} else {
			self::OutputFileWithRange($fp, $start, $end);
		}
		fclose($fp);
	}

	// this function output contain $end
	private function OutputFileWithRange($fp, $start, $end)
	{
		fseek($fp, $start);
		$buffer = 1024 * 8;
		while (!feof($fp) && ($end == -1 || ($p = ftell($fp)) <= $end)) {

			if ($p + $buffer > $end && $end != -1) {

				// In case we're only outputtin a chunk, make sure we don't
				// read past the length
				$buffer = $end - $p + 1;
			}

			echo fread($fp, $buffer);
			flush(); // Free up memory. Otherwise large files will trigger PHP's memory limit.
		}
	}

	private function GetLastModified($thumbPath)
	{
		$filest = @stat($thumbPath);

		if ($filest !== false) {
			$lastModified = gmdate('D, d M Y H:i:s', $filest[9]) . ' GMT';
			return $lastModified;
		} else {
			return false;
		}
	}

	private function CheckLastModified($lastModified)
	{
		if (isset($_SERVER['HTTP_IF_MODIFIED_SINCE'])) {
			$ims = preg_replace('/;.*$/', '', $_SERVER['HTTP_IF_MODIFIED_SINCE'] );
			if ($ims === $lastModified) {
				return true;
			}
		}

		return false;
	}

	private function GetDownloadName($filename)
	{
		if ($this->IsBrowserIE()) {
			return urlencode($filename);
		} else {
			if (preg_match("/Windows Phone OS/i", $_SERVER['HTTP_USER_AGENT'])) {
				$filename = preg_replace('/[^(\x20-\x7F)]*/', '_', $filename);
			}
			return addslashes($filename);
		}
	}

	private function IsBrowserIE()
	{
		if (isset($_SERVER['HTTP_USER_AGENT'])) {
			if (preg_match('/MSIE|Trident\/7|Edge/i', $_SERVER['HTTP_USER_AGENT'])) {
				return true;
			}
		}

		return false;
	}

	private function GetAtomInfo($fp, &$atomType, &$atomSize)
	{
		if ($fp == null) {
			syslog(LOG_ERR, "fp null");
			return FALSE;
		}

		if (FALSE === ($atomHeader = fread($fp, 8))) {
			syslog(LOG_ERR, "header error");
			return FALSE;
		}
		$byteArray = unpack("C*", $atomHeader);
		$atomSize = self::Pack32(array_slice($byteArray, 0, 4));
		$atomType = substr($atomHeader, 4);

		// 64-bit size
		if ($atomSize === 1) {
			if (FALSE === ($atomHeader = fread($fp, 8))) {
				syslog(LOG_ERR, "second header error");
				return FALSE;
			}
			// index of unpack result array start from 1, slice it to get a array start from 0
			$atomSize = self::Pack64(array_slice(unpack("C*", $atomHeader), 0));
		}

		if ($atomSize === FALSE) {
			syslog(LOG_ERR, "atom size error");
			return FALSE;
		}
		return $atomType;
	}

	private function FindMoovAtom($fp, $pos, &$moovAtomPos, &$moovAtomSize)
	{
		$ret = FALSE;
		if ($fp == null || -1 === fseek($fp, $pos, SEEK_SET)) {
			syslog(LOG_ERR, "init error");
			goto End;
		}

		while (!feof($fp)) {
			if (FALSE === self::GetAtomInfo($fp, $atomType, $atomSize)) {
				syslog(LOG_ERR, "info error");
				goto End;
			}

			if ($atomType == 'moov') {
				$moovAtomPos = $pos;
				$moovAtomSize = $atomSize;
				$ret = true;
				goto End;
			}

			$pos += $atomSize;
			if (-1 === fseek($fp, $pos, SEEK_SET)) {
				syslog(LOG_ERR, "seek error");
				goto End;
			}
		}
	End:
		return $ret;
	}

	private function IsMoovAtomFront($file)
	{
		$pos = 0;
		$fp = NULL;

		// output original file if this funtion failed
		$ret = true;
		if ($file == null) {
			syslog(LOG_ERR, "invalid filename");
			goto End;
		}

		if (FALSE === ($fp = fopen($file, 'rb'))) {
			syslog(LOG_ERR, "open file $file error");
			goto End;
		}

		if ('ftyp' != self::GetAtomInfo($fp, $atomType, $atomSize)) {
			syslog(LOG_ERR, "ftyp isn't the first atom");
			goto End;
		}

		$pos += $atomSize;
		if (-1 === fseek($fp, $pos, SEEK_SET)) {
			syslog(LOG_ERR, "failed to fseek()");
			goto End;
		}

		$moovPos = 0;
		$mdatPos = 0;
		while (!feof($fp)) {
			if (FALSE === self::GetAtomInfo($fp, $atomType, $atomSize)) {
				syslog(LOG_ERR, "atom type error");
				goto End;
			}

			if ($atomType == 'moov') {
				$ret = true;
				goto End;
			} else if ($atomType == 'mdat') {
				$ret = false;
				goto End;
			}

			$pos += $atomSize;
			if (-1 === fseek($fp, $pos, SEEK_SET)) {
				syslog(LOG_ERR, "failed to fseek()");
				goto End;
			}
		}
	End:
		if ($fp) {
			fclose($fp);
		}
		return $ret;
	}

	private function OutputMoovAtom($fp, $moovAtomPos, $moovAtomSize, $offset)
	{
		if (-1 === fseek($fp, $moovAtomPos, SEEK_SET)) {
			syslog(LOG_ERR, "failed to fseek()");
			return;
		}
		$moovAtom = fread($fp, $moovAtomSize);
		if (FALSE === $moovAtom) {
			syslog(LOG_ERR, "failed to get moov atom");
			return;
		}

		// patch moov atom
		for ($i = 8;$i < ($moovAtomSize - 4);$i++) {
			$atomType = substr($moovAtom, $i, 4);

			if ($atomType == "stco") {
				$atomSize = self::Pack32(array_slice(unpack("C*", substr($moovAtom, $i - 4, 4)), 0));
				if ($atomSize + $i - 4 > $moovAtomSize) {
					syslog(LOG_ERR, "bad atom size");
					return;
				}
				$entryCount = self::Pack32(array_slice(unpack("C*", substr($moovAtom, $i + 8, 4)), 0));
				for ($entryIndex = 0;$entryIndex < $entryCount;$entryIndex++) {
					$patchPos = $i + 12 + ($entryIndex * 4);
					$curOffset = substr($moovAtom, $patchPos, 4);
					$curOffset = self::Pack32(array_slice(unpack("C*", $curOffset), 0));
					$curOffset += $moovAtomSize;

					$newOffset = pack("C*", ($curOffset >> 24) & 0xFF,
											($curOffset >> 16) & 0xFF,
											($curOffset >>  8) & 0xFF,
											($curOffset >>  0) & 0xFF);

					$moovAtom = substr_replace($moovAtom, $newOffset, $patchPos, 4);
				}
				$i += $atomSize - 4;
			} else if ($atomType == "co64") {
				$atomSize = self::Pack32(array_slice(unpack("C*", substr($moovAtom, $i - 4, 4)), 0));
				if ($atomSize + $i - 4 > $moovAtomSize) {
					syslog(LOG_ERR, "bad atom size");
					return;
				}
				$entryCount = self::Pack32(array_slice(unpack("C*", substr($moovAtom, $i + 8, 4)), 0));
				for ($entryIndex = 0;$entryIndex < $entryCount;$entryIndex++) {
					$patchPos = $i + 12 + ($entryIndex * 8);

					$curOffset = substr($moovAtom, $patchPos, 8);
					$curOffset = self::Pack64(array_slice(unpack("C*", $curOffset), 0));
					$curOffset += $moovAtomSize;

					/* On Intel IA32 processors, only the right 5 bits of the right operand are used.  This means that the effective right operand will always be in the range of 0 to 31.
					 */
					$newOffset = pack("C*", ($curOffset >> 31 >> 1 >> 24) & 0xFF,
											($curOffset >> 31 >> 1 >> 16) & 0xFF,
											($curOffset >> 31 >> 1 >>  8) & 0xFF,
											($curOffset >> 31 >> 1 >>  0) & 0xFF,
											($curOffset >> 24) & 0xFF,
											($curOffset >> 16) & 0xFF,
											($curOffset >>  8) & 0xFF,
											($curOffset >>  0) & 0xFF);


					$moovAtom = substr_replace($moovAtom, $newOffset, $patchPos, 8);
				}
				$i += $atomSize - 4;
			}
		}

		echo substr($moovAtom, $offset);
	}

	private function Pack32($arr)
	{
		if (count($arr) !== 4) {
			return FALSE;
		}
		return ($arr[0] << 24) + ($arr[1] << 16) + ($arr[2] << 8) + $arr[3];
	}

	private function Pack64($arr)
	{
		if (count($arr) !== 8) {
			return FALSE;
		}
		return ($arr[0] << 56) + ($arr[1] << 48) + ($arr[2] << 40) + ($arr[3] << 32) +
			($arr[4] << 24) + ($arr[5] << 16) + ($arr[6] << 8) + $arr[7];
	}

	private function NeedToUseMov() {
		if (isset($_REQUEST['use_mov']) && $_REQUEST['use_mov'] === 'true') {
			// Flash player and Mac Safari will send this parameter
			return true;
		}

		if (isset($_SERVER['HTTP_USER_AGENT'])) {
			// detect iOS/tvOS
			if (strpos($_SERVER['HTTP_USER_AGENT'], 'AppleCoreMedia/') === 0) {
				return true;
			}
		}

		return false;
	}

	private function GetMovPath($path) {
		$path_parts = pathinfo($path);
		$dir = $path_parts['dirname'];
		$file = $path_parts['filename'];
		$ext = $path_parts['extension'];

		if ($ext !== 'mp4') {
			return false;
		}

		return "$dir/$file.mov";
	}
}

$api = new DownloadAPI();
$api->Run();
?>
