<?php
require_once('migration.inc.php');

define('MIGRATION_TEMPLATE_XML_PATH', '/var/packages/PhotoStation/target/etc/migration.template.xml');
define('TAG_SLUG_PREFIX', 'ps_');

class MigrationAPI extends WebAPI {
	private static $wp_class = array("post_date", "post_password", "status", "post_type",
		"comment_status", "comment", "comment_id", "comment_author", "comment_author_email",
		"comment_author_url", "comment_author_IP", "comment_date", "comment_content",
		"comment_approved", "comment_parent");

	function __construct()
	{
		parent::__construct(SZ_WEBAPI_API_DESCRIPTION_PATH);
	}

	protected function Process()
	{
		if (!strcasecmp($this->method, "export_blog")) {
			$this->ExportBlog();
		}
	}

	private function ExportBlog()
	{
		$tmp_dir = SYNOBLOG_EXPORT_TMP_DIR;

		if ('root' != SYNOPHOTO_ADMIN_USER) {
			$tmp_dir = SYNOBLOG_EXPORT_TMP_DIR.'/'.SYNOPHOTO_ADMIN_NAME.'/';
		}

		if (!file_exists($tmp_dir)) {
			mkdir($tmp_dir, 0777, true);
		}

		if (self::GenerateXMLFile($tmp_dir) === false) {
			PhotoLog::Add('Failed to export blog data.', false, 'admin');
		} else {
			if (file_exists($tmp_dir.SYNOBLOG_EXPORT_FILE)) {
				header("Content-Type: application/force-download");
				header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
				header("Content-Disposition: attachment; filename=\"".SYNOBLOG_EXPORT_FILE."\"");
				header("X-Download-Options: noopen");
				readfile($tmp_dir.SYNOBLOG_EXPORT_FILE);
				unlink($tmp_dir.SYNOBLOG_EXPORT_FILE);
				PhotoLog::Add('Blog data was export successfully.', true, 'admin');
			}
		}

		if ('root' != SYNOPHOTO_ADMIN_USER) {
			@rmdir($tmp_dir);
		}
		exit();
	}

	private static function GenerateXMLFile($tmp_dir)
	{
		if (false === ($cwd = getcwd())) {
			PhotoLog::Add('Failed fetch the export destination.', false, 'admin');
			return false;
		}

		$article_list = array();
		$label_list = array();
		$tag_slug_prefix = 'ps_';

		/* Generate Article List */
		$query = "SELECT * FROM blog_article ORDER BY date";
		$db_result = PHOTO_DB_Query($query);

		while(($row = PHOTO_DB_FetchRow($db_result))) {
			$info['title'] = $row['title'];
			$info['content'] = $row['content'];
			$info['creator'] = $row['author'];
			$info['description'] = $row['abstract'];
			$info['content'] = $row['content'];
			$info['post_date'] = $row['date'];
			$info['post_password'] = $row['access_key'];
			$info['status'] = ($row['draft'] ? 'draft' : 'publish');
			$info['post_type'] = 'post';
			$info['comment_status'] = ('t' == $row['allow_comment']) ? 'open' : 'close';

			$comment = self::GetArticleComment($row['article_id']);
			$info['comment'] = $comment;

			$label = self::GetArticleLabel($row['article_id']);
			$info['tag'] = $label;
			$article_list[$row['article_id']] = $info;
		}

		if ('root' != SYNOPHOTO_ADMIN_USER) {
			$hex_username = bin2hex(SYNOPHOTO_ADMIN_NAME);
			$tag_slug_prefix = 'pps_'.$hex_username.'_';
		}

		/* Generate Label List */
		$query = "SELECT * FROM blog_label";
		$db_result = PHOTO_DB_Query($query);
		while(($row = PHOTO_DB_FetchRow($db_result))) {
			$label['term_id'] = $row['label_id'];
			$label['tag_name'] = $row['label_name'];
			$label['tag_slug'] = $tag_slug_prefix . $row['label_id'];
			$label_list[$row['label_id']] = $label;
		}

		$xml_data = simplexml_load_file(MIGRATION_TEMPLATE_XML_PATH);
		self::LabelArrayToXML($label_list, $xml_data->channel);
		self::ArticleArrayToXML($article_list, $xml_data->channel);

		$file  = $tmp_dir . SYNOBLOG_EXPORT_FILE;
		if (false === chdir($tmp_dir)) {
			PhotoLog::Add("Failed to export files to the export destination.", false, 'admin');
			return false;
		}
		$ret = $xml_data->asXML($file);

		if (file_exists($file)) {
			if (false === chdir($cwd)) {
				PhotoLog::Add("Failed to change back to the original folder.", false, 'admin');
				return false;
			}
			return true;
		}
	}

	private static function ArticleArrayToXML($data, &$xml_data)
	{
		foreach( $data as $key => $value ) {
			if( is_array($value) ) {
				if( is_numeric($key) ){
					$key = 'item';
					$subnode = $xml_data->addChild($key);
					self::ArticleArrayToXML($value, $subnode);
				} else if ('comment' === $key || 'tag' === $key) {
					self::ArticleArrayToXML($value, $xml_data);
				} else {
					$temp_arr = explode('_', $key);
					if ('comment' === $temp_arr[0]) {
						$key = 'comment';
						$subnode = $xml_data->addChild($key, null, "http://wordpress.org/export/1.2/");
						self::ArticleArrayToXML($value, $subnode);
					} else if ('tag' === $temp_arr[0]) {
						$key = 'category';
						$subnode = $xml_data->addChild($key, htmlspecialchars($value['tag_name']));
						$subnode->addAttribute('domain', 'post_tag');
						$subnode->addAttribute('nicename', $value['tag_slug']);
					}
				}
			} else {
				if (in_array($key, self::$wp_class)) {
					$xml_data->addChild("$key", htmlspecialchars("$value"), "http://wordpress.org/export/1.2/");
				} else if ('creator' === $key) {
					$xml_data->addChild("$key", htmlspecialchars("$value"), "http://purl.org/dc/elements/1.1/");
				} else if ('content' === $key) {
					$xml_data->addChild("encoded", htmlspecialchars("$value"), "http://purl.org/rss/1.0/modules/content/");
				} else {
					$xml_data->addChild("$key", htmlspecialchars("$value"));
				}
			}
		}
	}

	private static function LabelArrayToXML($data, &$xml_data)
	{
		foreach( $data as $key => $value ) {
			if (is_array($value)) {
				if (is_numeric($key)) {
					$key = 'tag';
					$subnode = $xml_data->addChild($key, null, "http://wordpress.org/export/1.2/");
					self::LabelArrayToXML($value, $subnode);
				}
			} else {
				$xml_data->addChild("$key", htmlspecialchars("$value"), "http://wordpress.org/export/1.2/");
			}
		}
	}

	private static function GetArticleComment($article_id)
	{
		$comment_list = array();
		$query = "SELECT * FROM blog_comment WHERE article_id = " . $article_id . " ORDER BY date";
		$db_result = PHOTO_DB_Query($query);

		while(($row = PHOTO_DB_FetchRow($db_result))) {
			$info['comment_id'] = $row['comment_id'];
			$info['comment_author'] = $row['username'];
			$info['comment_author_email'] = $row['email'];
			$info['comment_author_IP'] = $row['ip'];
			$info['comment_date'] = $row['date'];
			$info['comment_content'] = $row['comment'];
			$info['comment_approved'] = 1;
			$info['comment_parent'] = 0;
			$comment_list['comment_'.$row['comment_id']] = $info;
		}
		return $comment_list;
	}

	private static function GetArticleLabel($article_id)
	{
		$label_list = array();
		$tag_slug_prefix = 'ps_';

		if ('root' != SYNOPHOTO_ADMIN_USER) {
			$hex_username = bin2hex(SYNOPHOTO_ADMIN_NAME);
			$tag_slug_prefix = 'pps_'.$hex_username.'_';
		}

		$query = "SELECT * FROM blog_article_label WHERE article_id = " . $article_id;
		$db_result = PHOTO_DB_Query($query);

		while(($row = PHOTO_DB_FetchRow($db_result))) {
			$info['tag_name'] = $row['label_name'];
			$info['tag_id'] = $row['label_id'];
			$info['tag_slug'] = $tag_slug_prefix . $row['label_id'];
			$label_list['tag_'.$row['article_label_id']] = $info;
		}
		return $label_list;
	}
}
$api = new MigrationAPI();
$api->Run();

?>
