<?php
require_once('albumutil.php');

class PhotoAPIUtil {
	static function getLabelIDConstraint($idList)
	{
		$ret = '';
		$ids = explode(',', $idList);
		$isFirst = true;
		foreach ($ids as $id) {
			$arr = explode('_', $id);
			if ('tag' !== $arr[0] || !is_numeric($arr[1])) {
				continue;
			}
			if (!$isFirst) {
				$ret .= " OR ";
			}
			$ret .= "label_id = $arr[1]";
			$isFirst = false;
		}
		return $ret;
	}

	static function getItemByPath($fullpath, $additional, $type, $getRealPath)
	{
		if ($getRealPath) {
			if (false === csSYNOPhotoMisc::CheckPathValid($fullpath = SYNOPHOTO_SERVICE_REAL_DIR . "/" . $fullpath)) {
				return false;
			}
		}

		$dbPath = substr($fullpath, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PREFIX));
		$sharename = substr(pathinfo($dbPath, PATHINFO_DIRNAME), strlen(SYNOPHOTO_SERVICE_REAL_DIR_PATH));

		if (Album::IsRootSharename($sharename)) {
			$sharename = '/';
		}

		$path = $fullpath;

		$needExif = in_array('photo_exif', $additional);
		$needCodec = in_array('video_codec', $additional);
		$needQuality = in_array('video_quality', $additional);
		$needThumbSize = in_array('thumb_size', $additional);

		$item = null;
		if ('photo' === $type) {
			$items = File::GetPhotoByDBPath(array($dbPath));
			$row = $items[$dbPath];
			if (!$row) {
				return false;
			}

            // TO-DO: use Decorator::PhotoFormula to construct return photo json
			$obj = null;
			$obj['name'] = $row['name'];
			$obj['title'] = $row['title'];
			$obj['createdate'] = $row['create_time'];
			$obj['size'] = (int)$row['size'];
			$obj['takendate'] = $row['timetaken'];
			$obj['resolutionx'] = (int)$row['resolutionx'];
			$obj['resolutiony'] = (int)$row['resolutiony'];
			$obj['description'] = $row['description'];
			$obj['rotated'] = (0 === (int)$row['version'] %2) ? false : true;
            $obj['rotate_version'] = (int)$row['version'];
            $obj['rotation'] = (int)$row['rotation'];
			$obj['rating'] = (int)$row['rating'];

			/* set photo exif if required */
			if ($needExif) {
				$addObj = null;
				$addObj['takendate'] = $row['timetaken'];
				$addObj['camera'] = $row['camera_make'];
				$addObj['camera_model'] = $row['camera_model'];
				$addObj['exposure'] = $row['exposure'];
				$addObj['aperture'] = $row['aperture'];
				$addObj['iso'] = (int)$row['iso'];
				$addObj['gps'] = json_decode($row['gps'], true);
				$addObj['version'] = $row['version'];
				$addObj['focal_length'] = $row['focal_length_v2'];
				$addObj['lens'] = $row['lens_v2'];
				$addObj['flash'] = $row['flash_v2'];
				$item['additional']['photo_exif'] = $addObj;
			}

			$orig_resolutionx = $row['resolutionx'];
			$orig_resolutiony = $row['resolutiony'];
			$blThumbRotated = (0 === (int)$row['version'] %2) ? false : true;

		} elseif ('video' === $type) {
			$items = File::GetVideoByDBPath(array($dbPath));
			$row = $items[$dbPath];
			if (false === $row) {
				return false;
			}
			$title_desc = csSYNOPhotoDB::GetDBInstance()->GetVideoCustomizedTitleDescription($dbPath);

			$obj = null;
			$obj['name'] = basename($path);
			$obj['createdate'] = $row['date'];
			$obj['takendate'] = $row['mdate'];
			$obj['size'] = (int)$row['filesize'];
			$obj['title'] = empty($title_desc['title']) ? $row['title'] : $title_desc['title'];
			$obj['description'] = $title_desc['description'];
			$obj['duration'] = (int)$row['duration'];
			$obj['gps'] = json_decode($row['gps']);
            $obj['rating'] = (int)$row['rating'];
            $obj['rotation'] = (int)$row['rotation'];

			/* set video codec if required */
			if ($needCodec) {
				$addObj = null;
				$addObj['container'] = $row['container_type'];
				$addObj['vcodec'] = $row['video_codec'];
				$addObj['acodec'] = $row['audio_codec'];
				$addObj['resolutionx'] = (int)$row['resolutionx'];
				$addObj['resolutiony'] = (int)$row['resolutiony'];
				$addObj['frame_bitrate'] = (int)$row['frame_bitrate'];
				$addObj['video_bitrate'] = (int)$row['video_bitrate'];
				$addObj['audio_bitrate'] = (int)$row['audio_bitrate'];
				$item['additional']['video_codec'] = $addObj;
			}
			/* set video quality if required */
			if ($needQuality) {
				$item['additional']['video_quality'] = AlbumAPIUtil::GetConvertedVideoInfo($dbPath);
			}

			$orig_resolutionx = $row['resolutionx'];
			$orig_resolutiony = $row['resolutiony'];
			$blThumbRotated = false;
		}

		$blConversion = csSYNOPhotoMisc::IsAlbumAllowConversion($sharename);
		$thumbnail = AlbumAPIUtil::GetThumbStatus($dbPath, $needThumbSize, $orig_resolutionx, $orig_resolutiony, $blThumbRotated, $blConversion);
		$item['thumbnail_status'] = $thumbnail['status'];
		if ($needThumbSize) {
			$item['additional']['thumb_size'] = $thumbnail['size'];
		}

        if (SYNOPHOTO_SERVICE_REAL_DIR === dirname($fullpath)) {
            $item['id'] = $type . '_' . bin2hex('/') . '_' . bin2hex(basename($path));
        } else {
            $item['id'] = $type . '_' . bin2hex($sharename) . '_' . bin2hex(basename($path));
        }
		$item['type'] = $type;
		$item['info'] = $obj;
		return $item;
	}
}

?>
