<?php
require_once('public.inc.php');
require_once('albumutil.php');
require_once('photoutil.php');

class PublicAPI extends WebAPI {
	function __construct() {
		parent::__construct(SZ_WEBAPI_API_DESCRIPTION_PATH);
	}

	protected function Process() {
		if (!strcasecmp($this->method, "list")) {
			$this->ListItem();
		}
	}

	private function GetParams_list() {
		$params = array();

		if (!isset($_REQUEST['offset']) || !isset($_REQUEST['limit']) || !isset($_REQUEST['type']) || !isset($_REQUEST['filter'])) {
			return false;
		}

		$params['offset'] = $_REQUEST['offset'];
		$params['limit'] = $_REQUEST['limit'];
		$params['type'] = array();
		$params['filter'] = $_REQUEST['filter'];
		$arr = explode(',', $_REQUEST['type']);
		foreach ($arr as $item) {
			if (!in_array($item, array('album','photo'))) {
				return false;
			}
			array_push($params['type'], $item);
		}

		$params['id'] = (isset($_REQUEST['id'])) ? $_REQUEST['id'] : null;
		if (isset($_REQUEST['id'])) {
			$split = explode('_', $_REQUEST['id']);
			$params['id'] = $split[1];
			$params['albumName'] = @pack('H*', $split[1]);
		}

		if ('smart' === $params['filter'] && isset($_REQUEST['id'])) {
			$params['filter_smart'] = $_REQUEST['id'];
		} else if ('shared' === $params['filter'] && isset($_REQUEST['id'])) {
			$params['filter_shared_album'] = $_REQUEST['id'];
		}

		$params['additional'] = array();
		$params['additional'] = explode(',', $_REQUEST['additional']);
		$params['ignore'] = explode(',', $_REQUEST['ignore']);

		$params['sort_by'] = isset($_REQUEST['sort_by']) ? $_REQUEST['sort_by'] : 'preference';
		if (!in_array($params['sort_by'], array('filename','takendate','createdate','preference','mtime'))) {
			return false;
		}

		$params['sort_direction'] = $_REQUEST['sort_direction'];
		if (!in_array($params['sort_direction'], array('asc', 'desc'))) {
			return false;
		}

		return $params;
	}

	private function ListItem() {
		$params = array();
		$params = $this->GetParams_list();
		if (!$params) {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			goto End;
		}

		csSYNOPhotoDB::GetDBInstance()->SetSessionCache();
		session_write_close();

		if ('album' === $params['filter']) {
			$this->AlbumList($params);
		} else if ('smart' === $params['filter']) {
			if (isset($params['id'])) {
				$this->SmartPhotoList($params);
			} else {
				$this->SmartAlbumList($params);
			}
		} else if ('category' === $params['filter']) {
			if (isset($params['id'])) {
				$this->CategoryItemList($params);
			} else {
				$this->CategoryList($params);
			}
		} else {
			$this->SetError(WEBAPI_ERR_BAD_REQUEST);
			goto End;
		}

		End:
			return;
	}

	private function AlbumList($params) {
		if (!empty($_REQUEST['id']) && !self::isAvailableShare($_REQUEST['id'])) {
			$this->SetResponse(array(
				'total' => 0,
				'offset' => 0,
				'items' => array(),
				'name' => pack('H*', explode('_', $_REQUEST['id'])[1])));
			return;
		}

		$sharePath = @pack('H*', $params['id']);
		$items = array();
		$items = csSYNOPhotoBrowse::GetBrowseInstance()->GetThumbList_New(isset($params['id']) ? $sharePath : '/',
			(int)$params['offset'], (int)$params['limit'], $params['sort_by'], $params['sort_direction'],
			!in_array('album', $params['type']), true, !in_array('photo', $params['type']));
		$itemsPublic = $this->FormItems($items, $params);
		$total = $itemsPublic['itemCount'];
		unset($itemsPublic['itemCount']);

		$resp = array();
		$resp['total'] = $total;
		$offset = (0 > (int)$params['limit']) ? $resp['total'] : $params['offset'] + $params['limit'];
		$resp['offset'] = ($offset > $resp['total']) ? $resp['total'] : $offset;
		$resp['items'] = $itemsPublic;
		$resp['name'] = $params['albumName'];
		$this->setResponse($resp);

		return;
	}

	private function FormItems($itemList, $params) {
		$items = array();
		$needThumbSize = in_array('thumb_size', $params['additional']);
		$types = array( 0 => 'album', 1 => 'photo');
		$count = 0;
		$decorator = array(
			'album' => 'Decorator::AlbumPublicFormula',
			'photo' => 'Decorator::PhotoPublicFormula'
		);
		foreach ($itemList['items'] as $item_node) {
			$type = $types[$item_node['itemType']];
			$func = $decorator[$type];

			$item = array();
			if ($func) {
				$item = call_user_func($func, $item_node, array(
					'allowComment' => false,
					'showAlbumHit' => false,
					'param' => $params,
					'needThumbSize' => $needThumbSize
				));
			}
			if ($item) {
				if (($item['type'] !== 'photo') || $params['id'] || csSYNOPhotoMisc::GetConfigDB("photo", "allow_root_folder_public", "photo_config")) {
					$count++;
					$items[] = $item;
				}
			}
		}
		$items['itemCount'] = $count;
		return $items;
	}

	private function CategoryList($params) {
		$dbCategories = Category::ListItem($_REQUEST['offset']+0, $_REQUEST['limit']+0, false);
		$categories = array();

		foreach ($dbCategories as $dbCategory) {
			$category = Decorator::CategoryFormula($dbCategory);
			$categories[] = $category;
		}

		$resp['total'] = (int)csSYNOPhotoDB::GetDBInstance()->GetTotalCategory($isAdmin);
		$offset = (0 > $_REQUEST['limit']) ? $resp['total'] : (int)($_REQUEST['offset'] + $_REQUEST['limit']);
		$resp['offset'] = ($offset >  $resp['total']) ?  $resp['total'] : $offset;
		$resp['items'] = $categories;
		$this->SetResponse($resp);
		return;
	}

	private function CategoryItemList($params)
	{
		$resp = array(
			'total' => 0,
			'offset' => 0,
			'items'=> array()
		);
		$needThumbSize = in_array('thumb_size', $params['additional']);

		if (!$this->IsAccessible($params['id'])) {
			$this->SetError(PHOTOSTATION_CATEGORY_ACCESS_DENY);
			goto End;
		}

		$dbItems = csSYNOPhotoDB::GetDBInstance()->ListCategoryItem($params['id'], $_REQUEST['offset'], $_REQUEST['limit']);
		if (false === $dbItems) {
			$this->SetError(PHOTOSTATION_CATEGORY_LIST_ITEM_FAIL);
			goto End;
		}

		$items = array();
		$denyCount = 0;
		foreach ($dbItems as $dbItem) {
			unset($item);

			if ('album' !== $dbItem['type']) {
				$denyCount++;
				continue;
			}
			$typeID = $dbItem['album_id'];
			if (false === $this->CheckAlbumPublic($typeID)) {
				$denyCount++;
				continue;
			}
			$row = csSYNOPhotoDB::GetDBInstance()->GetFieldByKeyValue('sharename', 'photo_share', 'shareid', $typeID);
			$albumID = bin2hex($row['sharename']);
			$itemID = "album_{$albumID}";
			$albumName = $row['sharename'];

			$item['id'] = $itemID;
			$item['type'] = $dbItem['type'];

			$row = csSYNOPhotoDB::GetDBInstance()->GetFieldByKeyValue('title', 'photo_share', 'shareid', $typeID);
			$item['title'] = empty($row['title']) ? basename($albumName) : $row['title'];

			$coverPath = '';
			$result = csSYNOPhotoAlbum::GetAlbumInstance()->GetAlbumCover($albumName);
			$coverPath = $result['coverPath'];
			$relativePath = substr($coverPath, strlen(SYNOPHOTO_SERVICE_REAL_DIR_PATH));
			$dirname = dirname($relativePath);
			$sharename = Album::IsRootSharename($dirname) ? '/' : $dirname;
			$blConversion = csSYNOPhotoMisc::IsAlbumAllowConversion($sharename);

			list($orig_resolutionx, $orig_resolutiony, $blThumbRotated) = AlbumAPIUtil::GetCoverResolutionRotation($coverPath);
			AlbumAPIUtil::FillThumbStatus($tmp, $coverPath, $needThumbSize, $orig_resolutionx, $orig_resolutiony, $blThumbRotated, $blConversion);
			$item['thumb_size'] = $tmp['additional']['thumb_size'];
			array_push($items, $item);
		}
		$resp['total'] = (int)csSYNOPhotoDB::GetDBInstance()->GetTotalCategoryItem($params['id']) - $denyCount;
		$offset = (0 > (int)$_REQUEST['limit']) ? $resp['total'] : (int)($_REQUEST['offset'] + $_REQUEST['limit']);
		$resp['offset'] = ($offset >  $resp['total']) ?  $resp['total'] : $offset;
		$resp['items'] = $items;
		End:
			$this->SetResponse($resp);
		return;
	}

	private function SmartAlbumList($params) {
		$resp = array(
			'total' => 0,
			'offset' => 0,
			'items'=> array()
		);

		$smartAlbumList = SmartAlbum::GetSmartAlbumInstance()->ReadSmartAlbumFile();
		$selectedAlbums = array();
		if (empty($smartAlbumList) || !is_array($smartAlbumList['smart_albums'])) {
			goto End;
		}
		$smartAlbums = $smartAlbumList['smart_albums'];
		$selectedAlbums = array();
		$smart_albums = array();
		$available_shares = self::getAvailableShares()['ids'];
		if (count($available_shares) === 0) {
			goto EmptyAlbum;
		}
		foreach ($smartAlbums as $key => $album) {
			$ids = SmartAlbum::GetSmartAlbumInstance()->GetSmartAlbumToIds($album, 'photo');
			if (count($ids) === 0) {
				continue;
			}
			$query = "SELECT count(*) FROM photo_image WHERE shareid IN (" . implode(', ', $available_shares) . ") AND id IN (" . implode(', ', $ids) . ")";

			$db_result = PHOTO_DB_Query($query);
			if ($row = PHOTO_DB_FetchRow($db_result)) {
				$photo_count = $row[0];
			}
			if ($photo_count > 0) {
				$selectedAlbums[$key] = $album;
			}
		}

		if (count($selectedAlbums)) {
			$albumNames = array_keys($selectedAlbums);
			$smart_albums = $this->FormSmartAlbums($albumNames, $params);
		}

EmptyAlbum:
		$total = count($smart_albums);
		$smartSort = $smart_albums;
		$resp['total'] = $total;
		$offset = (0 > $params['limit']) ? $resp['total'] : $params['offset'] + $params['limit'];
		$resp['offset'] = ($offset > $total) ?  $total : $offset;
		$resp['items'] = $smartSort;
End:
		$this->SetResponse($resp);
		return;
	}

	private function FormSmartAlbums($smartNames = false, $params = array()) {
		$smartAlbumList = SmartAlbum::GetSmartAlbumInstance()->ReadSmartAlbumFile();
		$smartAlbumArr = array();

		if (empty($smartAlbumList) || !is_array($smartAlbumList['smart_albums'])) {
			return $smartAlbumArr;
		}
		$smartAlbums = $smartAlbumList['smart_albums'];
		if (false != $smartNames) {
			foreach($smartNames as $name) {
				if ($smartAlbums[$name]) {
					$list[$name] = $smartAlbums[$name];
				}
			}
		} else {
			$list = $smartAlbums;
		}

		$needThumbSize = in_array('thumb_size', $params['additional']);
		foreach ($list as $key => $item) {
			$item['name'] = (string)$key;
			$smartAlbum = Decorator::SmartPublicFormula($item, array(
				'param'=> $params,
				'needThumbSize' => $needThumbSize
			));
			if (-1 === $smartAlbum) {
				continue;
			}
			$smartAlbumArr[] = $smartAlbum;
		}
		return $smartAlbumArr;
	}

	private function SmartPhotoList($params) {
		foreach ($params as $k => $v) {
			${$k} = $v;
		}

		$albumPath = SYNOPHOTO_SERVICE_REAL_DIR;
		$sharename = '/';

		$arr = explode('_', $filter_smart);
		if ('smart' !== $arr[0]) {
			$this->SetError(PHOTOSTATION_PHOTO_BAD_PARAMS);
			goto End;
		}
		$albumName = @pack('H*', $arr[1]);
		$data = array(
			"name" => $albumName,
			"offset" => $offset,
			"limit" => $limit,
			'date_begin' => $params['date_begin'],
			'date_end'	 => $params['date_end']
		);
		$smart = json_decode(SmartAlbum::GetSmartAlbumInstance()->ListItem(json_encode($data), $sort_by, $sort_direction), true);
		if (!$smart['success']) {
			$this->SetError(PHOTOSTATION_PHOTO_BAD_PARAMS);
			goto End;
		}

		$itemLists = $this->FormPhotoItems($smart['data']['itemList'], $params);
		$total = $itemLists['itemCount'];
		unset($itemLists['itemCount']);

		$resp = array();
		$resp['total'] = $total;
		$resp['offset'] = (-1 == $limit || $offset + $limit > $total) ? $total : $offset + $limit;
		$resp['items'] = $itemLists;
		$resp['name'] = $albumName;
		End:
			$this->SetResponse($resp);
		return;
	}

	private function FormPhotoItems($itemList, $params)
	{
		$items = array();
		$needThumbSize = in_array('thumb_size', $params['additional']);
		$count = 0;
		$idx = $params['offset'];

		$available_shares = self::getAvailableShares()['ids'];
		if (count($available_shares) === 0) {
			return array('itemCount' => 0);
		}
		foreach ($itemList as $item_node) {
			if ('smart' === $params['filter']) {
				$query = "SELECT count(*) FROM photo_image WHERE shareid IN (" . implode(', ', $available_shares) . ") AND id = " . $item_node['id'];

				$db_result = PHOTO_DB_Query($query);
				if ($row = PHOTO_DB_FetchRow($db_result)) {
					$photo_count = $row[0];
				}
				if ($photo_count == 0) {
					continue;
				}
			}

			if (!in_array($item_node['type'], $params['type'])) {
				continue;
			}

			$item_tmp = PhotoAPIUtil::getItemByPath($item_node['path'], $params['additional'], $item_node['type'], false);
			$item = Decorator::SmartPhotoPublicFormula($item_tmp, array('param' => $params, 'needThumbSize' => $needThumbSize));
			if ($item) {
				$count++;
				$items[] = $item;
			}
		}

		$items['itemCount'] = $count;
		return $items;
	}

	private function IsAccessible($id) {
		$hidden = csSYNOPhotoDB::GetDBInstance()->IsCategoryAccessible($id);
		if (true === $hidden) {
			return false;
		}
		return true;
	}

	private function CheckAlbumPublic($itemID)
	{
		return in_array($itemID, self::getAvailableShares()['ids']);
	}

	private static function getAvailableShares() {
		// XXX performance issue
		$query = "SELECT shareid, sharename, public FROM photo_share ORDER BY sharename ASC";
		$statement = PHOTO_DB_Query($query);
		if ($statement === false) {
			return false;
		}
		$available_shares = array(
			'ids' => array(),
			'names' => array());
		$public = array();
		while (true) {
			$row = PHOTO_DB_FetchRow($statement);
			if (!$row) {
				break;
			}
			if ($row['sharename'] === '/') {
				if (csSYNOPhotoMisc::GetConfigDB("photo", "allow_root_folder_public", "photo_config")) {
					$available_shares['ids'][] = $row['shareid'];
					$available_shares['names'][] = '';
					$available_shares['names'][] = $row['sharename'];
				}
			} else {
				$public[$row['sharename']] = $row['public'];
				$sharename = explode('/', $row['sharename']);
				if (((count($sharename) < 3) && $public[$sharename[0]] && $row['public'])
						|| ((count($sharename) > 2) && $public[implode('/', array($sharename[0], $sharename[1]))])) {
					$available_shares['ids'][] = $row['shareid'];
					$available_shares['names'][] = $row['sharename'];
				}
			}
		}
		return $available_shares;
	}

	private static function isAvailableShare($albumid) {
		return in_array(pack('H*', explode('_', $albumid)[1]), self::getAvailableShares()['names']);
	}
}

$api = new PublicAPI();
$api->Run();

?>
