<?php
require_once('watermark.inc.php');
require_once('watermarkutil.php');

define('WATERMARK_ERROR_BAD_REQUEST', 5566);

class WatermarkAPI extends WebAPI {
	function __construct() {
		parent::__construct(SZ_WEBAPI_API_DESCRIPTION_PATH);
	}

	protected function Process() {
		if (!strcasecmp('listshare', $this->method)) {
			$this->listShare();
		} elseif (!strcasecmp('copy', $this->method)) {
			$this->copyWatermark();
		} elseif (!strcasecmp('upload', $this->method)) {
			$this->upload();
		} elseif (!strcasecmp('delete', $this->method)) {
			$this->deleteWatermark();
		} elseif (!strcasecmp('remove', $this->method)) {
			$this->remove();
		}
	}

	/**
	 * Lists accessible shared folders of the currently logged in user
	 */
	private function listShare() {
		$resp = WatermarkUtil::listShare($_REQUEST['d']);
		if ($resp) {
			$this->SetResponse($resp);
		} else {
			$this->SetError(WATERMARK_ERROR_BAD_REQUEST);
		}
	}

	/**
	 * Copies the selected watermark to user watermark directory
	 */
	private function copyWatermark() {
		do {
			if (!isset($_REQUEST['id'])) {
				break;
			}
			$src = pack('H*', explode('_', $_REQUEST['id'])[1]);
			$info = pathinfo($src);

			// It is not necessary to copy if the source and the destination directories are the same
			$dst = WatermarkUtil::getUserWatermarkDir();
			if ($info['dirname'] !== $dst) {
				WatermarkUtil::copyWatermark($src, $info['basename']);
			}
			$path = $dst . '/' . $info['basename'];
			$this->SetResponse(array(
				'id' => ID_PREFIX . bin2hex($path),
				'path' => $path,
				'hash' => hash_file('crc32b', $path)));
			return;
		} while (false);
		$this->SetError(WATERMARK_ERROR_BAD_REQUEST);
	}

	/**
	 * Handles uploaded watermarks
	 */
	private function upload() {
		$resp = array(
			'failed' => array(),
			'ignored' => array());
		$dir = WatermarkUtil::getUserWatermarkDir();
		foreach ($_FILES['files']['error'] as $key => $error) {
			if ($error === UPLOAD_ERR_OK) {
				// Ignore gif files
				if (!WatermarkUtil::isIgnored($_FILES['files']['name'][$key])) {
					WatermarkUtil::copyWatermark(
						$_FILES['files']['tmp_name'][$key],
						$_FILES['files']['name'][$key]);
				} else {
					$resp['ignored'][] = $_FILES['files']['name'][$key];
				}
				unlink($_FILES['files']['tmp_name'][$key]);
			} else {
				$resp['failed'][] = $_FILES['files']['name'][$key];
			}
		}
		$this->SetResponse($resp);
	}

	/**
	 * Deletes the specified watermark from user watermark directory
	 */
	private function deleteWatermark() {
		do {
			if (!isset($_REQUEST['id'])) {
				break;
			}
			$ids = explode(',', $_REQUEST['id']);
			foreach ($ids as $id) {
				$path = pack('H*', explode('_', $id)[1]);
				$info = pathinfo($path);

				// Only handle files in user watermark directory
				if ($info['dirname'] === WatermarkUtil::getUserWatermarkDir()) {
					if (SYNOPHOTO_IS_PPS) {
						csSYNOPhotoMisc::ExecCmd(BIN_SYNOPHOTO_WATERMARK_UTIL, array('-p', WatermarkUtil::getUser(), '-r', $info['basename']));
					} else {
						csSYNOPhotoMisc::ExecCmd(BIN_SYNOPHOTO_WATERMARK_UTIL, array('-r', $info['basename']));
					}
				}
			}
			return;
		} while (false);
		$this->SetError(PHOTOSTATION_WATERMARK_BAD_PARAMS);
	}

	/**
	 * Removes watermarks and settings
	 */
	private function remove() {
		do {
			if (!isset($_REQUEST['id'])) {
				break;
			}
			$sharename = WatermarkUtil::getShareNameById($_REQUEST['id']);
			if (!$sharename) {
				break;
			}
			if (!WatermarkUtil::clearSettingsByShareName($sharename)) {
				break;
			}
			WatermarkUtil::removeAlbum($sharename);
			return;
		} while (false);
		$this->SetError(PHOTOSTATION_WATERMARK_BAD_PARAMS);
	}
} // class WatermarkAPI

if (isset($_REQUEST['method']) && !strcasecmp('getshare', $_REQUEST['method']) && isset($_REQUEST['node'])) {
	// TreePanel cannot parse the original format
	// Respond a customized json object
	header('content-type: application/json; charset=utf-8');
	echo json_encode(WatermarkUtil::getShare($_REQUEST['node']));
} else {
	$api = new WatermarkAPI();
	$api->Run();
}
?>
