<?php

define('SYNO_PHOTO_DSM_USER_PROG', '/usr/syno/bin/synophoto_dsm_user');

require_once('/var/packages/PhotoStation/target/photo/include/syno_defines.php');
require_once('/var/packages/PhotoStation/target/photo/include/photo/synophoto_csPhotoMisc.php');

function getDSMUserList()
{
	$dsmUserList = '';
	csSYNOPhotoMisc::ExecCmd(SYNO_PHOTO_DSM_USER_PROG, array('--enumlocal'), false, $dsmUserList);
	$list = array();

	foreach($dsmUserList as &$dsmUser) {
		$dsmUser = explode(',', $dsmUser);
		if (count($dsmUser) != 6) {
			continue;
		}
		if ('guest' === $dsmUser[1]) {
			continue;
		}
		$list[] = $dsmUser[1];
	}
	return $list;
}

function isPPS()
{
	global $user;

	return '' !== $user;
}

function getUserHomePath()
{
	global $user;

	if (!isPPS()) {
		return '';
	}

	//@exec(SYNO_PHOTO_DSM_USER_PROG . " --getinfo " . escapeshellarg($user), $output, $ret);
	$output = '';
	$ret = csSYNOPhotoMisc::ExecCmd(SYNO_PHOTO_DSM_USER_PROG, array('--getinfo', $user), false, $output);

	if (0 !== $ret) {
		syslog(LOG_ERR, "Failed to " . SYNO_PHOTO_DSM_USER_PROG . " --getinfo $user.");
		return false;
	}

	foreach($output as $line) {
		if (preg_match('/^User\sDir\s+:\s+\[(.+)\]$/', $line, $matches)) {
			return $matches[1];
		}
	}

	syslog(LOG_ERR, "Failed to parse $user's home path.");

	return false;
}

function getPhotoSharedFolderPath()
{
	global $userHome;

	if (isPPS()) {
		return "$userHome/photo";
	} else {
		return "/var/services/photo";
	}
}

function getDatabaseHandler()
{
	global $userHome;

	$dbh = false;

	if (isPPS()) {
		$user_photo_db = "$userHome/photo/.SYNOPPSDB";

		if(!file_exists($user_photo_db)){
			return $dbh;
		}

		try {
			$dbh = new PDO("sqlite:{$user_photo_db}");
			$dbh->exec('PRAGMA case_sensitive_like=1');
			$dbh->exec('PRAGMA foreign_keys=ON');
		} catch (PDOException $e) {
			die($e->getMessage());
		}
	} else {
		try {
			$dbh = new PDO('pgsql:dbname=photo', 'postgres', '', array(PDO::ATTR_PERSISTENT => false, PDO::ATTR_EMULATE_PREPARES => true));
		} catch (PDOException $e) {
			die($e->getMessage());
		}
	}

	return $dbh;
}

function getEscapeString()
{
	return isPPS() ? "ESCAPE '\'" : "";
}

function indentJson($json)
{
	if (!json_decode($json)) {
		return $json;
	}

	$result = '';
	$pos = 0;
	$strLen = strlen($json);
	$indentStr = "\t";
	$newLine = "\n";
	$prevChar = '';
	$outOfQuotes = true;

	for($i = 0; $i <= $strLen; $i++) {
		// Grab the next character in the string
		$char = substr($json, $i, 1);

		// Are we inside a quoted string?
		if($char == '"' && $prevChar != '\\') {
			$outOfQuotes = !$outOfQuotes;
		}
		// If this character is the end of an element,
		// output a new line and indent the next line
		else if(($char == '}' || $char == ']') && $outOfQuotes) {
			$result .= $newLine;
			$pos --;
			for ($j=0; $j<$pos; $j++) {
				$result .= $indentStr;
			}
		}
		// Add the character to the result string
		$result .= $char;

		// If the last character was the beginning of an element,
		// output a new line and indent the next line
		if (($char == ',' || $char == '{' || $char == '[') && $outOfQuotes) {
			$result .= $newLine;
			if ($char == '{' || $char == '[') {
				$pos ++;
			}
			for ($j = 0; $j < $pos; $j++) {
				$result .= $indentStr;
			}
		}
		$prevChar = $char;
	}

	return $result;
}


?>
