DROP TRIGGER IF EXISTS "PhotoAclAccessChange" ON photo_access_right_for_dsm_account;
DROP TRIGGER IF EXISTS "PhotoAclUploadChange" ON photo_upload_right_for_dsm_account;
DROP TRIGGER IF EXISTS "PhotoAclManageChange" ON photo_manage_right_for_dsm_account;
DROP TRIGGER IF EXISTS "PhotoAclGroupPermChange" ON photo_group_permission_for_dsm_account;
DROP TRIGGER IF EXISTS "PhotoAclPublicChange" ON photo_share;
DROP TRIGGER IF EXISTS "PhotoAclRootPublicChange" ON photo_config;
DROP TRIGGER IF EXISTS "PhotoAclAccountSystemChange" ON photo_config;
DROP FUNCTION IF EXISTS GroupPermChange(TEXT, BIGINT, INT, TEXT);
DROP FUNCTION IF EXISTS GroupPermChange(TEXT, BIGINT, INT);
DROP FUNCTION IF EXISTS AlbumPermChange(TEXT, BIGINT, INT);
DROP FUNCTION IF EXISTS RootPublicChange(TEXT);
DROP FUNCTION IF EXISTS PublicChange(TEXT, TEXT);
DROP FUNCTION IF EXISTS AlbumAccessChange(TEXT, BIGINT, TEXT);
DROP FUNCTION IF EXISTS AlbumUploadChange(TEXT, BIGINT, TEXT);
DROP FUNCTION IF EXISTS AlbumManageChange(TEXT, BIGINT, TEXT);
DROP FUNCTION IF EXISTS IsPermFolder(INTEGER);
DROP TABLE IF EXISTS "acl_version";

BEGIN;

-- control acl function and trigger version
CREATE TABLE IF NOT EXISTS acl_version (
	version NUMERIC NOT NULL
);

CREATE UNIQUE INDEX acl_version_one_row ON acl_version((version IS NOT NULL));

INSERT INTO acl_version (version) VALUES (7);

-- root photos public
CREATE OR REPLACE FUNCTION RootPublicChange(toggle TEXT, has_public_album INT)
RETURNS void AS '/var/packages/PhotoStation/target/trigger/pgtrigger.so', 'RootPublicChange'
LANGUAGE C SECURITY DEFINER;

CREATE OR REPLACE FUNCTION afterRootPublicChange()
RETURNS TRIGGER AS $$
	BEGIN

		IF (TG_OP = 'DELETE' AND OLD.module_name = 'photo' AND OLD.config_key ='allow_root_folder_public') THEN
			PERFORM RootPublicChange('off', HasFirstLayerPublicAlbum());
		END IF;

		IF (TG_OP = 'INSERT' OR TG_OP = 'UPDATE') THEN
			IF (NEW.module_name = 'photo' AND NEW.config_key ='allow_root_folder_public') THEN
				PERFORM RootPublicChange(NEW.config_value, HasFirstLayerPublicAlbum());
			END IF;
		END IF;

		RETURN NULL;
	END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER "PhotoAclRootPublicChange" AFTER INSERT OR UPDATE OR DELETE
	ON photo_config
	FOR EACH ROW
	EXECUTE PROCEDURE afterRootPublicChange();
-- end of root photos public

-- account system
CREATE OR REPLACE FUNCTION AccountSystemChange(account_system TEXT)
RETURNS void AS '/var/packages/PhotoStation/target/trigger/pgtrigger.so', 'AccountSystemChange'
LANGUAGE C SECURITY DEFINER;

CREATE OR REPLACE FUNCTION afterAccountSystemChange()
RETURNS TRIGGER AS $$
	BEGIN
		IF (TG_OP = 'INSERT' OR TG_OP = 'UPDATE') THEN
			IF (NEW.module_name = 'global' AND NEW.config_key = 'account_system') THEN
				PERFORM AccountSystemChange(NEW.config_value);
			END IF;
		END IF;

		RETURN NULL;
	END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER "PhotoAclAccountSystemChange" AFTER INSERT OR UPDATE
	ON photo_config
	FOR EACH ROW
	EXECUTE PROCEDURE afterAccountSystemChange();
-- end of account system

CREATE OR REPLACE FUNCTION HasFirstLayerPublicAlbum()
RETURNS INTEGER AS $$
	DECLARE
		result INTEGER;
	BEGIN
		SELECT SUM(public_count) INTO result FROM (
			SELECT 1::INTEGER as public_count FROM photo_config WHERE module_name = 'photo' AND config_key = 'allow_root_folder_public' AND config_value = 'on'
			UNION ALL
			SELECT 1::INTEGER as public_count FROM photo_share WHERE public = true AND is_subdir = false AND sharename != '/' LIMIT 1
		) AS tmp;

		IF result IS NULL THEN
			result := 0;
		END IF;

		RETURN result;
	END;
$$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION CanUserAccessSomeAlbum(uid BIGINT)
RETURNS INTEGER AS $$
	DECLARE
		result INTEGER;
	BEGIN
		SELECT 1 INTO result FROM photo_access_right_for_dsm_account WHERE userid = uid LIMIT 1;

		IF result IS NULL THEN
			SELECT 1 INTO result FROM photo_upload_right_for_dsm_account WHERE userid = uid LIMIT 1;

			IF result IS NULL THEN
				result := 0;
			END IF;
		END IF;

		RETURN result;
	END;
$$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION CanGroupAccessSomeAlbum(gid BIGINT)
RETURNS INTEGER AS $$
	DECLARE
		result INTEGER;
	BEGIN
		SELECT 1 INTO result FROM photo_group_permission_for_dsm_account WHERE permission & 1 = 1 AND groupid = gid LIMIT 1;

		IF result IS NULL THEN
			SELECT 1 INTO result FROM photo_group_permission_for_dsm_account WHERE permission & 2 = 2 AND groupid = gid LIMIT 1;
			IF result IS NULL THEN
				result := 0;
			END IF;
		END IF;

		RETURN result;
	END;
$$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION IsPermFolder(sid INTEGER)
RETURNS INTEGER AS $$
	DECLARE
		result INTEGER;
	BEGIN
		SELECT 1 INTO result FROM photo_share p1 INNER JOIN photo_share p2
			ON p1.shareid=sid AND p1.ref_shareid=p2.shareid AND p2.is_subdir=false;

		return result;
	END;
$$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION CalcUserPerm(sid INTEGER, uid BIGINT)
RETURNS INTEGER AS $$
	DECLARE
		result INTEGER;
	BEGIN
		SELECT SUM(perm) INTO result FROM
			(SELECT 1::INTEGER as perm FROM photo_share WHERE shareid=sid AND public=true
			UNION
			SELECT 1::INTEGER as perm FROM photo_access_right_for_dsm_account WHERE userid=uid AND shareid=sid
			UNION
			SELECT 2::INTEGER as perm FROM photo_upload_right_for_dsm_account WHERE userid=uid AND shareid=sid
			UNION
			SELECT 4::INTEGER as perm FROM photo_manage_right_for_dsm_account WHERE userid=uid AND shareid=sid)
		AS tmp;

		IF result IS NULL THEN
			result := 0;
		END IF;

		RETURN result;
	END;
$$ LANGUAGE plpgsql;


CREATE OR REPLACE FUNCTION AlbumPermChange(share TEXT, userid BIGINT, perm INT, can_access_some_album INT)
RETURNS void AS '/var/packages/PhotoStation/target/trigger/pgtrigger.so', 'AlbumPermChange'
LANGUAGE C SECURITY DEFINER;

CREATE OR REPLACE FUNCTION afterAlbumPermChange()
RETURNS TRIGGER AS $$
	DECLARE
		result INTEGER;
		uid BIGINT;
		sid INTEGER;
	BEGIN
		IF (TG_OP = 'DELETE') THEN
			uid := OLD.userid;
			sid := OLD.shareid;
		ELSIF (TG_OP = 'INSERT' OR TG_OP = 'UPDATE') THEN
			uid := NEW.userid;
			sid := NEW.shareid;
		END IF;

		SELECT IsPermFolder(sid) INTO result;
		IF result = 1 THEN
			SELECT CalcUserPerm(sid, uid) INTO result;
			IF result IS NOT NULL THEN
				PERFORM AlbumPermChange(sharename, uid, result, CanUserAccessSomeAlbum(uid)) FROM photo_share WHERE shareid=sid;
			END IF;
		END IF;

		RETURN NULL;
	END;
$$ LANGUAGE plpgsql;

-- User Browse
CREATE TRIGGER "PhotoAclAccessChange" AFTER INSERT OR UPDATE OR DELETE
	ON photo_access_right_for_dsm_account
	FOR EACH ROW
	EXECUTE PROCEDURE afterAlbumPermChange();
-- End of User Browse

-- User Upload
CREATE TRIGGER "PhotoAclUploadChange" AFTER INSERT OR UPDATE OR DELETE
	ON photo_upload_right_for_dsm_account
	FOR EACH ROW
	EXECUTE PROCEDURE afterAlbumPermChange();
-- End of User Upload

-- User Manage
CREATE TRIGGER "PhotoAclManageChange" AFTER INSERT OR UPDATE OR DELETE
	ON photo_manage_right_for_dsm_account
	FOR EACH ROW
	EXECUTE PROCEDURE afterAlbumPermChange();
-- End of User Manage

-- Group Perm
CREATE OR REPLACE FUNCTION GroupPermChange(share TEXT, groupid BIGINT, perm INT, can_access_some_album INT)
RETURNS void AS '/var/packages/PhotoStation/target/trigger/pgtrigger.so', 'GroupPermChange'
LANGUAGE C SECURITY DEFINER;

CREATE OR REPLACE FUNCTION afterGroupPermChange()
RETURNS "trigger" AS $$
	DECLARE
		result INTEGER;
		gid BIGINT;
		sid INTEGER;
		perm SMALLINT;
	BEGIN
		IF (TG_OP = 'DELETE') THEN
			gid  := OLD.groupid;
			sid  := OLD.shareid;
			perm := OLD.permission;
		ELSIF (TG_OP = 'INSERT' OR TG_OP = 'UPDATE') THEN
			gid  := NEW.groupid;
			sid  := NEW.shareid;
			perm := NEW.permission;
		END IF;

		SELECT IsPermFolder(sid) INTO result;
		IF result = 1 THEN
			PERFORM GroupPermChange(sharename, gid, perm | photo_share.public::INTEGER, CanGroupAccessSomeAlbum(gid)) FROM photo_share WHERE shareid=sid;
		END IF;

		RETURN NULL;
	END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER "PhotoAclGroupPermChange" AFTER INSERT OR UPDATE OR DELETE
	ON photo_group_permission_for_dsm_account
	FOR EACH ROW
	EXECUTE PROCEDURE afterGroupPermChange();
-- End of Group Perm

-- Public Album
CREATE OR REPLACE FUNCTION PublicChange(share TEXT, action TEXT, has_public_album INT)
RETURNS void AS '/var/packages/PhotoStation/target/trigger/pgtrigger.so', 'PublicChange'
LANGUAGE C SECURITY DEFINER;

CREATE OR REPLACE FUNCTION EveryoneShareRW(has_public_album INT)
RETURNS void AS '/var/packages/PhotoStation/target/trigger/pgtrigger.so', 'EveryoneShareRW'
LANGUAGE C SECURITY DEFINER;

CREATE OR REPLACE FUNCTION afterPublicChange()
RETURNS "trigger" AS $$
	BEGIN
		IF (TG_OP = 'INSERT' AND NEW.public = TRUE) THEN
			PERFORM PublicChange(NEW.sharename, 'INSERT', 1);
		ELSIF (TG_OP = 'UPDATE' AND NEW.public <> OLD.public) THEN
			IF (NEW.public = TRUE) THEN
				PERFORM PublicChange(NEW.sharename, 'INSERT', HasFirstLayerPublicAlbum());
			ELSE
				PERFORM PublicChange(NEW.sharename, 'DELETE', HasFirstLayerPublicAlbum());
			END IF;
		ELSIF (TG_OP = 'DELETE') THEN
			PERFORM EveryoneShareRW(HasFirstLayerPublicAlbum());
		END IF;
		RETURN NULL;
	END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER "PhotoAclPublicChange" AFTER INSERT OR UPDATE OR DELETE
	ON photo_share
	FOR EACH ROW
	EXECUTE PROCEDURE afterPublicChange();
-- End of Public Album

COMMIT;
