BEGIN;

create table photo_user
(
	userid int4 NOT NULL,
	username varchar(128) NOT NULL,
	description varchar(128),
	"password" varchar(128),
	disabled bool DEFAULT false,
	lock_pass bool DEFAULT false,
	admin bool DEFAULT false,
	email varchar(128),
	CONSTRAINT photo_user_pkey PRIMARY KEY (userid),
	CONSTRAINT photo_user_username_key UNIQUE (username)
);

create table photo_share
(
	shareid int4 NOT NULL,
	sharename varchar(1024),
	title text,
	description text,
	public bool,
	hits int8 DEFAULT 0,
	cover text,
	comment bool DEFAULT true,
	is_subdir bool DEFAULT false,
	updated character DEFAULT '1',
	password varchar(128) DEFAULT '',
	conversion bool DEFAULT true,
	ref_shareid int4 NOT NULL DEFAULT 0,
	CONSTRAINT photo_share_pkey PRIMARY KEY (shareid),
	CONSTRAINT photo_share_sharename_key UNIQUE (sharename)
);
CREATE INDEX photo_share_ref_shareid_idx ON photo_share USING btree (ref_shareid);
INSERT INTO photo_share (shareid, sharename, public, comment, ref_shareid) VALUES (1, '/', 't', 'f', 1);

create table photo_log
(
	logid int4 NOT NULL,
	create_time timestamp,
	log text,
	success bool,
	"user" varchar(128),
	CONSTRAINT photo_log_pkey PRIMARY KEY (logid)
);

create table photo_access_right
(
	userid int4 NOT NULL,
	shareid int4 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_access_right_pkey PRIMARY KEY (userid, shareid),
	CONSTRAINT "photo_access_right_shareID_fkey" FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT "photo_access_right_userID_fkey" FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);


create table photo_upload_right
(
	userid int4 NOT NULL,
	shareid int4 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_upload_right_pkey PRIMARY KEY (userid, shareid),
	CONSTRAINT "photo_upload_right_shareID_fkey" FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT "photo_upload_right_userID_fkey" FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);

create table photo_access_right_for_dsm_account
(
	userid int4 NOT NULL,
	shareid int4 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_access_right_for_dsm_account_pkey PRIMARY KEY (userid, shareid),
	CONSTRAINT "photo_access_right_for_dsm_shareID_fkey" FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);

create table photo_upload_right_for_dsm_account
(
	userid int4 NOT NULL,
	shareid int4 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_upload_right_for_dsm_account_pkey PRIMARY KEY (userid, shareid),
	CONSTRAINT "photo_upload_right_for_dsm_account_shareID_fkey" FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);

create table photo_image
(
	id serial NOT NULL,
	path text NOT NULL,
	name text NOT NULL,
	title text,
	description text,
	album text,
	size int4,
	resolutionx int4,
	resolutiony int4,
	camera_make varchar(100),
	camera_model varchar(100),
	exposure varchar(20),
	aperture varchar(20),
	iso int4,
	timetaken timestamp,
	updated char(1),
	version int4 DEFAULT 0,
	create_time timestamp,
	gps text DEFAULT '',
	disabled bool DEFAULT false,
	shareid int4 NOT NULL DEFAULT 0,
	privilege_shareid int4 NOT NULL DEFAULT 0,
	rotation int4 NOT NULL DEFAULT 0,
	lat float,
	lng float,
	focal_length_v2 text NOT NULL DEFAULT '',
	lens_v2 text NOT NULL DEFAULT '',
	flash_v2 text NOT NULL DEFAULT '',
	rating int4 NOT NULL DEFAULT 0,
	CONSTRAINT photo_pkey PRIMARY KEY (id),
	CONSTRAINT photo_image_path_key UNIQUE (path)
);

CREATE INDEX photo_image_create_time_idx ON photo_image USING btree (create_time);
CREATE UNIQUE INDEX photo_image_path_idx ON photo_image USING btree (path);
CREATE INDEX photo_image_shareid_idx ON photo_image USING btree (shareid);
CREATE INDEX photo_image_privilege_shareid_idx ON photo_image USING btree (privilege_shareid);
CREATE INDEX photo_image_lat_idx ON photo_image USING btree (lat);
CREATE INDEX photo_image_lng_idx ON photo_image USING btree (lng);

create table photo_comment
(
	id serial NOT NULL,
	photo_id int8 NOT NULL,
	name varchar(100),
	email varchar(128),
	comment text,
	date timestamp,
	CONSTRAINT photo_comment_pkey PRIMARY KEY (id),
	CONSTRAINT photo_comment_photo_id_fkey1 FOREIGN KEY (photo_id)
		REFERENCES photo_image (id) MATCH SIMPLE
		ON UPDATE RESTRICT ON DELETE CASCADE
);

CREATE TABLE video_comment
(
	id serial NOT NULL,
	path text NOT NULL,
	name varchar(100),
	email varchar(128),
	"comment" text,
	date timestamp,
	updated char(1),
	CONSTRAINT video_comment_pkey PRIMARY KEY (id)
);

CREATE TABLE video_desc
(
	id serial NOT NULL,
	path text NOT NULL,
	title text,
	description text,
	updated char(1),
	CONSTRAINT video_pkey PRIMARY KEY (id),
	CONSTRAINT video_path_key UNIQUE (path)
);


CREATE TABLE photo_config
(
	config_id serial NOT NULL,
	module_name varchar(128) NOT NULL,
	config_key varchar(512) NOT NULL,
	config_value text,
	CONSTRAINT photo_config_pkey PRIMARY KEY (config_id)
);

CREATE TABLE common_config
(
	config_id serial NOT NULL,
	module_name varchar(128) NOT NULL,
	config_key varchar(512) NOT NULL,
	config_value text,
	CONSTRAINT common_config_pkey PRIMARY KEY (config_id)
);

create INDEX photo_comment_photoid_index
	ON photo_comment
	USING hash
	(photo_id);


CREATE TABLE video
(
	id serial NOT NULL,
	path text NOT NULL,
	title text NOT NULL,
	filesize int8 NOT NULL DEFAULT 0,
	album text,
	container_type text NOT NULL,
	video_codec text,
	frame_bitrate int4,
	frame_rate_num int4,
	frame_rate_den int4,
	video_bitrate int4,
	video_profile int4,
	video_level int4,
	resolutionX int4,
	resolutionY int4,
	audio_codec text,
	audio_bitrate int4,
	frequency int4,
	channel int4,
	duration int4,
	date timestamp,
	mdate timestamp,
	gps text DEFAULT '',
	updated char(1),
	disabled bool DEFAULT false,
	shareid int4 NOT NULL DEFAULT 0,
	privilege_shareid int4 NOT NULL DEFAULT 0,
	rotation int4 NOT NULL DEFAULT 0,
	lat float,
	lng float,
	rating int4  NOT NULL DEFAULT 0,
	CONSTRAINT video_primary_key PRIMARY KEY (id)
)
WITHOUT OIDS;
CREATE INDEX video_title_idx ON video USING btree (title);
CREATE INDEX video_date_idx ON video USING btree (date);
CREATE INDEX video_mdate_idx ON video USING btree (mdate);
CREATE UNIQUE INDEX video_path_idx ON video USING btree (path);
CREATE INDEX video_shareid_idx ON video USING btree (shareid);
CREATE INDEX video_privilege_shareid_idx ON video USING btree (privilege_shareid);
CREATE INDEX video_lat_idx ON video USING btree (lat);
CREATE INDEX video_lng_idx ON video USING btree (lng);

CREATE TABLE video_convert (
	video_path text NOT NULL,
	convert_file_path text NOT NULL,
	filesize int8 NOT NULL DEFAULT 0,
	resolutionx int4 DEFAULT NULL,
	resolutiony int4 DEFAULT NULL,
	container_type text NOT NULL,
	video_bitrate int4 DEFAULT NULL,
	vcodec text DEFAULT NULL,
	video_profile int4 DEFAULT NULL,
	video_level int4 DEFAULT NULL,
	acodec text DEFAULT NULL,
	audio_bitrate int4 DEFAULT NULL,
	audio_frequency int4 DEFAULT NULL,
	audio_channel int4 DEFAULT NULL,
	convert_type text NOT NULL,
	updated char(1),
	CONSTRAINT video_convert_pkey PRIMARY KEY (convert_file_path),
	CONSTRAINT video_convert_fk1 FOREIGN KEY (video_path) REFERENCES video (path) ON DELETE CASCADE ON UPDATE CASCADE
)
WITHOUT OIDS;
CREATE INDEX video_convert_convert_type_idx ON video_convert USING btree (convert_type);
CREATE INDEX video_convert_video_path_idx ON video_convert USING btree (video_path);

CREATE TABLE photo_label (
	id serial NOT NULL unique,
	name text,
	category int4 NOT NULL,
	info text DEFAULT '',
        CONSTRAINT photo_label_id_primary_key PRIMARY KEY (id)
);

CREATE TABLE photo_image_label (
	id serial NOT NULL,
	image_id int4 NOT NULL,
	label_id int4 NOT NULL,
	info text DEFAULT '',
	info_new text DEFAULT '',
	status bool default true,
	PRIMARY KEY (id),
	CONSTRAINT photo_image_label_photo_id_fkey1 FOREIGN KEY (image_id) REFERENCES photo_image (id) MATCH SIMPLE ON UPDATE RESTRICT ON DELETE CASCADE,
	CONSTRAINT photo_image_label_label_id_fkey1 FOREIGN KEY (label_id) REFERENCES photo_label (id) MATCH SIMPLE ON UPDATE RESTRICT ON DELETE CASCADE,
	CONSTRAINT image_label_ukey UNIQUE (image_id, label_id)
);

CREATE TABLE photo_video_label (
	id serial NOT NULL,
	video_path text NOT NULL,
	label_id int4 NOT NULL,
	info text DEFAULT '',
	status bool default true,
	updated char(1),
	PRIMARY KEY (id),
	CONSTRAINT photo_video_label_label_id_fkey1 FOREIGN KEY (label_id) REFERENCES photo_label (id) MATCH SIMPLE ON UPDATE RESTRICT ON DELETE CASCADE
);

create table photo_manage_right
(
	userid int8 NOT NULL,
	shareid int4 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_manage_right_pkey PRIMARY KEY (userid, shareid),
	CONSTRAINT "photo_manage_right_shareID_fkey" FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT "photo_manage_right_userID_fkey" FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);

create table photo_manage_right_for_dsm_account
(
	userid int8 NOT NULL,
	shareid int4 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_manage_right_for_dsm_account_pkey PRIMARY KEY (userid, shareid),
	CONSTRAINT "photo_manage_right_for_dsm_shareID_fkey" FOREIGN KEY (shareid)
	REFERENCES photo_share (shareid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);

create table category
(
	id serial NOT NULL,
	name text NOT NULL,
	hidden boolean NOT NULL DEFAULT false,
	order_number int NOT NULL,
	create_date timestamp DEFAULT current_timestamp,
	modify_date timestamp DEFAULT current_timestamp,
	CONSTRAINT category_pkey PRIMARY KEY (id),
	CONSTRAINT category_ukey UNIQUE (name)
);

CREATE TYPE item_type AS ENUM ('album', 'smart', 'tag');
create table category_items
(
	id serial NOT NULL,
	category_id serial NOT NULL,
	type item_type NOT NULL,
	order_number int not NULL,
	album_id int
		REFERENCES photo_share (shareid)
		ON UPDATE CASCADE ON DELETE CASCADE,
	tag_id int
		REFERENCES photo_label (id)
		ON UPDATE CASCADE ON DELETE CASCADE,
	smart_id text,
	CONSTRAINT category_items_pkey PRIMARY KEY (id),
	CONSTRAINT category_item_album_ukey UNIQUE (category_id, album_id),
	CONSTRAINT category_items_tag_ukey UNIQUE (category_id, tag_id),
	CONSTRAINT category_items_smart_ukey UNIQUE (category_id, smart_id),
	CONSTRAINT category_items_fkey FOREIGN KEY (category_id)
		REFERENCES category (id) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_group
(
	groupid int8 NOT NULL,
	groupname varchar(128) NOT NULL,
	description varchar(128),
	CONSTRAINT photo_group_pkey PRIMARY KEY (groupid),
	CONSTRAINT photo_group_username_key UNIQUE (groupname)
);

CREATE TABLE photo_user_group (
	id serial NOT NULL,
	userid int8 NOT NULL,
	groupid int8 NOT NULL,
	PRIMARY KEY (id),
	CONSTRAINT photo_user_group_userID_fkey FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE ON UPDATE RESTRICT ON DELETE CASCADE,
	CONSTRAINT photo_user_group_groupID_fkey FOREIGN KEY (groupid)
		REFERENCES photo_group (groupid) MATCH SIMPLE ON UPDATE RESTRICT ON DELETE CASCADE,
	CONSTRAINT photo_user_group_key UNIQUE (userid, groupid)
);

CREATE TABLE photo_group_permission
(
	groupid int8 NOT NULL,
	shareid int4 NOT NULL,
	permission int2 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_group_permission_pkey PRIMARY KEY (groupid, shareid),
	CONSTRAINT photo_group_permission_shareID_fkey FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_group_permission_groupID_fkey FOREIGN KEY (groupid)
		REFERENCES photo_group (groupid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_group_permission_for_dsm_account
(
	groupid int8 NOT NULL,
	shareid int4 NOT NULL,
	permission int2 NOT NULL,
	create_time timestamp,
	CONSTRAINT photo_group_permission_for_dsm_account_pkey PRIMARY KEY (groupid, shareid),
	CONSTRAINT "photo_group_permission_for_dsm_shareID_fkey" FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

INSERT INTO photo_config (module_name, config_key, config_value) VALUES ('photo', 'ms_people_tag_merged', 'on'), ('photo', 'geo_tag_merged', 'on'), ('photo', 'migrate_recently_add_comment', 'on');

CREATE TABLE photo_public_share_right
(
	userid int8 NOT NULL,
	CONSTRAINT photo_public_share_right_pkey PRIMARY KEY (userid),
	CONSTRAINT photo_public_share_right_userID_fkey FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_public_share_right_for_dsm_account
(
	userid int8 NOT NULL,
	CONSTRAINT photo_public_share_right_for_dsm_account_pkey PRIMARY KEY (userid)
);

CREATE TABLE photo_group_public_share_right
(
	groupid int8 NOT NULL,
	CONSTRAINT photo_group_public_share_right_pkey PRIMARY KEY (groupid),
	CONSTRAINT photo_group_public_share_right_groupID_fkey FOREIGN KEY (groupid)
		REFERENCES photo_group (groupid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_group_public_share_right_for_dsm_account
(
	groupid int8 NOT NULL,
	CONSTRAINT photo_group_public_share_right_for_dsm_account_pkey PRIMARY KEY (groupid)
);

CREATE TABLE photo_personal_collection
(
	id serial NOT NULL,
	userid int8 NOT NULL,
	name varchar(128) NOT NULL,
	is_shared bool NOT NULL,
	start_time date,
	end_time date,
	sharelink varchar(8),
	create_date timestamp DEFAULT current_timestamp,
	hidden bool NOT NULL,
	is_album bool NOT NULL DEFAULT false,
	is_advanced bool NOT NULL DEFAULT false,
	shareid int4,
	recursive bool NOT NULL DEFAULT false,
	CONSTRAINT photo_personal_collection_pkey PRIMARY KEY (id),
	CONSTRAINT photo_personal_collection_fkey FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE ON UPDATE RESTRICT ON DELETE CASCADE,
	CONSTRAINT photo_collection_shareid_fkey FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_for_dsm_account
(
	id serial NOT NULL,
	userid int8 NOT NULL,
	name varchar(128) NOT NULL,
	is_shared bool NOT NULL,
	start_time date,
	end_time date,
	sharelink varchar(8),
	create_date timestamp DEFAULT current_timestamp,
	hidden bool NOT NULL,
	is_album bool NOT NULL DEFAULT false,
	is_advanced bool NOT NULL DEFAULT false,
	shareid int4,
	recursive bool NOT NULL DEFAULT false,
	CONSTRAINT photo_personal_collection_for_dsm_pkey PRIMARY KEY (id),
	CONSTRAINT photo_collection_dsm_shareid_fkey FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_for_admin
(
	id serial NOT NULL,
	name varchar(128) NOT NULL,
	is_shared bool NOT NULL,
	start_time date,
	end_time date,
	sharelink varchar(8),
	create_date timestamp DEFAULT current_timestamp,
	hidden bool NOT NULL,
	is_album bool NOT NULL DEFAULT false,
	is_advanced bool NOT NULL DEFAULT false,
	shareid int4,
	recursive bool NOT NULL DEFAULT false,
	CONSTRAINT photo_personal_collection_for_admin_pkey PRIMARY KEY (id),
	CONSTRAINT photo_collection_admin_shareid_fkey FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE INDEX photo_personal_collection_sharelink_idx ON photo_personal_collection USING btree (sharelink);
CREATE INDEX photo_personal_collection_for_dsm_sharelink_idx ON photo_personal_collection_for_dsm_account USING btree (sharelink);
CREATE INDEX photo_personal_collection_for_admin_sharelink_idx ON photo_personal_collection_for_admin USING btree (sharelink);

CREATE TABLE photo_personal_collection_photo
(
	collectionid integer NOT NULL,
	photoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_photo_pkey PRIMARY KEY (collectionid, photoid),
	CONSTRAINT photo_personal_collection_photo_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_photo_photoID_fkey FOREIGN KEY (photoid)
		REFERENCES photo_image (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_photo_for_dsm_account
(
	collectionid integer NOT NULL,
	photoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_photo_for_dsm_pkey PRIMARY KEY (collectionid, photoid),
	CONSTRAINT photo_personal_collection_photo_for_dsm_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_photo_for_dsm_photoID_fkey FOREIGN KEY (photoid)
		REFERENCES photo_image (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_photo_for_admin
(
	collectionid integer NOT NULL,
	photoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_photo_for_admin_pkey PRIMARY KEY (collectionid, photoid),
	CONSTRAINT photo_personal_collection_photo_for_admin_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_photo_for_admin_photoID_fkey FOREIGN KEY (photoid)
		REFERENCES photo_image (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_video
(
	collectionid integer NOT NULL,
	videoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_video_pkey PRIMARY KEY (collectionid, videoid),
	CONSTRAINT photo_personal_collection_video_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_video_videoID_fkey FOREIGN KEY (videoid)
		REFERENCES video (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_video_for_dsm_account
(
	collectionid integer NOT NULL,
	videoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_video_for_dsm_pkey PRIMARY KEY (collectionid, videoid),
	CONSTRAINT photo_personal_collection_video_for_dsm_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_video_for_dsm_videoID_fkey FOREIGN KEY (videoid)
		REFERENCES video (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_video_for_admin
(
	collectionid integer NOT NULL,
	videoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_video_for_admin_pkey PRIMARY KEY (collectionid, videoid),
	CONSTRAINT photo_personal_collection_video_for_admin_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_video_for_admin_videoID_fkey FOREIGN KEY (videoid)
		REFERENCES video (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE watermark
(
	shareid int4 NOT NULL,
	path varchar(1024),
	opacity int2,
	gravity int2,
	size int2,
	hash varchar(8),
	mtime int8,
	changed bool DEFAULT true,
	CONSTRAINT watermark_shareid_fk FOREIGN KEY (shareid)
		REFERENCES photo_share (shareid) MATCH SIMPLE
		ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection
(
	collectionid integer NOT NULL,
	comment bool DEFAULT false,
	tag_area bool DEFAULT false,
	enable_password bool DEFAULT false,
	password varchar(128) DEFAULT '',
	color_label bool DEFAULT false,
	color_label_1 varchar(128),
	color_label_2 varchar(128),
	color_label_3 varchar(128),
	color_label_4 varchar(128),
	color_label_5 varchar(128),
	color_label_6 varchar(128),
	CONSTRAINT photo_advanced_personal_collection_pkey PRIMARY KEY (collectionid),
	CONSTRAINT photo_advanced_personal_collection_collectionID_fkey FOREIGN KEY (collectionid)
	        REFERENCES photo_personal_collection (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_for_admin
(
	collectionid integer NOT NULL,
	comment bool DEFAULT false,
	tag_area bool DEFAULT false,
	enable_password bool DEFAULT false,
	password varchar(128) DEFAULT '',
	color_label bool DEFAULT false,
	color_label_1 varchar(128),
	color_label_2 varchar(128),
	color_label_3 varchar(128),
	color_label_4 varchar(128),
	color_label_5 varchar(128),
	color_label_6 varchar(128),
	CONSTRAINT photo_advanced_personal_collection_for_admin_pkey PRIMARY KEY (collectionid),
	CONSTRAINT photo_advanced_personal_collection_for_admin_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_for_dsm_account
(
    collectionid integer NOT NULL,
	comment bool DEFAULT false,
	tag_area bool DEFAULT false,
	enable_password bool DEFAULT false,
	password varchar(128) DEFAULT '',
	color_label bool DEFAULT false,
	color_label_1 varchar(128),
	color_label_2 varchar(128),
	color_label_3 varchar(128),
	color_label_4 varchar(128),
	color_label_5 varchar(128),
	color_label_6 varchar(128),
	CONSTRAINT photo_advanced_collection_for_dsm_account_pkey PRIMARY KEY (collectionid),
	CONSTRAINT photo_advanced_collection_for_dsm_account_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_item
(
	id serial NOT NULL,
	collectionid integer NOT NULL,
	type varchar(8) NOT NULL,
	item_id integer NOT NULL,
	color_label int4 DEFAULT 0,
	CONSTRAINT photo_advanced_personal_collection_item_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_personal_collection_item_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_item_for_admin
(
	id serial NOT NULL,
	collectionid integer NOT NULL,
	type varchar(8) NOT NULL,
	item_id integer NOT NULL,
	color_label int4 DEFAULT 0,
	CONSTRAINT photo_advanced_personal_collection_item_for_admin_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_personal_collection_item_for_admin_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_item_for_dsm_account
(
	id serial NOT NULL,
    collectionid integer NOT NULL,
	type varchar(8) NOT NULL,
	item_id integer NOT NULL,
	color_label int4 DEFAULT 0,
	CONSTRAINT photo_advanced_collection_item_for_dsm_account_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_collection_item_for_dsm_account_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_comment
(
	id serial NOT NULL,
	advanced_item_id integer NOT NULL,
	name varchar(100),
	email varchar(128),
	comment text,
	date timestamp,
	CONSTRAINT photo_advanced_collection_comment_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_collection_comment_itemID_fkey FOREIGN KEY (advanced_item_id)
		REFERENCES photo_advanced_personal_collection_item (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_comment_for_admin
(
	id serial NOT NULL,
	advanced_item_id integer NOT NULL,
	name varchar(100),
	email varchar(128),
	comment text,
	date timestamp,
	CONSTRAINT photo_advanced_collection_comment_for_admin_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_collection_comment_for_admin_itemID_fkey FOREIGN KEY (advanced_item_id)
		REFERENCES photo_advanced_personal_collection_item_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_comment_for_dsm_account
(
	id serial NOT NULL,
    advanced_item_id integer NOT NULL,
	name varchar(100),
	email varchar(128),
	comment text,
	date timestamp,
	CONSTRAINT photo_advanced_collection_comment_for_dsm_account_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_collection_comment_for_dsm_account_itemID_fkey FOREIGN KEY (advanced_item_id)
		REFERENCES photo_advanced_personal_collection_item_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_tag_area
(
	id serial NOT NULL,
	advanced_item_id integer NOT NULL,
	position text DEFAULT '',
	info text,
	CONSTRAINT photo_advanced_personal_collection_tag_area_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_personal_collection_tag_area_itemID_fkey FOREIGN KEY (advanced_item_id)
	    REFERENCES photo_advanced_personal_collection_item (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_tag_area_for_admin
(
	id serial NOT NULL,
    advanced_item_id integer NOT NULL,
	position text DEFAULT '',
	info text,
	CONSTRAINT photo_advanced_collection_tag_area_for_admin_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_collection_tag_area_for_admin_itemID_fkey FOREIGN KEY (advanced_item_id)
		REFERENCES photo_advanced_personal_collection_item_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE

);

CREATE TABLE photo_advanced_personal_collection_tag_area_for_dsm_account
(
	id serial NOT NULL,
	advanced_item_id integer NOT NULL,
	position text DEFAULT '',
	info text,
	CONSTRAINT photo_advanced_collection_tag_area_for_dsm_account_pkey PRIMARY KEY (id),
	CONSTRAINT photo_advanced_collection_tag_area_for_dsm_account_itemID_fkey FOREIGN KEY (advanced_item_id)
		REFERENCES photo_advanced_personal_collection_item_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_advanced_personal_collection_log (
	id serial PRIMARY KEY,
	collectionid integer
		REFERENCES photo_personal_collection (id)
		ON UPDATE CASCADE ON DELETE CASCADE,
	advanced_item_id integer
		REFERENCES photo_advanced_personal_collection_item (id)
		ON UPDATE CASCADE ON DELETE CASCADE,
	log text NOT NULL default '',
	date timestamp,
	category int2 NOT NULL default 0
);

CREATE TABLE photo_advanced_personal_collection_log_for_admin
(
	id serial PRIMARY KEY,
	collectionid integer
		REFERENCES photo_personal_collection_for_admin (id)
		ON UPDATE CASCADE ON DELETE CASCADE,
	advanced_item_id integer
		REFERENCES photo_advanced_personal_collection_item_for_admin (id)
		ON UPDATE CASCADE ON DELETE CASCADE,
	log text NOT NULL default '',
	date timestamp,
	category int2 NOT NULL default 0
);

CREATE TABLE photo_advanced_personal_collection_log_for_dsm_account
(
	id serial PRIMARY KEY,
	collectionid integer
		REFERENCES photo_personal_collection_for_dsm_account (id)
		ON UPDATE CASCADE ON DELETE CASCADE,
	advanced_item_id integer
		REFERENCES photo_advanced_personal_collection_item_for_dsm_account(id)
		ON UPDATE CASCADE ON DELETE CASCADE,
	log text NOT NULL default '',
	date timestamp,
	category int2 NOT NULL default 0
);

COMMIT;
