BEGIN;

CREATE TABLE photo_public_share_right
(
	userid int8 NOT NULL,
	CONSTRAINT photo_public_share_right_pkey PRIMARY KEY (userid),
	CONSTRAINT photo_public_share_right_userID_fkey FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_public_share_right_for_dsm_account
(
	userid int8 NOT NULL,
	CONSTRAINT photo_public_share_right_for_dsm_account_pkey PRIMARY KEY (userid)
);

CREATE TABLE photo_group_public_share_right
(
	groupid int8 NOT NULL,
	CONSTRAINT photo_group_public_share_right_pkey PRIMARY KEY (groupid),
	CONSTRAINT photo_group_public_share_right_groupID_fkey FOREIGN KEY (groupid)
		REFERENCES photo_group (groupid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_group_public_share_right_for_dsm_account
(
	groupid int8 NOT NULL,
	CONSTRAINT photo_group_public_share_right_for_dsm_account_pkey PRIMARY KEY (groupid)
);

CREATE TABLE photo_personal_collection
(
	id serial NOT NULL,
	userid int8 NOT NULL,
	name varchar(128) NOT NULL,
	is_shared bool NOT NULL,
	start_time date,
	end_time date,
	sharelink varchar(8),
	create_date timestamp DEFAULT current_timestamp,
	CONSTRAINT photo_personal_collection_pkey PRIMARY KEY (id),
	CONSTRAINT photo_personal_collection_fkey FOREIGN KEY (userid)
		REFERENCES photo_user (userid) MATCH SIMPLE ON UPDATE RESTRICT ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_for_dsm_account
(
	id serial NOT NULL,
	userid int8 NOT NULL,
	name varchar(128) NOT NULL,
	is_shared bool NOT NULL,
	start_time date,
	end_time date,
	sharelink varchar(8),
	create_date timestamp DEFAULT current_timestamp,
	CONSTRAINT photo_personal_collection_for_dsm_pkey PRIMARY KEY (id)
);

CREATE TABLE photo_personal_collection_for_admin
(
	id serial NOT NULL,
	name varchar(128) NOT NULL,
	is_shared bool NOT NULL,
	start_time date,
	end_time date,
	sharelink varchar(8),
	create_date timestamp DEFAULT current_timestamp,
	CONSTRAINT photo_personal_collection_for_admin_pkey PRIMARY KEY (id)
);

CREATE INDEX photo_personal_collection_sharelink_idx ON photo_personal_collection USING btree (sharelink);
CREATE INDEX photo_personal_collection_for_dsm_sharelink_idx ON photo_personal_collection_for_dsm_account USING btree (sharelink);
CREATE INDEX photo_personal_collection_for_admin_sharelink_idx ON photo_personal_collection_for_admin USING btree (sharelink);

CREATE TABLE photo_personal_collection_photo
(
	collectionid integer NOT NULL,
	photoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_photo_pkey PRIMARY KEY (collectionid, photoid),
	CONSTRAINT photo_personal_collection_photo_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_photo_photoID_fkey FOREIGN KEY (photoid)
		REFERENCES photo_image (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_photo_for_dsm_account
(
	collectionid integer NOT NULL,
	photoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_photo_for_dsm_pkey PRIMARY KEY (collectionid, photoid),
	CONSTRAINT photo_personal_collection_photo_for_dsm_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_photo_for_dsm_photoID_fkey FOREIGN KEY (photoid)
		REFERENCES photo_image (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_photo_for_admin
(
	collectionid integer NOT NULL,
	photoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_photo_for_admin_pkey PRIMARY KEY (collectionid, photoid),
	CONSTRAINT photo_personal_collection_photo_for_admin_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_photo_for_admin_photoID_fkey FOREIGN KEY (photoid)
		REFERENCES photo_image (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_video
(
	collectionid integer NOT NULL,
	videoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_video_pkey PRIMARY KEY (collectionid, videoid),
	CONSTRAINT photo_personal_collection_video_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_video_videoID_fkey FOREIGN KEY (videoid)
		REFERENCES video (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_video_for_dsm_account
(
	collectionid integer NOT NULL,
	videoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_video_for_dsm_pkey PRIMARY KEY (collectionid, videoid),
	CONSTRAINT photo_personal_collection_video_for_dsm_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_dsm_account (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_video_for_dsm_videoID_fkey FOREIGN KEY (videoid)
		REFERENCES video (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE TABLE photo_personal_collection_video_for_admin
(
	collectionid integer NOT NULL,
	videoid integer NOT NULL,
	CONSTRAINT photo_personal_collection_video_for_admin_pkey PRIMARY KEY (collectionid, videoid),
	CONSTRAINT photo_personal_collection_video_for_admin_collectionID_fkey FOREIGN KEY (collectionid)
		REFERENCES photo_personal_collection_for_admin (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT photo_personal_collection_video_for_admin_videoID_fkey FOREIGN KEY (videoid)
		REFERENCES video (id) MATCH SIMPLE ON UPDATE CASCADE ON DELETE CASCADE
);

COMMIT;
