<?php


define('ARGV_PARAM_KEY', 'param');
define('OLD_SMART_ALBUM_CONFIG', "smart_album.json");
define('SMART_ALBUM_CONFIG', "SYNOPHOTO_SMART_ALBUM_CONFIG");

/* get command line params */
$params = getParams();

define('PACKAGE_PATH', $params['package_path']);

/* include php files */
require_once(PACKAGE_PATH . '/target/photo_scripts/misc.php');

require_PHPFiles();

/* list dsm users */
$dsmUserList = getDSMUserList();
$usernameList = array_merge(array(''), $dsmUserList);

/* specify user for debug usage */
if (isset($params['user'])) {
	$name = $params['user'];
	if ($name === 'root') {
		$name = '';
	}
	$usernameList = array($name);
	syslog(LOG_ERR, "upgrade db data for specific user: $name");
}

/* name spaces for php files */
$namespaces = array(
	'merge_ms_people_tag',
	'merge_geo_tag',
	'migrate_recently_to_smart',
	'set_root_album_order',
	'update_photo_share',
	'update_gps',
	'update_watermark_path'
);

/* check "run" function in every single namespace */
foreach ($namespaces as $ns) {
	$runFunc = "$ns\\run";
	if (!function_exists($runFunc)) {
		syslog(LOG_ERR, "no such function: $runFunc");
		exit(1);
	}
}

foreach ($usernameList as $username) {
	//get global variables
	$needReIndex = false;
	$user = $username;
	if (false === ($userHome = getUserHomePath())) {
		exit(1);
	}
	$photoSharedFolder = getPhotoSharedFolderPath();
	if (false === ($dbh = getDatabaseHandler())) {
		//no database, skip
		if (!isPPS()) {
			syslog(LOG_ERR, "unable to access PostgreSQL database of PhotoStation.");
		}
		continue;
	}
	$escapeStr = getEscapeString();

	add_prefix_to_config_file($photoSharedFolder);

	foreach ($namespaces as $ns) {
		$runFunc = "$ns\\run";
		$runFunc();
	}

	// ignore '-P PhotoStation' because the files've been modified
	if ($needReIndex) {
		//@exec("/usr/syno/bin/synoindex -R " . escapeshellarg($photoSharedFolder));
		csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synoindex', array('-R', $photoSharedFolder));
		syslog(LOG_ERR, "PhotoStation: Re-index triggered [synoindex -R $photoSharedFolder]");
	}
}

function add_prefix_to_config_file($photo_share_folder)
{
	if (file_exists("$photo_share_folder/@eaDir/".OLD_SMART_ALBUM_CONFIG)) {
		//@exec(sprintf("mv %s %s", escapeshellarg("$photo_share_folder/@eaDir/".OLD_SMART_ALBUM_CONFIG), escapeshellarg("$photo_share_folder/@eaDir/".SMART_ALBUM_CONFIG)));
		csSYNOPhotoMisc::ExecCmd('/bin/mv', array(
			"$photo_share_folder/@eaDir/" . OLD_SMART_ALBUM_CONFIG,
			"$photo_share_folder/@eaDir/" . SMART_ALBUM_CONFIG));
	}
}

function getParams()
{
	$opts = getopt("", array(ARGV_PARAM_KEY . ":"));

	if (!isset($opts[ARGV_PARAM_KEY])) {
		return array();
	}

	$tempParams = $opts[ARGV_PARAM_KEY];
	if (!is_array($tempParams)) {
		$tempParams = array($tempParams);
	}

	$params = array();
	foreach ($tempParams as $param) {
		$explodedParam = explode("=", $param);
		if (2 !== count($explodedParam) || '' === $explodedParam[0]) {
			continue;
		}

		$params[$explodedParam[0]] = $explodedParam[1];
	}

	return $params;
}

function require_PHPFiles()
{
	foreach (glob(PACKAGE_PATH . "/target/photo_scripts/upgrade_db_data/*.php") as $phpFile) {
		require_once($phpFile);
	}
}

function setMergedKeyToDB($key)
{
	global $dbh;

	$sqlCond = "SELECT * FROM photo_config WHERE module_name = 'photo' AND config_key = ?";
	$sqlParam = array($key);

	$dbResult = $dbh->prepare($sqlCond);
	$dbResult->execute($sqlParam);

	if (false !== ($row = $dbResult->fetch())) {
		$sqlCond = "UPDATE photo_config SET config_value = 'on' WHERE config_id = ?";
		$sqlParam = array($row['config_id']);
	} else {
		$sqlCond = "INSERT INTO photo_config (module_name, config_key, config_value) VALUES ('photo', ?, 'on')";
		$sqlParam = array($key);
	}

	$dbResult = $dbh->prepare($sqlCond);
	$dbResult->execute($sqlParam);
}

function isSetMergedKeyInDB($key)
{
	global $dbh;

	$sqlCond = "SELECT * FROM photo_config WHERE module_name = 'photo' AND config_key = ?";
	$sqlParam = array($key);

	$dbResult = $dbh->prepare($sqlCond);
	$dbResult->execute($sqlParam);

	$ret = false;
	if (false !== ($row = $dbResult->fetch())) {
		if ('on' === $row['config_value']) {
			$ret = true;
		}
	}

	return $ret;
}

function readSmartAlbumFile()
{
	global $user;

	if (isPPS()) {
		if (false === ($userHome = getUserHomePath())) {
			syslog(LOG_ERR, "Couldn't user home path.");
			return null;
		} else {
			$smartAlbumFile = $userHome . "/photo/@eaDir/SYNOPHOTO_SMART_ALBUM_CONFIG";
		}
	} else {
		$smartAlbumFile = "/var/services/photo/@eaDir/SYNOPHOTO_SMART_ALBUM_CONFIG";
	}

	//test whether smart album file config exist or not
	if (!@file_exists($smartAlbumFile)) {
		return null;
	}

	//get contents from smart album config file
	if (!$smartAlbumJsonStr = @file_get_contents($smartAlbumFile)) {
		return null;
	}

	//parse contents
	if (!$smartAlbumList = json_decode($smartAlbumJsonStr, true)) {
		return null;
	}

	return $smartAlbumList;
}

function writeSmartAlbumFile($smartAlbumList)
{
	global $user;

	if (isPPS()) {
		if (false === ($userHome = getUserHomePath())) {
			syslog(LOG_ERR, "Couldn't user home path.");
			return false;
		} else {
			$smartAlbumFile = $userHome . "/photo/@eaDir/SYNOPHOTO_SMART_ALBUM_CONFIG";
		}
	} else {
		$smartAlbumFile = "/var/services/photo/@eaDir/SYNOPHOTO_SMART_ALBUM_CONFIG";
	}

	//encode smart album list to json string
	if (!$smartAlbumListJsonStr = json_encode($smartAlbumList)) {
		return;
	}

	//beautify json string
	$smartAlbumListJsonStr = indentJson($smartAlbumListJsonStr);

	//create @eaDir
	if(!@file_exists($eaDir)) {
		@mkdir($eaDir);
	}

	//put contents to smart album config file
	if (!@file_put_contents($smartAlbumFile, $smartAlbumListJsonStr)) {
		return false;
	}

	chmod($smartAlbumFile, 0666);
}
