<?php

/**
 * copy geo tags to general tag, and merge geo tags to new location tag
 */

namespace merge_geo_tag;

const SYNO_PHOTO_MERGED_KEY = 'geo_tag_merged',
	SYNO_EXIFTOOL_FILE = '/usr/bin/exiv2';

function run()
{
	global $params;

	if ('yes' === $params[SYNO_PHOTO_MERGED_KEY]) {
		//key "geo_tag_merged" in setting.conf is set
		setMergedKeyToDB(SYNO_PHOTO_MERGED_KEY);
		return;
	}

	if (isSetMergedKeyInDB(SYNO_PHOTO_MERGED_KEY)) {
		//key "geo_tag_merged" in database is set
		return;
	}

	//fetch original geo tag list
	$photoTagList = getAllPhotoGeoTagFromDB();
	$videoTagList = getAllVideoGeoTagFromDB();

	//change geo tag to genaral tag
	$geoTagList = getAllGeoTagFromDB();
	convertGeotagToDescTag($geoTagList);

	//merge geo tag for one photo/video
	mergeOriginalGeotag($photoTagList, $videoTagList);
	upgradeSmartAlbumCondition($geoTagList);

	setMergedKeyToDB(SYNO_PHOTO_MERGED_KEY);
}

function upgradeSmartAlbumCondition($geoTagList) {
	$smartAlbumList = readSmartAlbumFile();
	if (!$smartAlbumList) {
		return;
	}

	foreach($smartAlbumList['smart_albums'] as $smartName => $smartAlbum) {
		$geoRule = array();
		$descRule = array();
		$newRules = array();
		$idx = 0;
		foreach($smartAlbum['rule_sets'][0] as $rule) {
			if ('geo' == $rule['field']) {
				$geoRule = $rule;
			} else if ('desc' == $rule['field']) {
				$descRule = $rule;
			} else {
				$newRules[] = $rule;
			}
			$idx ++;
		}
		if (empty($geoRule)) {
			continue;
		}
		$newDescRule = combineGeoDescRule($geoRule, $descRule, $geoTagList);
		$newRules[] = $newDescRule;
		$smartAlbumList['smart_albums'][$smartName]['rule_sets'][0] = $newRules;
	}
	writeSmartAlbumFile($smartAlbumList);
}

function combineGeoDescRule($geoRule, $descRule, $geoTagList)
{
	$geoTagIdList = explode(',', $geoRule['value']);
	if (empty($descRule)) {
		$descRule['field'] = 'desc';
		$descRule['operator'] = $geoRule['operator'];
		$descRule['value'] = '';
		$descTagIdList = array();
	} else {
		$descTagIdList = explode(',', $descRule['value']);
	}

	foreach($geoTagIdList as $tagId) {
		if (false !== ($descId = findDescTagId($tagId, $geoTagList))) {
			$descTagIdList[] = $descId;
		}
	}

	$descRule['value'] = implode(',', array_unique($descTagIdList));
	return $descRule;
}

function findDescTagId($tagId, $geoTagList)
{
	$tagName = '';

	foreach($geoTagList as $tag) {
		if ($tagId == $tag['id']) {
			$tagName = $tag['name'];
			break;
		}
	}
	if (!empty($tagName) && false !== ($row = selectTag($tagName, 2))) {
		return $row['id'];
	}
	return false;
}

function convertGeotagToDescTag($geoTagList) {
	foreach($geoTagList as $geoTag) {
		if (false !== ($descTag = selectTag($geoTag['name'], 2))) {
			//deac is already exist, change geotag id to desctag id
			changePhotoTagId($geoTag['id'], $descTag['id']);
			//delete geotag
			deleteTag($geoTag['id']);
		} else {
			//change geo tag type
			changeGeoTagTypeToDesc($geoTag['id']);
		}
	}
}

function getAllGeoTagFromDB()
{
	global $dbh;
	$tagList = array();
	$sqlParam = array();

	$sql = 'SELECT * FROM photo_label WHERE category = 1';
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);

	$tagList = $dbResult->fetchAll(\PDO::FETCH_ASSOC);

	return $tagList;
}

function getAllPhotoGeoTagFromDB() {
	global $dbh;
	$photoList = array();
	$sqlParam = array();

	$sql = "SELECT image_id, label_id, photo_label.name FROM photo_image_label INNER JOIN photo_label ON label_id=photo_label.id WHERE category = 1";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);

	$photoList = $dbResult->fetchAll(\PDO::FETCH_ASSOC | \PDO::FETCH_GROUP);
	return $photoList;
}

function getAllVideoGeoTagFromDB() {
	global $dbh;
	$videoList = array();
	$sqlParam = array();

	$sql = "SELECT video_path, label_id, photo_label.name FROM photo_video_label INNER JOIN photo_label ON label_id=photo_label.id WHERE category = 1";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);

	$videoList = $dbResult->fetchAll(\PDO::FETCH_ASSOC | \PDO::FETCH_GROUP);
	return $videoList;
}

function mergeOriginalGeotag($photoTagList, $videoTagList)
{
	global $dbh;

	foreach($photoTagList as $photoId => $tagArr) {
		$tagNameArr = array();
		foreach($tagArr as $tag) {
			$tagNameArr[] = $tag['name'];
		}
		saveAsNewGeotag($photoId, implode(', ', $tagNameArr), true);
		updateMetaData($photoId);
	}

	foreach($videoTagList as $videoPath => $tagArr) {
		$tagNameArr = array();
		foreach($tagArr as $tag) {
			$tagNameArr[] = $tag['name'];
		}
		saveAsNewGeotag($videoPath, implode(', ', $tagNameArr), false);
	}
}

function saveAsNewGeotag($photoId, $tagName, $isPhoto)
{
	$sqlParam = array();
	$id = -1;
	if (false !== ($row = selectTag($tagName, 1))) {
		$id = $row['id'];
	} else {
		if (false === ($id = addNewTag($tagName))) {
			return;
		}
	}
	if ($isPhoto) {
		addPhotoTag($photoId, $id);
	} else {
		addVideoTag($photoId, $id);
	}
}

function updateMetaData($photoId)
{
	global $userHome, $dbh;

	//1. query file path from DB
	$query = 'SELECT path FROM photo_image WHERE id = ?';
	$sqlParam = array($photoId);
	$dbResult = $dbh->prepare($query);
	$dbResult->execute($sqlParam);
	if (false === ($row = $dbResult->fetch())) {
		return false;
	}
	if (isPPS()) {
		$path = "$userHome/photo/{$row['path']}";
	} else {
		$path = $row['path'];
	}

	if (false === IsExiv2SupportWriteMode($path)) {
		return false;
	}

	//2. remove existed metadata
	//$cmd = sprintf('%s -M "del %s" %s', SYNO_EXIFTOOL_FILE, "Iptc.Application2.Keywords", escapeshellarg($path));
	//@exec($cmd);
	csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
		'-M', 'del Iptc.Application2.Keywords',
		$path));
	//$cmd = sprintf('%s -M "del %s" %s', SYNO_EXIFTOOL_FILE, "Xmp.dc.subject", escapeshellarg($path));
	//@exec($cmd);
	csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
		'-M', 'del Xmp.dc.subject',
		$path));

	//3. query new metadata value from DB
	$query = 'SELECT A.id, B.name FROM photo_image_label A, photo_label B '.
		'WHERE A.image_id = ? AND B.id = A.label_id AND B.category = ? ';
	$sqlParam = array($photoId, 2);
	$dbResult = $dbh->prepare($query);
	$dbResult->execute($sqlParam);
	if (false === $dbResult) {
		return false;
	}

	//4. write metadata to file
	$count = 1;
	while ($row = $dbResult->fetch()) {
		//$cmd = sprintf('%s -M "add %s %s" %s', SYNO_EXIFTOOL_FILE,
		//			   "Iptc.Application2.Keywords String", str_replace('"', '\"', $row['name']), escapeshellarg($path));
		//@exec($cmd);
		csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
			'-M', 'add Iptc.Application2.Keywords String ' . $row['name'],
			$path));
		if (1 === $count) {
			csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
				'-M', "set Iptc.Envelope.CharacterSet String \x1B%G",
				$path));
			//$cmd = sprintf('%s -M "set %s %s" %s', SYNO_EXIFTOOL_FILE, "Xmp.dc.subject", "''", escapeshellarg($path));
			//@exec($cmd);
			csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
				'-M', "set Xmp.dc.subject ''",
				$path));
		}
		//$cmd = sprintf('%s -M "set %s[%d] %s" %s', SYNO_EXIFTOOL_FILE,
		//			   "Xmp.dc.subject", $count++, str_replace('"', '\"', $row['name']), escapeshellarg($path));
		//@exec($cmd);
		csSYNOPhotoMisc::ExecCmd(SYNO_EXIFTOOL_FILE, array(
			'-M', 'set Xmp.dc.subject[' . $count . '] ' . $row['name'],
			$path));
		++$count;
	}

	//update mtime of all thumbnails for prevent from re-making thumbnail
	//$cmd = sprintf('/usr/syno/bin/synophoto_dsm_user --updatethumbnailmtime %s', escapeshellarg($path));
	//@exec($cmd);
	csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_dsm_user', array('--updatethumbnailmtime', $path));
}

function addNewTag($tagName) {
	global $dbh;

	$sqlParam = array();

	if (isPPS()) {
		//personal tag id will not auto increase, get max id first
		$id = getTagMaxId() + 1;
		$sqlParam[] = $id;
		$sql = "INSERT INTO photo_label (id, name, category) VALUES (?, ?, ?)";
	} else {
		$sql = "INSERT INTO photo_label (name, category) VALUES (?, ?)";
	}

	$sqlParam[] = $tagName;
	$sqlParam[] = 1;
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);

	if (false !== ($row = selectTag($tagName, 1))) {
		return $row[id];
	}
	return false;
}

function getTagMaxId() {
	global $dbh;

	$sqlParam = array();
	$sql = "SELECT MAX(id) FROM photo_label;";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);

	if (false !== ($row = $dbResult->fetch())) {
		return $row[0];
	}
	return 0;
}

function addPhotoTag($photoId, $tagId) {
	global $dbh;

	$sqlParam = array();
	$sqlParam[] = $photoId;
	$sqlParam[] = $tagId;

	$sql = "INSERT INTO photo_image_label (image_id, label_id, info) VALUES (?, ?, '')";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);
}

function addVideoTag($videoPath, $tagId) {
	global $dbh;

	$sqlParam = array();
	$sqlParam[] = $videoPath;
	$sqlParam[] = $tagId;

	$sql = "INSERT INTO photo_video_label (video_path, label_id, info) VALUES (?, ?, '')";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);
}

function selectTag($name, $type) {
	global $dbh;

	$sqlParam = array();
	//test tag exist
	$sql = "SELECT * FROM photo_label WHERE name=? AND category=?";
	$sqlParam[] = $name;
	$sqlParam[] = $type;

	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);
	if (false !== ($row = $dbResult->fetch(\PDO::FETCH_ASSOC))) {
		return $row;
	}
	return false;
}

function deleteTag($tagId) {
	global $dbh;

	$sqlParam = array();
	$sqlParam[] = $tagId;

	$sql = "DELETE FROM photo_label WHERE id=?";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);
}

function changeGeoTagTypeToDesc($tagId) {
	global $dbh;

	$sqlParam = array();
	$sqlParam[] = $tagId;

	$sql = "UPDATE photo_label SET category=2, info='' WHERE id=?";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);
}

function changePhotoTagId($geoTagId, $descTagId) {
	global $dbh;

	$sqlParam = array();
	$sqlParam[] = $descTagId;
	$sqlParam[] = $geoTagId;
	$sqlParam[] = $descTagId;

	$sql = "UPDATE photo_image_label SET label_id=? WHERE label_id=? AND image_id NOT IN (SELECT image_id FROM photo_image_label WHERE label_id=?)";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);

	$sql = "UPDATE photo_video_label SET label_id=? WHERE label_id=? AND video_path NOT IN (SELECT video_path FROM photo_video_label where label_id=?)";
	$dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);
}

function IsExiv2SupportWriteMode($path)
{
	$SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT = array(
		"jpg", "jpeg", "jpe", "png", "tiff", "tif",
		"cr2", "nef", "pef", "orf", "dng");

	$ext = strtolower(pathinfo($filePath, PATHINFO_EXTENSION));
	if (!in_array($ext, $SYNOPHOTO_ALLOW_EXIV2_WRITE_EXT)) {
		return false;
	}
	return true;
}
?>
