<?php

/**
 * migrate recently add/comment album (old virtual albums) to smart album
 */

namespace migrate_recently_to_smart;

const SYNO_PHOTO_MERGED_KEY = 'migrate_recently_add_comment';

function run()
{
	global $params;

	if ('yes' === $params[SYNO_PHOTO_MERGED_KEY]) {
		//key "migrate_recently_add_comment" in setting.conf is set
		setMergedKeyToDB(SYNO_PHOTO_MERGED_KEY);
		return;
	}

	if (isSetMergedKeyInDB(SYNO_PHOTO_MERGED_KEY)) {
		//key "migrate_recently_add_comment" in database is set
		return;
	}

    $result = getRecentlyConfig();
	migrateToSmartAlbum($result);

	setMergedKeyToDB(SYNO_PHOTO_MERGED_KEY);
}

function getString($string)
{
    // get DSM language
    $lang = getDSMLang();
    if (empty($lang)) {
        return $string;
    }
    if ('def' === $lang) {
        $lang = 'enu';
    }
    $langFile = PACKAGE_PATH . "/target/photo/language/$lang.php";
    include($langFile);
    $pattern = preg_replace('/[^0-9a-z]/i','_', $string);
    if (!isset($$pattern)) {
        return $string;
    }
    return $$pattern;
}

function getName($smartAlbumList, $string)
{
	$targetName = getString($string);
	$newName = $targetName;
	$suffix = 0;

	while (isset($smartAlbumList['smart_albums'][$newName])) {
		$newName = $targetName.'_'.(++$suffix);
	}

	return $newName;
}

function migrateToSmartAlbum($data)
{
    if ('on' !== $data['recent_photo'] && 'on' !== $data['recent_video'] && 'on' !== $data['recent_commented_photo'] && 'on' !== $data['recent_commented_video']) {
        return;
    }

    $smartAlbumList = readSmartAlbumFile();
    if ('on' === $data['recent_photo']) {
        unset($smart);
        $smart['desc'] = '';
        $smart['show_photo'] = true;
        $smart['show_video'] = false;
        $rule_set['field'] = 'date';
        $rule_set['operator'] = 'recently_add';
        $rule_set['value'] = $data['recent_photo_num'];
        $smart['rule_sets'][0] = array();
        array_push($smart['rule_sets'][0], $rule_set);
        $smartAlbumList['smart_albums'][getName($smartAlbumList, 'photo_str_recent_photo')] = $smart;
    }
    if ('on' === $data['recent_video']) {
        unset($smart);
        $smart['desc'] = '';
        $smart['show_photo'] = false;
        $smart['show_video'] = true;
        $rule_set['field'] = 'date';
        $rule_set['operator'] = 'recently_add';
        $rule_set['value'] = $data['recent_video_num'];
        $smart['rule_sets'][0] = array();
        array_push($smart['rule_sets'][0], $rule_set);
        $smartAlbumList['smart_albums'][getName($smartAlbumList, 'photo_str_recent_video')] = $smart;
    }
    if ('on' === $data['recent_commented_photo']) {
        unset($smart);
        $smart['desc'] = '';
        $smart['show_photo'] = true;
        $smart['show_video'] = false;
        $rule_set['field'] = 'date';
        $rule_set['operator'] = 'recently_comment';
        $rule_set['value'] = $data['recent_commented_photo_num'];
        $smart['rule_sets'][0] = array();
        array_push($smart['rule_sets'][0], $rule_set);
        $smartAlbumList['smart_albums'][getName($smartAlbumList, 'photo_str_recent_commented_photo')] = $smart;
    }
    if ('on' === $data['recent_commented_video']) {
        unset($smart);
        $smart['desc'] = '';
        $smart['show_photo'] = false;
        $smart['show_video'] = true;
        $rule_set['field'] = 'date';
        $rule_set['operator'] = 'recently_comment';
        $rule_set['value'] = $data['recent_commented_video_num'];
        $smart['rule_sets'][0] = array();
        array_push($smart['rule_sets'][0], $rule_set);
        $smartAlbumList['smart_albums'][getName($smartAlbumList, 'photo_str_recent_commented_video')] = $smart;
    }
    writeSmartAlbumFile($smartAlbumList);
}

function getRecentlyConfig()
{
    global $dbh;

    $sqlParam = array();

    $sql = "select config_key, config_value from photo_config where module_name=?";
    $sqlParam[] = 'photo';
    $dbResult = $dbh->prepare($sql);
	$dbResult->execute($sqlParam);

    $photoConfig = $dbResult->fetchAll(\PDO::FETCH_ASSOC);
    foreach ($photoConfig as $row) {
        if ('recent_photo' === $row['config_key']) {
            $result['recent_photo'] = $row['config_value'];
        }
        if ('recent_video' === $row['config_key']) {
            $result['recent_video'] = $row['config_value'];
        }
        if ('recent_photo_num' === $row['config_key']) {
            $result['recent_photo_num'] = $row['config_value'];
        }
        if ('recent_video_num' === $row['config_key']) {
            $result['recent_video_num'] = $row['config_value'];
        }
        if ('recent_commented_photo' === $row['config_key']) {
            $result['recent_commented_photo'] = $row['config_value'];
        }
        if ('recent_commented_video' === $row['config_key']) {
            $result['recent_commented_video'] = $row['config_value'];
        }
        if ('recent_commented_photo_num' === $row['config_key']) {
            $result['recent_commented_photo_num'] = $row['config_value'];
        }
        if ('recent_commented_video_num' === $row['config_key']) {
            $result['recent_commented_video_num'] = $row['config_value'];
        }
    }
    return $result;
}

function getDSMLang()
{
    //@exec("/usr/syno/bin/synophoto_config --dsm --get language", $dsmLang);
    $dsmLang = '';
    csSYNOPhotoMisc::ExecCmd('/usr/syno/bin/synophoto_config', array('--dsm', '--get', 'language'), false, $dsmLang);
    return $dsmLang[0];
}

?>
