<?php

/**
 * update ref_shareid(photo_share) and shareid&privilege_shareid(photo_image,video) for faster accessing
 */

namespace update_photo_share;

function run()
{
	global $photoSharedFolder, $dbh;

	if (isPPS()) {
		$real_dir = "";
	} else {
		$real_dir = @readlink($photoSharedFolder) . '/';
	}

	updatePhotoShare($real_dir);
	updateTables("photo", $real_dir);
	updateTables("video", $real_dir);
}

function updatePhotoShare($real_dir)
{
	global $dbh;

	$sql = "SELECT * FROM photo_share WHERE ref_shareid = 0";
	$share_dbh = $dbh->prepare($sql);
	if (!$share_dbh) {
		return;
	}
	$shareid_dbh = $dbh->prepare("SELECT shareid, sharename FROM photo_share WHERE sharename = ?");
	$update_dbh = $dbh->prepare("UPDATE photo_share SET ref_shareid = ? WHERE shareid = ?");

	$hash = array();
	$share_dbh->execute();
	while($row = $share_dbh->fetch()) {
		$privilege_sharename = getRefSharename($row['sharename']);
		if ($row['sharename'] == $privilege_sharename) {
			$privilege_shareid = $hash[$privilege_sharename] = $row['shareid'];
		} else if (!array_key_exists($privilege_sharename, $hash)) {
				$shareid_dbh->execute(array($privilege_sharename));
				$temp = $shareid_dbh->fetch();
				if (!$temp) {
					continue;
				}
				$privilege_shareid = $hash[$privilege_sharename] = $temp['shareid'];
		} else {
			$privilege_shareid = $hash[$privilege_sharename];
		}
		$update_dbh->execute(array($privilege_shareid, $row['shareid']));
	}
}

function updateTables($type = "photo", $real_dir)
{
	global $dbh;

	$table = "photo" == $type ? "photo_image" : "video";

	$row = selectrow("SELECT count(*) FROM $table WHERE shareid = 0 or privilege_shareid = 0");

	$item_count = $row[0];
	if ($item_count == 0) {
		return;
	}

	$row = selectrow("SELECT count(*) FROM photo_share");
	$share_count = $row[0];

	if ($share_count > $item_count) {
		updateByItem($type, $real_dir);
	} else {
		updateByShare($type, $real_dir);
	}
}

function updateByShare ($type)
{
	global $user, $dbh, $escapeStr;

	$table = "photo" == $type ? "photo_image" : "video";
	$key = "photo" == $type ? "id" : "path";

	$sql = "SELECT shareid, sharename FROM photo_share ";
	$share_dbh = $dbh->prepare($sql);
	$share_dbh->execute();

	$updateSql = "UPDATE $table SET shareid = ?, privilege_shareid = ? WHERE path LIKE ? $escapeStr AND path NOT LIKE ? $escapeStr";
	$update_dbh = $dbh->prepare($updateSql);

	$shareid_dbh = $dbh->prepare("SELECT shareid, sharename FROM photo_share WHERE sharename = ?");

	if (!$update_dbh || !$share_dbh || !$shareid_dbh) {
		syslog(LOG_ERR, "update_photo_share: $user get statement handler failed. ".implode(';', $dbh->errorInfo()));
		return;
	}
	$hash = array();

	while($row = $share_dbh->fetch()) {
		$privilege_sharename = getPrivilegeSharename($row['sharename']);
		if ('/' == $row['sharename']) {
			$db_path = $real_dir;
		} else {
			$db_path = $real_dir . $row['sharename'] . "/";
		}
		if ($row['sharename'] == $privilege_sharename) {
			$hash[$privilege_sharename] = $row['shareid'];

			$param = array($row['shareid'], $row['shareid'], EscapeForLike($db_path)."%", EscapeForLike($db_path)."%/%");
			$res = $update_dbh->execute($param);
			if (!$res) {
				syslog(LOG_ERR, "update_photo_share: $updateSql ".implode(',',$param)." ". implode(';', $update_db->errorInfo()));
			}
		} else {
			if (array_key_exists($privilege_sharename, $hash)) {
				$privilege_shareid = $hash[$privilege_sharename];
			} else {
				$res = $shareid_dbh->execute(array($privilege_sharename));
				if (!$res){
					continue;
				}
				$item = $shareid_dbh->fetch();
				if (!$item) {
					continue;
				}
				$privilege_shareid = $hash[$item['sharename']] = $item['shareid'];
			}

			$param = array($row['shareid'], $privilege_shareid, EscapeForLike($db_path)."%", EscapeForLike($db_path)."%/%");
			$update_dbh->execute($param);
		}
	}
}

function updateByItem($type, $real_dir)
{
	global $user, $dbh;
	$table = "photo" == $type ? "photo_image" : "video";
	$key = "photo" == $type ? "id" : "path";

	// shareid default is 0
	$sqlCond = "SELECT $key, path FROM $table WHERE shareid = 0 or privilege_shareid = 0";
	$item_dbh = $dbh->prepare($sqlCond);
	$item_dbh->execute();

	$sql = "SELECT shareid FROM photo_share WHERE sharename = ?";
	$share_dbh = $dbh->prepare($sql);

	$updateSql = "UPDATE $table SET shareid =?, privilege_shareid=? WHERE $key = ?";
	$update_db = $dbh->prepare($updateSql);
	if (!$item_dbh || !$share_dbh || !$update_db) {
		syslog(LOG_ERR, "update_photo_share.php: $user get statement handler failed. ".implode(';', $dbh->errorInfo()));
		return;
	}

	$hash = array();
	while($row = $item_dbh->fetch()) {
		$sharename = getSharename($row['path'], $real_dir);
		$privilege_sharename = getPrivilegeSharename($sharename);

		if (array_key_exists($sharename, $hash)) {
			$shareid = $hash[$sharename];
		} else {
			$res = $share_dbh->execute(array($sharename));
			if (!$res) {
				continue;
			}
			$share = $share_dbh->fetch();
			$hash[$sharename] = $shareid = $share['shareid'];
		}

		if (array_key_exists($privilege_sharename, $hash)) {
			$privilege_shareid = $hash[$privilege_sharename];
		} else {
			$res = $share_dbh->execute(array($privilege_sharename));

			if (!$res) {
				continue;
			}

			$privilege_share = $share_dbh->fetch();
			if (!$privilege_share) {
				continue;
			}
			$hash[$privilege_sharename] = $privilege_shareid = $privilege_share['shareid'];
		}

		$res = $update_db->execute(array($shareid, $privilege_shareid, $row[$key]));
		if (!$res) {
			syslog(LOG_ERR, "update_photo_share.php: $user update shareid, ref_shareid in $table failed. ".implode(';', $update_db->errorInfo()));
		}
	}
}
function getRefSharename($sharename)
{
	$pathes = explode('/', $sharename);
	$level = count($pathes);

	if ($level > 2) {
		$res = $pathes[0].'/'.$pathes[1];
	} else if ($level == 2 && $sharename != '/') {
		$res = $pathes[0];
	} else {
		$res = $sharename;
	}

	return $res;
}

function getSharename($path, $realDirPath)
{
	$dirname = pathinfo($path, PATHINFO_DIRNAME);
	$sharename = substr($dirname, strlen($realDirPath));

	if ($sharename == '' || $sharename == '.') {
		$sharename = '/';
	}
	return $sharename;
}

function getPrivilegeSharename($sharename)
{
	$pathes = explode('/', $sharename);
	$level = count($pathes);

	if ($level > 2) {
		$res = $pathes[0].'/'.$pathes[1];
	} else {
		$res = $sharename;
	}

	return $res;
}

function selectrow($sql, $param=array())
{
	global $dbh;
	$dbResult = $dbh->prepare($sql);
	$res = $dbResult->execute();
	if (!$res) {
		syslog(LOG_ERR, "update_photo_share:$sql(".implode(',',$param).") Failed"
			. implode(';', $dbh->errorInfo()));
		return false;
	}
	$row = $dbResult->fetch();
	return $row;
}

function EscapeForLike($val){
	$val = str_replace('\\', '\\\\', $val);
	$val = str_replace('_', '\\_', $val);
	$val = str_replace('%', '\\%', $val);
	return $val;
}

?>
